/* Automatically generated by tree-sitter v0.25.3 (2a835ee029dca1c325e6f1c01dbce40396f6123e) */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 619
#define LARGE_STATE_COUNT 65
#define SYMBOL_COUNT 169
#define ALIAS_COUNT 1
#define TOKEN_COUNT 122
#define EXTERNAL_TOKEN_COUNT 8
#define FIELD_COUNT 11
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 33
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_COLONmanuscript_COLON = 1,
  anon_sym_COLON_COLON = 2,
  anon_sym_COLONparagraph_COLON = 3,
  aux_sym_mathblock_token1 = 4,
  anon_sym_COLONmathblock_COLON = 5,
  anon_sym_COLONappendix_COLON = 6,
  anon_sym_COLONbibliography_COLON = 7,
  anon_sym_COLONtoc_COLON = 8,
  aux_sym_specialblock_token1 = 9,
  aux_sym_specialblock_token2 = 10,
  aux_sym_specialblock_token3 = 11,
  aux_sym_specialblock_token4 = 12,
  anon_sym_COLONcodeblock_COLON = 13,
  anon_sym_COLONalgorithm_COLON = 14,
  anon_sym_COLONcaption_COLON = 15,
  anon_sym_COLONitem_COLON = 16,
  anon_sym_COLONprev_COLON = 17,
  anon_sym_COLONprev2_COLON = 18,
  anon_sym_COLONprev3_COLON = 19,
  aux_sym_specialinline_token1 = 20,
  aux_sym_specialinline_token2 = 21,
  anon_sym_COLONmath_COLON = 22,
  anon_sym_COLONcode_COLON = 23,
  aux_sym_specialinline_token3 = 24,
  anon_sym_STAR = 25,
  aux_sym_specialinline_token4 = 26,
  anon_sym_SLASH = 27,
  anon_sym_COLONref_COLON = 28,
  aux_sym_specialinline_token5 = 29,
  anon_sym_COMMA = 30,
  anon_sym_COLONprevious_COLON = 31,
  aux_sym_specialinline_token6 = 32,
  anon_sym_COLONurl_COLON = 33,
  aux_sym_specialinline_token7 = 34,
  anon_sym_COLONcite_COLON = 35,
  aux_sym_specialinline_token8 = 36,
  anon_sym_COLONqed_COLON = 37,
  anon_sym_LBRACE = 38,
  anon_sym_RBRACE = 39,
  aux_sym_metaval_any_token1 = 40,
  aux_sym_metaval_any_inline_token1 = 41,
  anon_sym_COLONtable_COLON = 42,
  anon_sym_COLONthead_COLON = 43,
  anon_sym_COLONtbody_COLON = 44,
  anon_sym_COLONtr_COLON = 45,
  anon_sym_COLON = 46,
  anon_sym_COLONtd_COLON = 47,
  anon_sym_COLONbibtex_COLON = 48,
  anon_sym_AT = 49,
  aux_sym_bibitem_token1 = 50,
  aux_sym_bibitem_token2 = 51,
  aux_sym_bibitempair_token1 = 52,
  anon_sym_EQ = 53,
  aux_sym_bibitempair_token2 = 54,
  anon_sym_COLONassume_COLON = 55,
  anon_sym_COLONsuppose_COLON = 56,
  anon_sym_COLONprove_COLON = 57,
  anon_sym_COLONthen_COLON = 58,
  anon_sym_COLONnew_COLON = 59,
  anon_sym_COLONlet_COLON = 60,
  anon_sym_COLONcase_COLON = 61,
  anon_sym_COLONdefine_COLON = 62,
  anon_sym_COLONwrite_COLON = 63,
  anon_sym_COLONwlog_COLON = 64,
  anon_sym_COLONsuffices_COLON = 65,
  anon_sym_COLONclaim_COLON = 66,
  anon_sym_COLON_PIPE_DASH_COLON = 67,
  anon_sym_COLONu22a2_COLON = 68,
  anon_sym_COLONpick_COLON = 69,
  anon_sym_COLONst_COLON = 70,
  anon_sym_COLONdraft_COLON = 71,
  anon_sym_COLONnote_COLON = 72,
  anon_sym_COLONspan_COLON = 73,
  anon_sym_COLONabstract_COLON = 74,
  anon_sym_COLONauthor_COLON = 75,
  anon_sym_COLONdefinition_COLON = 76,
  anon_sym_COLONcorollary_COLON = 77,
  anon_sym_COLONenumerate_COLON = 78,
  anon_sym_COLONexample_COLON = 79,
  anon_sym_COLONitemize_COLON = 80,
  anon_sym_COLONlemma_COLON = 81,
  anon_sym_COLONfigure_COLON = 82,
  anon_sym_COLONp_COLON = 83,
  anon_sym_COLONproof_COLON = 84,
  anon_sym_COLONproposition_COLON = 85,
  anon_sym_COLONremark_COLON = 86,
  anon_sym_COLONsection_COLON = 87,
  anon_sym_COLONsketch_COLON = 88,
  anon_sym_COLONsubsection_COLON = 89,
  anon_sym_COLONsubsubsection_COLON = 90,
  anon_sym_COLONsubsubsubsection_COLON = 91,
  anon_sym_COLONstep_COLON = 92,
  anon_sym_COLONtheorem_COLON = 93,
  anon_sym_COLONaffiliation_COLON = 94,
  anon_sym_COLONemail_COLON = 95,
  anon_sym_COLONlabel_COLON = 96,
  anon_sym_COLONname_COLON = 97,
  anon_sym_COLONreftext_COLON = 98,
  anon_sym_COLONtitle_COLON = 99,
  anon_sym_COLONgoal_COLON = 100,
  anon_sym_COLONlang_COLON = 101,
  anon_sym_COLONicon_COLON = 102,
  anon_sym_COLONnonum_COLON = 103,
  anon_sym_COLONstrong_COLON = 104,
  anon_sym_COLONemphas_COLON = 105,
  anon_sym_COLONisclaim_COLON = 106,
  anon_sym_COLONkeywords_COLON = 107,
  anon_sym_COLONmsc_COLON = 108,
  anon_sym_COLONtypes_COLON = 109,
  anon_sym_COLONdate_COLON = 110,
  anon_sym_COLONpath_COLON = 111,
  anon_sym_COLONscale_COLON = 112,
  sym_comment = 113,
  sym_upto_brace_or_comma_text = 114,
  sym_asis_dollar_text = 115,
  sym_asis_two_dollars_text = 116,
  sym_asis_backtick_text = 117,
  sym_asis_three_backticks_text = 118,
  sym_asis_halmos_text = 119,
  sym_text = 120,
  sym_paragraph_end = 121,
  sym_source_file = 122,
  sym_block = 123,
  sym_paragraph = 124,
  sym_inline = 125,
  sym_construct = 126,
  sym_mathblock = 127,
  sym_specialblock = 128,
  sym_caption = 129,
  sym_item = 130,
  sym_specialinline = 131,
  sym_specialconstruct = 132,
  sym_inlinemeta = 133,
  sym_blockmeta = 134,
  sym_inlinemetapair = 135,
  sym_pair = 136,
  sym_metaval_any = 137,
  sym_metaval_any_inline = 138,
  sym_metaval_text = 139,
  sym_metaval_text_inline = 140,
  sym_metaval_list = 141,
  sym_metaval_list_inline = 142,
  sym_table = 143,
  sym_thead = 144,
  sym_tbody = 145,
  sym_tr = 146,
  sym_trshort = 147,
  sym_td = 148,
  sym_tdcontent = 149,
  sym_bibtex = 150,
  sym_bibitem = 151,
  sym_bibitempair = 152,
  sym__paragraphcontent_no_special = 153,
  sym_metakey_text = 154,
  sym_metakey_bool = 155,
  sym_metakey_list = 156,
  sym_metakey_any = 157,
  aux_sym_source_file_repeat1 = 158,
  aux_sym_paragraph_repeat1 = 159,
  aux_sym_inline_repeat1 = 160,
  aux_sym_inlinemeta_repeat1 = 161,
  aux_sym_blockmeta_repeat1 = 162,
  aux_sym_metaval_list_repeat1 = 163,
  aux_sym_thead_repeat1 = 164,
  aux_sym_tr_repeat1 = 165,
  aux_sym_trshort_repeat1 = 166,
  aux_sym_bibtex_repeat1 = 167,
  aux_sym_bibitem_repeat1 = 168,
  anon_alias_sym_math = 169,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_COLONmanuscript_COLON] = "manuscript",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_COLONparagraph_COLON] = ":paragraph:",
  [aux_sym_mathblock_token1] = "mathblock_token1",
  [anon_sym_COLONmathblock_COLON] = ":mathblock:",
  [anon_sym_COLONappendix_COLON] = "appendix",
  [anon_sym_COLONbibliography_COLON] = "bibliography",
  [anon_sym_COLONtoc_COLON] = "toc",
  [aux_sym_specialblock_token1] = "section",
  [aux_sym_specialblock_token2] = "subsection",
  [aux_sym_specialblock_token3] = "subsubsection",
  [aux_sym_specialblock_token4] = "specialblock_token4",
  [anon_sym_COLONcodeblock_COLON] = "codeblock",
  [anon_sym_COLONalgorithm_COLON] = "algorithm",
  [anon_sym_COLONcaption_COLON] = ":caption:",
  [anon_sym_COLONitem_COLON] = ":item:",
  [anon_sym_COLONprev_COLON] = "prev",
  [anon_sym_COLONprev2_COLON] = "prev2",
  [anon_sym_COLONprev3_COLON] = "prev3",
  [aux_sym_specialinline_token1] = "math",
  [aux_sym_specialinline_token2] = "specialinline_token2",
  [anon_sym_COLONmath_COLON] = "math",
  [anon_sym_COLONcode_COLON] = "code",
  [aux_sym_specialinline_token3] = "spanstrong",
  [anon_sym_STAR] = "*",
  [aux_sym_specialinline_token4] = "spanemphas",
  [anon_sym_SLASH] = "/",
  [anon_sym_COLONref_COLON] = "ref",
  [aux_sym_specialinline_token5] = "text",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLONprevious_COLON] = "previous",
  [aux_sym_specialinline_token6] = "text",
  [anon_sym_COLONurl_COLON] = "url",
  [aux_sym_specialinline_token7] = "text",
  [anon_sym_COLONcite_COLON] = "cite",
  [aux_sym_specialinline_token8] = "text",
  [anon_sym_COLONqed_COLON] = "qed",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_metaval_any_token1] = "text",
  [aux_sym_metaval_any_inline_token1] = "text",
  [anon_sym_COLONtable_COLON] = ":table:",
  [anon_sym_COLONthead_COLON] = ":thead:",
  [anon_sym_COLONtbody_COLON] = ":tbody:",
  [anon_sym_COLONtr_COLON] = ":tr:",
  [anon_sym_COLON] = ":",
  [anon_sym_COLONtd_COLON] = ":td:",
  [anon_sym_COLONbibtex_COLON] = ":bibtex:",
  [anon_sym_AT] = "@",
  [aux_sym_bibitem_token1] = "kind",
  [aux_sym_bibitem_token2] = "label",
  [aux_sym_bibitempair_token1] = "key",
  [anon_sym_EQ] = "=",
  [aux_sym_bibitempair_token2] = "value",
  [anon_sym_COLONassume_COLON] = "assume",
  [anon_sym_COLONsuppose_COLON] = "suppose",
  [anon_sym_COLONprove_COLON] = "prove",
  [anon_sym_COLONthen_COLON] = "then",
  [anon_sym_COLONnew_COLON] = "new",
  [anon_sym_COLONlet_COLON] = "let",
  [anon_sym_COLONcase_COLON] = "case",
  [anon_sym_COLONdefine_COLON] = "define",
  [anon_sym_COLONwrite_COLON] = "write",
  [anon_sym_COLONwlog_COLON] = "wlog",
  [anon_sym_COLONsuffices_COLON] = "suffices",
  [anon_sym_COLONclaim_COLON] = "claim",
  [anon_sym_COLON_PIPE_DASH_COLON] = "claim",
  [anon_sym_COLONu22a2_COLON] = "claim",
  [anon_sym_COLONpick_COLON] = "pick",
  [anon_sym_COLONst_COLON] = "st",
  [anon_sym_COLONdraft_COLON] = "draft",
  [anon_sym_COLONnote_COLON] = "note",
  [anon_sym_COLONspan_COLON] = "span",
  [anon_sym_COLONabstract_COLON] = "abstract",
  [anon_sym_COLONauthor_COLON] = "author",
  [anon_sym_COLONdefinition_COLON] = "definition",
  [anon_sym_COLONcorollary_COLON] = "corollary",
  [anon_sym_COLONenumerate_COLON] = "enumerate",
  [anon_sym_COLONexample_COLON] = "example",
  [anon_sym_COLONitemize_COLON] = "itemize",
  [anon_sym_COLONlemma_COLON] = "lemma",
  [anon_sym_COLONfigure_COLON] = "figure",
  [anon_sym_COLONp_COLON] = "subproof",
  [anon_sym_COLONproof_COLON] = "proof",
  [anon_sym_COLONproposition_COLON] = "proposition",
  [anon_sym_COLONremark_COLON] = "remark",
  [anon_sym_COLONsection_COLON] = "section",
  [anon_sym_COLONsketch_COLON] = "sketch",
  [anon_sym_COLONsubsection_COLON] = "subsection",
  [anon_sym_COLONsubsubsection_COLON] = "subsubsection",
  [anon_sym_COLONsubsubsubsection_COLON] = "subsubsubsection",
  [anon_sym_COLONstep_COLON] = "step",
  [anon_sym_COLONtheorem_COLON] = "theorem",
  [anon_sym_COLONaffiliation_COLON] = "affiliation",
  [anon_sym_COLONemail_COLON] = "email",
  [anon_sym_COLONlabel_COLON] = "label",
  [anon_sym_COLONname_COLON] = "name",
  [anon_sym_COLONreftext_COLON] = "reftext",
  [anon_sym_COLONtitle_COLON] = "title",
  [anon_sym_COLONgoal_COLON] = "goal",
  [anon_sym_COLONlang_COLON] = "lang",
  [anon_sym_COLONicon_COLON] = "icon",
  [anon_sym_COLONnonum_COLON] = "nonum",
  [anon_sym_COLONstrong_COLON] = "strong",
  [anon_sym_COLONemphas_COLON] = "emphas",
  [anon_sym_COLONisclaim_COLON] = "isclaim",
  [anon_sym_COLONkeywords_COLON] = "keywords",
  [anon_sym_COLONmsc_COLON] = "msc",
  [anon_sym_COLONtypes_COLON] = "types",
  [anon_sym_COLONdate_COLON] = "date",
  [anon_sym_COLONpath_COLON] = "path",
  [anon_sym_COLONscale_COLON] = "scale",
  [sym_comment] = "comment",
  [sym_upto_brace_or_comma_text] = "metaval_list_item",
  [sym_asis_dollar_text] = "asis_text",
  [sym_asis_two_dollars_text] = "asis_text",
  [sym_asis_backtick_text] = "asis_text",
  [sym_asis_three_backticks_text] = "asis_text",
  [sym_asis_halmos_text] = "asis_text",
  [sym_text] = "text",
  [sym_paragraph_end] = "paragraph_end",
  [sym_source_file] = "source_file",
  [sym_block] = "block",
  [sym_paragraph] = "paragraph",
  [sym_inline] = "inline",
  [sym_construct] = "construct",
  [sym_mathblock] = "mathblock",
  [sym_specialblock] = "specialblock",
  [sym_caption] = "caption",
  [sym_item] = "item",
  [sym_specialinline] = "specialinline",
  [sym_specialconstruct] = "specialconstruct",
  [sym_inlinemeta] = "inlinemeta",
  [sym_blockmeta] = "blockmeta",
  [sym_inlinemetapair] = "pair",
  [sym_pair] = "pair",
  [sym_metaval_any] = "metaval_any",
  [sym_metaval_any_inline] = "metaval_any",
  [sym_metaval_text] = "metaval_text",
  [sym_metaval_text_inline] = "metaval_text",
  [sym_metaval_list] = "metaval_list",
  [sym_metaval_list_inline] = "metaval_list",
  [sym_table] = "table",
  [sym_thead] = "thead",
  [sym_tbody] = "tbody",
  [sym_tr] = "tr",
  [sym_trshort] = "trshort",
  [sym_td] = "td",
  [sym_tdcontent] = "tdcontent",
  [sym_bibtex] = "bibtex",
  [sym_bibitem] = "bibitem",
  [sym_bibitempair] = "bibitempair",
  [sym__paragraphcontent_no_special] = "_paragraphcontent_no_special",
  [sym_metakey_text] = "metakey_text",
  [sym_metakey_bool] = "metakey_bool",
  [sym_metakey_list] = "metakey_list",
  [sym_metakey_any] = "metakey_any",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_paragraph_repeat1] = "paragraph_repeat1",
  [aux_sym_inline_repeat1] = "inline_repeat1",
  [aux_sym_inlinemeta_repeat1] = "inlinemeta_repeat1",
  [aux_sym_blockmeta_repeat1] = "blockmeta_repeat1",
  [aux_sym_metaval_list_repeat1] = "metaval_list_repeat1",
  [aux_sym_thead_repeat1] = "thead_repeat1",
  [aux_sym_tr_repeat1] = "tr_repeat1",
  [aux_sym_trshort_repeat1] = "trshort_repeat1",
  [aux_sym_bibtex_repeat1] = "bibtex_repeat1",
  [aux_sym_bibitem_repeat1] = "bibitem_repeat1",
  [anon_alias_sym_math] = "math",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_COLONmanuscript_COLON] = anon_sym_COLONmanuscript_COLON,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_COLONparagraph_COLON] = anon_sym_COLONparagraph_COLON,
  [aux_sym_mathblock_token1] = aux_sym_mathblock_token1,
  [anon_sym_COLONmathblock_COLON] = anon_sym_COLONmathblock_COLON,
  [anon_sym_COLONappendix_COLON] = anon_sym_COLONappendix_COLON,
  [anon_sym_COLONbibliography_COLON] = anon_sym_COLONbibliography_COLON,
  [anon_sym_COLONtoc_COLON] = anon_sym_COLONtoc_COLON,
  [aux_sym_specialblock_token1] = aux_sym_specialblock_token1,
  [aux_sym_specialblock_token2] = aux_sym_specialblock_token2,
  [aux_sym_specialblock_token3] = aux_sym_specialblock_token3,
  [aux_sym_specialblock_token4] = aux_sym_specialblock_token4,
  [anon_sym_COLONcodeblock_COLON] = anon_sym_COLONcodeblock_COLON,
  [anon_sym_COLONalgorithm_COLON] = anon_sym_COLONalgorithm_COLON,
  [anon_sym_COLONcaption_COLON] = anon_sym_COLONcaption_COLON,
  [anon_sym_COLONitem_COLON] = anon_sym_COLONitem_COLON,
  [anon_sym_COLONprev_COLON] = anon_sym_COLONprev_COLON,
  [anon_sym_COLONprev2_COLON] = anon_sym_COLONprev2_COLON,
  [anon_sym_COLONprev3_COLON] = anon_sym_COLONprev3_COLON,
  [aux_sym_specialinline_token1] = aux_sym_specialinline_token1,
  [aux_sym_specialinline_token2] = aux_sym_specialinline_token2,
  [anon_sym_COLONmath_COLON] = aux_sym_specialinline_token1,
  [anon_sym_COLONcode_COLON] = anon_sym_COLONcode_COLON,
  [aux_sym_specialinline_token3] = aux_sym_specialinline_token3,
  [anon_sym_STAR] = anon_sym_STAR,
  [aux_sym_specialinline_token4] = aux_sym_specialinline_token4,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_COLONref_COLON] = anon_sym_COLONref_COLON,
  [aux_sym_specialinline_token5] = sym_text,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLONprevious_COLON] = anon_sym_COLONprevious_COLON,
  [aux_sym_specialinline_token6] = sym_text,
  [anon_sym_COLONurl_COLON] = anon_sym_COLONurl_COLON,
  [aux_sym_specialinline_token7] = sym_text,
  [anon_sym_COLONcite_COLON] = anon_sym_COLONcite_COLON,
  [aux_sym_specialinline_token8] = sym_text,
  [anon_sym_COLONqed_COLON] = anon_sym_COLONqed_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_metaval_any_token1] = aux_sym_metaval_any_token1,
  [aux_sym_metaval_any_inline_token1] = aux_sym_metaval_any_token1,
  [anon_sym_COLONtable_COLON] = anon_sym_COLONtable_COLON,
  [anon_sym_COLONthead_COLON] = anon_sym_COLONthead_COLON,
  [anon_sym_COLONtbody_COLON] = anon_sym_COLONtbody_COLON,
  [anon_sym_COLONtr_COLON] = anon_sym_COLONtr_COLON,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COLONtd_COLON] = anon_sym_COLONtd_COLON,
  [anon_sym_COLONbibtex_COLON] = anon_sym_COLONbibtex_COLON,
  [anon_sym_AT] = anon_sym_AT,
  [aux_sym_bibitem_token1] = aux_sym_bibitem_token1,
  [aux_sym_bibitem_token2] = aux_sym_bibitem_token2,
  [aux_sym_bibitempair_token1] = aux_sym_bibitempair_token1,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_bibitempair_token2] = aux_sym_bibitempair_token2,
  [anon_sym_COLONassume_COLON] = anon_sym_COLONassume_COLON,
  [anon_sym_COLONsuppose_COLON] = anon_sym_COLONsuppose_COLON,
  [anon_sym_COLONprove_COLON] = anon_sym_COLONprove_COLON,
  [anon_sym_COLONthen_COLON] = anon_sym_COLONthen_COLON,
  [anon_sym_COLONnew_COLON] = anon_sym_COLONnew_COLON,
  [anon_sym_COLONlet_COLON] = anon_sym_COLONlet_COLON,
  [anon_sym_COLONcase_COLON] = anon_sym_COLONcase_COLON,
  [anon_sym_COLONdefine_COLON] = anon_sym_COLONdefine_COLON,
  [anon_sym_COLONwrite_COLON] = anon_sym_COLONwrite_COLON,
  [anon_sym_COLONwlog_COLON] = anon_sym_COLONwlog_COLON,
  [anon_sym_COLONsuffices_COLON] = anon_sym_COLONsuffices_COLON,
  [anon_sym_COLONclaim_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLON_PIPE_DASH_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONu22a2_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONpick_COLON] = anon_sym_COLONpick_COLON,
  [anon_sym_COLONst_COLON] = anon_sym_COLONst_COLON,
  [anon_sym_COLONdraft_COLON] = anon_sym_COLONdraft_COLON,
  [anon_sym_COLONnote_COLON] = anon_sym_COLONnote_COLON,
  [anon_sym_COLONspan_COLON] = anon_sym_COLONspan_COLON,
  [anon_sym_COLONabstract_COLON] = anon_sym_COLONabstract_COLON,
  [anon_sym_COLONauthor_COLON] = anon_sym_COLONauthor_COLON,
  [anon_sym_COLONdefinition_COLON] = anon_sym_COLONdefinition_COLON,
  [anon_sym_COLONcorollary_COLON] = anon_sym_COLONcorollary_COLON,
  [anon_sym_COLONenumerate_COLON] = anon_sym_COLONenumerate_COLON,
  [anon_sym_COLONexample_COLON] = anon_sym_COLONexample_COLON,
  [anon_sym_COLONitemize_COLON] = anon_sym_COLONitemize_COLON,
  [anon_sym_COLONlemma_COLON] = anon_sym_COLONlemma_COLON,
  [anon_sym_COLONfigure_COLON] = anon_sym_COLONfigure_COLON,
  [anon_sym_COLONp_COLON] = anon_sym_COLONp_COLON,
  [anon_sym_COLONproof_COLON] = anon_sym_COLONproof_COLON,
  [anon_sym_COLONproposition_COLON] = anon_sym_COLONproposition_COLON,
  [anon_sym_COLONremark_COLON] = anon_sym_COLONremark_COLON,
  [anon_sym_COLONsection_COLON] = aux_sym_specialblock_token1,
  [anon_sym_COLONsketch_COLON] = anon_sym_COLONsketch_COLON,
  [anon_sym_COLONsubsection_COLON] = aux_sym_specialblock_token2,
  [anon_sym_COLONsubsubsection_COLON] = aux_sym_specialblock_token3,
  [anon_sym_COLONsubsubsubsection_COLON] = anon_sym_COLONsubsubsubsection_COLON,
  [anon_sym_COLONstep_COLON] = anon_sym_COLONstep_COLON,
  [anon_sym_COLONtheorem_COLON] = anon_sym_COLONtheorem_COLON,
  [anon_sym_COLONaffiliation_COLON] = anon_sym_COLONaffiliation_COLON,
  [anon_sym_COLONemail_COLON] = anon_sym_COLONemail_COLON,
  [anon_sym_COLONlabel_COLON] = aux_sym_bibitem_token2,
  [anon_sym_COLONname_COLON] = anon_sym_COLONname_COLON,
  [anon_sym_COLONreftext_COLON] = anon_sym_COLONreftext_COLON,
  [anon_sym_COLONtitle_COLON] = anon_sym_COLONtitle_COLON,
  [anon_sym_COLONgoal_COLON] = anon_sym_COLONgoal_COLON,
  [anon_sym_COLONlang_COLON] = anon_sym_COLONlang_COLON,
  [anon_sym_COLONicon_COLON] = anon_sym_COLONicon_COLON,
  [anon_sym_COLONnonum_COLON] = anon_sym_COLONnonum_COLON,
  [anon_sym_COLONstrong_COLON] = anon_sym_COLONstrong_COLON,
  [anon_sym_COLONemphas_COLON] = anon_sym_COLONemphas_COLON,
  [anon_sym_COLONisclaim_COLON] = anon_sym_COLONisclaim_COLON,
  [anon_sym_COLONkeywords_COLON] = anon_sym_COLONkeywords_COLON,
  [anon_sym_COLONmsc_COLON] = anon_sym_COLONmsc_COLON,
  [anon_sym_COLONtypes_COLON] = anon_sym_COLONtypes_COLON,
  [anon_sym_COLONdate_COLON] = anon_sym_COLONdate_COLON,
  [anon_sym_COLONpath_COLON] = anon_sym_COLONpath_COLON,
  [anon_sym_COLONscale_COLON] = anon_sym_COLONscale_COLON,
  [sym_comment] = sym_comment,
  [sym_upto_brace_or_comma_text] = sym_upto_brace_or_comma_text,
  [sym_asis_dollar_text] = sym_asis_dollar_text,
  [sym_asis_two_dollars_text] = sym_asis_dollar_text,
  [sym_asis_backtick_text] = sym_asis_dollar_text,
  [sym_asis_three_backticks_text] = sym_asis_dollar_text,
  [sym_asis_halmos_text] = sym_asis_dollar_text,
  [sym_text] = sym_text,
  [sym_paragraph_end] = sym_paragraph_end,
  [sym_source_file] = sym_source_file,
  [sym_block] = sym_block,
  [sym_paragraph] = sym_paragraph,
  [sym_inline] = sym_inline,
  [sym_construct] = sym_construct,
  [sym_mathblock] = sym_mathblock,
  [sym_specialblock] = sym_specialblock,
  [sym_caption] = sym_caption,
  [sym_item] = sym_item,
  [sym_specialinline] = sym_specialinline,
  [sym_specialconstruct] = sym_specialconstruct,
  [sym_inlinemeta] = sym_inlinemeta,
  [sym_blockmeta] = sym_blockmeta,
  [sym_inlinemetapair] = sym_inlinemetapair,
  [sym_pair] = sym_inlinemetapair,
  [sym_metaval_any] = sym_metaval_any,
  [sym_metaval_any_inline] = sym_metaval_any,
  [sym_metaval_text] = sym_metaval_text,
  [sym_metaval_text_inline] = sym_metaval_text,
  [sym_metaval_list] = sym_metaval_list,
  [sym_metaval_list_inline] = sym_metaval_list,
  [sym_table] = sym_table,
  [sym_thead] = sym_thead,
  [sym_tbody] = sym_tbody,
  [sym_tr] = sym_tr,
  [sym_trshort] = sym_trshort,
  [sym_td] = sym_td,
  [sym_tdcontent] = sym_tdcontent,
  [sym_bibtex] = sym_bibtex,
  [sym_bibitem] = sym_bibitem,
  [sym_bibitempair] = sym_bibitempair,
  [sym__paragraphcontent_no_special] = sym__paragraphcontent_no_special,
  [sym_metakey_text] = sym_metakey_text,
  [sym_metakey_bool] = sym_metakey_bool,
  [sym_metakey_list] = sym_metakey_list,
  [sym_metakey_any] = sym_metakey_any,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_paragraph_repeat1] = aux_sym_paragraph_repeat1,
  [aux_sym_inline_repeat1] = aux_sym_inline_repeat1,
  [aux_sym_inlinemeta_repeat1] = aux_sym_inlinemeta_repeat1,
  [aux_sym_blockmeta_repeat1] = aux_sym_blockmeta_repeat1,
  [aux_sym_metaval_list_repeat1] = aux_sym_metaval_list_repeat1,
  [aux_sym_thead_repeat1] = aux_sym_thead_repeat1,
  [aux_sym_tr_repeat1] = aux_sym_tr_repeat1,
  [aux_sym_trshort_repeat1] = aux_sym_trshort_repeat1,
  [aux_sym_bibtex_repeat1] = aux_sym_bibtex_repeat1,
  [aux_sym_bibitem_repeat1] = aux_sym_bibitem_repeat1,
  [anon_alias_sym_math] = anon_alias_sym_math,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_COLONmanuscript_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONparagraph_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_mathblock_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONmathblock_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONappendix_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONbibliography_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtoc_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialblock_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialblock_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialblock_token3] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialblock_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONcodeblock_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONalgorithm_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcaption_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONitem_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONprev_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprev2_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprev3_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONmath_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcode_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token3] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_specialinline_token4] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONref_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token5] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONprevious_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token6] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONurl_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token7] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcite_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token8] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONqed_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_metaval_any_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_metaval_any_inline_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtable_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONthead_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtbody_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtr_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtd_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONbibtex_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bibitem_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bibitem_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bibitempair_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bibitempair_token2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONassume_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsuppose_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprove_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONthen_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnew_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlet_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcase_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdefine_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONwrite_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONwlog_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsuffices_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONclaim_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON_PIPE_DASH_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONu22a2_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONpick_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONst_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdraft_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnote_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONspan_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONabstract_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONauthor_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdefinition_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcorollary_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONenumerate_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONexample_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONitemize_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlemma_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONfigure_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONp_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproof_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproposition_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONremark_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsketch_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsubsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsubsubsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsubsubsubsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONstep_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtheorem_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONaffiliation_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONemail_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlabel_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONname_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONreftext_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtitle_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONgoal_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlang_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONicon_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnonum_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONstrong_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONemphas_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONisclaim_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONkeywords_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONmsc_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtypes_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdate_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONpath_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONscale_COLON] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_upto_brace_or_comma_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_dollar_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_two_dollars_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_backtick_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_three_backticks_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_halmos_text] = {
    .visible = true,
    .named = true,
  },
  [sym_text] = {
    .visible = true,
    .named = true,
  },
  [sym_paragraph_end] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_paragraph] = {
    .visible = true,
    .named = true,
  },
  [sym_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_mathblock] = {
    .visible = true,
    .named = true,
  },
  [sym_specialblock] = {
    .visible = true,
    .named = true,
  },
  [sym_caption] = {
    .visible = true,
    .named = true,
  },
  [sym_item] = {
    .visible = true,
    .named = true,
  },
  [sym_specialinline] = {
    .visible = true,
    .named = true,
  },
  [sym_specialconstruct] = {
    .visible = true,
    .named = true,
  },
  [sym_inlinemeta] = {
    .visible = true,
    .named = true,
  },
  [sym_blockmeta] = {
    .visible = true,
    .named = true,
  },
  [sym_inlinemetapair] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_any] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_any_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_text] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_text_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_list] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_list_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_table] = {
    .visible = true,
    .named = true,
  },
  [sym_thead] = {
    .visible = true,
    .named = true,
  },
  [sym_tbody] = {
    .visible = true,
    .named = true,
  },
  [sym_tr] = {
    .visible = true,
    .named = true,
  },
  [sym_trshort] = {
    .visible = true,
    .named = true,
  },
  [sym_td] = {
    .visible = true,
    .named = true,
  },
  [sym_tdcontent] = {
    .visible = true,
    .named = true,
  },
  [sym_bibtex] = {
    .visible = true,
    .named = true,
  },
  [sym_bibitem] = {
    .visible = true,
    .named = true,
  },
  [sym_bibitempair] = {
    .visible = true,
    .named = true,
  },
  [sym__paragraphcontent_no_special] = {
    .visible = false,
    .named = true,
  },
  [sym_metakey_text] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_bool] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_list] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_any] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_paragraph_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inline_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inlinemeta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_blockmeta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaval_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_thead_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_trshort_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bibtex_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bibitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym_math] = {
    .visible = true,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_body = 1,
  field_caption = 2,
  field_head = 3,
  field_kind = 4,
  field_label = 5,
  field_meta = 6,
  field_reftext = 7,
  field_tag = 8,
  field_target = 9,
  field_targetlabels = 10,
  field_title = 11,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_body] = "body",
  [field_caption] = "caption",
  [field_head] = "head",
  [field_kind] = "kind",
  [field_label] = "label",
  [field_meta] = "meta",
  [field_reftext] = "reftext",
  [field_tag] = "tag",
  [field_target] = "target",
  [field_targetlabels] = "targetlabels",
  [field_title] = "title",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 2},
  [5] = {.index = 3, .length = 2},
  [6] = {.index = 0, .length = 1},
  [7] = {.index = 0, .length = 1},
  [8] = {.index = 0, .length = 1},
  [9] = {.index = 5, .length = 2},
  [10] = {.index = 7, .length = 2},
  [11] = {.index = 9, .length = 2},
  [12] = {.index = 11, .length = 2},
  [13] = {.index = 13, .length = 2},
  [14] = {.index = 15, .length = 1},
  [15] = {.index = 16, .length = 3},
  [16] = {.index = 1, .length = 2},
  [17] = {.index = 1, .length = 2},
  [18] = {.index = 1, .length = 2},
  [19] = {.index = 19, .length = 3},
  [20] = {.index = 22, .length = 3},
  [21] = {.index = 25, .length = 3},
  [22] = {.index = 28, .length = 3},
  [23] = {.index = 31, .length = 3},
  [24] = {.index = 34, .length = 3},
  [25] = {.index = 37, .length = 3},
  [26] = {.index = 40, .length = 3},
  [27] = {.index = 43, .length = 4},
  [28] = {.index = 47, .length = 4},
  [29] = {.index = 51, .length = 4},
  [30] = {.index = 55, .length = 4},
  [31] = {.index = 59, .length = 5},
  [32] = {.index = 64, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_tag, 0},
  [1] =
    {field_meta, 1},
    {field_tag, 0},
  [3] =
    {field_tag, 0},
    {field_title, 1},
  [5] =
    {field_tag, 0},
    {field_target, 1},
  [7] =
    {field_tag, 0},
    {field_targetlabels, 1},
  [9] =
    {field_caption, 1},
    {field_tag, 0},
  [11] =
    {field_head, 1},
    {field_tag, 0},
  [13] =
    {field_body, 1},
    {field_tag, 0},
  [15] =
    {field_meta, 1},
  [16] =
    {field_meta, 2},
    {field_tag, 0},
    {field_title, 1},
  [19] =
    {field_caption, 2},
    {field_meta, 1},
    {field_tag, 0},
  [22] =
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [25] =
    {field_body, 2},
    {field_meta, 1},
    {field_tag, 0},
  [28] =
    {field_caption, 2},
    {field_head, 1},
    {field_tag, 0},
  [31] =
    {field_body, 2},
    {field_head, 1},
    {field_tag, 0},
  [34] =
    {field_body, 1},
    {field_caption, 2},
    {field_tag, 0},
  [37] =
    {field_reftext, 3},
    {field_tag, 0},
    {field_target, 1},
  [40] =
    {field_reftext, 3},
    {field_tag, 0},
    {field_targetlabels, 1},
  [43] =
    {field_caption, 3},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [47] =
    {field_body, 3},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [51] =
    {field_body, 2},
    {field_caption, 3},
    {field_meta, 1},
    {field_tag, 0},
  [55] =
    {field_body, 2},
    {field_caption, 3},
    {field_head, 1},
    {field_tag, 0},
  [59] =
    {field_body, 3},
    {field_caption, 4},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [64] =
    {field_kind, 1},
    {field_label, 3},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [3] = {
    [0] = aux_sym_metaval_any_token1,
  },
  [4] = {
    [0] = sym_upto_brace_or_comma_text,
  },
  [6] = {
    [0] = anon_sym_COLONcodeblock_COLON,
  },
  [7] = {
    [2] = anon_alias_sym_math,
  },
  [8] = {
    [0] = anon_sym_COLONcode_COLON,
  },
  [16] = {
    [0] = anon_sym_COLONcodeblock_COLON,
  },
  [17] = {
    [3] = anon_alias_sym_math,
  },
  [18] = {
    [0] = anon_sym_COLONcode_COLON,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 66,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 69,
  [76] = 76,
  [77] = 74,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 80,
  [86] = 82,
  [87] = 80,
  [88] = 82,
  [89] = 80,
  [90] = 82,
  [91] = 80,
  [92] = 82,
  [93] = 83,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 98,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 97,
  [109] = 95,
  [110] = 97,
  [111] = 106,
  [112] = 107,
  [113] = 113,
  [114] = 113,
  [115] = 115,
  [116] = 98,
  [117] = 100,
  [118] = 101,
  [119] = 105,
  [120] = 115,
  [121] = 97,
  [122] = 104,
  [123] = 106,
  [124] = 107,
  [125] = 113,
  [126] = 115,
  [127] = 98,
  [128] = 100,
  [129] = 101,
  [130] = 105,
  [131] = 102,
  [132] = 104,
  [133] = 106,
  [134] = 107,
  [135] = 113,
  [136] = 115,
  [137] = 98,
  [138] = 100,
  [139] = 101,
  [140] = 105,
  [141] = 102,
  [142] = 104,
  [143] = 106,
  [144] = 107,
  [145] = 113,
  [146] = 115,
  [147] = 100,
  [148] = 101,
  [149] = 105,
  [150] = 102,
  [151] = 104,
  [152] = 102,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 27,
  [171] = 171,
  [172] = 172,
  [173] = 41,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 168,
  [179] = 161,
  [180] = 160,
  [181] = 166,
  [182] = 169,
  [183] = 171,
  [184] = 172,
  [185] = 175,
  [186] = 167,
  [187] = 164,
  [188] = 157,
  [189] = 162,
  [190] = 174,
  [191] = 156,
  [192] = 163,
  [193] = 176,
  [194] = 155,
  [195] = 195,
  [196] = 177,
  [197] = 154,
  [198] = 165,
  [199] = 158,
  [200] = 200,
  [201] = 159,
  [202] = 176,
  [203] = 160,
  [204] = 169,
  [205] = 171,
  [206] = 172,
  [207] = 175,
  [208] = 164,
  [209] = 157,
  [210] = 162,
  [211] = 174,
  [212] = 156,
  [213] = 163,
  [214] = 164,
  [215] = 155,
  [216] = 177,
  [217] = 154,
  [218] = 165,
  [219] = 158,
  [220] = 159,
  [221] = 157,
  [222] = 162,
  [223] = 174,
  [224] = 156,
  [225] = 163,
  [226] = 176,
  [227] = 155,
  [228] = 177,
  [229] = 154,
  [230] = 165,
  [231] = 195,
  [232] = 168,
  [233] = 167,
  [234] = 161,
  [235] = 160,
  [236] = 158,
  [237] = 166,
  [238] = 166,
  [239] = 169,
  [240] = 169,
  [241] = 171,
  [242] = 172,
  [243] = 175,
  [244] = 200,
  [245] = 164,
  [246] = 157,
  [247] = 162,
  [248] = 171,
  [249] = 172,
  [250] = 174,
  [251] = 156,
  [252] = 163,
  [253] = 175,
  [254] = 176,
  [255] = 155,
  [256] = 177,
  [257] = 168,
  [258] = 154,
  [259] = 167,
  [260] = 165,
  [261] = 161,
  [262] = 160,
  [263] = 158,
  [264] = 159,
  [265] = 168,
  [266] = 167,
  [267] = 161,
  [268] = 166,
  [269] = 159,
  [270] = 270,
  [271] = 271,
  [272] = 6,
  [273] = 5,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 277,
  [280] = 274,
  [281] = 6,
  [282] = 5,
  [283] = 6,
  [284] = 5,
  [285] = 5,
  [286] = 6,
  [287] = 287,
  [288] = 7,
  [289] = 289,
  [290] = 289,
  [291] = 289,
  [292] = 292,
  [293] = 292,
  [294] = 292,
  [295] = 292,
  [296] = 289,
  [297] = 289,
  [298] = 292,
  [299] = 8,
  [300] = 9,
  [301] = 12,
  [302] = 11,
  [303] = 13,
  [304] = 10,
  [305] = 8,
  [306] = 10,
  [307] = 11,
  [308] = 12,
  [309] = 7,
  [310] = 13,
  [311] = 13,
  [312] = 11,
  [313] = 12,
  [314] = 8,
  [315] = 9,
  [316] = 10,
  [317] = 9,
  [318] = 7,
  [319] = 11,
  [320] = 12,
  [321] = 10,
  [322] = 13,
  [323] = 7,
  [324] = 8,
  [325] = 9,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 340,
  [349] = 349,
  [350] = 350,
  [351] = 340,
  [352] = 340,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 340,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 356,
  [362] = 358,
  [363] = 359,
  [364] = 360,
  [365] = 356,
  [366] = 358,
  [367] = 359,
  [368] = 360,
  [369] = 356,
  [370] = 358,
  [371] = 359,
  [372] = 358,
  [373] = 359,
  [374] = 360,
  [375] = 356,
  [376] = 360,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 378,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 380,
  [392] = 392,
  [393] = 381,
  [394] = 382,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 383,
  [399] = 381,
  [400] = 383,
  [401] = 386,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 389,
  [406] = 406,
  [407] = 380,
  [408] = 408,
  [409] = 381,
  [410] = 382,
  [411] = 411,
  [412] = 412,
  [413] = 383,
  [414] = 414,
  [415] = 378,
  [416] = 386,
  [417] = 417,
  [418] = 389,
  [419] = 386,
  [420] = 420,
  [421] = 421,
  [422] = 389,
  [423] = 423,
  [424] = 424,
  [425] = 417,
  [426] = 426,
  [427] = 380,
  [428] = 428,
  [429] = 380,
  [430] = 378,
  [431] = 431,
  [432] = 417,
  [433] = 381,
  [434] = 382,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 383,
  [439] = 439,
  [440] = 417,
  [441] = 378,
  [442] = 386,
  [443] = 443,
  [444] = 437,
  [445] = 389,
  [446] = 446,
  [447] = 417,
  [448] = 436,
  [449] = 436,
  [450] = 436,
  [451] = 436,
  [452] = 382,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 200,
  [476] = 476,
  [477] = 454,
  [478] = 456,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 31,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 457,
  [488] = 458,
  [489] = 459,
  [490] = 460,
  [491] = 491,
  [492] = 470,
  [493] = 493,
  [494] = 471,
  [495] = 495,
  [496] = 457,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 470,
  [501] = 471,
  [502] = 472,
  [503] = 473,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 454,
  [508] = 456,
  [509] = 509,
  [510] = 510,
  [511] = 511,
  [512] = 195,
  [513] = 513,
  [514] = 514,
  [515] = 472,
  [516] = 473,
  [517] = 457,
  [518] = 458,
  [519] = 459,
  [520] = 460,
  [521] = 521,
  [522] = 522,
  [523] = 200,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 458,
  [529] = 529,
  [530] = 470,
  [531] = 471,
  [532] = 472,
  [533] = 473,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 454,
  [538] = 456,
  [539] = 459,
  [540] = 47,
  [541] = 541,
  [542] = 542,
  [543] = 479,
  [544] = 504,
  [545] = 545,
  [546] = 546,
  [547] = 461,
  [548] = 462,
  [549] = 481,
  [550] = 484,
  [551] = 457,
  [552] = 509,
  [553] = 553,
  [554] = 554,
  [555] = 522,
  [556] = 529,
  [557] = 557,
  [558] = 558,
  [559] = 458,
  [560] = 534,
  [561] = 453,
  [562] = 459,
  [563] = 460,
  [564] = 564,
  [565] = 453,
  [566] = 557,
  [567] = 461,
  [568] = 462,
  [569] = 481,
  [570] = 484,
  [571] = 571,
  [572] = 522,
  [573] = 529,
  [574] = 557,
  [575] = 558,
  [576] = 576,
  [577] = 534,
  [578] = 453,
  [579] = 195,
  [580] = 545,
  [581] = 553,
  [582] = 582,
  [583] = 583,
  [584] = 461,
  [585] = 462,
  [586] = 481,
  [587] = 484,
  [588] = 541,
  [589] = 522,
  [590] = 529,
  [591] = 557,
  [592] = 558,
  [593] = 593,
  [594] = 534,
  [595] = 470,
  [596] = 471,
  [597] = 472,
  [598] = 473,
  [599] = 599,
  [600] = 583,
  [601] = 461,
  [602] = 462,
  [603] = 481,
  [604] = 484,
  [605] = 460,
  [606] = 522,
  [607] = 529,
  [608] = 557,
  [609] = 558,
  [610] = 454,
  [611] = 534,
  [612] = 453,
  [613] = 456,
  [614] = 195,
  [615] = 558,
  [616] = 200,
  [617] = 617,
  [618] = 554,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(483);
      ADVANCE_MAP(
        '#', 7,
        '$', 504,
        '%', 618,
        '*', 510,
        ',', 517,
        '/', 512,
        ':', 543,
        '=', 554,
        '@', 548,
        '`', 506,
        'a', 393,
        'b', 365,
        'd', 359,
        'e', 180,
        'j', 356,
        'n', 458,
        'p', 459,
        's', 351,
        't', 263,
        'u', 394,
        'v', 354,
        'y', 183,
        '{', 533,
        '}', 534,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(519);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(616);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0) ADVANCE(3);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(536);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(616);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0) ADVANCE(3);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(535);
      if (lookahead != 0) ADVANCE(3);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(4);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(617);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(538);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(617);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 6:
      if (lookahead == '\n') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 7:
      if (lookahead == ' ') ADVANCE(492);
      if (lookahead == '#') ADVANCE(8);
      END_STATE();
    case 8:
      if (lookahead == ' ') ADVANCE(493);
      if (lookahead == '#') ADVANCE(9);
      END_STATE();
    case 9:
      if (lookahead == ' ') ADVANCE(494);
      END_STATE();
    case 10:
      if (lookahead == '$') ADVANCE(504);
      if (lookahead == '%') ADVANCE(618);
      if (lookahead == '*') ADVANCE(509);
      if (lookahead == '/') ADVANCE(511);
      if (lookahead == ':') ADVANCE(130);
      if (lookahead == '`') ADVANCE(505);
      if (lookahead == '{') ADVANCE(533);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 11:
      if (lookahead == '$') ADVANCE(503);
      if (lookahead == '%') ADVANCE(618);
      if (lookahead == '*') ADVANCE(510);
      if (lookahead == '/') ADVANCE(511);
      if (lookahead == ':') ADVANCE(545);
      if (lookahead == '`') ADVANCE(505);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 12:
      if (lookahead == '$') ADVANCE(503);
      if (lookahead == '%') ADVANCE(618);
      if (lookahead == '*') ADVANCE(509);
      if (lookahead == '/') ADVANCE(512);
      if (lookahead == ':') ADVANCE(129);
      if (lookahead == '`') ADVANCE(505);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      if (lookahead == '$') ADVANCE(503);
      if (lookahead == '%') ADVANCE(618);
      if (lookahead == '*') ADVANCE(509);
      if (lookahead == '/') ADVANCE(511);
      if (lookahead == ':') ADVANCE(26);
      if (lookahead == '`') ADVANCE(505);
      if (lookahead == '{') ADVANCE(533);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 14:
      if (lookahead == '$') ADVANCE(503);
      if (lookahead == '%') ADVANCE(618);
      if (lookahead == '*') ADVANCE(509);
      if (lookahead == '/') ADVANCE(511);
      if (lookahead == ':') ADVANCE(544);
      if (lookahead == '`') ADVANCE(505);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      END_STATE();
    case 15:
      if (lookahead == '$') ADVANCE(503);
      if (lookahead == '%') ADVANCE(618);
      if (lookahead == '*') ADVANCE(509);
      if (lookahead == '/') ADVANCE(511);
      if (lookahead == ':') ADVANCE(545);
      if (lookahead == '`') ADVANCE(505);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      END_STATE();
    case 16:
      if (lookahead == '%') ADVANCE(514);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(515);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(516);
      END_STATE();
    case 17:
      if (lookahead == '%') ADVANCE(526);
      if (lookahead == 'h') ADVANCE(525);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(527);
      END_STATE();
    case 18:
      if (lookahead == '%') ADVANCE(529);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(530);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(531);
      END_STATE();
    case 19:
      if (lookahead == '%') ADVANCE(555);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(556);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(557);
      END_STATE();
    case 20:
      if (lookahead == '%') ADVANCE(550);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(551);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(552);
      END_STATE();
    case 21:
      if (lookahead == '-') ADVANCE(33);
      END_STATE();
    case 22:
      if (lookahead == '/') ADVANCE(481);
      END_STATE();
    case 23:
      if (lookahead == '/') ADVANCE(22);
      END_STATE();
    case 24:
      if (lookahead == '2') ADVANCE(67);
      if (lookahead == '3') ADVANCE(68);
      if (lookahead == ':') ADVANCE(500);
      if (lookahead == 'i') ADVANCE(363);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        ':', 485,
        'a', 148,
        'b', 261,
        'c', 116,
        'd', 144,
        'e', 317,
        'f', 262,
        'g', 361,
        'i', 161,
        'k', 184,
        'l', 117,
        'm', 118,
        'n', 119,
        'p', 27,
        'q', 194,
        'r', 186,
        's', 160,
        't', 135,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 26:
      ADVANCE_MAP(
        ':', 485,
        'a', 413,
        'c', 145,
        'd', 223,
        'l', 201,
        'm', 132,
        'n', 185,
        'p', 264,
        'q', 194,
        'r', 221,
        's', 383,
        't', 174,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 27:
      if (lookahead == ':') ADVANCE(586);
      if (lookahead == 'a') ADVANCE(399);
      if (lookahead == 'i') ADVANCE(157);
      if (lookahead == 'r') ADVANCE(188);
      END_STATE();
    case 28:
      if (lookahead == ':') ADVANCE(571);
      END_STATE();
    case 29:
      if (lookahead == ':') ADVANCE(573);
      END_STATE();
    case 30:
      if (lookahead == ':') ADVANCE(573);
      if (lookahead == 'e') ADVANCE(388);
      if (lookahead == 'r') ADVANCE(362);
      END_STATE();
    case 31:
      if (lookahead == ':') ADVANCE(546);
      END_STATE();
    case 32:
      if (lookahead == ':') ADVANCE(542);
      END_STATE();
    case 33:
      if (lookahead == ':') ADVANCE(570);
      END_STATE();
    case 34:
      if (lookahead == ':') ADVANCE(563);
      END_STATE();
    case 35:
      if (lookahead == ':') ADVANCE(611);
      END_STATE();
    case 36:
      if (lookahead == ':') ADVANCE(562);
      END_STATE();
    case 37:
      if (lookahead == ':') ADVANCE(532);
      END_STATE();
    case 38:
      if (lookahead == ':') ADVANCE(513);
      END_STATE();
    case 39:
      if (lookahead == ':') ADVANCE(513);
      if (lookahead == 't') ADVANCE(195);
      END_STATE();
    case 40:
      if (lookahead == ':') ADVANCE(491);
      END_STATE();
    case 41:
      if (lookahead == ':') ADVANCE(520);
      END_STATE();
    case 42:
      if (lookahead == ':') ADVANCE(564);
      END_STATE();
    case 43:
      if (lookahead == ':') ADVANCE(528);
      END_STATE();
    case 44:
      if (lookahead == ':') ADVANCE(508);
      END_STATE();
    case 45:
      if (lookahead == ':') ADVANCE(508);
      if (lookahead == 'b') ADVANCE(305);
      END_STATE();
    case 46:
      if (lookahead == ':') ADVANCE(613);
      END_STATE();
    case 47:
      if (lookahead == ':') ADVANCE(603);
      END_STATE();
    case 48:
      if (lookahead == ':') ADVANCE(605);
      END_STATE();
    case 49:
      if (lookahead == ':') ADVANCE(499);
      if (lookahead == 'i') ADVANCE(480);
      END_STATE();
    case 50:
      if (lookahead == ':') ADVANCE(604);
      END_STATE();
    case 51:
      if (lookahead == ':') ADVANCE(507);
      END_STATE();
    case 52:
      if (lookahead == ':') ADVANCE(507);
      if (lookahead == 'b') ADVANCE(316);
      END_STATE();
    case 53:
      if (lookahead == ':') ADVANCE(600);
      END_STATE();
    case 54:
      if (lookahead == ':') ADVANCE(575);
      END_STATE();
    case 55:
      if (lookahead == ':') ADVANCE(614);
      END_STATE();
    case 56:
      if (lookahead == ':') ADVANCE(572);
      END_STATE();
    case 57:
      if (lookahead == ':') ADVANCE(576);
      END_STATE();
    case 58:
      if (lookahead == ':') ADVANCE(595);
      END_STATE();
    case 59:
      if (lookahead == ':') ADVANCE(561);
      END_STATE();
    case 60:
      if (lookahead == ':') ADVANCE(567);
      END_STATE();
    case 61:
      if (lookahead == ':') ADVANCE(569);
      END_STATE();
    case 62:
      if (lookahead == ':') ADVANCE(574);
      END_STATE();
    case 63:
      if (lookahead == ':') ADVANCE(598);
      END_STATE();
    case 64:
      if (lookahead == ':') ADVANCE(599);
      END_STATE();
    case 65:
      if (lookahead == ':') ADVANCE(584);
      END_STATE();
    case 66:
      if (lookahead == ':') ADVANCE(606);
      END_STATE();
    case 67:
      if (lookahead == ':') ADVANCE(501);
      END_STATE();
    case 68:
      if (lookahead == ':') ADVANCE(502);
      END_STATE();
    case 69:
      if (lookahead == ':') ADVANCE(587);
      END_STATE();
    case 70:
      if (lookahead == ':') ADVANCE(560);
      END_STATE();
    case 71:
      if (lookahead == ':') ADVANCE(615);
      END_STATE();
    case 72:
      if (lookahead == ':') ADVANCE(539);
      END_STATE();
    case 73:
      if (lookahead == ':') ADVANCE(541);
      END_STATE();
    case 74:
      if (lookahead == ':') ADVANCE(540);
      END_STATE();
    case 75:
      if (lookahead == ':') ADVANCE(602);
      END_STATE();
    case 76:
      if (lookahead == ':') ADVANCE(612);
      END_STATE();
    case 77:
      if (lookahead == ':') ADVANCE(566);
      END_STATE();
    case 78:
      if (lookahead == ':') ADVANCE(558);
      END_STATE();
    case 79:
      if (lookahead == ':') ADVANCE(578);
      END_STATE();
    case 80:
      if (lookahead == ':') ADVANCE(547);
      END_STATE();
    case 81:
      if (lookahead == ':') ADVANCE(565);
      END_STATE();
    case 82:
      if (lookahead == ':') ADVANCE(608);
      END_STATE();
    case 83:
      if (lookahead == ':') ADVANCE(585);
      END_STATE();
    case 84:
      if (lookahead == ':') ADVANCE(589);
      END_STATE();
    case 85:
      if (lookahead == ':') ADVANCE(591);
      END_STATE();
    case 86:
      if (lookahead == ':') ADVANCE(607);
      END_STATE();
    case 87:
      if (lookahead == ':') ADVANCE(498);
      END_STATE();
    case 88:
      if (lookahead == ':') ADVANCE(582);
      END_STATE();
    case 89:
      if (lookahead == ':') ADVANCE(609);
      END_STATE();
    case 90:
      if (lookahead == ':') ADVANCE(583);
      END_STATE();
    case 91:
      if (lookahead == ':') ADVANCE(601);
      END_STATE();
    case 92:
      if (lookahead == ':') ADVANCE(590);
      END_STATE();
    case 93:
      if (lookahead == ':') ADVANCE(559);
      END_STATE();
    case 94:
      if (lookahead == ':') ADVANCE(596);
      END_STATE();
    case 95:
      if (lookahead == ':') ADVANCE(577);
      END_STATE();
    case 96:
      if (lookahead == ':') ADVANCE(489);
      END_STATE();
    case 97:
      if (lookahead == ':') ADVANCE(610);
      END_STATE();
    case 98:
      if (lookahead == ':') ADVANCE(518);
      END_STATE();
    case 99:
      if (lookahead == ':') ADVANCE(568);
      END_STATE();
    case 100:
      if (lookahead == ':') ADVANCE(497);
      END_STATE();
    case 101:
      if (lookahead == ':') ADVANCE(496);
      END_STATE();
    case 102:
      if (lookahead == ':') ADVANCE(580);
      END_STATE();
    case 103:
      if (lookahead == ':') ADVANCE(581);
      END_STATE();
    case 104:
      if (lookahead == ':') ADVANCE(488);
      END_STATE();
    case 105:
      if (lookahead == ':') ADVANCE(486);
      END_STATE();
    case 106:
      if (lookahead == ':') ADVANCE(579);
      END_STATE();
    case 107:
      if (lookahead == ':') ADVANCE(484);
      END_STATE();
    case 108:
      if (lookahead == ':') ADVANCE(592);
      END_STATE();
    case 109:
      if (lookahead == ':') ADVANCE(597);
      END_STATE();
    case 110:
      if (lookahead == ':') ADVANCE(588);
      END_STATE();
    case 111:
      if (lookahead == ':') ADVANCE(490);
      END_STATE();
    case 112:
      if (lookahead == ':') ADVANCE(593);
      END_STATE();
    case 113:
      if (lookahead == ':') ADVANCE(594);
      END_STATE();
    case 114:
      if (lookahead == '`') ADVANCE(495);
      END_STATE();
    case 115:
      if (lookahead == 'a') ADVANCE(296);
      END_STATE();
    case 116:
      if (lookahead == 'a') ADVANCE(389);
      if (lookahead == 'i') ADVANCE(444);
      if (lookahead == 'l') ADVANCE(124);
      if (lookahead == 'o') ADVANCE(177);
      END_STATE();
    case 117:
      if (lookahead == 'a') ADVANCE(152);
      if (lookahead == 'e') ADVANCE(321);
      END_STATE();
    case 118:
      if (lookahead == 'a') ADVANCE(334);
      if (lookahead == 's') ADVANCE(158);
      END_STATE();
    case 119:
      if (lookahead == 'a') ADVANCE(330);
      if (lookahead == 'e') ADVANCE(470);
      if (lookahead == 'o') ADVANCE(349);
      END_STATE();
    case 120:
      if (lookahead == 'a') ADVANCE(395);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(320);
      END_STATE();
    case 122:
      if (lookahead == 'a') ADVANCE(246);
      END_STATE();
    case 123:
      if (lookahead == 'a') ADVANCE(390);
      END_STATE();
    case 124:
      if (lookahead == 'a') ADVANCE(266);
      END_STATE();
    case 125:
      if (lookahead == 'a') ADVANCE(409);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(384);
      END_STATE();
    case 127:
      if (lookahead == 'a') ADVANCE(168);
      END_STATE();
    case 128:
      if (lookahead == 'a') ADVANCE(280);
      if (lookahead == 'p') ADVANCE(249);
      END_STATE();
    case 129:
      ADVANCE_MAP(
        'a', 413,
        'c', 145,
        'd', 223,
        'l', 201,
        'm', 132,
        'n', 185,
        'p', 264,
        'q', 194,
        'r', 221,
        's', 383,
        't', 254,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 130:
      ADVANCE_MAP(
        'a', 413,
        'c', 145,
        'd', 223,
        'l', 201,
        'm', 133,
        'n', 185,
        'p', 264,
        'q', 194,
        'r', 221,
        's', 383,
        't', 254,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(408);
      END_STATE();
    case 132:
      if (lookahead == 'a') ADVANCE(446);
      END_STATE();
    case 133:
      if (lookahead == 'a') ADVANCE(430);
      END_STATE();
    case 134:
      if (lookahead == 'a') ADVANCE(65);
      END_STATE();
    case 135:
      ADVANCE_MAP(
        'a', 156,
        'b', 355,
        'd', 31,
        'h', 190,
        'i', 450,
        'o', 162,
        'r', 32,
        'y', 386,
      );
      END_STATE();
    case 136:
      if (lookahead == 'a') ADVANCE(235);
      END_STATE();
    case 137:
      if (lookahead == 'a') ADVANCE(337);
      END_STATE();
    case 138:
      if (lookahead == 'a') ADVANCE(179);
      if (lookahead == 'n') ADVANCE(59);
      if (lookahead == 'o') ADVANCE(405);
      END_STATE();
    case 139:
      if (lookahead == 'a') ADVANCE(303);
      END_STATE();
    case 140:
      if (lookahead == 'a') ADVANCE(310);
      END_STATE();
    case 141:
      if (lookahead == 'a') ADVANCE(420);
      END_STATE();
    case 142:
      if (lookahead == 'a') ADVANCE(281);
      END_STATE();
    case 143:
      if (lookahead == 'a') ADVANCE(406);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(445);
      if (lookahead == 'e') ADVANCE(234);
      if (lookahead == 'r') ADVANCE(136);
      END_STATE();
    case 145:
      if (lookahead == 'a') ADVANCE(417);
      if (lookahead == 'i') ADVANCE(444);
      if (lookahead == 'l') ADVANCE(124);
      if (lookahead == 'o') ADVANCE(182);
      END_STATE();
    case 146:
      if (lookahead == 'a') ADVANCE(449);
      END_STATE();
    case 147:
      if (lookahead == 'a') ADVANCE(454);
      END_STATE();
    case 148:
      if (lookahead == 'b') ADVANCE(415);
      if (lookahead == 'f') ADVANCE(233);
      if (lookahead == 'l') ADVANCE(242);
      if (lookahead == 'p') ADVANCE(385);
      if (lookahead == 's') ADVANCE(425);
      if (lookahead == 'u') ADVANCE(443);
      END_STATE();
    case 149:
      if (lookahead == 'b') ADVANCE(308);
      END_STATE();
    case 150:
      if (lookahead == 'b') ADVANCE(412);
      if (lookahead == 'f') ADVANCE(236);
      if (lookahead == 'p') ADVANCE(387);
      END_STATE();
    case 151:
      if (lookahead == 'b') ADVANCE(300);
      END_STATE();
    case 152:
      if (lookahead == 'b') ADVANCE(224);
      if (lookahead == 'n') ADVANCE(243);
      END_STATE();
    case 153:
      if (lookahead == 'b') ADVANCE(196);
      END_STATE();
    case 154:
      if (lookahead == 'b') ADVANCE(424);
      END_STATE();
    case 155:
      if (lookahead == 'b') ADVANCE(418);
      END_STATE();
    case 156:
      if (lookahead == 'b') ADVANCE(311);
      END_STATE();
    case 157:
      if (lookahead == 'c') ADVANCE(292);
      END_STATE();
    case 158:
      if (lookahead == 'c') ADVANCE(35);
      END_STATE();
    case 159:
      if (lookahead == 'c') ADVANCE(314);
      END_STATE();
    case 160:
      if (lookahead == 'c') ADVANCE(140);
      if (lookahead == 'e') ADVANCE(170);
      if (lookahead == 'k') ADVANCE(200);
      if (lookahead == 'p') ADVANCE(137);
      if (lookahead == 't') ADVANCE(30);
      if (lookahead == 'u') ADVANCE(150);
      END_STATE();
    case 161:
      if (lookahead == 'c') ADVANCE(353);
      if (lookahead == 's') ADVANCE(159);
      if (lookahead == 't') ADVANCE(198);
      END_STATE();
    case 162:
      if (lookahead == 'c') ADVANCE(40);
      END_STATE();
    case 163:
      if (lookahead == 'c') ADVANCE(403);
      END_STATE();
    case 164:
      if (lookahead == 'c') ADVANCE(255);
      END_STATE();
    case 165:
      if (lookahead == 'c') ADVANCE(226);
      END_STATE();
    case 166:
      if (lookahead == 'c') ADVANCE(294);
      END_STATE();
    case 167:
      if (lookahead == 'c') ADVANCE(304);
      END_STATE();
    case 168:
      if (lookahead == 'c') ADVANCE(441);
      END_STATE();
    case 169:
      if (lookahead == 'c') ADVANCE(295);
      END_STATE();
    case 170:
      if (lookahead == 'c') ADVANCE(451);
      END_STATE();
    case 171:
      if (lookahead == 'c') ADVANCE(453);
      END_STATE();
    case 172:
      if (lookahead == 'c') ADVANCE(456);
      END_STATE();
    case 173:
      if (lookahead == 'c') ADVANCE(457);
      END_STATE();
    case 174:
      if (lookahead == 'd') ADVANCE(31);
      if (lookahead == 'h') ADVANCE(227);
      END_STATE();
    case 175:
      if (lookahead == 'd') ADVANCE(477);
      END_STATE();
    case 176:
      if (lookahead == 'd') ADVANCE(37);
      END_STATE();
    case 177:
      if (lookahead == 'd') ADVANCE(192);
      if (lookahead == 'r') ADVANCE(366);
      END_STATE();
    case 178:
      if (lookahead == 'd') ADVANCE(277);
      END_STATE();
    case 179:
      if (lookahead == 'd') ADVANCE(74);
      END_STATE();
    case 180:
      if (lookahead == 'd') ADVANCE(275);
      END_STATE();
    case 181:
      if (lookahead == 'd') ADVANCE(421);
      END_STATE();
    case 182:
      if (lookahead == 'd') ADVANCE(220);
      END_STATE();
    case 183:
      if (lookahead == 'e') ADVANCE(120);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(476);
      END_STATE();
    case 185:
      if (lookahead == 'e') ADVANCE(470);
      if (lookahead == 'o') ADVANCE(447);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(231);
      END_STATE();
    case 187:
      if (lookahead == 'e') ADVANCE(553);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(468);
      if (lookahead == 'o') ADVANCE(358);
      END_STATE();
    case 189:
      if (lookahead == 'e') ADVANCE(468);
      if (lookahead == 'o') ADVANCE(469);
      END_STATE();
    case 190:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 191:
      if (lookahead == 'e') ADVANCE(549);
      END_STATE();
    case 192:
      if (lookahead == 'e') ADVANCE(45);
      END_STATE();
    case 193:
      if (lookahead == 'e') ADVANCE(473);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(176);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(475);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(395);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(347);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(318);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(435);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(433);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(42);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(43);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(46);
      END_STATE();
    case 205:
      if (lookahead == 'e') ADVANCE(53);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(54);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 208:
      if (lookahead == 'e') ADVANCE(71);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(72);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(77);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(78);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 214:
      if (lookahead == 'e') ADVANCE(81);
      if (lookahead == 'i') ADVANCE(452);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(88);
      END_STATE();
    case 217:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 220:
      if (lookahead == 'e') ADVANCE(44);
      END_STATE();
    case 221:
      if (lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 222:
      if (lookahead == 'e') ADVANCE(401);
      END_STATE();
    case 223:
      if (lookahead == 'e') ADVANCE(237);
      if (lookahead == 'r') ADVANCE(136);
      END_STATE();
    case 224:
      if (lookahead == 'e') ADVANCE(307);
      END_STATE();
    case 225:
      if (lookahead == 'e') ADVANCE(328);
      END_STATE();
    case 226:
      if (lookahead == 'e') ADVANCE(423);
      END_STATE();
    case 227:
      if (lookahead == 'e') ADVANCE(338);
      END_STATE();
    case 228:
      if (lookahead == 'e') ADVANCE(171);
      if (lookahead == 'u') ADVANCE(154);
      END_STATE();
    case 229:
      if (lookahead == 'e') ADVANCE(172);
      if (lookahead == 'u') ADVANCE(155);
      END_STATE();
    case 230:
      if (lookahead == 'e') ADVANCE(173);
      END_STATE();
    case 231:
      if (lookahead == 'f') ADVANCE(39);
      if (lookahead == 'm') ADVANCE(125);
      END_STATE();
    case 232:
      if (lookahead == 'f') ADVANCE(429);
      END_STATE();
    case 233:
      if (lookahead == 'f') ADVANCE(278);
      END_STATE();
    case 234:
      if (lookahead == 'f') ADVANCE(265);
      END_STATE();
    case 235:
      if (lookahead == 'f') ADVANCE(439);
      END_STATE();
    case 236:
      if (lookahead == 'f') ADVANCE(269);
      END_STATE();
    case 237:
      if (lookahead == 'f') ADVANCE(270);
      END_STATE();
    case 238:
      if (lookahead == 'f') ADVANCE(69);
      END_STATE();
    case 239:
      if (lookahead == 'f') ADVANCE(38);
      END_STATE();
    case 240:
      if (lookahead == 'f') ADVANCE(236);
      if (lookahead == 'p') ADVANCE(387);
      END_STATE();
    case 241:
      if (lookahead == 'g') ADVANCE(462);
      END_STATE();
    case 242:
      if (lookahead == 'g') ADVANCE(360);
      END_STATE();
    case 243:
      if (lookahead == 'g') ADVANCE(50);
      END_STATE();
    case 244:
      if (lookahead == 'g') ADVANCE(60);
      END_STATE();
    case 245:
      if (lookahead == 'g') ADVANCE(86);
      END_STATE();
    case 246:
      if (lookahead == 'g') ADVANCE(402);
      END_STATE();
    case 247:
      if (lookahead == 'g') ADVANCE(404);
      END_STATE();
    case 248:
      if (lookahead == 'h') ADVANCE(52);
      END_STATE();
    case 249:
      if (lookahead == 'h') ADVANCE(141);
      END_STATE();
    case 250:
      if (lookahead == 'h') ADVANCE(196);
      END_STATE();
    case 251:
      if (lookahead == 'h') ADVANCE(357);
      END_STATE();
    case 252:
      if (lookahead == 'h') ADVANCE(368);
      END_STATE();
    case 253:
      if (lookahead == 'h') ADVANCE(55);
      END_STATE();
    case 254:
      if (lookahead == 'h') ADVANCE(227);
      END_STATE();
    case 255:
      if (lookahead == 'h') ADVANCE(85);
      END_STATE();
    case 256:
      if (lookahead == 'h') ADVANCE(105);
      END_STATE();
    case 257:
      if (lookahead == 'h') ADVANCE(51);
      END_STATE();
    case 258:
      if (lookahead == 'h') ADVANCE(479);
      END_STATE();
    case 259:
      if (lookahead == 'h') ADVANCE(329);
      END_STATE();
    case 260:
      if (lookahead == 'i') ADVANCE(553);
      END_STATE();
    case 261:
      if (lookahead == 'i') ADVANCE(149);
      END_STATE();
    case 262:
      if (lookahead == 'i') ADVANCE(241);
      END_STATE();
    case 263:
      if (lookahead == 'i') ADVANCE(434);
      END_STATE();
    case 264:
      if (lookahead == 'i') ADVANCE(157);
      if (lookahead == 'r') ADVANCE(189);
      END_STATE();
    case 265:
      if (lookahead == 'i') ADVANCE(333);
      END_STATE();
    case 266:
      if (lookahead == 'i') ADVANCE(325);
      END_STATE();
    case 267:
      if (lookahead == 'i') ADVANCE(414);
      END_STATE();
    case 268:
      if (lookahead == 'i') ADVANCE(391);
      END_STATE();
    case 269:
      if (lookahead == 'i') ADVANCE(165);
      END_STATE();
    case 270:
      if (lookahead == 'i') ADVANCE(350);
      END_STATE();
    case 271:
      if (lookahead == 'i') ADVANCE(436);
      END_STATE();
    case 272:
      if (lookahead == 'i') ADVANCE(147);
      END_STATE();
    case 273:
      if (lookahead == 'i') ADVANCE(364);
      END_STATE();
    case 274:
      if (lookahead == 'i') ADVANCE(381);
      END_STATE();
    case 275:
      if (lookahead == 'i') ADVANCE(437);
      END_STATE();
    case 276:
      if (lookahead == 'i') ADVANCE(167);
      END_STATE();
    case 277:
      if (lookahead == 'i') ADVANCE(474);
      END_STATE();
    case 278:
      if (lookahead == 'i') ADVANCE(301);
      END_STATE();
    case 279:
      if (lookahead == 'i') ADVANCE(373);
      END_STATE();
    case 280:
      if (lookahead == 'i') ADVANCE(306);
      END_STATE();
    case 281:
      if (lookahead == 'i') ADVANCE(327);
      END_STATE();
    case 282:
      if (lookahead == 'i') ADVANCE(374);
      END_STATE();
    case 283:
      if (lookahead == 'i') ADVANCE(448);
      END_STATE();
    case 284:
      if (lookahead == 'i') ADVANCE(375);
      END_STATE();
    case 285:
      if (lookahead == 'i') ADVANCE(376);
      END_STATE();
    case 286:
      if (lookahead == 'i') ADVANCE(377);
      END_STATE();
    case 287:
      if (lookahead == 'i') ADVANCE(378);
      END_STATE();
    case 288:
      if (lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 289:
      if (lookahead == 'i') ADVANCE(380);
      END_STATE();
    case 290:
      if (lookahead == 'i') ADVANCE(455);
      END_STATE();
    case 291:
      if (lookahead == 'k') ADVANCE(549);
      END_STATE();
    case 292:
      if (lookahead == 'k') ADVANCE(56);
      END_STATE();
    case 293:
      if (lookahead == 'k') ADVANCE(84);
      END_STATE();
    case 294:
      if (lookahead == 'k') ADVANCE(101);
      END_STATE();
    case 295:
      if (lookahead == 'k') ADVANCE(104);
      END_STATE();
    case 296:
      if (lookahead == 'l') ADVANCE(553);
      END_STATE();
    case 297:
      if (lookahead == 'l') ADVANCE(309);
      END_STATE();
    case 298:
      if (lookahead == 'l') ADVANCE(371);
      if (lookahead == 'r') ADVANCE(283);
      END_STATE();
    case 299:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 300:
      if (lookahead == 'l') ADVANCE(267);
      END_STATE();
    case 301:
      if (lookahead == 'l') ADVANCE(272);
      END_STATE();
    case 302:
      if (lookahead == 'l') ADVANCE(187);
      END_STATE();
    case 303:
      if (lookahead == 'l') ADVANCE(47);
      END_STATE();
    case 304:
      if (lookahead == 'l') ADVANCE(191);
      END_STATE();
    case 305:
      if (lookahead == 'l') ADVANCE(372);
      END_STATE();
    case 306:
      if (lookahead == 'l') ADVANCE(63);
      END_STATE();
    case 307:
      if (lookahead == 'l') ADVANCE(64);
      END_STATE();
    case 308:
      if (lookahead == 'l') ADVANCE(274);
      if (lookahead == 't') ADVANCE(193);
      END_STATE();
    case 309:
      if (lookahead == 'l') ADVANCE(131);
      END_STATE();
    case 310:
      if (lookahead == 'l') ADVANCE(208);
      END_STATE();
    case 311:
      if (lookahead == 'l') ADVANCE(209);
      END_STATE();
    case 312:
      if (lookahead == 'l') ADVANCE(210);
      END_STATE();
    case 313:
      if (lookahead == 'l') ADVANCE(216);
      END_STATE();
    case 314:
      if (lookahead == 'l') ADVANCE(142);
      END_STATE();
    case 315:
      if (lookahead == 'l') ADVANCE(465);
      END_STATE();
    case 316:
      if (lookahead == 'l') ADVANCE(382);
      END_STATE();
    case 317:
      if (lookahead == 'm') ADVANCE(128);
      if (lookahead == 'n') ADVANCE(463);
      if (lookahead == 'x') ADVANCE(121);
      END_STATE();
    case 318:
      if (lookahead == 'm') ADVANCE(49);
      END_STATE();
    case 319:
      if (lookahead == 'm') ADVANCE(153);
      END_STATE();
    case 320:
      if (lookahead == 'm') ADVANCE(392);
      END_STATE();
    case 321:
      if (lookahead == 'm') ADVANCE(322);
      if (lookahead == 't') ADVANCE(34);
      END_STATE();
    case 322:
      if (lookahead == 'm') ADVANCE(134);
      END_STATE();
    case 323:
      if (lookahead == 'm') ADVANCE(187);
      END_STATE();
    case 324:
      if (lookahead == 'm') ADVANCE(222);
      END_STATE();
    case 325:
      if (lookahead == 'm') ADVANCE(61);
      END_STATE();
    case 326:
      if (lookahead == 'm') ADVANCE(66);
      END_STATE();
    case 327:
      if (lookahead == 'm') ADVANCE(89);
      END_STATE();
    case 328:
      if (lookahead == 'm') ADVANCE(94);
      END_STATE();
    case 329:
      if (lookahead == 'm') ADVANCE(100);
      END_STATE();
    case 330:
      if (lookahead == 'm') ADVANCE(205);
      END_STATE();
    case 331:
      if (lookahead == 'm') ADVANCE(212);
      END_STATE();
    case 332:
      if (lookahead == 'n') ADVANCE(553);
      END_STATE();
    case 333:
      if (lookahead == 'n') ADVANCE(214);
      END_STATE();
    case 334:
      if (lookahead == 'n') ADVANCE(461);
      if (lookahead == 't') ADVANCE(248);
      END_STATE();
    case 335:
      if (lookahead == 'n') ADVANCE(115);
      END_STATE();
    case 336:
      if (lookahead == 'n') ADVANCE(48);
      END_STATE();
    case 337:
      if (lookahead == 'n') ADVANCE(57);
      END_STATE();
    case 338:
      if (lookahead == 'n') ADVANCE(59);
      END_STATE();
    case 339:
      if (lookahead == 'n') ADVANCE(87);
      END_STATE();
    case 340:
      if (lookahead == 'n') ADVANCE(92);
      END_STATE();
    case 341:
      if (lookahead == 'n') ADVANCE(106);
      END_STATE();
    case 342:
      if (lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 343:
      if (lookahead == 'n') ADVANCE(109);
      END_STATE();
    case 344:
      if (lookahead == 'n') ADVANCE(110);
      END_STATE();
    case 345:
      if (lookahead == 'n') ADVANCE(112);
      END_STATE();
    case 346:
      if (lookahead == 'n') ADVANCE(113);
      END_STATE();
    case 347:
      if (lookahead == 'n') ADVANCE(178);
      END_STATE();
    case 348:
      if (lookahead == 'n') ADVANCE(245);
      END_STATE();
    case 349:
      if (lookahead == 'n') ADVANCE(464);
      if (lookahead == 't') ADVANCE(206);
      END_STATE();
    case 350:
      if (lookahead == 'n') ADVANCE(213);
      END_STATE();
    case 351:
      if (lookahead == 'o') ADVANCE(232);
      END_STATE();
    case 352:
      if (lookahead == 'o') ADVANCE(291);
      END_STATE();
    case 353:
      if (lookahead == 'o') ADVANCE(336);
      END_STATE();
    case 354:
      if (lookahead == 'o') ADVANCE(315);
      END_STATE();
    case 355:
      if (lookahead == 'o') ADVANCE(175);
      END_STATE();
    case 356:
      if (lookahead == 'o') ADVANCE(460);
      END_STATE();
    case 357:
      if (lookahead == 'o') ADVANCE(395);
      END_STATE();
    case 358:
      if (lookahead == 'o') ADVANCE(238);
      if (lookahead == 'p') ADVANCE(367);
      if (lookahead == 'v') ADVANCE(207);
      END_STATE();
    case 359:
      if (lookahead == 'o') ADVANCE(260);
      END_STATE();
    case 360:
      if (lookahead == 'o') ADVANCE(410);
      END_STATE();
    case 361:
      if (lookahead == 'o') ADVANCE(139);
      END_STATE();
    case 362:
      if (lookahead == 'o') ADVANCE(348);
      END_STATE();
    case 363:
      if (lookahead == 'o') ADVANCE(466);
      END_STATE();
    case 364:
      if (lookahead == 'o') ADVANCE(332);
      END_STATE();
    case 365:
      if (lookahead == 'o') ADVANCE(352);
      END_STATE();
    case 366:
      if (lookahead == 'o') ADVANCE(297);
      END_STATE();
    case 367:
      if (lookahead == 'o') ADVANCE(427);
      END_STATE();
    case 368:
      if (lookahead == 'o') ADVANCE(407);
      END_STATE();
    case 369:
      if (lookahead == 'o') ADVANCE(426);
      END_STATE();
    case 370:
      if (lookahead == 'o') ADVANCE(398);
      END_STATE();
    case 371:
      if (lookahead == 'o') ADVANCE(244);
      END_STATE();
    case 372:
      if (lookahead == 'o') ADVANCE(166);
      END_STATE();
    case 373:
      if (lookahead == 'o') ADVANCE(339);
      END_STATE();
    case 374:
      if (lookahead == 'o') ADVANCE(340);
      END_STATE();
    case 375:
      if (lookahead == 'o') ADVANCE(341);
      END_STATE();
    case 376:
      if (lookahead == 'o') ADVANCE(342);
      END_STATE();
    case 377:
      if (lookahead == 'o') ADVANCE(343);
      END_STATE();
    case 378:
      if (lookahead == 'o') ADVANCE(344);
      END_STATE();
    case 379:
      if (lookahead == 'o') ADVANCE(345);
      END_STATE();
    case 380:
      if (lookahead == 'o') ADVANCE(346);
      END_STATE();
    case 381:
      if (lookahead == 'o') ADVANCE(247);
      END_STATE();
    case 382:
      if (lookahead == 'o') ADVANCE(169);
      END_STATE();
    case 383:
      if (lookahead == 'p') ADVANCE(137);
      if (lookahead == 't') ADVANCE(29);
      if (lookahead == 'u') ADVANCE(240);
      END_STATE();
    case 384:
      if (lookahead == 'p') ADVANCE(258);
      END_STATE();
    case 385:
      if (lookahead == 'p') ADVANCE(197);
      END_STATE();
    case 386:
      if (lookahead == 'p') ADVANCE(199);
      END_STATE();
    case 387:
      if (lookahead == 'p') ADVANCE(369);
      END_STATE();
    case 388:
      if (lookahead == 'p') ADVANCE(58);
      END_STATE();
    case 389:
      if (lookahead == 'p') ADVANCE(438);
      if (lookahead == 's') ADVANCE(202);
      END_STATE();
    case 390:
      if (lookahead == 'p') ADVANCE(256);
      END_STATE();
    case 391:
      if (lookahead == 'p') ADVANCE(442);
      END_STATE();
    case 392:
      if (lookahead == 'p') ADVANCE(313);
      END_STATE();
    case 393:
      if (lookahead == 'r') ADVANCE(432);
      if (lookahead == 'u') ADVANCE(428);
      END_STATE();
    case 394:
      if (lookahead == 'r') ADVANCE(296);
      END_STATE();
    case 395:
      if (lookahead == 'r') ADVANCE(553);
      END_STATE();
    case 396:
      if (lookahead == 'r') ADVANCE(335);
      END_STATE();
    case 397:
      if (lookahead == 'r') ADVANCE(299);
      END_STATE();
    case 398:
      if (lookahead == 'r') ADVANCE(181);
      END_STATE();
    case 399:
      if (lookahead == 'r') ADVANCE(122);
      if (lookahead == 't') ADVANCE(253);
      END_STATE();
    case 400:
      if (lookahead == 'r') ADVANCE(127);
      END_STATE();
    case 401:
      if (lookahead == 'r') ADVANCE(146);
      END_STATE();
    case 402:
      if (lookahead == 'r') ADVANCE(123);
      END_STATE();
    case 403:
      if (lookahead == 'r') ADVANCE(268);
      END_STATE();
    case 404:
      if (lookahead == 'r') ADVANCE(126);
      END_STATE();
    case 405:
      if (lookahead == 'r') ADVANCE(225);
      END_STATE();
    case 406:
      if (lookahead == 'r') ADVANCE(191);
      END_STATE();
    case 407:
      if (lookahead == 'r') ADVANCE(79);
      END_STATE();
    case 408:
      if (lookahead == 'r') ADVANCE(478);
      END_STATE();
    case 409:
      if (lookahead == 'r') ADVANCE(293);
      END_STATE();
    case 410:
      if (lookahead == 'r') ADVANCE(271);
      END_STATE();
    case 411:
      if (lookahead == 'r') ADVANCE(215);
      END_STATE();
    case 412:
      if (lookahead == 's') ADVANCE(228);
      END_STATE();
    case 413:
      if (lookahead == 's') ADVANCE(425);
      END_STATE();
    case 414:
      if (lookahead == 's') ADVANCE(250);
      END_STATE();
    case 415:
      if (lookahead == 's') ADVANCE(431);
      END_STATE();
    case 416:
      if (lookahead == 's') ADVANCE(163);
      END_STATE();
    case 417:
      if (lookahead == 's') ADVANCE(202);
      END_STATE();
    case 418:
      if (lookahead == 's') ADVANCE(230);
      END_STATE();
    case 419:
      if (lookahead == 's') ADVANCE(76);
      END_STATE();
    case 420:
      if (lookahead == 's') ADVANCE(82);
      END_STATE();
    case 421:
      if (lookahead == 's') ADVANCE(97);
      END_STATE();
    case 422:
      if (lookahead == 's') ADVANCE(98);
      END_STATE();
    case 423:
      if (lookahead == 's') ADVANCE(99);
      END_STATE();
    case 424:
      if (lookahead == 's') ADVANCE(229);
      END_STATE();
    case 425:
      if (lookahead == 's') ADVANCE(467);
      END_STATE();
    case 426:
      if (lookahead == 's') ADVANCE(218);
      END_STATE();
    case 427:
      if (lookahead == 's') ADVANCE(290);
      END_STATE();
    case 428:
      if (lookahead == 't') ADVANCE(251);
      END_STATE();
    case 429:
      if (lookahead == 't') ADVANCE(472);
      END_STATE();
    case 430:
      if (lookahead == 't') ADVANCE(248);
      END_STATE();
    case 431:
      if (lookahead == 't') ADVANCE(400);
      END_STATE();
    case 432:
      if (lookahead == 't') ADVANCE(276);
      END_STATE();
    case 433:
      if (lookahead == 't') ADVANCE(34);
      END_STATE();
    case 434:
      if (lookahead == 't') ADVANCE(302);
      END_STATE();
    case 435:
      if (lookahead == 't') ADVANCE(164);
      END_STATE();
    case 436:
      if (lookahead == 't') ADVANCE(259);
      END_STATE();
    case 437:
      if (lookahead == 't') ADVANCE(273);
      END_STATE();
    case 438:
      if (lookahead == 't') ADVANCE(279);
      END_STATE();
    case 439:
      if (lookahead == 't') ADVANCE(62);
      END_STATE();
    case 440:
      if (lookahead == 't') ADVANCE(91);
      END_STATE();
    case 441:
      if (lookahead == 't') ADVANCE(95);
      END_STATE();
    case 442:
      if (lookahead == 't') ADVANCE(107);
      END_STATE();
    case 443:
      if (lookahead == 't') ADVANCE(252);
      END_STATE();
    case 444:
      if (lookahead == 't') ADVANCE(203);
      END_STATE();
    case 445:
      if (lookahead == 't') ADVANCE(204);
      END_STATE();
    case 446:
      if (lookahead == 't') ADVANCE(257);
      END_STATE();
    case 447:
      if (lookahead == 't') ADVANCE(206);
      END_STATE();
    case 448:
      if (lookahead == 't') ADVANCE(211);
      END_STATE();
    case 449:
      if (lookahead == 't') ADVANCE(219);
      END_STATE();
    case 450:
      if (lookahead == 't') ADVANCE(312);
      END_STATE();
    case 451:
      if (lookahead == 't') ADVANCE(282);
      END_STATE();
    case 452:
      if (lookahead == 't') ADVANCE(284);
      END_STATE();
    case 453:
      if (lookahead == 't') ADVANCE(285);
      END_STATE();
    case 454:
      if (lookahead == 't') ADVANCE(286);
      END_STATE();
    case 455:
      if (lookahead == 't') ADVANCE(287);
      END_STATE();
    case 456:
      if (lookahead == 't') ADVANCE(288);
      END_STATE();
    case 457:
      if (lookahead == 't') ADVANCE(289);
      END_STATE();
    case 458:
      if (lookahead == 'u') ADVANCE(319);
      END_STATE();
    case 459:
      if (lookahead == 'u') ADVANCE(151);
      END_STATE();
    case 460:
      if (lookahead == 'u') ADVANCE(396);
      END_STATE();
    case 461:
      if (lookahead == 'u') ADVANCE(416);
      END_STATE();
    case 462:
      if (lookahead == 'u') ADVANCE(411);
      END_STATE();
    case 463:
      if (lookahead == 'u') ADVANCE(324);
      END_STATE();
    case 464:
      if (lookahead == 'u') ADVANCE(326);
      END_STATE();
    case 465:
      if (lookahead == 'u') ADVANCE(323);
      END_STATE();
    case 466:
      if (lookahead == 'u') ADVANCE(422);
      END_STATE();
    case 467:
      if (lookahead == 'u') ADVANCE(331);
      END_STATE();
    case 468:
      if (lookahead == 'v') ADVANCE(24);
      END_STATE();
    case 469:
      if (lookahead == 'v') ADVANCE(207);
      END_STATE();
    case 470:
      if (lookahead == 'w') ADVANCE(36);
      END_STATE();
    case 471:
      if (lookahead == 'w') ADVANCE(370);
      END_STATE();
    case 472:
      if (lookahead == 'w') ADVANCE(143);
      END_STATE();
    case 473:
      if (lookahead == 'x') ADVANCE(80);
      END_STATE();
    case 474:
      if (lookahead == 'x') ADVANCE(96);
      END_STATE();
    case 475:
      if (lookahead == 'x') ADVANCE(440);
      END_STATE();
    case 476:
      if (lookahead == 'y') ADVANCE(471);
      END_STATE();
    case 477:
      if (lookahead == 'y') ADVANCE(73);
      END_STATE();
    case 478:
      if (lookahead == 'y') ADVANCE(102);
      END_STATE();
    case 479:
      if (lookahead == 'y') ADVANCE(111);
      END_STATE();
    case 480:
      if (lookahead == 'z') ADVANCE(217);
      END_STATE();
    case 481:
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(527);
      END_STATE();
    case 482:
      if (eof) ADVANCE(483);
      ADVANCE_MAP(
        '#', 7,
        '$', 504,
        '%', 618,
        '*', 509,
        ',', 517,
        '/', 511,
        ':', 25,
        '`', 506,
        '}', 534,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(482);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_COLONmanuscript_COLON);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_COLONparagraph_COLON);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(aux_sym_mathblock_token1);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_COLONmathblock_COLON);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_COLONappendix_COLON);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_COLONbibliography_COLON);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_COLONtoc_COLON);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(aux_sym_specialblock_token1);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(aux_sym_specialblock_token2);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(aux_sym_specialblock_token3);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(aux_sym_specialblock_token4);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_COLONcodeblock_COLON);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_COLONalgorithm_COLON);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_COLONcaption_COLON);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_COLONitem_COLON);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_COLONprev_COLON);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_COLONprev2_COLON);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_COLONprev3_COLON);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(aux_sym_specialinline_token1);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(aux_sym_specialinline_token1);
      if (lookahead == '$') ADVANCE(487);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(aux_sym_specialinline_token2);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(aux_sym_specialinline_token2);
      if (lookahead == '`') ADVANCE(114);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_COLONmath_COLON);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_COLONcode_COLON);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(aux_sym_specialinline_token3);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(aux_sym_specialinline_token4);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_COLONref_COLON);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead == '\n') ADVANCE(516);
      if (lookahead == ',' ||
          lookahead == ':') ADVANCE(618);
      if (lookahead != 0) ADVANCE(514);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead == '%') ADVANCE(514);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(515);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(516);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(516);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_COLONprevious_COLON);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(aux_sym_specialinline_token6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(519);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_COLONurl_COLON);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == ':') ADVANCE(23);
      if (lookahead == 's') ADVANCE(522);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(527);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == ':') ADVANCE(23);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(527);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 'p') ADVANCE(521);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(527);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 't') ADVANCE(523);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(527);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 't') ADVANCE(524);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(527);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == ',' ||
          lookahead == ':') ADVANCE(618);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(526);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(527);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_COLONcite_COLON);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead == '\n') ADVANCE(531);
      if (lookahead == ':') ADVANCE(618);
      if (lookahead != 0) ADVANCE(529);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead == '%') ADVANCE(529);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(530);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(531);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(531);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_COLONqed_COLON);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(aux_sym_metaval_any_token1);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(aux_sym_metaval_any_token1);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(616);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(3);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(aux_sym_metaval_any_inline_token1);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(aux_sym_metaval_any_inline_token1);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(617);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_COLONtable_COLON);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_COLONthead_COLON);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_COLONtbody_COLON);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_COLONtr_COLON);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        ':', 485,
        'a', 148,
        'b', 261,
        'c', 116,
        'd', 144,
        'e', 317,
        'f', 262,
        'g', 361,
        'i', 161,
        'k', 184,
        'l', 117,
        'm', 118,
        'n', 119,
        'p', 27,
        'q', 194,
        'r', 186,
        's', 160,
        't', 135,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        ':', 485,
        'a', 413,
        'c', 145,
        'd', 223,
        'l', 201,
        'm', 132,
        'n', 185,
        'p', 264,
        'q', 194,
        'r', 221,
        's', 383,
        't', 254,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        'a', 413,
        'c', 145,
        'd', 223,
        'l', 201,
        'm', 132,
        'n', 185,
        'p', 264,
        'q', 194,
        'r', 221,
        's', 383,
        't', 254,
        'u', 397,
        'w', 298,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_COLONtd_COLON);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_COLONbibtex_COLON);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(aux_sym_bibitem_token1);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead == '\n') ADVANCE(552);
      if (lookahead == ',') ADVANCE(618);
      if (lookahead != 0) ADVANCE(550);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead == '%') ADVANCE(550);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(551);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(552);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(552);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(aux_sym_bibitempair_token1);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead == '\n') ADVANCE(557);
      if (lookahead == '}') ADVANCE(618);
      if (lookahead != 0) ADVANCE(555);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead == '%') ADVANCE(555);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(556);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(557);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(557);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_COLONassume_COLON);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_COLONsuppose_COLON);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_COLONprove_COLON);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_COLONthen_COLON);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_COLONnew_COLON);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_COLONlet_COLON);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_COLONcase_COLON);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_COLONdefine_COLON);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_COLONwrite_COLON);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_COLONwlog_COLON);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_COLONsuffices_COLON);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_COLONclaim_COLON);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_COLON_PIPE_DASH_COLON);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_COLONu22a2_COLON);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_COLONpick_COLON);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_COLONst_COLON);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_COLONdraft_COLON);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_COLONnote_COLON);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_COLONspan_COLON);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_COLONabstract_COLON);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_COLONauthor_COLON);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_COLONdefinition_COLON);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_COLONcorollary_COLON);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_COLONenumerate_COLON);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_COLONexample_COLON);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_COLONitemize_COLON);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_COLONlemma_COLON);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_COLONfigure_COLON);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_COLONp_COLON);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_COLONproof_COLON);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_COLONproposition_COLON);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_COLONremark_COLON);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_COLONsection_COLON);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_COLONsketch_COLON);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_COLONsubsection_COLON);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_COLONsubsubsection_COLON);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_COLONsubsubsubsection_COLON);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_COLONstep_COLON);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_COLONtheorem_COLON);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_COLONaffiliation_COLON);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_COLONemail_COLON);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_COLONlabel_COLON);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_COLONname_COLON);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_COLONreftext_COLON);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_COLONtitle_COLON);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_COLONgoal_COLON);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_COLONlang_COLON);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_COLONicon_COLON);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_COLONnonum_COLON);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym_COLONstrong_COLON);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_COLONemphas_COLON);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_COLONisclaim_COLON);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_COLONkeywords_COLON);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(anon_sym_COLONmsc_COLON);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(anon_sym_COLONtypes_COLON);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_COLONdate_COLON);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_COLONpath_COLON);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_COLONscale_COLON);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(535);
      if (lookahead != 0) ADVANCE(616);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(537);
      if (lookahead == ',' ||
          lookahead == '}') ADVANCE(618);
      if (lookahead != 0) ADVANCE(617);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(618);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 482},
  [2] = {.lex_state = 482, .external_lex_state = 2},
  [3] = {.lex_state = 482, .external_lex_state = 2},
  [4] = {.lex_state = 482, .external_lex_state = 2},
  [5] = {.lex_state = 482, .external_lex_state = 2},
  [6] = {.lex_state = 482, .external_lex_state = 2},
  [7] = {.lex_state = 482, .external_lex_state = 2},
  [8] = {.lex_state = 482, .external_lex_state = 2},
  [9] = {.lex_state = 482, .external_lex_state = 2},
  [10] = {.lex_state = 482, .external_lex_state = 2},
  [11] = {.lex_state = 482, .external_lex_state = 2},
  [12] = {.lex_state = 482, .external_lex_state = 2},
  [13] = {.lex_state = 482, .external_lex_state = 2},
  [14] = {.lex_state = 482, .external_lex_state = 2},
  [15] = {.lex_state = 482, .external_lex_state = 2},
  [16] = {.lex_state = 482, .external_lex_state = 2},
  [17] = {.lex_state = 482, .external_lex_state = 2},
  [18] = {.lex_state = 482, .external_lex_state = 2},
  [19] = {.lex_state = 482, .external_lex_state = 2},
  [20] = {.lex_state = 482, .external_lex_state = 2},
  [21] = {.lex_state = 482, .external_lex_state = 2},
  [22] = {.lex_state = 482, .external_lex_state = 2},
  [23] = {.lex_state = 482, .external_lex_state = 2},
  [24] = {.lex_state = 482, .external_lex_state = 2},
  [25] = {.lex_state = 482, .external_lex_state = 2},
  [26] = {.lex_state = 482, .external_lex_state = 2},
  [27] = {.lex_state = 482, .external_lex_state = 2},
  [28] = {.lex_state = 482, .external_lex_state = 2},
  [29] = {.lex_state = 482, .external_lex_state = 2},
  [30] = {.lex_state = 482, .external_lex_state = 2},
  [31] = {.lex_state = 482, .external_lex_state = 2},
  [32] = {.lex_state = 482, .external_lex_state = 2},
  [33] = {.lex_state = 482, .external_lex_state = 2},
  [34] = {.lex_state = 482, .external_lex_state = 2},
  [35] = {.lex_state = 482, .external_lex_state = 2},
  [36] = {.lex_state = 482, .external_lex_state = 2},
  [37] = {.lex_state = 482, .external_lex_state = 2},
  [38] = {.lex_state = 482, .external_lex_state = 2},
  [39] = {.lex_state = 482, .external_lex_state = 2},
  [40] = {.lex_state = 482, .external_lex_state = 2},
  [41] = {.lex_state = 482, .external_lex_state = 2},
  [42] = {.lex_state = 482, .external_lex_state = 2},
  [43] = {.lex_state = 482, .external_lex_state = 2},
  [44] = {.lex_state = 482, .external_lex_state = 2},
  [45] = {.lex_state = 482, .external_lex_state = 2},
  [46] = {.lex_state = 482, .external_lex_state = 2},
  [47] = {.lex_state = 482, .external_lex_state = 2},
  [48] = {.lex_state = 482, .external_lex_state = 2},
  [49] = {.lex_state = 482, .external_lex_state = 2},
  [50] = {.lex_state = 482, .external_lex_state = 2},
  [51] = {.lex_state = 482, .external_lex_state = 2},
  [52] = {.lex_state = 482, .external_lex_state = 2},
  [53] = {.lex_state = 482, .external_lex_state = 2},
  [54] = {.lex_state = 482, .external_lex_state = 2},
  [55] = {.lex_state = 482, .external_lex_state = 2},
  [56] = {.lex_state = 482, .external_lex_state = 2},
  [57] = {.lex_state = 482, .external_lex_state = 2},
  [58] = {.lex_state = 482, .external_lex_state = 2},
  [59] = {.lex_state = 482, .external_lex_state = 2},
  [60] = {.lex_state = 482, .external_lex_state = 2},
  [61] = {.lex_state = 482, .external_lex_state = 2},
  [62] = {.lex_state = 482, .external_lex_state = 2},
  [63] = {.lex_state = 482, .external_lex_state = 2},
  [64] = {.lex_state = 482, .external_lex_state = 2},
  [65] = {.lex_state = 13, .external_lex_state = 2},
  [66] = {.lex_state = 10, .external_lex_state = 2},
  [67] = {.lex_state = 10, .external_lex_state = 2},
  [68] = {.lex_state = 10, .external_lex_state = 2},
  [69] = {.lex_state = 10, .external_lex_state = 3},
  [70] = {.lex_state = 10, .external_lex_state = 3},
  [71] = {.lex_state = 10, .external_lex_state = 3},
  [72] = {.lex_state = 10, .external_lex_state = 3},
  [73] = {.lex_state = 10, .external_lex_state = 3},
  [74] = {.lex_state = 10, .external_lex_state = 3},
  [75] = {.lex_state = 10, .external_lex_state = 3},
  [76] = {.lex_state = 10, .external_lex_state = 3},
  [77] = {.lex_state = 10, .external_lex_state = 3},
  [78] = {.lex_state = 10, .external_lex_state = 3},
  [79] = {.lex_state = 10, .external_lex_state = 3},
  [80] = {.lex_state = 13, .external_lex_state = 2},
  [81] = {.lex_state = 10, .external_lex_state = 2},
  [82] = {.lex_state = 13, .external_lex_state = 2},
  [83] = {.lex_state = 10, .external_lex_state = 2},
  [84] = {.lex_state = 13, .external_lex_state = 2},
  [85] = {.lex_state = 13, .external_lex_state = 2},
  [86] = {.lex_state = 13, .external_lex_state = 2},
  [87] = {.lex_state = 13, .external_lex_state = 2},
  [88] = {.lex_state = 13, .external_lex_state = 2},
  [89] = {.lex_state = 13, .external_lex_state = 2},
  [90] = {.lex_state = 13, .external_lex_state = 2},
  [91] = {.lex_state = 13, .external_lex_state = 2},
  [92] = {.lex_state = 13, .external_lex_state = 2},
  [93] = {.lex_state = 10, .external_lex_state = 2},
  [94] = {.lex_state = 13, .external_lex_state = 2},
  [95] = {.lex_state = 14, .external_lex_state = 2},
  [96] = {.lex_state = 13, .external_lex_state = 2},
  [97] = {.lex_state = 14, .external_lex_state = 2},
  [98] = {.lex_state = 13, .external_lex_state = 2},
  [99] = {.lex_state = 13, .external_lex_state = 2},
  [100] = {.lex_state = 13, .external_lex_state = 2},
  [101] = {.lex_state = 13, .external_lex_state = 2},
  [102] = {.lex_state = 13, .external_lex_state = 2},
  [103] = {.lex_state = 13, .external_lex_state = 2},
  [104] = {.lex_state = 13, .external_lex_state = 2},
  [105] = {.lex_state = 13, .external_lex_state = 2},
  [106] = {.lex_state = 11, .external_lex_state = 2},
  [107] = {.lex_state = 12, .external_lex_state = 2},
  [108] = {.lex_state = 12, .external_lex_state = 2},
  [109] = {.lex_state = 15, .external_lex_state = 2},
  [110] = {.lex_state = 15, .external_lex_state = 2},
  [111] = {.lex_state = 11, .external_lex_state = 2},
  [112] = {.lex_state = 12, .external_lex_state = 2},
  [113] = {.lex_state = 11, .external_lex_state = 2},
  [114] = {.lex_state = 11, .external_lex_state = 2},
  [115] = {.lex_state = 12, .external_lex_state = 2},
  [116] = {.lex_state = 13, .external_lex_state = 2},
  [117] = {.lex_state = 13, .external_lex_state = 2},
  [118] = {.lex_state = 13, .external_lex_state = 2},
  [119] = {.lex_state = 13, .external_lex_state = 2},
  [120] = {.lex_state = 12, .external_lex_state = 2},
  [121] = {.lex_state = 11, .external_lex_state = 2},
  [122] = {.lex_state = 13, .external_lex_state = 2},
  [123] = {.lex_state = 11, .external_lex_state = 2},
  [124] = {.lex_state = 12, .external_lex_state = 2},
  [125] = {.lex_state = 11, .external_lex_state = 2},
  [126] = {.lex_state = 12, .external_lex_state = 2},
  [127] = {.lex_state = 13, .external_lex_state = 2},
  [128] = {.lex_state = 13, .external_lex_state = 2},
  [129] = {.lex_state = 13, .external_lex_state = 2},
  [130] = {.lex_state = 13, .external_lex_state = 2},
  [131] = {.lex_state = 13, .external_lex_state = 2},
  [132] = {.lex_state = 13, .external_lex_state = 2},
  [133] = {.lex_state = 11, .external_lex_state = 2},
  [134] = {.lex_state = 12, .external_lex_state = 2},
  [135] = {.lex_state = 11, .external_lex_state = 2},
  [136] = {.lex_state = 12, .external_lex_state = 2},
  [137] = {.lex_state = 13, .external_lex_state = 2},
  [138] = {.lex_state = 13, .external_lex_state = 2},
  [139] = {.lex_state = 13, .external_lex_state = 2},
  [140] = {.lex_state = 13, .external_lex_state = 2},
  [141] = {.lex_state = 13, .external_lex_state = 2},
  [142] = {.lex_state = 13, .external_lex_state = 2},
  [143] = {.lex_state = 11, .external_lex_state = 2},
  [144] = {.lex_state = 12, .external_lex_state = 2},
  [145] = {.lex_state = 11, .external_lex_state = 2},
  [146] = {.lex_state = 12, .external_lex_state = 2},
  [147] = {.lex_state = 13, .external_lex_state = 2},
  [148] = {.lex_state = 13, .external_lex_state = 2},
  [149] = {.lex_state = 13, .external_lex_state = 2},
  [150] = {.lex_state = 13, .external_lex_state = 2},
  [151] = {.lex_state = 13, .external_lex_state = 2},
  [152] = {.lex_state = 13, .external_lex_state = 2},
  [153] = {.lex_state = 13, .external_lex_state = 2},
  [154] = {.lex_state = 10, .external_lex_state = 3},
  [155] = {.lex_state = 10, .external_lex_state = 3},
  [156] = {.lex_state = 10, .external_lex_state = 3},
  [157] = {.lex_state = 10, .external_lex_state = 3},
  [158] = {.lex_state = 10, .external_lex_state = 3},
  [159] = {.lex_state = 10, .external_lex_state = 3},
  [160] = {.lex_state = 10, .external_lex_state = 3},
  [161] = {.lex_state = 10, .external_lex_state = 3},
  [162] = {.lex_state = 10, .external_lex_state = 3},
  [163] = {.lex_state = 10, .external_lex_state = 3},
  [164] = {.lex_state = 10, .external_lex_state = 3},
  [165] = {.lex_state = 10, .external_lex_state = 3},
  [166] = {.lex_state = 10, .external_lex_state = 3},
  [167] = {.lex_state = 10, .external_lex_state = 3},
  [168] = {.lex_state = 10, .external_lex_state = 3},
  [169] = {.lex_state = 10, .external_lex_state = 3},
  [170] = {.lex_state = 10, .external_lex_state = 3},
  [171] = {.lex_state = 10, .external_lex_state = 3},
  [172] = {.lex_state = 10, .external_lex_state = 3},
  [173] = {.lex_state = 10, .external_lex_state = 3},
  [174] = {.lex_state = 10, .external_lex_state = 3},
  [175] = {.lex_state = 10, .external_lex_state = 3},
  [176] = {.lex_state = 10, .external_lex_state = 3},
  [177] = {.lex_state = 10, .external_lex_state = 3},
  [178] = {.lex_state = 14, .external_lex_state = 2},
  [179] = {.lex_state = 14, .external_lex_state = 2},
  [180] = {.lex_state = 14, .external_lex_state = 2},
  [181] = {.lex_state = 14, .external_lex_state = 2},
  [182] = {.lex_state = 14, .external_lex_state = 2},
  [183] = {.lex_state = 14, .external_lex_state = 2},
  [184] = {.lex_state = 14, .external_lex_state = 2},
  [185] = {.lex_state = 14, .external_lex_state = 2},
  [186] = {.lex_state = 14, .external_lex_state = 2},
  [187] = {.lex_state = 14, .external_lex_state = 2},
  [188] = {.lex_state = 14, .external_lex_state = 2},
  [189] = {.lex_state = 14, .external_lex_state = 2},
  [190] = {.lex_state = 14, .external_lex_state = 2},
  [191] = {.lex_state = 14, .external_lex_state = 2},
  [192] = {.lex_state = 14, .external_lex_state = 2},
  [193] = {.lex_state = 14, .external_lex_state = 2},
  [194] = {.lex_state = 14, .external_lex_state = 2},
  [195] = {.lex_state = 10, .external_lex_state = 2},
  [196] = {.lex_state = 14, .external_lex_state = 2},
  [197] = {.lex_state = 14, .external_lex_state = 2},
  [198] = {.lex_state = 14, .external_lex_state = 2},
  [199] = {.lex_state = 14, .external_lex_state = 2},
  [200] = {.lex_state = 10, .external_lex_state = 2},
  [201] = {.lex_state = 14, .external_lex_state = 2},
  [202] = {.lex_state = 15, .external_lex_state = 2},
  [203] = {.lex_state = 12, .external_lex_state = 2},
  [204] = {.lex_state = 15, .external_lex_state = 2},
  [205] = {.lex_state = 15, .external_lex_state = 2},
  [206] = {.lex_state = 15, .external_lex_state = 2},
  [207] = {.lex_state = 15, .external_lex_state = 2},
  [208] = {.lex_state = 15, .external_lex_state = 2},
  [209] = {.lex_state = 15, .external_lex_state = 2},
  [210] = {.lex_state = 15, .external_lex_state = 2},
  [211] = {.lex_state = 15, .external_lex_state = 2},
  [212] = {.lex_state = 15, .external_lex_state = 2},
  [213] = {.lex_state = 15, .external_lex_state = 2},
  [214] = {.lex_state = 12, .external_lex_state = 2},
  [215] = {.lex_state = 15, .external_lex_state = 2},
  [216] = {.lex_state = 15, .external_lex_state = 2},
  [217] = {.lex_state = 15, .external_lex_state = 2},
  [218] = {.lex_state = 15, .external_lex_state = 2},
  [219] = {.lex_state = 15, .external_lex_state = 2},
  [220] = {.lex_state = 15, .external_lex_state = 2},
  [221] = {.lex_state = 12, .external_lex_state = 2},
  [222] = {.lex_state = 12, .external_lex_state = 2},
  [223] = {.lex_state = 12, .external_lex_state = 2},
  [224] = {.lex_state = 12, .external_lex_state = 2},
  [225] = {.lex_state = 12, .external_lex_state = 2},
  [226] = {.lex_state = 12, .external_lex_state = 2},
  [227] = {.lex_state = 12, .external_lex_state = 2},
  [228] = {.lex_state = 12, .external_lex_state = 2},
  [229] = {.lex_state = 12, .external_lex_state = 2},
  [230] = {.lex_state = 12, .external_lex_state = 2},
  [231] = {.lex_state = 13, .external_lex_state = 2},
  [232] = {.lex_state = 11, .external_lex_state = 2},
  [233] = {.lex_state = 11, .external_lex_state = 2},
  [234] = {.lex_state = 11, .external_lex_state = 2},
  [235] = {.lex_state = 11, .external_lex_state = 2},
  [236] = {.lex_state = 12, .external_lex_state = 2},
  [237] = {.lex_state = 12, .external_lex_state = 2},
  [238] = {.lex_state = 11, .external_lex_state = 2},
  [239] = {.lex_state = 12, .external_lex_state = 2},
  [240] = {.lex_state = 11, .external_lex_state = 2},
  [241] = {.lex_state = 11, .external_lex_state = 2},
  [242] = {.lex_state = 11, .external_lex_state = 2},
  [243] = {.lex_state = 11, .external_lex_state = 2},
  [244] = {.lex_state = 13, .external_lex_state = 2},
  [245] = {.lex_state = 11, .external_lex_state = 2},
  [246] = {.lex_state = 11, .external_lex_state = 2},
  [247] = {.lex_state = 11, .external_lex_state = 2},
  [248] = {.lex_state = 12, .external_lex_state = 2},
  [249] = {.lex_state = 12, .external_lex_state = 2},
  [250] = {.lex_state = 11, .external_lex_state = 2},
  [251] = {.lex_state = 11, .external_lex_state = 2},
  [252] = {.lex_state = 11, .external_lex_state = 2},
  [253] = {.lex_state = 12, .external_lex_state = 2},
  [254] = {.lex_state = 11, .external_lex_state = 2},
  [255] = {.lex_state = 11, .external_lex_state = 2},
  [256] = {.lex_state = 11, .external_lex_state = 2},
  [257] = {.lex_state = 15, .external_lex_state = 2},
  [258] = {.lex_state = 11, .external_lex_state = 2},
  [259] = {.lex_state = 15, .external_lex_state = 2},
  [260] = {.lex_state = 11, .external_lex_state = 2},
  [261] = {.lex_state = 15, .external_lex_state = 2},
  [262] = {.lex_state = 15, .external_lex_state = 2},
  [263] = {.lex_state = 11, .external_lex_state = 2},
  [264] = {.lex_state = 11, .external_lex_state = 2},
  [265] = {.lex_state = 12, .external_lex_state = 2},
  [266] = {.lex_state = 12, .external_lex_state = 2},
  [267] = {.lex_state = 12, .external_lex_state = 2},
  [268] = {.lex_state = 15, .external_lex_state = 2},
  [269] = {.lex_state = 12, .external_lex_state = 2},
  [270] = {.lex_state = 13, .external_lex_state = 2},
  [271] = {.lex_state = 482},
  [272] = {.lex_state = 482},
  [273] = {.lex_state = 482},
  [274] = {.lex_state = 482, .external_lex_state = 4},
  [275] = {.lex_state = 482, .external_lex_state = 4},
  [276] = {.lex_state = 482, .external_lex_state = 5},
  [277] = {.lex_state = 482, .external_lex_state = 6},
  [278] = {.lex_state = 482, .external_lex_state = 4},
  [279] = {.lex_state = 482, .external_lex_state = 6},
  [280] = {.lex_state = 482, .external_lex_state = 4},
  [281] = {.lex_state = 482, .external_lex_state = 6},
  [282] = {.lex_state = 482, .external_lex_state = 6},
  [283] = {.lex_state = 482, .external_lex_state = 4},
  [284] = {.lex_state = 482, .external_lex_state = 4},
  [285] = {.lex_state = 482, .external_lex_state = 5},
  [286] = {.lex_state = 482, .external_lex_state = 5},
  [287] = {.lex_state = 482},
  [288] = {.lex_state = 482},
  [289] = {.lex_state = 482},
  [290] = {.lex_state = 482},
  [291] = {.lex_state = 482},
  [292] = {.lex_state = 482},
  [293] = {.lex_state = 482},
  [294] = {.lex_state = 482},
  [295] = {.lex_state = 482},
  [296] = {.lex_state = 482},
  [297] = {.lex_state = 482},
  [298] = {.lex_state = 482},
  [299] = {.lex_state = 482},
  [300] = {.lex_state = 482},
  [301] = {.lex_state = 482},
  [302] = {.lex_state = 482},
  [303] = {.lex_state = 482},
  [304] = {.lex_state = 482},
  [305] = {.lex_state = 482, .external_lex_state = 5},
  [306] = {.lex_state = 482, .external_lex_state = 5},
  [307] = {.lex_state = 482, .external_lex_state = 5},
  [308] = {.lex_state = 482, .external_lex_state = 5},
  [309] = {.lex_state = 482, .external_lex_state = 4},
  [310] = {.lex_state = 482, .external_lex_state = 6},
  [311] = {.lex_state = 482, .external_lex_state = 5},
  [312] = {.lex_state = 482, .external_lex_state = 6},
  [313] = {.lex_state = 482, .external_lex_state = 6},
  [314] = {.lex_state = 482, .external_lex_state = 4},
  [315] = {.lex_state = 482, .external_lex_state = 6},
  [316] = {.lex_state = 482, .external_lex_state = 4},
  [317] = {.lex_state = 482, .external_lex_state = 4},
  [318] = {.lex_state = 482, .external_lex_state = 6},
  [319] = {.lex_state = 482, .external_lex_state = 4},
  [320] = {.lex_state = 482, .external_lex_state = 4},
  [321] = {.lex_state = 482, .external_lex_state = 6},
  [322] = {.lex_state = 482, .external_lex_state = 4},
  [323] = {.lex_state = 482, .external_lex_state = 5},
  [324] = {.lex_state = 482, .external_lex_state = 6},
  [325] = {.lex_state = 482, .external_lex_state = 5},
  [326] = {.lex_state = 482},
  [327] = {.lex_state = 482},
  [328] = {.lex_state = 482},
  [329] = {.lex_state = 482},
  [330] = {.lex_state = 482},
  [331] = {.lex_state = 482},
  [332] = {.lex_state = 482},
  [333] = {.lex_state = 482},
  [334] = {.lex_state = 0},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 482},
  [337] = {.lex_state = 482},
  [338] = {.lex_state = 482},
  [339] = {.lex_state = 0},
  [340] = {.lex_state = 0, .external_lex_state = 2},
  [341] = {.lex_state = 482},
  [342] = {.lex_state = 482},
  [343] = {.lex_state = 482},
  [344] = {.lex_state = 482},
  [345] = {.lex_state = 482},
  [346] = {.lex_state = 482},
  [347] = {.lex_state = 482},
  [348] = {.lex_state = 0, .external_lex_state = 2},
  [349] = {.lex_state = 0, .external_lex_state = 7},
  [350] = {.lex_state = 482},
  [351] = {.lex_state = 0, .external_lex_state = 2},
  [352] = {.lex_state = 0, .external_lex_state = 2},
  [353] = {.lex_state = 0},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 482},
  [356] = {.lex_state = 0, .external_lex_state = 4},
  [357] = {.lex_state = 0, .external_lex_state = 2},
  [358] = {.lex_state = 0, .external_lex_state = 8},
  [359] = {.lex_state = 0, .external_lex_state = 9},
  [360] = {.lex_state = 0, .external_lex_state = 4},
  [361] = {.lex_state = 0, .external_lex_state = 4},
  [362] = {.lex_state = 0, .external_lex_state = 8},
  [363] = {.lex_state = 0, .external_lex_state = 9},
  [364] = {.lex_state = 0, .external_lex_state = 4},
  [365] = {.lex_state = 0, .external_lex_state = 4},
  [366] = {.lex_state = 0, .external_lex_state = 8},
  [367] = {.lex_state = 0, .external_lex_state = 9},
  [368] = {.lex_state = 0, .external_lex_state = 4},
  [369] = {.lex_state = 0, .external_lex_state = 4},
  [370] = {.lex_state = 0, .external_lex_state = 8},
  [371] = {.lex_state = 0, .external_lex_state = 9},
  [372] = {.lex_state = 0, .external_lex_state = 8},
  [373] = {.lex_state = 0, .external_lex_state = 9},
  [374] = {.lex_state = 0, .external_lex_state = 4},
  [375] = {.lex_state = 0, .external_lex_state = 4},
  [376] = {.lex_state = 0, .external_lex_state = 4},
  [377] = {.lex_state = 0},
  [378] = {.lex_state = 0},
  [379] = {.lex_state = 482},
  [380] = {.lex_state = 1},
  [381] = {.lex_state = 0},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 0},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 482},
  [388] = {.lex_state = 482},
  [389] = {.lex_state = 0, .external_lex_state = 2},
  [390] = {.lex_state = 14},
  [391] = {.lex_state = 1},
  [392] = {.lex_state = 0},
  [393] = {.lex_state = 0},
  [394] = {.lex_state = 0},
  [395] = {.lex_state = 0},
  [396] = {.lex_state = 482},
  [397] = {.lex_state = 0},
  [398] = {.lex_state = 0},
  [399] = {.lex_state = 0},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 0},
  [402] = {.lex_state = 0},
  [403] = {.lex_state = 0},
  [404] = {.lex_state = 0, .external_lex_state = 7},
  [405] = {.lex_state = 0, .external_lex_state = 2},
  [406] = {.lex_state = 0},
  [407] = {.lex_state = 1},
  [408] = {.lex_state = 0},
  [409] = {.lex_state = 0},
  [410] = {.lex_state = 0},
  [411] = {.lex_state = 0},
  [412] = {.lex_state = 0},
  [413] = {.lex_state = 0},
  [414] = {.lex_state = 0},
  [415] = {.lex_state = 0},
  [416] = {.lex_state = 0},
  [417] = {.lex_state = 0, .external_lex_state = 7},
  [418] = {.lex_state = 0, .external_lex_state = 2},
  [419] = {.lex_state = 0},
  [420] = {.lex_state = 0, .external_lex_state = 7},
  [421] = {.lex_state = 0, .external_lex_state = 7},
  [422] = {.lex_state = 0, .external_lex_state = 2},
  [423] = {.lex_state = 0, .external_lex_state = 7},
  [424] = {.lex_state = 0},
  [425] = {.lex_state = 0, .external_lex_state = 7},
  [426] = {.lex_state = 0},
  [427] = {.lex_state = 1},
  [428] = {.lex_state = 0},
  [429] = {.lex_state = 1},
  [430] = {.lex_state = 0},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 0, .external_lex_state = 7},
  [433] = {.lex_state = 0},
  [434] = {.lex_state = 0},
  [435] = {.lex_state = 4},
  [436] = {.lex_state = 0, .external_lex_state = 7},
  [437] = {.lex_state = 0, .external_lex_state = 2},
  [438] = {.lex_state = 0},
  [439] = {.lex_state = 482},
  [440] = {.lex_state = 0, .external_lex_state = 7},
  [441] = {.lex_state = 0},
  [442] = {.lex_state = 0},
  [443] = {.lex_state = 482},
  [444] = {.lex_state = 0, .external_lex_state = 7},
  [445] = {.lex_state = 0, .external_lex_state = 2},
  [446] = {.lex_state = 14},
  [447] = {.lex_state = 0, .external_lex_state = 7},
  [448] = {.lex_state = 0, .external_lex_state = 7},
  [449] = {.lex_state = 0, .external_lex_state = 7},
  [450] = {.lex_state = 0, .external_lex_state = 7},
  [451] = {.lex_state = 0, .external_lex_state = 7},
  [452] = {.lex_state = 0},
  [453] = {.lex_state = 0, .external_lex_state = 2},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 0},
  [456] = {.lex_state = 0},
  [457] = {.lex_state = 13},
  [458] = {.lex_state = 13},
  [459] = {.lex_state = 0},
  [460] = {.lex_state = 0},
  [461] = {.lex_state = 16},
  [462] = {.lex_state = 0},
  [463] = {.lex_state = 0},
  [464] = {.lex_state = 0},
  [465] = {.lex_state = 0},
  [466] = {.lex_state = 0},
  [467] = {.lex_state = 0, .external_lex_state = 5},
  [468] = {.lex_state = 0},
  [469] = {.lex_state = 0},
  [470] = {.lex_state = 13},
  [471] = {.lex_state = 13},
  [472] = {.lex_state = 0},
  [473] = {.lex_state = 0},
  [474] = {.lex_state = 0},
  [475] = {.lex_state = 0, .external_lex_state = 8},
  [476] = {.lex_state = 0},
  [477] = {.lex_state = 0},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 4},
  [480] = {.lex_state = 0},
  [481] = {.lex_state = 17},
  [482] = {.lex_state = 0},
  [483] = {.lex_state = 11},
  [484] = {.lex_state = 18},
  [485] = {.lex_state = 0},
  [486] = {.lex_state = 0, .external_lex_state = 2},
  [487] = {.lex_state = 13},
  [488] = {.lex_state = 13},
  [489] = {.lex_state = 0},
  [490] = {.lex_state = 0},
  [491] = {.lex_state = 0},
  [492] = {.lex_state = 13},
  [493] = {.lex_state = 0, .external_lex_state = 4},
  [494] = {.lex_state = 13},
  [495] = {.lex_state = 0},
  [496] = {.lex_state = 13},
  [497] = {.lex_state = 0},
  [498] = {.lex_state = 0},
  [499] = {.lex_state = 0},
  [500] = {.lex_state = 13},
  [501] = {.lex_state = 13},
  [502] = {.lex_state = 0},
  [503] = {.lex_state = 0},
  [504] = {.lex_state = 0},
  [505] = {.lex_state = 0},
  [506] = {.lex_state = 0},
  [507] = {.lex_state = 0},
  [508] = {.lex_state = 0},
  [509] = {.lex_state = 0, .external_lex_state = 6},
  [510] = {.lex_state = 0},
  [511] = {.lex_state = 0},
  [512] = {.lex_state = 0, .external_lex_state = 4},
  [513] = {.lex_state = 0},
  [514] = {.lex_state = 0},
  [515] = {.lex_state = 0},
  [516] = {.lex_state = 0},
  [517] = {.lex_state = 13},
  [518] = {.lex_state = 13},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 0},
  [521] = {.lex_state = 19},
  [522] = {.lex_state = 0, .external_lex_state = 8},
  [523] = {.lex_state = 0, .external_lex_state = 4},
  [524] = {.lex_state = 0},
  [525] = {.lex_state = 0, .external_lex_state = 7},
  [526] = {.lex_state = 0},
  [527] = {.lex_state = 0},
  [528] = {.lex_state = 13},
  [529] = {.lex_state = 0, .external_lex_state = 9},
  [530] = {.lex_state = 13},
  [531] = {.lex_state = 13},
  [532] = {.lex_state = 0},
  [533] = {.lex_state = 0},
  [534] = {.lex_state = 0, .external_lex_state = 2},
  [535] = {.lex_state = 0},
  [536] = {.lex_state = 20},
  [537] = {.lex_state = 0},
  [538] = {.lex_state = 0},
  [539] = {.lex_state = 0},
  [540] = {.lex_state = 0},
  [541] = {.lex_state = 0},
  [542] = {.lex_state = 0},
  [543] = {.lex_state = 1},
  [544] = {.lex_state = 0},
  [545] = {.lex_state = 0},
  [546] = {.lex_state = 0},
  [547] = {.lex_state = 16},
  [548] = {.lex_state = 0},
  [549] = {.lex_state = 17},
  [550] = {.lex_state = 18},
  [551] = {.lex_state = 13},
  [552] = {.lex_state = 0, .external_lex_state = 6},
  [553] = {.lex_state = 0, .external_lex_state = 4},
  [554] = {.lex_state = 0, .external_lex_state = 7},
  [555] = {.lex_state = 0, .external_lex_state = 8},
  [556] = {.lex_state = 0, .external_lex_state = 9},
  [557] = {.lex_state = 0, .external_lex_state = 4},
  [558] = {.lex_state = 0, .external_lex_state = 4},
  [559] = {.lex_state = 13},
  [560] = {.lex_state = 0, .external_lex_state = 2},
  [561] = {.lex_state = 0, .external_lex_state = 2},
  [562] = {.lex_state = 0},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 0},
  [565] = {.lex_state = 0, .external_lex_state = 2},
  [566] = {.lex_state = 0, .external_lex_state = 4},
  [567] = {.lex_state = 16},
  [568] = {.lex_state = 0},
  [569] = {.lex_state = 17},
  [570] = {.lex_state = 18},
  [571] = {.lex_state = 0},
  [572] = {.lex_state = 0, .external_lex_state = 8},
  [573] = {.lex_state = 0, .external_lex_state = 9},
  [574] = {.lex_state = 0, .external_lex_state = 4},
  [575] = {.lex_state = 0, .external_lex_state = 4},
  [576] = {.lex_state = 0},
  [577] = {.lex_state = 0, .external_lex_state = 2},
  [578] = {.lex_state = 0, .external_lex_state = 2},
  [579] = {.lex_state = 0, .external_lex_state = 9},
  [580] = {.lex_state = 0},
  [581] = {.lex_state = 0, .external_lex_state = 4},
  [582] = {.lex_state = 0, .external_lex_state = 4},
  [583] = {.lex_state = 0},
  [584] = {.lex_state = 16},
  [585] = {.lex_state = 0},
  [586] = {.lex_state = 17},
  [587] = {.lex_state = 18},
  [588] = {.lex_state = 0},
  [589] = {.lex_state = 0, .external_lex_state = 8},
  [590] = {.lex_state = 0, .external_lex_state = 9},
  [591] = {.lex_state = 0, .external_lex_state = 4},
  [592] = {.lex_state = 0, .external_lex_state = 4},
  [593] = {.lex_state = 0},
  [594] = {.lex_state = 0, .external_lex_state = 2},
  [595] = {.lex_state = 13},
  [596] = {.lex_state = 13},
  [597] = {.lex_state = 0},
  [598] = {.lex_state = 0},
  [599] = {.lex_state = 0},
  [600] = {.lex_state = 0},
  [601] = {.lex_state = 16},
  [602] = {.lex_state = 0},
  [603] = {.lex_state = 17},
  [604] = {.lex_state = 18},
  [605] = {.lex_state = 0},
  [606] = {.lex_state = 0, .external_lex_state = 8},
  [607] = {.lex_state = 0, .external_lex_state = 9},
  [608] = {.lex_state = 0, .external_lex_state = 4},
  [609] = {.lex_state = 0, .external_lex_state = 4},
  [610] = {.lex_state = 0},
  [611] = {.lex_state = 0, .external_lex_state = 2},
  [612] = {.lex_state = 0, .external_lex_state = 2},
  [613] = {.lex_state = 0},
  [614] = {.lex_state = 0, .external_lex_state = 8},
  [615] = {.lex_state = 0, .external_lex_state = 4},
  [616] = {.lex_state = 0, .external_lex_state = 9},
  [617] = {.lex_state = 0},
  [618] = {.lex_state = 0, .external_lex_state = 2},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_COLONmanuscript_COLON] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(1),
    [aux_sym_mathblock_token1] = ACTIONS(1),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(1),
    [anon_sym_COLONappendix_COLON] = ACTIONS(1),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(1),
    [anon_sym_COLONtoc_COLON] = ACTIONS(1),
    [aux_sym_specialblock_token1] = ACTIONS(1),
    [aux_sym_specialblock_token2] = ACTIONS(1),
    [aux_sym_specialblock_token3] = ACTIONS(1),
    [aux_sym_specialblock_token4] = ACTIONS(1),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(1),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(1),
    [anon_sym_COLONcaption_COLON] = ACTIONS(1),
    [anon_sym_COLONitem_COLON] = ACTIONS(1),
    [anon_sym_COLONprev_COLON] = ACTIONS(1),
    [anon_sym_COLONprev2_COLON] = ACTIONS(1),
    [anon_sym_COLONprev3_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token1] = ACTIONS(1),
    [aux_sym_specialinline_token2] = ACTIONS(1),
    [anon_sym_COLONmath_COLON] = ACTIONS(1),
    [anon_sym_COLONcode_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token3] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [aux_sym_specialinline_token4] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_COLONref_COLON] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLONprevious_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token6] = ACTIONS(1),
    [anon_sym_COLONurl_COLON] = ACTIONS(1),
    [anon_sym_COLONcite_COLON] = ACTIONS(1),
    [anon_sym_COLONqed_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_COLONtable_COLON] = ACTIONS(1),
    [anon_sym_COLONthead_COLON] = ACTIONS(1),
    [anon_sym_COLONtbody_COLON] = ACTIONS(1),
    [anon_sym_COLONtr_COLON] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COLONtd_COLON] = ACTIONS(1),
    [anon_sym_COLONbibtex_COLON] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [aux_sym_bibitem_token1] = ACTIONS(1),
    [aux_sym_bibitempair_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLONassume_COLON] = ACTIONS(1),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(1),
    [anon_sym_COLONprove_COLON] = ACTIONS(1),
    [anon_sym_COLONthen_COLON] = ACTIONS(1),
    [anon_sym_COLONnew_COLON] = ACTIONS(1),
    [anon_sym_COLONlet_COLON] = ACTIONS(1),
    [anon_sym_COLONcase_COLON] = ACTIONS(1),
    [anon_sym_COLONdefine_COLON] = ACTIONS(1),
    [anon_sym_COLONwrite_COLON] = ACTIONS(1),
    [anon_sym_COLONwlog_COLON] = ACTIONS(1),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(1),
    [anon_sym_COLONclaim_COLON] = ACTIONS(1),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(1),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(1),
    [anon_sym_COLONpick_COLON] = ACTIONS(1),
    [anon_sym_COLONst_COLON] = ACTIONS(1),
    [anon_sym_COLONdraft_COLON] = ACTIONS(1),
    [anon_sym_COLONnote_COLON] = ACTIONS(1),
    [anon_sym_COLONspan_COLON] = ACTIONS(1),
    [anon_sym_COLONabstract_COLON] = ACTIONS(1),
    [anon_sym_COLONauthor_COLON] = ACTIONS(1),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(1),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(1),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(1),
    [anon_sym_COLONexample_COLON] = ACTIONS(1),
    [anon_sym_COLONitemize_COLON] = ACTIONS(1),
    [anon_sym_COLONlemma_COLON] = ACTIONS(1),
    [anon_sym_COLONfigure_COLON] = ACTIONS(1),
    [anon_sym_COLONp_COLON] = ACTIONS(1),
    [anon_sym_COLONproof_COLON] = ACTIONS(1),
    [anon_sym_COLONproposition_COLON] = ACTIONS(1),
    [anon_sym_COLONremark_COLON] = ACTIONS(1),
    [anon_sym_COLONsection_COLON] = ACTIONS(1),
    [anon_sym_COLONsketch_COLON] = ACTIONS(1),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(1),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(1),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(1),
    [anon_sym_COLONstep_COLON] = ACTIONS(1),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(1),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(1),
    [anon_sym_COLONemail_COLON] = ACTIONS(1),
    [anon_sym_COLONlabel_COLON] = ACTIONS(1),
    [anon_sym_COLONname_COLON] = ACTIONS(1),
    [anon_sym_COLONreftext_COLON] = ACTIONS(1),
    [anon_sym_COLONtitle_COLON] = ACTIONS(1),
    [anon_sym_COLONgoal_COLON] = ACTIONS(1),
    [anon_sym_COLONlang_COLON] = ACTIONS(1),
    [anon_sym_COLONicon_COLON] = ACTIONS(1),
    [anon_sym_COLONnonum_COLON] = ACTIONS(1),
    [anon_sym_COLONstrong_COLON] = ACTIONS(1),
    [anon_sym_COLONemphas_COLON] = ACTIONS(1),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(1),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(1),
    [anon_sym_COLONmsc_COLON] = ACTIONS(1),
    [anon_sym_COLONtypes_COLON] = ACTIONS(1),
    [anon_sym_COLONdate_COLON] = ACTIONS(1),
    [anon_sym_COLONpath_COLON] = ACTIONS(1),
    [anon_sym_COLONscale_COLON] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_upto_brace_or_comma_text] = ACTIONS(1),
    [sym_asis_dollar_text] = ACTIONS(1),
    [sym_asis_two_dollars_text] = ACTIONS(1),
    [sym_asis_backtick_text] = ACTIONS(1),
    [sym_asis_three_backticks_text] = ACTIONS(1),
    [sym_asis_halmos_text] = ACTIONS(1),
    [sym_text] = ACTIONS(1),
    [sym_paragraph_end] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(546),
    [anon_sym_COLONmanuscript_COLON] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(2)] = {
    [sym_block] = STATE(17),
    [sym_paragraph] = STATE(17),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(17),
    [sym_specialblock] = STATE(17),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_blockmeta] = STATE(16),
    [sym_pair] = STATE(5),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [sym_metakey_text] = STATE(445),
    [sym_metakey_bool] = STATE(8),
    [sym_metakey_list] = STATE(340),
    [sym_metakey_any] = STATE(429),
    [aux_sym_source_file_repeat1] = STATE(17),
    [aux_sym_blockmeta_repeat1] = STATE(5),
    [anon_sym_COLON_COLON] = ACTIONS(7),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(3)] = {
    [sym_block] = STATE(20),
    [sym_paragraph] = STATE(20),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(20),
    [sym_specialblock] = STATE(20),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_blockmeta] = STATE(19),
    [sym_pair] = STATE(5),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [sym_metakey_text] = STATE(445),
    [sym_metakey_bool] = STATE(8),
    [sym_metakey_list] = STATE(340),
    [sym_metakey_any] = STATE(429),
    [aux_sym_source_file_repeat1] = STATE(20),
    [aux_sym_blockmeta_repeat1] = STATE(5),
    [anon_sym_COLON_COLON] = ACTIONS(73),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(4)] = {
    [sym_block] = STATE(15),
    [sym_paragraph] = STATE(15),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(15),
    [sym_specialblock] = STATE(15),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_blockmeta] = STATE(14),
    [sym_pair] = STATE(5),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [sym_metakey_text] = STATE(445),
    [sym_metakey_bool] = STATE(8),
    [sym_metakey_list] = STATE(340),
    [sym_metakey_any] = STATE(429),
    [aux_sym_source_file_repeat1] = STATE(15),
    [aux_sym_blockmeta_repeat1] = STATE(5),
    [anon_sym_COLON_COLON] = ACTIONS(75),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(5)] = {
    [sym_pair] = STATE(6),
    [sym_metakey_text] = STATE(445),
    [sym_metakey_bool] = STATE(8),
    [sym_metakey_list] = STATE(340),
    [sym_metakey_any] = STATE(429),
    [aux_sym_blockmeta_repeat1] = STATE(6),
    [anon_sym_COLON_COLON] = ACTIONS(77),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(77),
    [aux_sym_mathblock_token1] = ACTIONS(77),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(77),
    [anon_sym_COLONappendix_COLON] = ACTIONS(77),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(77),
    [anon_sym_COLONtoc_COLON] = ACTIONS(77),
    [aux_sym_specialblock_token1] = ACTIONS(77),
    [aux_sym_specialblock_token2] = ACTIONS(77),
    [aux_sym_specialblock_token3] = ACTIONS(77),
    [aux_sym_specialblock_token4] = ACTIONS(77),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(77),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(77),
    [anon_sym_COLONcaption_COLON] = ACTIONS(77),
    [anon_sym_COLONitem_COLON] = ACTIONS(77),
    [anon_sym_COLONprev_COLON] = ACTIONS(77),
    [anon_sym_COLONprev2_COLON] = ACTIONS(77),
    [anon_sym_COLONprev3_COLON] = ACTIONS(77),
    [aux_sym_specialinline_token1] = ACTIONS(79),
    [aux_sym_specialinline_token2] = ACTIONS(79),
    [anon_sym_COLONmath_COLON] = ACTIONS(77),
    [anon_sym_COLONcode_COLON] = ACTIONS(77),
    [aux_sym_specialinline_token3] = ACTIONS(77),
    [aux_sym_specialinline_token4] = ACTIONS(77),
    [anon_sym_COLONref_COLON] = ACTIONS(77),
    [anon_sym_COLONprevious_COLON] = ACTIONS(77),
    [anon_sym_COLONurl_COLON] = ACTIONS(77),
    [anon_sym_COLONcite_COLON] = ACTIONS(77),
    [anon_sym_COLONqed_COLON] = ACTIONS(77),
    [anon_sym_COLONtable_COLON] = ACTIONS(77),
    [anon_sym_COLONassume_COLON] = ACTIONS(77),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(77),
    [anon_sym_COLONprove_COLON] = ACTIONS(77),
    [anon_sym_COLONthen_COLON] = ACTIONS(77),
    [anon_sym_COLONnew_COLON] = ACTIONS(77),
    [anon_sym_COLONlet_COLON] = ACTIONS(77),
    [anon_sym_COLONcase_COLON] = ACTIONS(77),
    [anon_sym_COLONdefine_COLON] = ACTIONS(77),
    [anon_sym_COLONwrite_COLON] = ACTIONS(77),
    [anon_sym_COLONwlog_COLON] = ACTIONS(77),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(77),
    [anon_sym_COLONclaim_COLON] = ACTIONS(77),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(77),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(77),
    [anon_sym_COLONpick_COLON] = ACTIONS(77),
    [anon_sym_COLONst_COLON] = ACTIONS(77),
    [anon_sym_COLONdraft_COLON] = ACTIONS(77),
    [anon_sym_COLONnote_COLON] = ACTIONS(77),
    [anon_sym_COLONspan_COLON] = ACTIONS(77),
    [anon_sym_COLONabstract_COLON] = ACTIONS(77),
    [anon_sym_COLONauthor_COLON] = ACTIONS(77),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(77),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(77),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(77),
    [anon_sym_COLONexample_COLON] = ACTIONS(77),
    [anon_sym_COLONitemize_COLON] = ACTIONS(77),
    [anon_sym_COLONlemma_COLON] = ACTIONS(77),
    [anon_sym_COLONfigure_COLON] = ACTIONS(77),
    [anon_sym_COLONp_COLON] = ACTIONS(77),
    [anon_sym_COLONproof_COLON] = ACTIONS(77),
    [anon_sym_COLONproposition_COLON] = ACTIONS(77),
    [anon_sym_COLONremark_COLON] = ACTIONS(77),
    [anon_sym_COLONsection_COLON] = ACTIONS(77),
    [anon_sym_COLONsketch_COLON] = ACTIONS(77),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(77),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(77),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(77),
    [anon_sym_COLONstep_COLON] = ACTIONS(77),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(77),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(77),
  },
  [STATE(6)] = {
    [sym_pair] = STATE(6),
    [sym_metakey_text] = STATE(445),
    [sym_metakey_bool] = STATE(8),
    [sym_metakey_list] = STATE(340),
    [sym_metakey_any] = STATE(429),
    [aux_sym_blockmeta_repeat1] = STATE(6),
    [anon_sym_COLON_COLON] = ACTIONS(81),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(81),
    [aux_sym_mathblock_token1] = ACTIONS(81),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(81),
    [anon_sym_COLONappendix_COLON] = ACTIONS(81),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(81),
    [anon_sym_COLONtoc_COLON] = ACTIONS(81),
    [aux_sym_specialblock_token1] = ACTIONS(81),
    [aux_sym_specialblock_token2] = ACTIONS(81),
    [aux_sym_specialblock_token3] = ACTIONS(81),
    [aux_sym_specialblock_token4] = ACTIONS(81),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(81),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(81),
    [anon_sym_COLONcaption_COLON] = ACTIONS(81),
    [anon_sym_COLONitem_COLON] = ACTIONS(81),
    [anon_sym_COLONprev_COLON] = ACTIONS(81),
    [anon_sym_COLONprev2_COLON] = ACTIONS(81),
    [anon_sym_COLONprev3_COLON] = ACTIONS(81),
    [aux_sym_specialinline_token1] = ACTIONS(83),
    [aux_sym_specialinline_token2] = ACTIONS(83),
    [anon_sym_COLONmath_COLON] = ACTIONS(81),
    [anon_sym_COLONcode_COLON] = ACTIONS(81),
    [aux_sym_specialinline_token3] = ACTIONS(81),
    [aux_sym_specialinline_token4] = ACTIONS(81),
    [anon_sym_COLONref_COLON] = ACTIONS(81),
    [anon_sym_COLONprevious_COLON] = ACTIONS(81),
    [anon_sym_COLONurl_COLON] = ACTIONS(81),
    [anon_sym_COLONcite_COLON] = ACTIONS(81),
    [anon_sym_COLONqed_COLON] = ACTIONS(81),
    [anon_sym_COLONtable_COLON] = ACTIONS(81),
    [anon_sym_COLONassume_COLON] = ACTIONS(81),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(81),
    [anon_sym_COLONprove_COLON] = ACTIONS(81),
    [anon_sym_COLONthen_COLON] = ACTIONS(81),
    [anon_sym_COLONnew_COLON] = ACTIONS(81),
    [anon_sym_COLONlet_COLON] = ACTIONS(81),
    [anon_sym_COLONcase_COLON] = ACTIONS(81),
    [anon_sym_COLONdefine_COLON] = ACTIONS(81),
    [anon_sym_COLONwrite_COLON] = ACTIONS(81),
    [anon_sym_COLONwlog_COLON] = ACTIONS(81),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(81),
    [anon_sym_COLONclaim_COLON] = ACTIONS(81),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(81),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(81),
    [anon_sym_COLONpick_COLON] = ACTIONS(81),
    [anon_sym_COLONst_COLON] = ACTIONS(81),
    [anon_sym_COLONdraft_COLON] = ACTIONS(81),
    [anon_sym_COLONnote_COLON] = ACTIONS(81),
    [anon_sym_COLONspan_COLON] = ACTIONS(81),
    [anon_sym_COLONabstract_COLON] = ACTIONS(81),
    [anon_sym_COLONauthor_COLON] = ACTIONS(81),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(81),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(81),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(81),
    [anon_sym_COLONexample_COLON] = ACTIONS(81),
    [anon_sym_COLONitemize_COLON] = ACTIONS(81),
    [anon_sym_COLONlemma_COLON] = ACTIONS(81),
    [anon_sym_COLONfigure_COLON] = ACTIONS(81),
    [anon_sym_COLONp_COLON] = ACTIONS(81),
    [anon_sym_COLONproof_COLON] = ACTIONS(81),
    [anon_sym_COLONproposition_COLON] = ACTIONS(81),
    [anon_sym_COLONremark_COLON] = ACTIONS(81),
    [anon_sym_COLONsection_COLON] = ACTIONS(81),
    [anon_sym_COLONsketch_COLON] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(81),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(81),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(81),
    [anon_sym_COLONstep_COLON] = ACTIONS(81),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(81),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(85),
    [anon_sym_COLONemail_COLON] = ACTIONS(85),
    [anon_sym_COLONlabel_COLON] = ACTIONS(85),
    [anon_sym_COLONname_COLON] = ACTIONS(85),
    [anon_sym_COLONreftext_COLON] = ACTIONS(85),
    [anon_sym_COLONtitle_COLON] = ACTIONS(85),
    [anon_sym_COLONgoal_COLON] = ACTIONS(85),
    [anon_sym_COLONlang_COLON] = ACTIONS(85),
    [anon_sym_COLONicon_COLON] = ACTIONS(85),
    [anon_sym_COLONnonum_COLON] = ACTIONS(88),
    [anon_sym_COLONstrong_COLON] = ACTIONS(88),
    [anon_sym_COLONemphas_COLON] = ACTIONS(88),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(88),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(91),
    [anon_sym_COLONmsc_COLON] = ACTIONS(91),
    [anon_sym_COLONtypes_COLON] = ACTIONS(91),
    [anon_sym_COLONdate_COLON] = ACTIONS(94),
    [anon_sym_COLONpath_COLON] = ACTIONS(94),
    [anon_sym_COLONscale_COLON] = ACTIONS(94),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(81),
  },
  [STATE(7)] = {
    [anon_sym_COLON_COLON] = ACTIONS(97),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(97),
    [aux_sym_mathblock_token1] = ACTIONS(97),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(97),
    [anon_sym_COLONappendix_COLON] = ACTIONS(97),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(97),
    [anon_sym_COLONtoc_COLON] = ACTIONS(97),
    [aux_sym_specialblock_token1] = ACTIONS(97),
    [aux_sym_specialblock_token2] = ACTIONS(97),
    [aux_sym_specialblock_token3] = ACTIONS(97),
    [aux_sym_specialblock_token4] = ACTIONS(97),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(97),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(97),
    [anon_sym_COLONcaption_COLON] = ACTIONS(97),
    [anon_sym_COLONitem_COLON] = ACTIONS(97),
    [anon_sym_COLONprev_COLON] = ACTIONS(97),
    [anon_sym_COLONprev2_COLON] = ACTIONS(97),
    [anon_sym_COLONprev3_COLON] = ACTIONS(97),
    [aux_sym_specialinline_token1] = ACTIONS(99),
    [aux_sym_specialinline_token2] = ACTIONS(99),
    [anon_sym_COLONmath_COLON] = ACTIONS(97),
    [anon_sym_COLONcode_COLON] = ACTIONS(97),
    [aux_sym_specialinline_token3] = ACTIONS(97),
    [aux_sym_specialinline_token4] = ACTIONS(97),
    [anon_sym_COLONref_COLON] = ACTIONS(97),
    [anon_sym_COLONprevious_COLON] = ACTIONS(97),
    [anon_sym_COLONurl_COLON] = ACTIONS(97),
    [anon_sym_COLONcite_COLON] = ACTIONS(97),
    [anon_sym_COLONqed_COLON] = ACTIONS(97),
    [anon_sym_COLONtable_COLON] = ACTIONS(97),
    [anon_sym_COLONassume_COLON] = ACTIONS(97),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(97),
    [anon_sym_COLONprove_COLON] = ACTIONS(97),
    [anon_sym_COLONthen_COLON] = ACTIONS(97),
    [anon_sym_COLONnew_COLON] = ACTIONS(97),
    [anon_sym_COLONlet_COLON] = ACTIONS(97),
    [anon_sym_COLONcase_COLON] = ACTIONS(97),
    [anon_sym_COLONdefine_COLON] = ACTIONS(97),
    [anon_sym_COLONwrite_COLON] = ACTIONS(97),
    [anon_sym_COLONwlog_COLON] = ACTIONS(97),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(97),
    [anon_sym_COLONclaim_COLON] = ACTIONS(97),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(97),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(97),
    [anon_sym_COLONpick_COLON] = ACTIONS(97),
    [anon_sym_COLONst_COLON] = ACTIONS(97),
    [anon_sym_COLONdraft_COLON] = ACTIONS(97),
    [anon_sym_COLONnote_COLON] = ACTIONS(97),
    [anon_sym_COLONspan_COLON] = ACTIONS(97),
    [anon_sym_COLONabstract_COLON] = ACTIONS(97),
    [anon_sym_COLONauthor_COLON] = ACTIONS(97),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(97),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(97),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(97),
    [anon_sym_COLONexample_COLON] = ACTIONS(97),
    [anon_sym_COLONitemize_COLON] = ACTIONS(97),
    [anon_sym_COLONlemma_COLON] = ACTIONS(97),
    [anon_sym_COLONfigure_COLON] = ACTIONS(97),
    [anon_sym_COLONp_COLON] = ACTIONS(97),
    [anon_sym_COLONproof_COLON] = ACTIONS(97),
    [anon_sym_COLONproposition_COLON] = ACTIONS(97),
    [anon_sym_COLONremark_COLON] = ACTIONS(97),
    [anon_sym_COLONsection_COLON] = ACTIONS(97),
    [anon_sym_COLONsketch_COLON] = ACTIONS(97),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(97),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(97),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(97),
    [anon_sym_COLONstep_COLON] = ACTIONS(97),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(97),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(97),
    [anon_sym_COLONemail_COLON] = ACTIONS(97),
    [anon_sym_COLONlabel_COLON] = ACTIONS(97),
    [anon_sym_COLONname_COLON] = ACTIONS(97),
    [anon_sym_COLONreftext_COLON] = ACTIONS(97),
    [anon_sym_COLONtitle_COLON] = ACTIONS(97),
    [anon_sym_COLONgoal_COLON] = ACTIONS(97),
    [anon_sym_COLONlang_COLON] = ACTIONS(97),
    [anon_sym_COLONicon_COLON] = ACTIONS(97),
    [anon_sym_COLONnonum_COLON] = ACTIONS(97),
    [anon_sym_COLONstrong_COLON] = ACTIONS(97),
    [anon_sym_COLONemphas_COLON] = ACTIONS(97),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(97),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(97),
    [anon_sym_COLONmsc_COLON] = ACTIONS(97),
    [anon_sym_COLONtypes_COLON] = ACTIONS(97),
    [anon_sym_COLONdate_COLON] = ACTIONS(97),
    [anon_sym_COLONpath_COLON] = ACTIONS(97),
    [anon_sym_COLONscale_COLON] = ACTIONS(97),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(97),
  },
  [STATE(8)] = {
    [anon_sym_COLON_COLON] = ACTIONS(101),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(101),
    [aux_sym_mathblock_token1] = ACTIONS(101),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(101),
    [anon_sym_COLONappendix_COLON] = ACTIONS(101),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(101),
    [anon_sym_COLONtoc_COLON] = ACTIONS(101),
    [aux_sym_specialblock_token1] = ACTIONS(101),
    [aux_sym_specialblock_token2] = ACTIONS(101),
    [aux_sym_specialblock_token3] = ACTIONS(101),
    [aux_sym_specialblock_token4] = ACTIONS(101),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(101),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(101),
    [anon_sym_COLONcaption_COLON] = ACTIONS(101),
    [anon_sym_COLONitem_COLON] = ACTIONS(101),
    [anon_sym_COLONprev_COLON] = ACTIONS(101),
    [anon_sym_COLONprev2_COLON] = ACTIONS(101),
    [anon_sym_COLONprev3_COLON] = ACTIONS(101),
    [aux_sym_specialinline_token1] = ACTIONS(103),
    [aux_sym_specialinline_token2] = ACTIONS(103),
    [anon_sym_COLONmath_COLON] = ACTIONS(101),
    [anon_sym_COLONcode_COLON] = ACTIONS(101),
    [aux_sym_specialinline_token3] = ACTIONS(101),
    [aux_sym_specialinline_token4] = ACTIONS(101),
    [anon_sym_COLONref_COLON] = ACTIONS(101),
    [anon_sym_COLONprevious_COLON] = ACTIONS(101),
    [anon_sym_COLONurl_COLON] = ACTIONS(101),
    [anon_sym_COLONcite_COLON] = ACTIONS(101),
    [anon_sym_COLONqed_COLON] = ACTIONS(101),
    [anon_sym_COLONtable_COLON] = ACTIONS(101),
    [anon_sym_COLONassume_COLON] = ACTIONS(101),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(101),
    [anon_sym_COLONprove_COLON] = ACTIONS(101),
    [anon_sym_COLONthen_COLON] = ACTIONS(101),
    [anon_sym_COLONnew_COLON] = ACTIONS(101),
    [anon_sym_COLONlet_COLON] = ACTIONS(101),
    [anon_sym_COLONcase_COLON] = ACTIONS(101),
    [anon_sym_COLONdefine_COLON] = ACTIONS(101),
    [anon_sym_COLONwrite_COLON] = ACTIONS(101),
    [anon_sym_COLONwlog_COLON] = ACTIONS(101),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(101),
    [anon_sym_COLONclaim_COLON] = ACTIONS(101),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(101),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(101),
    [anon_sym_COLONpick_COLON] = ACTIONS(101),
    [anon_sym_COLONst_COLON] = ACTIONS(101),
    [anon_sym_COLONdraft_COLON] = ACTIONS(101),
    [anon_sym_COLONnote_COLON] = ACTIONS(101),
    [anon_sym_COLONspan_COLON] = ACTIONS(101),
    [anon_sym_COLONabstract_COLON] = ACTIONS(101),
    [anon_sym_COLONauthor_COLON] = ACTIONS(101),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(101),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(101),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(101),
    [anon_sym_COLONexample_COLON] = ACTIONS(101),
    [anon_sym_COLONitemize_COLON] = ACTIONS(101),
    [anon_sym_COLONlemma_COLON] = ACTIONS(101),
    [anon_sym_COLONfigure_COLON] = ACTIONS(101),
    [anon_sym_COLONp_COLON] = ACTIONS(101),
    [anon_sym_COLONproof_COLON] = ACTIONS(101),
    [anon_sym_COLONproposition_COLON] = ACTIONS(101),
    [anon_sym_COLONremark_COLON] = ACTIONS(101),
    [anon_sym_COLONsection_COLON] = ACTIONS(101),
    [anon_sym_COLONsketch_COLON] = ACTIONS(101),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(101),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(101),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(101),
    [anon_sym_COLONstep_COLON] = ACTIONS(101),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(101),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(101),
    [anon_sym_COLONemail_COLON] = ACTIONS(101),
    [anon_sym_COLONlabel_COLON] = ACTIONS(101),
    [anon_sym_COLONname_COLON] = ACTIONS(101),
    [anon_sym_COLONreftext_COLON] = ACTIONS(101),
    [anon_sym_COLONtitle_COLON] = ACTIONS(101),
    [anon_sym_COLONgoal_COLON] = ACTIONS(101),
    [anon_sym_COLONlang_COLON] = ACTIONS(101),
    [anon_sym_COLONicon_COLON] = ACTIONS(101),
    [anon_sym_COLONnonum_COLON] = ACTIONS(101),
    [anon_sym_COLONstrong_COLON] = ACTIONS(101),
    [anon_sym_COLONemphas_COLON] = ACTIONS(101),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(101),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(101),
    [anon_sym_COLONmsc_COLON] = ACTIONS(101),
    [anon_sym_COLONtypes_COLON] = ACTIONS(101),
    [anon_sym_COLONdate_COLON] = ACTIONS(101),
    [anon_sym_COLONpath_COLON] = ACTIONS(101),
    [anon_sym_COLONscale_COLON] = ACTIONS(101),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(101),
  },
  [STATE(9)] = {
    [anon_sym_COLON_COLON] = ACTIONS(105),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(105),
    [aux_sym_mathblock_token1] = ACTIONS(105),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(105),
    [anon_sym_COLONappendix_COLON] = ACTIONS(105),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(105),
    [anon_sym_COLONtoc_COLON] = ACTIONS(105),
    [aux_sym_specialblock_token1] = ACTIONS(105),
    [aux_sym_specialblock_token2] = ACTIONS(105),
    [aux_sym_specialblock_token3] = ACTIONS(105),
    [aux_sym_specialblock_token4] = ACTIONS(105),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(105),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(105),
    [anon_sym_COLONcaption_COLON] = ACTIONS(105),
    [anon_sym_COLONitem_COLON] = ACTIONS(105),
    [anon_sym_COLONprev_COLON] = ACTIONS(105),
    [anon_sym_COLONprev2_COLON] = ACTIONS(105),
    [anon_sym_COLONprev3_COLON] = ACTIONS(105),
    [aux_sym_specialinline_token1] = ACTIONS(107),
    [aux_sym_specialinline_token2] = ACTIONS(107),
    [anon_sym_COLONmath_COLON] = ACTIONS(105),
    [anon_sym_COLONcode_COLON] = ACTIONS(105),
    [aux_sym_specialinline_token3] = ACTIONS(105),
    [aux_sym_specialinline_token4] = ACTIONS(105),
    [anon_sym_COLONref_COLON] = ACTIONS(105),
    [anon_sym_COLONprevious_COLON] = ACTIONS(105),
    [anon_sym_COLONurl_COLON] = ACTIONS(105),
    [anon_sym_COLONcite_COLON] = ACTIONS(105),
    [anon_sym_COLONqed_COLON] = ACTIONS(105),
    [anon_sym_COLONtable_COLON] = ACTIONS(105),
    [anon_sym_COLONassume_COLON] = ACTIONS(105),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(105),
    [anon_sym_COLONprove_COLON] = ACTIONS(105),
    [anon_sym_COLONthen_COLON] = ACTIONS(105),
    [anon_sym_COLONnew_COLON] = ACTIONS(105),
    [anon_sym_COLONlet_COLON] = ACTIONS(105),
    [anon_sym_COLONcase_COLON] = ACTIONS(105),
    [anon_sym_COLONdefine_COLON] = ACTIONS(105),
    [anon_sym_COLONwrite_COLON] = ACTIONS(105),
    [anon_sym_COLONwlog_COLON] = ACTIONS(105),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(105),
    [anon_sym_COLONclaim_COLON] = ACTIONS(105),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(105),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(105),
    [anon_sym_COLONpick_COLON] = ACTIONS(105),
    [anon_sym_COLONst_COLON] = ACTIONS(105),
    [anon_sym_COLONdraft_COLON] = ACTIONS(105),
    [anon_sym_COLONnote_COLON] = ACTIONS(105),
    [anon_sym_COLONspan_COLON] = ACTIONS(105),
    [anon_sym_COLONabstract_COLON] = ACTIONS(105),
    [anon_sym_COLONauthor_COLON] = ACTIONS(105),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(105),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(105),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(105),
    [anon_sym_COLONexample_COLON] = ACTIONS(105),
    [anon_sym_COLONitemize_COLON] = ACTIONS(105),
    [anon_sym_COLONlemma_COLON] = ACTIONS(105),
    [anon_sym_COLONfigure_COLON] = ACTIONS(105),
    [anon_sym_COLONp_COLON] = ACTIONS(105),
    [anon_sym_COLONproof_COLON] = ACTIONS(105),
    [anon_sym_COLONproposition_COLON] = ACTIONS(105),
    [anon_sym_COLONremark_COLON] = ACTIONS(105),
    [anon_sym_COLONsection_COLON] = ACTIONS(105),
    [anon_sym_COLONsketch_COLON] = ACTIONS(105),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(105),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(105),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(105),
    [anon_sym_COLONstep_COLON] = ACTIONS(105),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(105),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(105),
    [anon_sym_COLONemail_COLON] = ACTIONS(105),
    [anon_sym_COLONlabel_COLON] = ACTIONS(105),
    [anon_sym_COLONname_COLON] = ACTIONS(105),
    [anon_sym_COLONreftext_COLON] = ACTIONS(105),
    [anon_sym_COLONtitle_COLON] = ACTIONS(105),
    [anon_sym_COLONgoal_COLON] = ACTIONS(105),
    [anon_sym_COLONlang_COLON] = ACTIONS(105),
    [anon_sym_COLONicon_COLON] = ACTIONS(105),
    [anon_sym_COLONnonum_COLON] = ACTIONS(105),
    [anon_sym_COLONstrong_COLON] = ACTIONS(105),
    [anon_sym_COLONemphas_COLON] = ACTIONS(105),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(105),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(105),
    [anon_sym_COLONmsc_COLON] = ACTIONS(105),
    [anon_sym_COLONtypes_COLON] = ACTIONS(105),
    [anon_sym_COLONdate_COLON] = ACTIONS(105),
    [anon_sym_COLONpath_COLON] = ACTIONS(105),
    [anon_sym_COLONscale_COLON] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(105),
  },
  [STATE(10)] = {
    [anon_sym_COLON_COLON] = ACTIONS(109),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(109),
    [aux_sym_mathblock_token1] = ACTIONS(109),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(109),
    [anon_sym_COLONappendix_COLON] = ACTIONS(109),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(109),
    [anon_sym_COLONtoc_COLON] = ACTIONS(109),
    [aux_sym_specialblock_token1] = ACTIONS(109),
    [aux_sym_specialblock_token2] = ACTIONS(109),
    [aux_sym_specialblock_token3] = ACTIONS(109),
    [aux_sym_specialblock_token4] = ACTIONS(109),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(109),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(109),
    [anon_sym_COLONcaption_COLON] = ACTIONS(109),
    [anon_sym_COLONitem_COLON] = ACTIONS(109),
    [anon_sym_COLONprev_COLON] = ACTIONS(109),
    [anon_sym_COLONprev2_COLON] = ACTIONS(109),
    [anon_sym_COLONprev3_COLON] = ACTIONS(109),
    [aux_sym_specialinline_token1] = ACTIONS(111),
    [aux_sym_specialinline_token2] = ACTIONS(111),
    [anon_sym_COLONmath_COLON] = ACTIONS(109),
    [anon_sym_COLONcode_COLON] = ACTIONS(109),
    [aux_sym_specialinline_token3] = ACTIONS(109),
    [aux_sym_specialinline_token4] = ACTIONS(109),
    [anon_sym_COLONref_COLON] = ACTIONS(109),
    [anon_sym_COLONprevious_COLON] = ACTIONS(109),
    [anon_sym_COLONurl_COLON] = ACTIONS(109),
    [anon_sym_COLONcite_COLON] = ACTIONS(109),
    [anon_sym_COLONqed_COLON] = ACTIONS(109),
    [anon_sym_COLONtable_COLON] = ACTIONS(109),
    [anon_sym_COLONassume_COLON] = ACTIONS(109),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(109),
    [anon_sym_COLONprove_COLON] = ACTIONS(109),
    [anon_sym_COLONthen_COLON] = ACTIONS(109),
    [anon_sym_COLONnew_COLON] = ACTIONS(109),
    [anon_sym_COLONlet_COLON] = ACTIONS(109),
    [anon_sym_COLONcase_COLON] = ACTIONS(109),
    [anon_sym_COLONdefine_COLON] = ACTIONS(109),
    [anon_sym_COLONwrite_COLON] = ACTIONS(109),
    [anon_sym_COLONwlog_COLON] = ACTIONS(109),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(109),
    [anon_sym_COLONclaim_COLON] = ACTIONS(109),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(109),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(109),
    [anon_sym_COLONpick_COLON] = ACTIONS(109),
    [anon_sym_COLONst_COLON] = ACTIONS(109),
    [anon_sym_COLONdraft_COLON] = ACTIONS(109),
    [anon_sym_COLONnote_COLON] = ACTIONS(109),
    [anon_sym_COLONspan_COLON] = ACTIONS(109),
    [anon_sym_COLONabstract_COLON] = ACTIONS(109),
    [anon_sym_COLONauthor_COLON] = ACTIONS(109),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(109),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(109),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(109),
    [anon_sym_COLONexample_COLON] = ACTIONS(109),
    [anon_sym_COLONitemize_COLON] = ACTIONS(109),
    [anon_sym_COLONlemma_COLON] = ACTIONS(109),
    [anon_sym_COLONfigure_COLON] = ACTIONS(109),
    [anon_sym_COLONp_COLON] = ACTIONS(109),
    [anon_sym_COLONproof_COLON] = ACTIONS(109),
    [anon_sym_COLONproposition_COLON] = ACTIONS(109),
    [anon_sym_COLONremark_COLON] = ACTIONS(109),
    [anon_sym_COLONsection_COLON] = ACTIONS(109),
    [anon_sym_COLONsketch_COLON] = ACTIONS(109),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(109),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(109),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(109),
    [anon_sym_COLONstep_COLON] = ACTIONS(109),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(109),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(109),
    [anon_sym_COLONemail_COLON] = ACTIONS(109),
    [anon_sym_COLONlabel_COLON] = ACTIONS(109),
    [anon_sym_COLONname_COLON] = ACTIONS(109),
    [anon_sym_COLONreftext_COLON] = ACTIONS(109),
    [anon_sym_COLONtitle_COLON] = ACTIONS(109),
    [anon_sym_COLONgoal_COLON] = ACTIONS(109),
    [anon_sym_COLONlang_COLON] = ACTIONS(109),
    [anon_sym_COLONicon_COLON] = ACTIONS(109),
    [anon_sym_COLONnonum_COLON] = ACTIONS(109),
    [anon_sym_COLONstrong_COLON] = ACTIONS(109),
    [anon_sym_COLONemphas_COLON] = ACTIONS(109),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(109),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(109),
    [anon_sym_COLONmsc_COLON] = ACTIONS(109),
    [anon_sym_COLONtypes_COLON] = ACTIONS(109),
    [anon_sym_COLONdate_COLON] = ACTIONS(109),
    [anon_sym_COLONpath_COLON] = ACTIONS(109),
    [anon_sym_COLONscale_COLON] = ACTIONS(109),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(109),
  },
  [STATE(11)] = {
    [anon_sym_COLON_COLON] = ACTIONS(113),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(113),
    [aux_sym_mathblock_token1] = ACTIONS(113),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(113),
    [anon_sym_COLONappendix_COLON] = ACTIONS(113),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(113),
    [anon_sym_COLONtoc_COLON] = ACTIONS(113),
    [aux_sym_specialblock_token1] = ACTIONS(113),
    [aux_sym_specialblock_token2] = ACTIONS(113),
    [aux_sym_specialblock_token3] = ACTIONS(113),
    [aux_sym_specialblock_token4] = ACTIONS(113),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(113),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(113),
    [anon_sym_COLONcaption_COLON] = ACTIONS(113),
    [anon_sym_COLONitem_COLON] = ACTIONS(113),
    [anon_sym_COLONprev_COLON] = ACTIONS(113),
    [anon_sym_COLONprev2_COLON] = ACTIONS(113),
    [anon_sym_COLONprev3_COLON] = ACTIONS(113),
    [aux_sym_specialinline_token1] = ACTIONS(115),
    [aux_sym_specialinline_token2] = ACTIONS(115),
    [anon_sym_COLONmath_COLON] = ACTIONS(113),
    [anon_sym_COLONcode_COLON] = ACTIONS(113),
    [aux_sym_specialinline_token3] = ACTIONS(113),
    [aux_sym_specialinline_token4] = ACTIONS(113),
    [anon_sym_COLONref_COLON] = ACTIONS(113),
    [anon_sym_COLONprevious_COLON] = ACTIONS(113),
    [anon_sym_COLONurl_COLON] = ACTIONS(113),
    [anon_sym_COLONcite_COLON] = ACTIONS(113),
    [anon_sym_COLONqed_COLON] = ACTIONS(113),
    [anon_sym_COLONtable_COLON] = ACTIONS(113),
    [anon_sym_COLONassume_COLON] = ACTIONS(113),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(113),
    [anon_sym_COLONprove_COLON] = ACTIONS(113),
    [anon_sym_COLONthen_COLON] = ACTIONS(113),
    [anon_sym_COLONnew_COLON] = ACTIONS(113),
    [anon_sym_COLONlet_COLON] = ACTIONS(113),
    [anon_sym_COLONcase_COLON] = ACTIONS(113),
    [anon_sym_COLONdefine_COLON] = ACTIONS(113),
    [anon_sym_COLONwrite_COLON] = ACTIONS(113),
    [anon_sym_COLONwlog_COLON] = ACTIONS(113),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(113),
    [anon_sym_COLONclaim_COLON] = ACTIONS(113),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(113),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(113),
    [anon_sym_COLONpick_COLON] = ACTIONS(113),
    [anon_sym_COLONst_COLON] = ACTIONS(113),
    [anon_sym_COLONdraft_COLON] = ACTIONS(113),
    [anon_sym_COLONnote_COLON] = ACTIONS(113),
    [anon_sym_COLONspan_COLON] = ACTIONS(113),
    [anon_sym_COLONabstract_COLON] = ACTIONS(113),
    [anon_sym_COLONauthor_COLON] = ACTIONS(113),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(113),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(113),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(113),
    [anon_sym_COLONexample_COLON] = ACTIONS(113),
    [anon_sym_COLONitemize_COLON] = ACTIONS(113),
    [anon_sym_COLONlemma_COLON] = ACTIONS(113),
    [anon_sym_COLONfigure_COLON] = ACTIONS(113),
    [anon_sym_COLONp_COLON] = ACTIONS(113),
    [anon_sym_COLONproof_COLON] = ACTIONS(113),
    [anon_sym_COLONproposition_COLON] = ACTIONS(113),
    [anon_sym_COLONremark_COLON] = ACTIONS(113),
    [anon_sym_COLONsection_COLON] = ACTIONS(113),
    [anon_sym_COLONsketch_COLON] = ACTIONS(113),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(113),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(113),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(113),
    [anon_sym_COLONstep_COLON] = ACTIONS(113),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(113),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(113),
    [anon_sym_COLONemail_COLON] = ACTIONS(113),
    [anon_sym_COLONlabel_COLON] = ACTIONS(113),
    [anon_sym_COLONname_COLON] = ACTIONS(113),
    [anon_sym_COLONreftext_COLON] = ACTIONS(113),
    [anon_sym_COLONtitle_COLON] = ACTIONS(113),
    [anon_sym_COLONgoal_COLON] = ACTIONS(113),
    [anon_sym_COLONlang_COLON] = ACTIONS(113),
    [anon_sym_COLONicon_COLON] = ACTIONS(113),
    [anon_sym_COLONnonum_COLON] = ACTIONS(113),
    [anon_sym_COLONstrong_COLON] = ACTIONS(113),
    [anon_sym_COLONemphas_COLON] = ACTIONS(113),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(113),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(113),
    [anon_sym_COLONmsc_COLON] = ACTIONS(113),
    [anon_sym_COLONtypes_COLON] = ACTIONS(113),
    [anon_sym_COLONdate_COLON] = ACTIONS(113),
    [anon_sym_COLONpath_COLON] = ACTIONS(113),
    [anon_sym_COLONscale_COLON] = ACTIONS(113),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(113),
  },
  [STATE(12)] = {
    [anon_sym_COLON_COLON] = ACTIONS(117),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(117),
    [aux_sym_mathblock_token1] = ACTIONS(117),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(117),
    [anon_sym_COLONappendix_COLON] = ACTIONS(117),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(117),
    [anon_sym_COLONtoc_COLON] = ACTIONS(117),
    [aux_sym_specialblock_token1] = ACTIONS(117),
    [aux_sym_specialblock_token2] = ACTIONS(117),
    [aux_sym_specialblock_token3] = ACTIONS(117),
    [aux_sym_specialblock_token4] = ACTIONS(117),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(117),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(117),
    [anon_sym_COLONcaption_COLON] = ACTIONS(117),
    [anon_sym_COLONitem_COLON] = ACTIONS(117),
    [anon_sym_COLONprev_COLON] = ACTIONS(117),
    [anon_sym_COLONprev2_COLON] = ACTIONS(117),
    [anon_sym_COLONprev3_COLON] = ACTIONS(117),
    [aux_sym_specialinline_token1] = ACTIONS(119),
    [aux_sym_specialinline_token2] = ACTIONS(119),
    [anon_sym_COLONmath_COLON] = ACTIONS(117),
    [anon_sym_COLONcode_COLON] = ACTIONS(117),
    [aux_sym_specialinline_token3] = ACTIONS(117),
    [aux_sym_specialinline_token4] = ACTIONS(117),
    [anon_sym_COLONref_COLON] = ACTIONS(117),
    [anon_sym_COLONprevious_COLON] = ACTIONS(117),
    [anon_sym_COLONurl_COLON] = ACTIONS(117),
    [anon_sym_COLONcite_COLON] = ACTIONS(117),
    [anon_sym_COLONqed_COLON] = ACTIONS(117),
    [anon_sym_COLONtable_COLON] = ACTIONS(117),
    [anon_sym_COLONassume_COLON] = ACTIONS(117),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(117),
    [anon_sym_COLONprove_COLON] = ACTIONS(117),
    [anon_sym_COLONthen_COLON] = ACTIONS(117),
    [anon_sym_COLONnew_COLON] = ACTIONS(117),
    [anon_sym_COLONlet_COLON] = ACTIONS(117),
    [anon_sym_COLONcase_COLON] = ACTIONS(117),
    [anon_sym_COLONdefine_COLON] = ACTIONS(117),
    [anon_sym_COLONwrite_COLON] = ACTIONS(117),
    [anon_sym_COLONwlog_COLON] = ACTIONS(117),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(117),
    [anon_sym_COLONclaim_COLON] = ACTIONS(117),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(117),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(117),
    [anon_sym_COLONpick_COLON] = ACTIONS(117),
    [anon_sym_COLONst_COLON] = ACTIONS(117),
    [anon_sym_COLONdraft_COLON] = ACTIONS(117),
    [anon_sym_COLONnote_COLON] = ACTIONS(117),
    [anon_sym_COLONspan_COLON] = ACTIONS(117),
    [anon_sym_COLONabstract_COLON] = ACTIONS(117),
    [anon_sym_COLONauthor_COLON] = ACTIONS(117),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(117),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(117),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(117),
    [anon_sym_COLONexample_COLON] = ACTIONS(117),
    [anon_sym_COLONitemize_COLON] = ACTIONS(117),
    [anon_sym_COLONlemma_COLON] = ACTIONS(117),
    [anon_sym_COLONfigure_COLON] = ACTIONS(117),
    [anon_sym_COLONp_COLON] = ACTIONS(117),
    [anon_sym_COLONproof_COLON] = ACTIONS(117),
    [anon_sym_COLONproposition_COLON] = ACTIONS(117),
    [anon_sym_COLONremark_COLON] = ACTIONS(117),
    [anon_sym_COLONsection_COLON] = ACTIONS(117),
    [anon_sym_COLONsketch_COLON] = ACTIONS(117),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(117),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(117),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(117),
    [anon_sym_COLONstep_COLON] = ACTIONS(117),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(117),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(117),
    [anon_sym_COLONemail_COLON] = ACTIONS(117),
    [anon_sym_COLONlabel_COLON] = ACTIONS(117),
    [anon_sym_COLONname_COLON] = ACTIONS(117),
    [anon_sym_COLONreftext_COLON] = ACTIONS(117),
    [anon_sym_COLONtitle_COLON] = ACTIONS(117),
    [anon_sym_COLONgoal_COLON] = ACTIONS(117),
    [anon_sym_COLONlang_COLON] = ACTIONS(117),
    [anon_sym_COLONicon_COLON] = ACTIONS(117),
    [anon_sym_COLONnonum_COLON] = ACTIONS(117),
    [anon_sym_COLONstrong_COLON] = ACTIONS(117),
    [anon_sym_COLONemphas_COLON] = ACTIONS(117),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(117),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(117),
    [anon_sym_COLONmsc_COLON] = ACTIONS(117),
    [anon_sym_COLONtypes_COLON] = ACTIONS(117),
    [anon_sym_COLONdate_COLON] = ACTIONS(117),
    [anon_sym_COLONpath_COLON] = ACTIONS(117),
    [anon_sym_COLONscale_COLON] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(117),
  },
  [STATE(13)] = {
    [anon_sym_COLON_COLON] = ACTIONS(121),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(121),
    [aux_sym_mathblock_token1] = ACTIONS(121),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(121),
    [anon_sym_COLONappendix_COLON] = ACTIONS(121),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(121),
    [anon_sym_COLONtoc_COLON] = ACTIONS(121),
    [aux_sym_specialblock_token1] = ACTIONS(121),
    [aux_sym_specialblock_token2] = ACTIONS(121),
    [aux_sym_specialblock_token3] = ACTIONS(121),
    [aux_sym_specialblock_token4] = ACTIONS(121),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(121),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(121),
    [anon_sym_COLONcaption_COLON] = ACTIONS(121),
    [anon_sym_COLONitem_COLON] = ACTIONS(121),
    [anon_sym_COLONprev_COLON] = ACTIONS(121),
    [anon_sym_COLONprev2_COLON] = ACTIONS(121),
    [anon_sym_COLONprev3_COLON] = ACTIONS(121),
    [aux_sym_specialinline_token1] = ACTIONS(123),
    [aux_sym_specialinline_token2] = ACTIONS(123),
    [anon_sym_COLONmath_COLON] = ACTIONS(121),
    [anon_sym_COLONcode_COLON] = ACTIONS(121),
    [aux_sym_specialinline_token3] = ACTIONS(121),
    [aux_sym_specialinline_token4] = ACTIONS(121),
    [anon_sym_COLONref_COLON] = ACTIONS(121),
    [anon_sym_COLONprevious_COLON] = ACTIONS(121),
    [anon_sym_COLONurl_COLON] = ACTIONS(121),
    [anon_sym_COLONcite_COLON] = ACTIONS(121),
    [anon_sym_COLONqed_COLON] = ACTIONS(121),
    [anon_sym_COLONtable_COLON] = ACTIONS(121),
    [anon_sym_COLONassume_COLON] = ACTIONS(121),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(121),
    [anon_sym_COLONprove_COLON] = ACTIONS(121),
    [anon_sym_COLONthen_COLON] = ACTIONS(121),
    [anon_sym_COLONnew_COLON] = ACTIONS(121),
    [anon_sym_COLONlet_COLON] = ACTIONS(121),
    [anon_sym_COLONcase_COLON] = ACTIONS(121),
    [anon_sym_COLONdefine_COLON] = ACTIONS(121),
    [anon_sym_COLONwrite_COLON] = ACTIONS(121),
    [anon_sym_COLONwlog_COLON] = ACTIONS(121),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(121),
    [anon_sym_COLONclaim_COLON] = ACTIONS(121),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(121),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(121),
    [anon_sym_COLONpick_COLON] = ACTIONS(121),
    [anon_sym_COLONst_COLON] = ACTIONS(121),
    [anon_sym_COLONdraft_COLON] = ACTIONS(121),
    [anon_sym_COLONnote_COLON] = ACTIONS(121),
    [anon_sym_COLONspan_COLON] = ACTIONS(121),
    [anon_sym_COLONabstract_COLON] = ACTIONS(121),
    [anon_sym_COLONauthor_COLON] = ACTIONS(121),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(121),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(121),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(121),
    [anon_sym_COLONexample_COLON] = ACTIONS(121),
    [anon_sym_COLONitemize_COLON] = ACTIONS(121),
    [anon_sym_COLONlemma_COLON] = ACTIONS(121),
    [anon_sym_COLONfigure_COLON] = ACTIONS(121),
    [anon_sym_COLONp_COLON] = ACTIONS(121),
    [anon_sym_COLONproof_COLON] = ACTIONS(121),
    [anon_sym_COLONproposition_COLON] = ACTIONS(121),
    [anon_sym_COLONremark_COLON] = ACTIONS(121),
    [anon_sym_COLONsection_COLON] = ACTIONS(121),
    [anon_sym_COLONsketch_COLON] = ACTIONS(121),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(121),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(121),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(121),
    [anon_sym_COLONstep_COLON] = ACTIONS(121),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(121),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(121),
    [anon_sym_COLONemail_COLON] = ACTIONS(121),
    [anon_sym_COLONlabel_COLON] = ACTIONS(121),
    [anon_sym_COLONname_COLON] = ACTIONS(121),
    [anon_sym_COLONreftext_COLON] = ACTIONS(121),
    [anon_sym_COLONtitle_COLON] = ACTIONS(121),
    [anon_sym_COLONgoal_COLON] = ACTIONS(121),
    [anon_sym_COLONlang_COLON] = ACTIONS(121),
    [anon_sym_COLONicon_COLON] = ACTIONS(121),
    [anon_sym_COLONnonum_COLON] = ACTIONS(121),
    [anon_sym_COLONstrong_COLON] = ACTIONS(121),
    [anon_sym_COLONemphas_COLON] = ACTIONS(121),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(121),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(121),
    [anon_sym_COLONmsc_COLON] = ACTIONS(121),
    [anon_sym_COLONtypes_COLON] = ACTIONS(121),
    [anon_sym_COLONdate_COLON] = ACTIONS(121),
    [anon_sym_COLONpath_COLON] = ACTIONS(121),
    [anon_sym_COLONscale_COLON] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(121),
  },
  [STATE(14)] = {
    [sym_block] = STATE(18),
    [sym_paragraph] = STATE(18),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(18),
    [sym_specialblock] = STATE(18),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(18),
    [anon_sym_COLON_COLON] = ACTIONS(125),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(15)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(127),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(16)] = {
    [sym_block] = STATE(21),
    [sym_paragraph] = STATE(21),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(21),
    [sym_specialblock] = STATE(21),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(21),
    [anon_sym_COLON_COLON] = ACTIONS(129),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(17)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(18)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(133),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(19)] = {
    [sym_block] = STATE(23),
    [sym_paragraph] = STATE(23),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(23),
    [sym_specialblock] = STATE(23),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(23),
    [anon_sym_COLON_COLON] = ACTIONS(135),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(20)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(21)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(139),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(22)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(141),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(143),
    [aux_sym_mathblock_token1] = ACTIONS(146),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(149),
    [anon_sym_COLONappendix_COLON] = ACTIONS(152),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(155),
    [anon_sym_COLONtoc_COLON] = ACTIONS(155),
    [aux_sym_specialblock_token1] = ACTIONS(158),
    [aux_sym_specialblock_token2] = ACTIONS(158),
    [aux_sym_specialblock_token3] = ACTIONS(158),
    [aux_sym_specialblock_token4] = ACTIONS(161),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(164),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(167),
    [anon_sym_COLONcaption_COLON] = ACTIONS(170),
    [anon_sym_COLONitem_COLON] = ACTIONS(173),
    [anon_sym_COLONprev_COLON] = ACTIONS(176),
    [anon_sym_COLONprev2_COLON] = ACTIONS(176),
    [anon_sym_COLONprev3_COLON] = ACTIONS(176),
    [aux_sym_specialinline_token1] = ACTIONS(179),
    [aux_sym_specialinline_token2] = ACTIONS(182),
    [anon_sym_COLONmath_COLON] = ACTIONS(185),
    [anon_sym_COLONcode_COLON] = ACTIONS(188),
    [aux_sym_specialinline_token3] = ACTIONS(191),
    [aux_sym_specialinline_token4] = ACTIONS(194),
    [anon_sym_COLONref_COLON] = ACTIONS(197),
    [anon_sym_COLONprevious_COLON] = ACTIONS(200),
    [anon_sym_COLONurl_COLON] = ACTIONS(203),
    [anon_sym_COLONcite_COLON] = ACTIONS(206),
    [anon_sym_COLONqed_COLON] = ACTIONS(209),
    [anon_sym_COLONtable_COLON] = ACTIONS(212),
    [anon_sym_COLONassume_COLON] = ACTIONS(215),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(215),
    [anon_sym_COLONprove_COLON] = ACTIONS(215),
    [anon_sym_COLONthen_COLON] = ACTIONS(215),
    [anon_sym_COLONnew_COLON] = ACTIONS(215),
    [anon_sym_COLONlet_COLON] = ACTIONS(215),
    [anon_sym_COLONcase_COLON] = ACTIONS(215),
    [anon_sym_COLONdefine_COLON] = ACTIONS(215),
    [anon_sym_COLONwrite_COLON] = ACTIONS(215),
    [anon_sym_COLONwlog_COLON] = ACTIONS(215),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(215),
    [anon_sym_COLONclaim_COLON] = ACTIONS(215),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(215),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(215),
    [anon_sym_COLONpick_COLON] = ACTIONS(215),
    [anon_sym_COLONst_COLON] = ACTIONS(215),
    [anon_sym_COLONdraft_COLON] = ACTIONS(218),
    [anon_sym_COLONnote_COLON] = ACTIONS(218),
    [anon_sym_COLONspan_COLON] = ACTIONS(218),
    [anon_sym_COLONabstract_COLON] = ACTIONS(221),
    [anon_sym_COLONauthor_COLON] = ACTIONS(221),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(221),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(221),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(221),
    [anon_sym_COLONexample_COLON] = ACTIONS(221),
    [anon_sym_COLONitemize_COLON] = ACTIONS(221),
    [anon_sym_COLONlemma_COLON] = ACTIONS(221),
    [anon_sym_COLONfigure_COLON] = ACTIONS(221),
    [anon_sym_COLONp_COLON] = ACTIONS(221),
    [anon_sym_COLONproof_COLON] = ACTIONS(221),
    [anon_sym_COLONproposition_COLON] = ACTIONS(221),
    [anon_sym_COLONremark_COLON] = ACTIONS(221),
    [anon_sym_COLONsection_COLON] = ACTIONS(221),
    [anon_sym_COLONsketch_COLON] = ACTIONS(221),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(221),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(221),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(221),
    [anon_sym_COLONstep_COLON] = ACTIONS(221),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(221),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(224),
  },
  [STATE(23)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(79),
    [sym_construct] = STATE(79),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(62),
    [sym_item] = STATE(62),
    [sym_specialinline] = STATE(79),
    [sym_specialconstruct] = STATE(79),
    [sym_table] = STATE(25),
    [sym__paragraphcontent_no_special] = STATE(79),
    [aux_sym_source_file_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(227),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(11),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(15),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(17),
    [anon_sym_COLONtoc_COLON] = ACTIONS(17),
    [aux_sym_specialblock_token1] = ACTIONS(19),
    [aux_sym_specialblock_token2] = ACTIONS(19),
    [aux_sym_specialblock_token3] = ACTIONS(19),
    [aux_sym_specialblock_token4] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(24)] = {
    [anon_sym_COLON_COLON] = ACTIONS(229),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(229),
    [aux_sym_mathblock_token1] = ACTIONS(229),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(229),
    [anon_sym_COLONappendix_COLON] = ACTIONS(229),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(229),
    [anon_sym_COLONtoc_COLON] = ACTIONS(229),
    [aux_sym_specialblock_token1] = ACTIONS(229),
    [aux_sym_specialblock_token2] = ACTIONS(229),
    [aux_sym_specialblock_token3] = ACTIONS(229),
    [aux_sym_specialblock_token4] = ACTIONS(229),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(229),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(229),
    [anon_sym_COLONcaption_COLON] = ACTIONS(229),
    [anon_sym_COLONitem_COLON] = ACTIONS(229),
    [anon_sym_COLONprev_COLON] = ACTIONS(229),
    [anon_sym_COLONprev2_COLON] = ACTIONS(229),
    [anon_sym_COLONprev3_COLON] = ACTIONS(229),
    [aux_sym_specialinline_token1] = ACTIONS(231),
    [aux_sym_specialinline_token2] = ACTIONS(231),
    [anon_sym_COLONmath_COLON] = ACTIONS(229),
    [anon_sym_COLONcode_COLON] = ACTIONS(229),
    [aux_sym_specialinline_token3] = ACTIONS(229),
    [aux_sym_specialinline_token4] = ACTIONS(229),
    [anon_sym_COLONref_COLON] = ACTIONS(229),
    [anon_sym_COLONprevious_COLON] = ACTIONS(229),
    [anon_sym_COLONurl_COLON] = ACTIONS(229),
    [anon_sym_COLONcite_COLON] = ACTIONS(229),
    [anon_sym_COLONqed_COLON] = ACTIONS(229),
    [anon_sym_COLONtable_COLON] = ACTIONS(229),
    [anon_sym_COLONassume_COLON] = ACTIONS(229),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(229),
    [anon_sym_COLONprove_COLON] = ACTIONS(229),
    [anon_sym_COLONthen_COLON] = ACTIONS(229),
    [anon_sym_COLONnew_COLON] = ACTIONS(229),
    [anon_sym_COLONlet_COLON] = ACTIONS(229),
    [anon_sym_COLONcase_COLON] = ACTIONS(229),
    [anon_sym_COLONdefine_COLON] = ACTIONS(229),
    [anon_sym_COLONwrite_COLON] = ACTIONS(229),
    [anon_sym_COLONwlog_COLON] = ACTIONS(229),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(229),
    [anon_sym_COLONclaim_COLON] = ACTIONS(229),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(229),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(229),
    [anon_sym_COLONpick_COLON] = ACTIONS(229),
    [anon_sym_COLONst_COLON] = ACTIONS(229),
    [anon_sym_COLONdraft_COLON] = ACTIONS(229),
    [anon_sym_COLONnote_COLON] = ACTIONS(229),
    [anon_sym_COLONspan_COLON] = ACTIONS(229),
    [anon_sym_COLONabstract_COLON] = ACTIONS(229),
    [anon_sym_COLONauthor_COLON] = ACTIONS(229),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(229),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(229),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(229),
    [anon_sym_COLONexample_COLON] = ACTIONS(229),
    [anon_sym_COLONitemize_COLON] = ACTIONS(229),
    [anon_sym_COLONlemma_COLON] = ACTIONS(229),
    [anon_sym_COLONfigure_COLON] = ACTIONS(229),
    [anon_sym_COLONp_COLON] = ACTIONS(229),
    [anon_sym_COLONproof_COLON] = ACTIONS(229),
    [anon_sym_COLONproposition_COLON] = ACTIONS(229),
    [anon_sym_COLONremark_COLON] = ACTIONS(229),
    [anon_sym_COLONsection_COLON] = ACTIONS(229),
    [anon_sym_COLONsketch_COLON] = ACTIONS(229),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(229),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(229),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(229),
    [anon_sym_COLONstep_COLON] = ACTIONS(229),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(229),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(229),
  },
  [STATE(25)] = {
    [anon_sym_COLON_COLON] = ACTIONS(233),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(233),
    [aux_sym_mathblock_token1] = ACTIONS(233),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(233),
    [anon_sym_COLONappendix_COLON] = ACTIONS(233),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(233),
    [anon_sym_COLONtoc_COLON] = ACTIONS(233),
    [aux_sym_specialblock_token1] = ACTIONS(233),
    [aux_sym_specialblock_token2] = ACTIONS(233),
    [aux_sym_specialblock_token3] = ACTIONS(233),
    [aux_sym_specialblock_token4] = ACTIONS(233),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(233),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(233),
    [anon_sym_COLONcaption_COLON] = ACTIONS(233),
    [anon_sym_COLONitem_COLON] = ACTIONS(233),
    [anon_sym_COLONprev_COLON] = ACTIONS(233),
    [anon_sym_COLONprev2_COLON] = ACTIONS(233),
    [anon_sym_COLONprev3_COLON] = ACTIONS(233),
    [aux_sym_specialinline_token1] = ACTIONS(235),
    [aux_sym_specialinline_token2] = ACTIONS(235),
    [anon_sym_COLONmath_COLON] = ACTIONS(233),
    [anon_sym_COLONcode_COLON] = ACTIONS(233),
    [aux_sym_specialinline_token3] = ACTIONS(233),
    [aux_sym_specialinline_token4] = ACTIONS(233),
    [anon_sym_COLONref_COLON] = ACTIONS(233),
    [anon_sym_COLONprevious_COLON] = ACTIONS(233),
    [anon_sym_COLONurl_COLON] = ACTIONS(233),
    [anon_sym_COLONcite_COLON] = ACTIONS(233),
    [anon_sym_COLONqed_COLON] = ACTIONS(233),
    [anon_sym_COLONtable_COLON] = ACTIONS(233),
    [anon_sym_COLONassume_COLON] = ACTIONS(233),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(233),
    [anon_sym_COLONprove_COLON] = ACTIONS(233),
    [anon_sym_COLONthen_COLON] = ACTIONS(233),
    [anon_sym_COLONnew_COLON] = ACTIONS(233),
    [anon_sym_COLONlet_COLON] = ACTIONS(233),
    [anon_sym_COLONcase_COLON] = ACTIONS(233),
    [anon_sym_COLONdefine_COLON] = ACTIONS(233),
    [anon_sym_COLONwrite_COLON] = ACTIONS(233),
    [anon_sym_COLONwlog_COLON] = ACTIONS(233),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(233),
    [anon_sym_COLONclaim_COLON] = ACTIONS(233),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(233),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(233),
    [anon_sym_COLONpick_COLON] = ACTIONS(233),
    [anon_sym_COLONst_COLON] = ACTIONS(233),
    [anon_sym_COLONdraft_COLON] = ACTIONS(233),
    [anon_sym_COLONnote_COLON] = ACTIONS(233),
    [anon_sym_COLONspan_COLON] = ACTIONS(233),
    [anon_sym_COLONabstract_COLON] = ACTIONS(233),
    [anon_sym_COLONauthor_COLON] = ACTIONS(233),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(233),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(233),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(233),
    [anon_sym_COLONexample_COLON] = ACTIONS(233),
    [anon_sym_COLONitemize_COLON] = ACTIONS(233),
    [anon_sym_COLONlemma_COLON] = ACTIONS(233),
    [anon_sym_COLONfigure_COLON] = ACTIONS(233),
    [anon_sym_COLONp_COLON] = ACTIONS(233),
    [anon_sym_COLONproof_COLON] = ACTIONS(233),
    [anon_sym_COLONproposition_COLON] = ACTIONS(233),
    [anon_sym_COLONremark_COLON] = ACTIONS(233),
    [anon_sym_COLONsection_COLON] = ACTIONS(233),
    [anon_sym_COLONsketch_COLON] = ACTIONS(233),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(233),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(233),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(233),
    [anon_sym_COLONstep_COLON] = ACTIONS(233),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(233),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(233),
  },
  [STATE(26)] = {
    [anon_sym_COLON_COLON] = ACTIONS(237),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(237),
    [aux_sym_mathblock_token1] = ACTIONS(237),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(237),
    [anon_sym_COLONappendix_COLON] = ACTIONS(237),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(237),
    [anon_sym_COLONtoc_COLON] = ACTIONS(237),
    [aux_sym_specialblock_token1] = ACTIONS(237),
    [aux_sym_specialblock_token2] = ACTIONS(237),
    [aux_sym_specialblock_token3] = ACTIONS(237),
    [aux_sym_specialblock_token4] = ACTIONS(237),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(237),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(237),
    [anon_sym_COLONcaption_COLON] = ACTIONS(237),
    [anon_sym_COLONitem_COLON] = ACTIONS(237),
    [anon_sym_COLONprev_COLON] = ACTIONS(237),
    [anon_sym_COLONprev2_COLON] = ACTIONS(237),
    [anon_sym_COLONprev3_COLON] = ACTIONS(237),
    [aux_sym_specialinline_token1] = ACTIONS(239),
    [aux_sym_specialinline_token2] = ACTIONS(239),
    [anon_sym_COLONmath_COLON] = ACTIONS(237),
    [anon_sym_COLONcode_COLON] = ACTIONS(237),
    [aux_sym_specialinline_token3] = ACTIONS(237),
    [aux_sym_specialinline_token4] = ACTIONS(237),
    [anon_sym_COLONref_COLON] = ACTIONS(237),
    [anon_sym_COLONprevious_COLON] = ACTIONS(237),
    [anon_sym_COLONurl_COLON] = ACTIONS(237),
    [anon_sym_COLONcite_COLON] = ACTIONS(237),
    [anon_sym_COLONqed_COLON] = ACTIONS(237),
    [anon_sym_COLONtable_COLON] = ACTIONS(237),
    [anon_sym_COLONassume_COLON] = ACTIONS(237),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(237),
    [anon_sym_COLONprove_COLON] = ACTIONS(237),
    [anon_sym_COLONthen_COLON] = ACTIONS(237),
    [anon_sym_COLONnew_COLON] = ACTIONS(237),
    [anon_sym_COLONlet_COLON] = ACTIONS(237),
    [anon_sym_COLONcase_COLON] = ACTIONS(237),
    [anon_sym_COLONdefine_COLON] = ACTIONS(237),
    [anon_sym_COLONwrite_COLON] = ACTIONS(237),
    [anon_sym_COLONwlog_COLON] = ACTIONS(237),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(237),
    [anon_sym_COLONclaim_COLON] = ACTIONS(237),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(237),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(237),
    [anon_sym_COLONpick_COLON] = ACTIONS(237),
    [anon_sym_COLONst_COLON] = ACTIONS(237),
    [anon_sym_COLONdraft_COLON] = ACTIONS(237),
    [anon_sym_COLONnote_COLON] = ACTIONS(237),
    [anon_sym_COLONspan_COLON] = ACTIONS(237),
    [anon_sym_COLONabstract_COLON] = ACTIONS(237),
    [anon_sym_COLONauthor_COLON] = ACTIONS(237),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(237),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(237),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(237),
    [anon_sym_COLONexample_COLON] = ACTIONS(237),
    [anon_sym_COLONitemize_COLON] = ACTIONS(237),
    [anon_sym_COLONlemma_COLON] = ACTIONS(237),
    [anon_sym_COLONfigure_COLON] = ACTIONS(237),
    [anon_sym_COLONp_COLON] = ACTIONS(237),
    [anon_sym_COLONproof_COLON] = ACTIONS(237),
    [anon_sym_COLONproposition_COLON] = ACTIONS(237),
    [anon_sym_COLONremark_COLON] = ACTIONS(237),
    [anon_sym_COLONsection_COLON] = ACTIONS(237),
    [anon_sym_COLONsketch_COLON] = ACTIONS(237),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(237),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(237),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(237),
    [anon_sym_COLONstep_COLON] = ACTIONS(237),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(237),
  },
  [STATE(27)] = {
    [anon_sym_COLON_COLON] = ACTIONS(241),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(241),
    [aux_sym_mathblock_token1] = ACTIONS(241),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(241),
    [anon_sym_COLONappendix_COLON] = ACTIONS(241),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(241),
    [anon_sym_COLONtoc_COLON] = ACTIONS(241),
    [aux_sym_specialblock_token1] = ACTIONS(241),
    [aux_sym_specialblock_token2] = ACTIONS(241),
    [aux_sym_specialblock_token3] = ACTIONS(241),
    [aux_sym_specialblock_token4] = ACTIONS(241),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(241),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(241),
    [anon_sym_COLONcaption_COLON] = ACTIONS(241),
    [anon_sym_COLONitem_COLON] = ACTIONS(241),
    [anon_sym_COLONprev_COLON] = ACTIONS(241),
    [anon_sym_COLONprev2_COLON] = ACTIONS(241),
    [anon_sym_COLONprev3_COLON] = ACTIONS(241),
    [aux_sym_specialinline_token1] = ACTIONS(243),
    [aux_sym_specialinline_token2] = ACTIONS(243),
    [anon_sym_COLONmath_COLON] = ACTIONS(241),
    [anon_sym_COLONcode_COLON] = ACTIONS(241),
    [aux_sym_specialinline_token3] = ACTIONS(241),
    [aux_sym_specialinline_token4] = ACTIONS(241),
    [anon_sym_COLONref_COLON] = ACTIONS(241),
    [anon_sym_COLONprevious_COLON] = ACTIONS(241),
    [anon_sym_COLONurl_COLON] = ACTIONS(241),
    [anon_sym_COLONcite_COLON] = ACTIONS(241),
    [anon_sym_COLONqed_COLON] = ACTIONS(241),
    [anon_sym_COLONtable_COLON] = ACTIONS(241),
    [anon_sym_COLONassume_COLON] = ACTIONS(241),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(241),
    [anon_sym_COLONprove_COLON] = ACTIONS(241),
    [anon_sym_COLONthen_COLON] = ACTIONS(241),
    [anon_sym_COLONnew_COLON] = ACTIONS(241),
    [anon_sym_COLONlet_COLON] = ACTIONS(241),
    [anon_sym_COLONcase_COLON] = ACTIONS(241),
    [anon_sym_COLONdefine_COLON] = ACTIONS(241),
    [anon_sym_COLONwrite_COLON] = ACTIONS(241),
    [anon_sym_COLONwlog_COLON] = ACTIONS(241),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(241),
    [anon_sym_COLONclaim_COLON] = ACTIONS(241),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(241),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(241),
    [anon_sym_COLONpick_COLON] = ACTIONS(241),
    [anon_sym_COLONst_COLON] = ACTIONS(241),
    [anon_sym_COLONdraft_COLON] = ACTIONS(241),
    [anon_sym_COLONnote_COLON] = ACTIONS(241),
    [anon_sym_COLONspan_COLON] = ACTIONS(241),
    [anon_sym_COLONabstract_COLON] = ACTIONS(241),
    [anon_sym_COLONauthor_COLON] = ACTIONS(241),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(241),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(241),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(241),
    [anon_sym_COLONexample_COLON] = ACTIONS(241),
    [anon_sym_COLONitemize_COLON] = ACTIONS(241),
    [anon_sym_COLONlemma_COLON] = ACTIONS(241),
    [anon_sym_COLONfigure_COLON] = ACTIONS(241),
    [anon_sym_COLONp_COLON] = ACTIONS(241),
    [anon_sym_COLONproof_COLON] = ACTIONS(241),
    [anon_sym_COLONproposition_COLON] = ACTIONS(241),
    [anon_sym_COLONremark_COLON] = ACTIONS(241),
    [anon_sym_COLONsection_COLON] = ACTIONS(241),
    [anon_sym_COLONsketch_COLON] = ACTIONS(241),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(241),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(241),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(241),
    [anon_sym_COLONstep_COLON] = ACTIONS(241),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(241),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(241),
  },
  [STATE(28)] = {
    [anon_sym_COLON_COLON] = ACTIONS(245),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(245),
    [aux_sym_mathblock_token1] = ACTIONS(245),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(245),
    [anon_sym_COLONappendix_COLON] = ACTIONS(245),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(245),
    [anon_sym_COLONtoc_COLON] = ACTIONS(245),
    [aux_sym_specialblock_token1] = ACTIONS(245),
    [aux_sym_specialblock_token2] = ACTIONS(245),
    [aux_sym_specialblock_token3] = ACTIONS(245),
    [aux_sym_specialblock_token4] = ACTIONS(245),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(245),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(245),
    [anon_sym_COLONcaption_COLON] = ACTIONS(245),
    [anon_sym_COLONitem_COLON] = ACTIONS(245),
    [anon_sym_COLONprev_COLON] = ACTIONS(245),
    [anon_sym_COLONprev2_COLON] = ACTIONS(245),
    [anon_sym_COLONprev3_COLON] = ACTIONS(245),
    [aux_sym_specialinline_token1] = ACTIONS(247),
    [aux_sym_specialinline_token2] = ACTIONS(247),
    [anon_sym_COLONmath_COLON] = ACTIONS(245),
    [anon_sym_COLONcode_COLON] = ACTIONS(245),
    [aux_sym_specialinline_token3] = ACTIONS(245),
    [aux_sym_specialinline_token4] = ACTIONS(245),
    [anon_sym_COLONref_COLON] = ACTIONS(245),
    [anon_sym_COLONprevious_COLON] = ACTIONS(245),
    [anon_sym_COLONurl_COLON] = ACTIONS(245),
    [anon_sym_COLONcite_COLON] = ACTIONS(245),
    [anon_sym_COLONqed_COLON] = ACTIONS(245),
    [anon_sym_COLONtable_COLON] = ACTIONS(245),
    [anon_sym_COLONassume_COLON] = ACTIONS(245),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(245),
    [anon_sym_COLONprove_COLON] = ACTIONS(245),
    [anon_sym_COLONthen_COLON] = ACTIONS(245),
    [anon_sym_COLONnew_COLON] = ACTIONS(245),
    [anon_sym_COLONlet_COLON] = ACTIONS(245),
    [anon_sym_COLONcase_COLON] = ACTIONS(245),
    [anon_sym_COLONdefine_COLON] = ACTIONS(245),
    [anon_sym_COLONwrite_COLON] = ACTIONS(245),
    [anon_sym_COLONwlog_COLON] = ACTIONS(245),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(245),
    [anon_sym_COLONclaim_COLON] = ACTIONS(245),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(245),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(245),
    [anon_sym_COLONpick_COLON] = ACTIONS(245),
    [anon_sym_COLONst_COLON] = ACTIONS(245),
    [anon_sym_COLONdraft_COLON] = ACTIONS(245),
    [anon_sym_COLONnote_COLON] = ACTIONS(245),
    [anon_sym_COLONspan_COLON] = ACTIONS(245),
    [anon_sym_COLONabstract_COLON] = ACTIONS(245),
    [anon_sym_COLONauthor_COLON] = ACTIONS(245),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(245),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(245),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(245),
    [anon_sym_COLONexample_COLON] = ACTIONS(245),
    [anon_sym_COLONitemize_COLON] = ACTIONS(245),
    [anon_sym_COLONlemma_COLON] = ACTIONS(245),
    [anon_sym_COLONfigure_COLON] = ACTIONS(245),
    [anon_sym_COLONp_COLON] = ACTIONS(245),
    [anon_sym_COLONproof_COLON] = ACTIONS(245),
    [anon_sym_COLONproposition_COLON] = ACTIONS(245),
    [anon_sym_COLONremark_COLON] = ACTIONS(245),
    [anon_sym_COLONsection_COLON] = ACTIONS(245),
    [anon_sym_COLONsketch_COLON] = ACTIONS(245),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(245),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(245),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(245),
    [anon_sym_COLONstep_COLON] = ACTIONS(245),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(245),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(245),
  },
  [STATE(29)] = {
    [anon_sym_COLON_COLON] = ACTIONS(249),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(249),
    [aux_sym_mathblock_token1] = ACTIONS(249),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(249),
    [anon_sym_COLONappendix_COLON] = ACTIONS(249),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(249),
    [anon_sym_COLONtoc_COLON] = ACTIONS(249),
    [aux_sym_specialblock_token1] = ACTIONS(249),
    [aux_sym_specialblock_token2] = ACTIONS(249),
    [aux_sym_specialblock_token3] = ACTIONS(249),
    [aux_sym_specialblock_token4] = ACTIONS(249),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(249),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(249),
    [anon_sym_COLONcaption_COLON] = ACTIONS(249),
    [anon_sym_COLONitem_COLON] = ACTIONS(249),
    [anon_sym_COLONprev_COLON] = ACTIONS(249),
    [anon_sym_COLONprev2_COLON] = ACTIONS(249),
    [anon_sym_COLONprev3_COLON] = ACTIONS(249),
    [aux_sym_specialinline_token1] = ACTIONS(251),
    [aux_sym_specialinline_token2] = ACTIONS(251),
    [anon_sym_COLONmath_COLON] = ACTIONS(249),
    [anon_sym_COLONcode_COLON] = ACTIONS(249),
    [aux_sym_specialinline_token3] = ACTIONS(249),
    [aux_sym_specialinline_token4] = ACTIONS(249),
    [anon_sym_COLONref_COLON] = ACTIONS(249),
    [anon_sym_COLONprevious_COLON] = ACTIONS(249),
    [anon_sym_COLONurl_COLON] = ACTIONS(249),
    [anon_sym_COLONcite_COLON] = ACTIONS(249),
    [anon_sym_COLONqed_COLON] = ACTIONS(249),
    [anon_sym_COLONtable_COLON] = ACTIONS(249),
    [anon_sym_COLONassume_COLON] = ACTIONS(249),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(249),
    [anon_sym_COLONprove_COLON] = ACTIONS(249),
    [anon_sym_COLONthen_COLON] = ACTIONS(249),
    [anon_sym_COLONnew_COLON] = ACTIONS(249),
    [anon_sym_COLONlet_COLON] = ACTIONS(249),
    [anon_sym_COLONcase_COLON] = ACTIONS(249),
    [anon_sym_COLONdefine_COLON] = ACTIONS(249),
    [anon_sym_COLONwrite_COLON] = ACTIONS(249),
    [anon_sym_COLONwlog_COLON] = ACTIONS(249),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(249),
    [anon_sym_COLONclaim_COLON] = ACTIONS(249),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(249),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(249),
    [anon_sym_COLONpick_COLON] = ACTIONS(249),
    [anon_sym_COLONst_COLON] = ACTIONS(249),
    [anon_sym_COLONdraft_COLON] = ACTIONS(249),
    [anon_sym_COLONnote_COLON] = ACTIONS(249),
    [anon_sym_COLONspan_COLON] = ACTIONS(249),
    [anon_sym_COLONabstract_COLON] = ACTIONS(249),
    [anon_sym_COLONauthor_COLON] = ACTIONS(249),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(249),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(249),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(249),
    [anon_sym_COLONexample_COLON] = ACTIONS(249),
    [anon_sym_COLONitemize_COLON] = ACTIONS(249),
    [anon_sym_COLONlemma_COLON] = ACTIONS(249),
    [anon_sym_COLONfigure_COLON] = ACTIONS(249),
    [anon_sym_COLONp_COLON] = ACTIONS(249),
    [anon_sym_COLONproof_COLON] = ACTIONS(249),
    [anon_sym_COLONproposition_COLON] = ACTIONS(249),
    [anon_sym_COLONremark_COLON] = ACTIONS(249),
    [anon_sym_COLONsection_COLON] = ACTIONS(249),
    [anon_sym_COLONsketch_COLON] = ACTIONS(249),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(249),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(249),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(249),
    [anon_sym_COLONstep_COLON] = ACTIONS(249),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(249),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(249),
  },
  [STATE(30)] = {
    [anon_sym_COLON_COLON] = ACTIONS(253),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(253),
    [aux_sym_mathblock_token1] = ACTIONS(253),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(253),
    [anon_sym_COLONappendix_COLON] = ACTIONS(253),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(253),
    [anon_sym_COLONtoc_COLON] = ACTIONS(253),
    [aux_sym_specialblock_token1] = ACTIONS(253),
    [aux_sym_specialblock_token2] = ACTIONS(253),
    [aux_sym_specialblock_token3] = ACTIONS(253),
    [aux_sym_specialblock_token4] = ACTIONS(253),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(253),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(253),
    [anon_sym_COLONcaption_COLON] = ACTIONS(253),
    [anon_sym_COLONitem_COLON] = ACTIONS(253),
    [anon_sym_COLONprev_COLON] = ACTIONS(253),
    [anon_sym_COLONprev2_COLON] = ACTIONS(253),
    [anon_sym_COLONprev3_COLON] = ACTIONS(253),
    [aux_sym_specialinline_token1] = ACTIONS(255),
    [aux_sym_specialinline_token2] = ACTIONS(255),
    [anon_sym_COLONmath_COLON] = ACTIONS(253),
    [anon_sym_COLONcode_COLON] = ACTIONS(253),
    [aux_sym_specialinline_token3] = ACTIONS(253),
    [aux_sym_specialinline_token4] = ACTIONS(253),
    [anon_sym_COLONref_COLON] = ACTIONS(253),
    [anon_sym_COLONprevious_COLON] = ACTIONS(253),
    [anon_sym_COLONurl_COLON] = ACTIONS(253),
    [anon_sym_COLONcite_COLON] = ACTIONS(253),
    [anon_sym_COLONqed_COLON] = ACTIONS(253),
    [anon_sym_COLONtable_COLON] = ACTIONS(253),
    [anon_sym_COLONassume_COLON] = ACTIONS(253),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(253),
    [anon_sym_COLONprove_COLON] = ACTIONS(253),
    [anon_sym_COLONthen_COLON] = ACTIONS(253),
    [anon_sym_COLONnew_COLON] = ACTIONS(253),
    [anon_sym_COLONlet_COLON] = ACTIONS(253),
    [anon_sym_COLONcase_COLON] = ACTIONS(253),
    [anon_sym_COLONdefine_COLON] = ACTIONS(253),
    [anon_sym_COLONwrite_COLON] = ACTIONS(253),
    [anon_sym_COLONwlog_COLON] = ACTIONS(253),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(253),
    [anon_sym_COLONclaim_COLON] = ACTIONS(253),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(253),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(253),
    [anon_sym_COLONpick_COLON] = ACTIONS(253),
    [anon_sym_COLONst_COLON] = ACTIONS(253),
    [anon_sym_COLONdraft_COLON] = ACTIONS(253),
    [anon_sym_COLONnote_COLON] = ACTIONS(253),
    [anon_sym_COLONspan_COLON] = ACTIONS(253),
    [anon_sym_COLONabstract_COLON] = ACTIONS(253),
    [anon_sym_COLONauthor_COLON] = ACTIONS(253),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(253),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(253),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(253),
    [anon_sym_COLONexample_COLON] = ACTIONS(253),
    [anon_sym_COLONitemize_COLON] = ACTIONS(253),
    [anon_sym_COLONlemma_COLON] = ACTIONS(253),
    [anon_sym_COLONfigure_COLON] = ACTIONS(253),
    [anon_sym_COLONp_COLON] = ACTIONS(253),
    [anon_sym_COLONproof_COLON] = ACTIONS(253),
    [anon_sym_COLONproposition_COLON] = ACTIONS(253),
    [anon_sym_COLONremark_COLON] = ACTIONS(253),
    [anon_sym_COLONsection_COLON] = ACTIONS(253),
    [anon_sym_COLONsketch_COLON] = ACTIONS(253),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(253),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(253),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(253),
    [anon_sym_COLONstep_COLON] = ACTIONS(253),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(253),
  },
  [STATE(31)] = {
    [anon_sym_COLON_COLON] = ACTIONS(257),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(257),
    [aux_sym_mathblock_token1] = ACTIONS(257),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(257),
    [anon_sym_COLONappendix_COLON] = ACTIONS(257),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(257),
    [anon_sym_COLONtoc_COLON] = ACTIONS(257),
    [aux_sym_specialblock_token1] = ACTIONS(257),
    [aux_sym_specialblock_token2] = ACTIONS(257),
    [aux_sym_specialblock_token3] = ACTIONS(257),
    [aux_sym_specialblock_token4] = ACTIONS(257),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(257),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(257),
    [anon_sym_COLONcaption_COLON] = ACTIONS(257),
    [anon_sym_COLONitem_COLON] = ACTIONS(257),
    [anon_sym_COLONprev_COLON] = ACTIONS(257),
    [anon_sym_COLONprev2_COLON] = ACTIONS(257),
    [anon_sym_COLONprev3_COLON] = ACTIONS(257),
    [aux_sym_specialinline_token1] = ACTIONS(259),
    [aux_sym_specialinline_token2] = ACTIONS(259),
    [anon_sym_COLONmath_COLON] = ACTIONS(257),
    [anon_sym_COLONcode_COLON] = ACTIONS(257),
    [aux_sym_specialinline_token3] = ACTIONS(257),
    [aux_sym_specialinline_token4] = ACTIONS(257),
    [anon_sym_COLONref_COLON] = ACTIONS(257),
    [anon_sym_COLONprevious_COLON] = ACTIONS(257),
    [anon_sym_COLONurl_COLON] = ACTIONS(257),
    [anon_sym_COLONcite_COLON] = ACTIONS(257),
    [anon_sym_COLONqed_COLON] = ACTIONS(257),
    [anon_sym_COLONtable_COLON] = ACTIONS(257),
    [anon_sym_COLONassume_COLON] = ACTIONS(257),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(257),
    [anon_sym_COLONprove_COLON] = ACTIONS(257),
    [anon_sym_COLONthen_COLON] = ACTIONS(257),
    [anon_sym_COLONnew_COLON] = ACTIONS(257),
    [anon_sym_COLONlet_COLON] = ACTIONS(257),
    [anon_sym_COLONcase_COLON] = ACTIONS(257),
    [anon_sym_COLONdefine_COLON] = ACTIONS(257),
    [anon_sym_COLONwrite_COLON] = ACTIONS(257),
    [anon_sym_COLONwlog_COLON] = ACTIONS(257),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(257),
    [anon_sym_COLONclaim_COLON] = ACTIONS(257),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(257),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(257),
    [anon_sym_COLONpick_COLON] = ACTIONS(257),
    [anon_sym_COLONst_COLON] = ACTIONS(257),
    [anon_sym_COLONdraft_COLON] = ACTIONS(257),
    [anon_sym_COLONnote_COLON] = ACTIONS(257),
    [anon_sym_COLONspan_COLON] = ACTIONS(257),
    [anon_sym_COLONabstract_COLON] = ACTIONS(257),
    [anon_sym_COLONauthor_COLON] = ACTIONS(257),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(257),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(257),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(257),
    [anon_sym_COLONexample_COLON] = ACTIONS(257),
    [anon_sym_COLONitemize_COLON] = ACTIONS(257),
    [anon_sym_COLONlemma_COLON] = ACTIONS(257),
    [anon_sym_COLONfigure_COLON] = ACTIONS(257),
    [anon_sym_COLONp_COLON] = ACTIONS(257),
    [anon_sym_COLONproof_COLON] = ACTIONS(257),
    [anon_sym_COLONproposition_COLON] = ACTIONS(257),
    [anon_sym_COLONremark_COLON] = ACTIONS(257),
    [anon_sym_COLONsection_COLON] = ACTIONS(257),
    [anon_sym_COLONsketch_COLON] = ACTIONS(257),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(257),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(257),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(257),
    [anon_sym_COLONstep_COLON] = ACTIONS(257),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(257),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(257),
  },
  [STATE(32)] = {
    [anon_sym_COLON_COLON] = ACTIONS(261),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(261),
    [aux_sym_mathblock_token1] = ACTIONS(261),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(261),
    [anon_sym_COLONappendix_COLON] = ACTIONS(261),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(261),
    [anon_sym_COLONtoc_COLON] = ACTIONS(261),
    [aux_sym_specialblock_token1] = ACTIONS(261),
    [aux_sym_specialblock_token2] = ACTIONS(261),
    [aux_sym_specialblock_token3] = ACTIONS(261),
    [aux_sym_specialblock_token4] = ACTIONS(261),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(261),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(261),
    [anon_sym_COLONcaption_COLON] = ACTIONS(261),
    [anon_sym_COLONitem_COLON] = ACTIONS(261),
    [anon_sym_COLONprev_COLON] = ACTIONS(261),
    [anon_sym_COLONprev2_COLON] = ACTIONS(261),
    [anon_sym_COLONprev3_COLON] = ACTIONS(261),
    [aux_sym_specialinline_token1] = ACTIONS(263),
    [aux_sym_specialinline_token2] = ACTIONS(263),
    [anon_sym_COLONmath_COLON] = ACTIONS(261),
    [anon_sym_COLONcode_COLON] = ACTIONS(261),
    [aux_sym_specialinline_token3] = ACTIONS(261),
    [aux_sym_specialinline_token4] = ACTIONS(261),
    [anon_sym_COLONref_COLON] = ACTIONS(261),
    [anon_sym_COLONprevious_COLON] = ACTIONS(261),
    [anon_sym_COLONurl_COLON] = ACTIONS(261),
    [anon_sym_COLONcite_COLON] = ACTIONS(261),
    [anon_sym_COLONqed_COLON] = ACTIONS(261),
    [anon_sym_COLONtable_COLON] = ACTIONS(261),
    [anon_sym_COLONassume_COLON] = ACTIONS(261),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(261),
    [anon_sym_COLONprove_COLON] = ACTIONS(261),
    [anon_sym_COLONthen_COLON] = ACTIONS(261),
    [anon_sym_COLONnew_COLON] = ACTIONS(261),
    [anon_sym_COLONlet_COLON] = ACTIONS(261),
    [anon_sym_COLONcase_COLON] = ACTIONS(261),
    [anon_sym_COLONdefine_COLON] = ACTIONS(261),
    [anon_sym_COLONwrite_COLON] = ACTIONS(261),
    [anon_sym_COLONwlog_COLON] = ACTIONS(261),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(261),
    [anon_sym_COLONclaim_COLON] = ACTIONS(261),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(261),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(261),
    [anon_sym_COLONpick_COLON] = ACTIONS(261),
    [anon_sym_COLONst_COLON] = ACTIONS(261),
    [anon_sym_COLONdraft_COLON] = ACTIONS(261),
    [anon_sym_COLONnote_COLON] = ACTIONS(261),
    [anon_sym_COLONspan_COLON] = ACTIONS(261),
    [anon_sym_COLONabstract_COLON] = ACTIONS(261),
    [anon_sym_COLONauthor_COLON] = ACTIONS(261),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(261),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(261),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(261),
    [anon_sym_COLONexample_COLON] = ACTIONS(261),
    [anon_sym_COLONitemize_COLON] = ACTIONS(261),
    [anon_sym_COLONlemma_COLON] = ACTIONS(261),
    [anon_sym_COLONfigure_COLON] = ACTIONS(261),
    [anon_sym_COLONp_COLON] = ACTIONS(261),
    [anon_sym_COLONproof_COLON] = ACTIONS(261),
    [anon_sym_COLONproposition_COLON] = ACTIONS(261),
    [anon_sym_COLONremark_COLON] = ACTIONS(261),
    [anon_sym_COLONsection_COLON] = ACTIONS(261),
    [anon_sym_COLONsketch_COLON] = ACTIONS(261),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(261),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(261),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(261),
    [anon_sym_COLONstep_COLON] = ACTIONS(261),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(261),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(261),
  },
  [STATE(33)] = {
    [anon_sym_COLON_COLON] = ACTIONS(265),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(265),
    [aux_sym_mathblock_token1] = ACTIONS(265),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(265),
    [anon_sym_COLONappendix_COLON] = ACTIONS(265),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(265),
    [anon_sym_COLONtoc_COLON] = ACTIONS(265),
    [aux_sym_specialblock_token1] = ACTIONS(265),
    [aux_sym_specialblock_token2] = ACTIONS(265),
    [aux_sym_specialblock_token3] = ACTIONS(265),
    [aux_sym_specialblock_token4] = ACTIONS(265),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(265),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(265),
    [anon_sym_COLONcaption_COLON] = ACTIONS(265),
    [anon_sym_COLONitem_COLON] = ACTIONS(265),
    [anon_sym_COLONprev_COLON] = ACTIONS(265),
    [anon_sym_COLONprev2_COLON] = ACTIONS(265),
    [anon_sym_COLONprev3_COLON] = ACTIONS(265),
    [aux_sym_specialinline_token1] = ACTIONS(267),
    [aux_sym_specialinline_token2] = ACTIONS(267),
    [anon_sym_COLONmath_COLON] = ACTIONS(265),
    [anon_sym_COLONcode_COLON] = ACTIONS(265),
    [aux_sym_specialinline_token3] = ACTIONS(265),
    [aux_sym_specialinline_token4] = ACTIONS(265),
    [anon_sym_COLONref_COLON] = ACTIONS(265),
    [anon_sym_COLONprevious_COLON] = ACTIONS(265),
    [anon_sym_COLONurl_COLON] = ACTIONS(265),
    [anon_sym_COLONcite_COLON] = ACTIONS(265),
    [anon_sym_COLONqed_COLON] = ACTIONS(265),
    [anon_sym_COLONtable_COLON] = ACTIONS(265),
    [anon_sym_COLONassume_COLON] = ACTIONS(265),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(265),
    [anon_sym_COLONprove_COLON] = ACTIONS(265),
    [anon_sym_COLONthen_COLON] = ACTIONS(265),
    [anon_sym_COLONnew_COLON] = ACTIONS(265),
    [anon_sym_COLONlet_COLON] = ACTIONS(265),
    [anon_sym_COLONcase_COLON] = ACTIONS(265),
    [anon_sym_COLONdefine_COLON] = ACTIONS(265),
    [anon_sym_COLONwrite_COLON] = ACTIONS(265),
    [anon_sym_COLONwlog_COLON] = ACTIONS(265),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(265),
    [anon_sym_COLONclaim_COLON] = ACTIONS(265),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(265),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(265),
    [anon_sym_COLONpick_COLON] = ACTIONS(265),
    [anon_sym_COLONst_COLON] = ACTIONS(265),
    [anon_sym_COLONdraft_COLON] = ACTIONS(265),
    [anon_sym_COLONnote_COLON] = ACTIONS(265),
    [anon_sym_COLONspan_COLON] = ACTIONS(265),
    [anon_sym_COLONabstract_COLON] = ACTIONS(265),
    [anon_sym_COLONauthor_COLON] = ACTIONS(265),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(265),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(265),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(265),
    [anon_sym_COLONexample_COLON] = ACTIONS(265),
    [anon_sym_COLONitemize_COLON] = ACTIONS(265),
    [anon_sym_COLONlemma_COLON] = ACTIONS(265),
    [anon_sym_COLONfigure_COLON] = ACTIONS(265),
    [anon_sym_COLONp_COLON] = ACTIONS(265),
    [anon_sym_COLONproof_COLON] = ACTIONS(265),
    [anon_sym_COLONproposition_COLON] = ACTIONS(265),
    [anon_sym_COLONremark_COLON] = ACTIONS(265),
    [anon_sym_COLONsection_COLON] = ACTIONS(265),
    [anon_sym_COLONsketch_COLON] = ACTIONS(265),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(265),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(265),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(265),
    [anon_sym_COLONstep_COLON] = ACTIONS(265),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(265),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(265),
  },
  [STATE(34)] = {
    [anon_sym_COLON_COLON] = ACTIONS(269),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(269),
    [aux_sym_mathblock_token1] = ACTIONS(269),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(269),
    [anon_sym_COLONappendix_COLON] = ACTIONS(269),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(269),
    [anon_sym_COLONtoc_COLON] = ACTIONS(269),
    [aux_sym_specialblock_token1] = ACTIONS(269),
    [aux_sym_specialblock_token2] = ACTIONS(269),
    [aux_sym_specialblock_token3] = ACTIONS(269),
    [aux_sym_specialblock_token4] = ACTIONS(269),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(269),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(269),
    [anon_sym_COLONcaption_COLON] = ACTIONS(269),
    [anon_sym_COLONitem_COLON] = ACTIONS(269),
    [anon_sym_COLONprev_COLON] = ACTIONS(269),
    [anon_sym_COLONprev2_COLON] = ACTIONS(269),
    [anon_sym_COLONprev3_COLON] = ACTIONS(269),
    [aux_sym_specialinline_token1] = ACTIONS(271),
    [aux_sym_specialinline_token2] = ACTIONS(271),
    [anon_sym_COLONmath_COLON] = ACTIONS(269),
    [anon_sym_COLONcode_COLON] = ACTIONS(269),
    [aux_sym_specialinline_token3] = ACTIONS(269),
    [aux_sym_specialinline_token4] = ACTIONS(269),
    [anon_sym_COLONref_COLON] = ACTIONS(269),
    [anon_sym_COLONprevious_COLON] = ACTIONS(269),
    [anon_sym_COLONurl_COLON] = ACTIONS(269),
    [anon_sym_COLONcite_COLON] = ACTIONS(269),
    [anon_sym_COLONqed_COLON] = ACTIONS(269),
    [anon_sym_COLONtable_COLON] = ACTIONS(269),
    [anon_sym_COLONassume_COLON] = ACTIONS(269),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(269),
    [anon_sym_COLONprove_COLON] = ACTIONS(269),
    [anon_sym_COLONthen_COLON] = ACTIONS(269),
    [anon_sym_COLONnew_COLON] = ACTIONS(269),
    [anon_sym_COLONlet_COLON] = ACTIONS(269),
    [anon_sym_COLONcase_COLON] = ACTIONS(269),
    [anon_sym_COLONdefine_COLON] = ACTIONS(269),
    [anon_sym_COLONwrite_COLON] = ACTIONS(269),
    [anon_sym_COLONwlog_COLON] = ACTIONS(269),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(269),
    [anon_sym_COLONclaim_COLON] = ACTIONS(269),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(269),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(269),
    [anon_sym_COLONpick_COLON] = ACTIONS(269),
    [anon_sym_COLONst_COLON] = ACTIONS(269),
    [anon_sym_COLONdraft_COLON] = ACTIONS(269),
    [anon_sym_COLONnote_COLON] = ACTIONS(269),
    [anon_sym_COLONspan_COLON] = ACTIONS(269),
    [anon_sym_COLONabstract_COLON] = ACTIONS(269),
    [anon_sym_COLONauthor_COLON] = ACTIONS(269),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(269),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(269),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(269),
    [anon_sym_COLONexample_COLON] = ACTIONS(269),
    [anon_sym_COLONitemize_COLON] = ACTIONS(269),
    [anon_sym_COLONlemma_COLON] = ACTIONS(269),
    [anon_sym_COLONfigure_COLON] = ACTIONS(269),
    [anon_sym_COLONp_COLON] = ACTIONS(269),
    [anon_sym_COLONproof_COLON] = ACTIONS(269),
    [anon_sym_COLONproposition_COLON] = ACTIONS(269),
    [anon_sym_COLONremark_COLON] = ACTIONS(269),
    [anon_sym_COLONsection_COLON] = ACTIONS(269),
    [anon_sym_COLONsketch_COLON] = ACTIONS(269),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(269),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(269),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(269),
    [anon_sym_COLONstep_COLON] = ACTIONS(269),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(269),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(269),
  },
  [STATE(35)] = {
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(273),
    [aux_sym_mathblock_token1] = ACTIONS(273),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(273),
    [anon_sym_COLONappendix_COLON] = ACTIONS(273),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(273),
    [anon_sym_COLONtoc_COLON] = ACTIONS(273),
    [aux_sym_specialblock_token1] = ACTIONS(273),
    [aux_sym_specialblock_token2] = ACTIONS(273),
    [aux_sym_specialblock_token3] = ACTIONS(273),
    [aux_sym_specialblock_token4] = ACTIONS(273),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(273),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(273),
    [anon_sym_COLONcaption_COLON] = ACTIONS(273),
    [anon_sym_COLONitem_COLON] = ACTIONS(273),
    [anon_sym_COLONprev_COLON] = ACTIONS(273),
    [anon_sym_COLONprev2_COLON] = ACTIONS(273),
    [anon_sym_COLONprev3_COLON] = ACTIONS(273),
    [aux_sym_specialinline_token1] = ACTIONS(275),
    [aux_sym_specialinline_token2] = ACTIONS(275),
    [anon_sym_COLONmath_COLON] = ACTIONS(273),
    [anon_sym_COLONcode_COLON] = ACTIONS(273),
    [aux_sym_specialinline_token3] = ACTIONS(273),
    [aux_sym_specialinline_token4] = ACTIONS(273),
    [anon_sym_COLONref_COLON] = ACTIONS(273),
    [anon_sym_COLONprevious_COLON] = ACTIONS(273),
    [anon_sym_COLONurl_COLON] = ACTIONS(273),
    [anon_sym_COLONcite_COLON] = ACTIONS(273),
    [anon_sym_COLONqed_COLON] = ACTIONS(273),
    [anon_sym_COLONtable_COLON] = ACTIONS(273),
    [anon_sym_COLONassume_COLON] = ACTIONS(273),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(273),
    [anon_sym_COLONprove_COLON] = ACTIONS(273),
    [anon_sym_COLONthen_COLON] = ACTIONS(273),
    [anon_sym_COLONnew_COLON] = ACTIONS(273),
    [anon_sym_COLONlet_COLON] = ACTIONS(273),
    [anon_sym_COLONcase_COLON] = ACTIONS(273),
    [anon_sym_COLONdefine_COLON] = ACTIONS(273),
    [anon_sym_COLONwrite_COLON] = ACTIONS(273),
    [anon_sym_COLONwlog_COLON] = ACTIONS(273),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(273),
    [anon_sym_COLONclaim_COLON] = ACTIONS(273),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(273),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(273),
    [anon_sym_COLONpick_COLON] = ACTIONS(273),
    [anon_sym_COLONst_COLON] = ACTIONS(273),
    [anon_sym_COLONdraft_COLON] = ACTIONS(273),
    [anon_sym_COLONnote_COLON] = ACTIONS(273),
    [anon_sym_COLONspan_COLON] = ACTIONS(273),
    [anon_sym_COLONabstract_COLON] = ACTIONS(273),
    [anon_sym_COLONauthor_COLON] = ACTIONS(273),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(273),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(273),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(273),
    [anon_sym_COLONexample_COLON] = ACTIONS(273),
    [anon_sym_COLONitemize_COLON] = ACTIONS(273),
    [anon_sym_COLONlemma_COLON] = ACTIONS(273),
    [anon_sym_COLONfigure_COLON] = ACTIONS(273),
    [anon_sym_COLONp_COLON] = ACTIONS(273),
    [anon_sym_COLONproof_COLON] = ACTIONS(273),
    [anon_sym_COLONproposition_COLON] = ACTIONS(273),
    [anon_sym_COLONremark_COLON] = ACTIONS(273),
    [anon_sym_COLONsection_COLON] = ACTIONS(273),
    [anon_sym_COLONsketch_COLON] = ACTIONS(273),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(273),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(273),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(273),
    [anon_sym_COLONstep_COLON] = ACTIONS(273),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(273),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(273),
  },
  [STATE(36)] = {
    [anon_sym_COLON_COLON] = ACTIONS(277),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(277),
    [aux_sym_mathblock_token1] = ACTIONS(277),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(277),
    [anon_sym_COLONappendix_COLON] = ACTIONS(277),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(277),
    [anon_sym_COLONtoc_COLON] = ACTIONS(277),
    [aux_sym_specialblock_token1] = ACTIONS(277),
    [aux_sym_specialblock_token2] = ACTIONS(277),
    [aux_sym_specialblock_token3] = ACTIONS(277),
    [aux_sym_specialblock_token4] = ACTIONS(277),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(277),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(277),
    [anon_sym_COLONcaption_COLON] = ACTIONS(277),
    [anon_sym_COLONitem_COLON] = ACTIONS(277),
    [anon_sym_COLONprev_COLON] = ACTIONS(277),
    [anon_sym_COLONprev2_COLON] = ACTIONS(277),
    [anon_sym_COLONprev3_COLON] = ACTIONS(277),
    [aux_sym_specialinline_token1] = ACTIONS(279),
    [aux_sym_specialinline_token2] = ACTIONS(279),
    [anon_sym_COLONmath_COLON] = ACTIONS(277),
    [anon_sym_COLONcode_COLON] = ACTIONS(277),
    [aux_sym_specialinline_token3] = ACTIONS(277),
    [aux_sym_specialinline_token4] = ACTIONS(277),
    [anon_sym_COLONref_COLON] = ACTIONS(277),
    [anon_sym_COLONprevious_COLON] = ACTIONS(277),
    [anon_sym_COLONurl_COLON] = ACTIONS(277),
    [anon_sym_COLONcite_COLON] = ACTIONS(277),
    [anon_sym_COLONqed_COLON] = ACTIONS(277),
    [anon_sym_COLONtable_COLON] = ACTIONS(277),
    [anon_sym_COLONassume_COLON] = ACTIONS(277),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(277),
    [anon_sym_COLONprove_COLON] = ACTIONS(277),
    [anon_sym_COLONthen_COLON] = ACTIONS(277),
    [anon_sym_COLONnew_COLON] = ACTIONS(277),
    [anon_sym_COLONlet_COLON] = ACTIONS(277),
    [anon_sym_COLONcase_COLON] = ACTIONS(277),
    [anon_sym_COLONdefine_COLON] = ACTIONS(277),
    [anon_sym_COLONwrite_COLON] = ACTIONS(277),
    [anon_sym_COLONwlog_COLON] = ACTIONS(277),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(277),
    [anon_sym_COLONclaim_COLON] = ACTIONS(277),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(277),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(277),
    [anon_sym_COLONpick_COLON] = ACTIONS(277),
    [anon_sym_COLONst_COLON] = ACTIONS(277),
    [anon_sym_COLONdraft_COLON] = ACTIONS(277),
    [anon_sym_COLONnote_COLON] = ACTIONS(277),
    [anon_sym_COLONspan_COLON] = ACTIONS(277),
    [anon_sym_COLONabstract_COLON] = ACTIONS(277),
    [anon_sym_COLONauthor_COLON] = ACTIONS(277),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(277),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(277),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(277),
    [anon_sym_COLONexample_COLON] = ACTIONS(277),
    [anon_sym_COLONitemize_COLON] = ACTIONS(277),
    [anon_sym_COLONlemma_COLON] = ACTIONS(277),
    [anon_sym_COLONfigure_COLON] = ACTIONS(277),
    [anon_sym_COLONp_COLON] = ACTIONS(277),
    [anon_sym_COLONproof_COLON] = ACTIONS(277),
    [anon_sym_COLONproposition_COLON] = ACTIONS(277),
    [anon_sym_COLONremark_COLON] = ACTIONS(277),
    [anon_sym_COLONsection_COLON] = ACTIONS(277),
    [anon_sym_COLONsketch_COLON] = ACTIONS(277),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(277),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(277),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(277),
    [anon_sym_COLONstep_COLON] = ACTIONS(277),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(277),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(277),
  },
  [STATE(37)] = {
    [anon_sym_COLON_COLON] = ACTIONS(281),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(281),
    [aux_sym_mathblock_token1] = ACTIONS(281),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(281),
    [anon_sym_COLONappendix_COLON] = ACTIONS(281),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(281),
    [anon_sym_COLONtoc_COLON] = ACTIONS(281),
    [aux_sym_specialblock_token1] = ACTIONS(281),
    [aux_sym_specialblock_token2] = ACTIONS(281),
    [aux_sym_specialblock_token3] = ACTIONS(281),
    [aux_sym_specialblock_token4] = ACTIONS(281),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(281),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(281),
    [anon_sym_COLONcaption_COLON] = ACTIONS(281),
    [anon_sym_COLONitem_COLON] = ACTIONS(281),
    [anon_sym_COLONprev_COLON] = ACTIONS(281),
    [anon_sym_COLONprev2_COLON] = ACTIONS(281),
    [anon_sym_COLONprev3_COLON] = ACTIONS(281),
    [aux_sym_specialinline_token1] = ACTIONS(283),
    [aux_sym_specialinline_token2] = ACTIONS(283),
    [anon_sym_COLONmath_COLON] = ACTIONS(281),
    [anon_sym_COLONcode_COLON] = ACTIONS(281),
    [aux_sym_specialinline_token3] = ACTIONS(281),
    [aux_sym_specialinline_token4] = ACTIONS(281),
    [anon_sym_COLONref_COLON] = ACTIONS(281),
    [anon_sym_COLONprevious_COLON] = ACTIONS(281),
    [anon_sym_COLONurl_COLON] = ACTIONS(281),
    [anon_sym_COLONcite_COLON] = ACTIONS(281),
    [anon_sym_COLONqed_COLON] = ACTIONS(281),
    [anon_sym_COLONtable_COLON] = ACTIONS(281),
    [anon_sym_COLONassume_COLON] = ACTIONS(281),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(281),
    [anon_sym_COLONprove_COLON] = ACTIONS(281),
    [anon_sym_COLONthen_COLON] = ACTIONS(281),
    [anon_sym_COLONnew_COLON] = ACTIONS(281),
    [anon_sym_COLONlet_COLON] = ACTIONS(281),
    [anon_sym_COLONcase_COLON] = ACTIONS(281),
    [anon_sym_COLONdefine_COLON] = ACTIONS(281),
    [anon_sym_COLONwrite_COLON] = ACTIONS(281),
    [anon_sym_COLONwlog_COLON] = ACTIONS(281),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(281),
    [anon_sym_COLONclaim_COLON] = ACTIONS(281),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(281),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(281),
    [anon_sym_COLONpick_COLON] = ACTIONS(281),
    [anon_sym_COLONst_COLON] = ACTIONS(281),
    [anon_sym_COLONdraft_COLON] = ACTIONS(281),
    [anon_sym_COLONnote_COLON] = ACTIONS(281),
    [anon_sym_COLONspan_COLON] = ACTIONS(281),
    [anon_sym_COLONabstract_COLON] = ACTIONS(281),
    [anon_sym_COLONauthor_COLON] = ACTIONS(281),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(281),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(281),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(281),
    [anon_sym_COLONexample_COLON] = ACTIONS(281),
    [anon_sym_COLONitemize_COLON] = ACTIONS(281),
    [anon_sym_COLONlemma_COLON] = ACTIONS(281),
    [anon_sym_COLONfigure_COLON] = ACTIONS(281),
    [anon_sym_COLONp_COLON] = ACTIONS(281),
    [anon_sym_COLONproof_COLON] = ACTIONS(281),
    [anon_sym_COLONproposition_COLON] = ACTIONS(281),
    [anon_sym_COLONremark_COLON] = ACTIONS(281),
    [anon_sym_COLONsection_COLON] = ACTIONS(281),
    [anon_sym_COLONsketch_COLON] = ACTIONS(281),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(281),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(281),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(281),
    [anon_sym_COLONstep_COLON] = ACTIONS(281),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(281),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(281),
  },
  [STATE(38)] = {
    [anon_sym_COLON_COLON] = ACTIONS(285),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(285),
    [aux_sym_mathblock_token1] = ACTIONS(285),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(285),
    [anon_sym_COLONappendix_COLON] = ACTIONS(285),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(285),
    [anon_sym_COLONtoc_COLON] = ACTIONS(285),
    [aux_sym_specialblock_token1] = ACTIONS(285),
    [aux_sym_specialblock_token2] = ACTIONS(285),
    [aux_sym_specialblock_token3] = ACTIONS(285),
    [aux_sym_specialblock_token4] = ACTIONS(285),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(285),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(285),
    [anon_sym_COLONcaption_COLON] = ACTIONS(285),
    [anon_sym_COLONitem_COLON] = ACTIONS(285),
    [anon_sym_COLONprev_COLON] = ACTIONS(285),
    [anon_sym_COLONprev2_COLON] = ACTIONS(285),
    [anon_sym_COLONprev3_COLON] = ACTIONS(285),
    [aux_sym_specialinline_token1] = ACTIONS(287),
    [aux_sym_specialinline_token2] = ACTIONS(287),
    [anon_sym_COLONmath_COLON] = ACTIONS(285),
    [anon_sym_COLONcode_COLON] = ACTIONS(285),
    [aux_sym_specialinline_token3] = ACTIONS(285),
    [aux_sym_specialinline_token4] = ACTIONS(285),
    [anon_sym_COLONref_COLON] = ACTIONS(285),
    [anon_sym_COLONprevious_COLON] = ACTIONS(285),
    [anon_sym_COLONurl_COLON] = ACTIONS(285),
    [anon_sym_COLONcite_COLON] = ACTIONS(285),
    [anon_sym_COLONqed_COLON] = ACTIONS(285),
    [anon_sym_COLONtable_COLON] = ACTIONS(285),
    [anon_sym_COLONassume_COLON] = ACTIONS(285),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(285),
    [anon_sym_COLONprove_COLON] = ACTIONS(285),
    [anon_sym_COLONthen_COLON] = ACTIONS(285),
    [anon_sym_COLONnew_COLON] = ACTIONS(285),
    [anon_sym_COLONlet_COLON] = ACTIONS(285),
    [anon_sym_COLONcase_COLON] = ACTIONS(285),
    [anon_sym_COLONdefine_COLON] = ACTIONS(285),
    [anon_sym_COLONwrite_COLON] = ACTIONS(285),
    [anon_sym_COLONwlog_COLON] = ACTIONS(285),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(285),
    [anon_sym_COLONclaim_COLON] = ACTIONS(285),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(285),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(285),
    [anon_sym_COLONpick_COLON] = ACTIONS(285),
    [anon_sym_COLONst_COLON] = ACTIONS(285),
    [anon_sym_COLONdraft_COLON] = ACTIONS(285),
    [anon_sym_COLONnote_COLON] = ACTIONS(285),
    [anon_sym_COLONspan_COLON] = ACTIONS(285),
    [anon_sym_COLONabstract_COLON] = ACTIONS(285),
    [anon_sym_COLONauthor_COLON] = ACTIONS(285),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(285),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(285),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(285),
    [anon_sym_COLONexample_COLON] = ACTIONS(285),
    [anon_sym_COLONitemize_COLON] = ACTIONS(285),
    [anon_sym_COLONlemma_COLON] = ACTIONS(285),
    [anon_sym_COLONfigure_COLON] = ACTIONS(285),
    [anon_sym_COLONp_COLON] = ACTIONS(285),
    [anon_sym_COLONproof_COLON] = ACTIONS(285),
    [anon_sym_COLONproposition_COLON] = ACTIONS(285),
    [anon_sym_COLONremark_COLON] = ACTIONS(285),
    [anon_sym_COLONsection_COLON] = ACTIONS(285),
    [anon_sym_COLONsketch_COLON] = ACTIONS(285),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(285),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(285),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(285),
    [anon_sym_COLONstep_COLON] = ACTIONS(285),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(285),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(285),
  },
  [STATE(39)] = {
    [anon_sym_COLON_COLON] = ACTIONS(289),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(289),
    [aux_sym_mathblock_token1] = ACTIONS(289),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(289),
    [anon_sym_COLONappendix_COLON] = ACTIONS(289),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(289),
    [anon_sym_COLONtoc_COLON] = ACTIONS(289),
    [aux_sym_specialblock_token1] = ACTIONS(289),
    [aux_sym_specialblock_token2] = ACTIONS(289),
    [aux_sym_specialblock_token3] = ACTIONS(289),
    [aux_sym_specialblock_token4] = ACTIONS(289),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(289),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(289),
    [anon_sym_COLONcaption_COLON] = ACTIONS(289),
    [anon_sym_COLONitem_COLON] = ACTIONS(289),
    [anon_sym_COLONprev_COLON] = ACTIONS(289),
    [anon_sym_COLONprev2_COLON] = ACTIONS(289),
    [anon_sym_COLONprev3_COLON] = ACTIONS(289),
    [aux_sym_specialinline_token1] = ACTIONS(291),
    [aux_sym_specialinline_token2] = ACTIONS(291),
    [anon_sym_COLONmath_COLON] = ACTIONS(289),
    [anon_sym_COLONcode_COLON] = ACTIONS(289),
    [aux_sym_specialinline_token3] = ACTIONS(289),
    [aux_sym_specialinline_token4] = ACTIONS(289),
    [anon_sym_COLONref_COLON] = ACTIONS(289),
    [anon_sym_COLONprevious_COLON] = ACTIONS(289),
    [anon_sym_COLONurl_COLON] = ACTIONS(289),
    [anon_sym_COLONcite_COLON] = ACTIONS(289),
    [anon_sym_COLONqed_COLON] = ACTIONS(289),
    [anon_sym_COLONtable_COLON] = ACTIONS(289),
    [anon_sym_COLONassume_COLON] = ACTIONS(289),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(289),
    [anon_sym_COLONprove_COLON] = ACTIONS(289),
    [anon_sym_COLONthen_COLON] = ACTIONS(289),
    [anon_sym_COLONnew_COLON] = ACTIONS(289),
    [anon_sym_COLONlet_COLON] = ACTIONS(289),
    [anon_sym_COLONcase_COLON] = ACTIONS(289),
    [anon_sym_COLONdefine_COLON] = ACTIONS(289),
    [anon_sym_COLONwrite_COLON] = ACTIONS(289),
    [anon_sym_COLONwlog_COLON] = ACTIONS(289),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(289),
    [anon_sym_COLONclaim_COLON] = ACTIONS(289),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(289),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(289),
    [anon_sym_COLONpick_COLON] = ACTIONS(289),
    [anon_sym_COLONst_COLON] = ACTIONS(289),
    [anon_sym_COLONdraft_COLON] = ACTIONS(289),
    [anon_sym_COLONnote_COLON] = ACTIONS(289),
    [anon_sym_COLONspan_COLON] = ACTIONS(289),
    [anon_sym_COLONabstract_COLON] = ACTIONS(289),
    [anon_sym_COLONauthor_COLON] = ACTIONS(289),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(289),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(289),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(289),
    [anon_sym_COLONexample_COLON] = ACTIONS(289),
    [anon_sym_COLONitemize_COLON] = ACTIONS(289),
    [anon_sym_COLONlemma_COLON] = ACTIONS(289),
    [anon_sym_COLONfigure_COLON] = ACTIONS(289),
    [anon_sym_COLONp_COLON] = ACTIONS(289),
    [anon_sym_COLONproof_COLON] = ACTIONS(289),
    [anon_sym_COLONproposition_COLON] = ACTIONS(289),
    [anon_sym_COLONremark_COLON] = ACTIONS(289),
    [anon_sym_COLONsection_COLON] = ACTIONS(289),
    [anon_sym_COLONsketch_COLON] = ACTIONS(289),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(289),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(289),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(289),
    [anon_sym_COLONstep_COLON] = ACTIONS(289),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(289),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(289),
  },
  [STATE(40)] = {
    [anon_sym_COLON_COLON] = ACTIONS(293),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(293),
    [aux_sym_mathblock_token1] = ACTIONS(293),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(293),
    [anon_sym_COLONappendix_COLON] = ACTIONS(293),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(293),
    [anon_sym_COLONtoc_COLON] = ACTIONS(293),
    [aux_sym_specialblock_token1] = ACTIONS(293),
    [aux_sym_specialblock_token2] = ACTIONS(293),
    [aux_sym_specialblock_token3] = ACTIONS(293),
    [aux_sym_specialblock_token4] = ACTIONS(293),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(293),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(293),
    [anon_sym_COLONcaption_COLON] = ACTIONS(293),
    [anon_sym_COLONitem_COLON] = ACTIONS(293),
    [anon_sym_COLONprev_COLON] = ACTIONS(293),
    [anon_sym_COLONprev2_COLON] = ACTIONS(293),
    [anon_sym_COLONprev3_COLON] = ACTIONS(293),
    [aux_sym_specialinline_token1] = ACTIONS(295),
    [aux_sym_specialinline_token2] = ACTIONS(295),
    [anon_sym_COLONmath_COLON] = ACTIONS(293),
    [anon_sym_COLONcode_COLON] = ACTIONS(293),
    [aux_sym_specialinline_token3] = ACTIONS(293),
    [aux_sym_specialinline_token4] = ACTIONS(293),
    [anon_sym_COLONref_COLON] = ACTIONS(293),
    [anon_sym_COLONprevious_COLON] = ACTIONS(293),
    [anon_sym_COLONurl_COLON] = ACTIONS(293),
    [anon_sym_COLONcite_COLON] = ACTIONS(293),
    [anon_sym_COLONqed_COLON] = ACTIONS(293),
    [anon_sym_COLONtable_COLON] = ACTIONS(293),
    [anon_sym_COLONassume_COLON] = ACTIONS(293),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(293),
    [anon_sym_COLONprove_COLON] = ACTIONS(293),
    [anon_sym_COLONthen_COLON] = ACTIONS(293),
    [anon_sym_COLONnew_COLON] = ACTIONS(293),
    [anon_sym_COLONlet_COLON] = ACTIONS(293),
    [anon_sym_COLONcase_COLON] = ACTIONS(293),
    [anon_sym_COLONdefine_COLON] = ACTIONS(293),
    [anon_sym_COLONwrite_COLON] = ACTIONS(293),
    [anon_sym_COLONwlog_COLON] = ACTIONS(293),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(293),
    [anon_sym_COLONclaim_COLON] = ACTIONS(293),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(293),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(293),
    [anon_sym_COLONpick_COLON] = ACTIONS(293),
    [anon_sym_COLONst_COLON] = ACTIONS(293),
    [anon_sym_COLONdraft_COLON] = ACTIONS(293),
    [anon_sym_COLONnote_COLON] = ACTIONS(293),
    [anon_sym_COLONspan_COLON] = ACTIONS(293),
    [anon_sym_COLONabstract_COLON] = ACTIONS(293),
    [anon_sym_COLONauthor_COLON] = ACTIONS(293),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(293),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(293),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(293),
    [anon_sym_COLONexample_COLON] = ACTIONS(293),
    [anon_sym_COLONitemize_COLON] = ACTIONS(293),
    [anon_sym_COLONlemma_COLON] = ACTIONS(293),
    [anon_sym_COLONfigure_COLON] = ACTIONS(293),
    [anon_sym_COLONp_COLON] = ACTIONS(293),
    [anon_sym_COLONproof_COLON] = ACTIONS(293),
    [anon_sym_COLONproposition_COLON] = ACTIONS(293),
    [anon_sym_COLONremark_COLON] = ACTIONS(293),
    [anon_sym_COLONsection_COLON] = ACTIONS(293),
    [anon_sym_COLONsketch_COLON] = ACTIONS(293),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(293),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(293),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(293),
    [anon_sym_COLONstep_COLON] = ACTIONS(293),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(293),
  },
  [STATE(41)] = {
    [anon_sym_COLON_COLON] = ACTIONS(297),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(297),
    [aux_sym_mathblock_token1] = ACTIONS(297),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(297),
    [anon_sym_COLONappendix_COLON] = ACTIONS(297),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(297),
    [anon_sym_COLONtoc_COLON] = ACTIONS(297),
    [aux_sym_specialblock_token1] = ACTIONS(297),
    [aux_sym_specialblock_token2] = ACTIONS(297),
    [aux_sym_specialblock_token3] = ACTIONS(297),
    [aux_sym_specialblock_token4] = ACTIONS(297),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(297),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(297),
    [anon_sym_COLONcaption_COLON] = ACTIONS(297),
    [anon_sym_COLONitem_COLON] = ACTIONS(297),
    [anon_sym_COLONprev_COLON] = ACTIONS(297),
    [anon_sym_COLONprev2_COLON] = ACTIONS(297),
    [anon_sym_COLONprev3_COLON] = ACTIONS(297),
    [aux_sym_specialinline_token1] = ACTIONS(299),
    [aux_sym_specialinline_token2] = ACTIONS(299),
    [anon_sym_COLONmath_COLON] = ACTIONS(297),
    [anon_sym_COLONcode_COLON] = ACTIONS(297),
    [aux_sym_specialinline_token3] = ACTIONS(297),
    [aux_sym_specialinline_token4] = ACTIONS(297),
    [anon_sym_COLONref_COLON] = ACTIONS(297),
    [anon_sym_COLONprevious_COLON] = ACTIONS(297),
    [anon_sym_COLONurl_COLON] = ACTIONS(297),
    [anon_sym_COLONcite_COLON] = ACTIONS(297),
    [anon_sym_COLONqed_COLON] = ACTIONS(297),
    [anon_sym_COLONtable_COLON] = ACTIONS(297),
    [anon_sym_COLONassume_COLON] = ACTIONS(297),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(297),
    [anon_sym_COLONprove_COLON] = ACTIONS(297),
    [anon_sym_COLONthen_COLON] = ACTIONS(297),
    [anon_sym_COLONnew_COLON] = ACTIONS(297),
    [anon_sym_COLONlet_COLON] = ACTIONS(297),
    [anon_sym_COLONcase_COLON] = ACTIONS(297),
    [anon_sym_COLONdefine_COLON] = ACTIONS(297),
    [anon_sym_COLONwrite_COLON] = ACTIONS(297),
    [anon_sym_COLONwlog_COLON] = ACTIONS(297),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(297),
    [anon_sym_COLONclaim_COLON] = ACTIONS(297),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(297),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(297),
    [anon_sym_COLONpick_COLON] = ACTIONS(297),
    [anon_sym_COLONst_COLON] = ACTIONS(297),
    [anon_sym_COLONdraft_COLON] = ACTIONS(297),
    [anon_sym_COLONnote_COLON] = ACTIONS(297),
    [anon_sym_COLONspan_COLON] = ACTIONS(297),
    [anon_sym_COLONabstract_COLON] = ACTIONS(297),
    [anon_sym_COLONauthor_COLON] = ACTIONS(297),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(297),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(297),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(297),
    [anon_sym_COLONexample_COLON] = ACTIONS(297),
    [anon_sym_COLONitemize_COLON] = ACTIONS(297),
    [anon_sym_COLONlemma_COLON] = ACTIONS(297),
    [anon_sym_COLONfigure_COLON] = ACTIONS(297),
    [anon_sym_COLONp_COLON] = ACTIONS(297),
    [anon_sym_COLONproof_COLON] = ACTIONS(297),
    [anon_sym_COLONproposition_COLON] = ACTIONS(297),
    [anon_sym_COLONremark_COLON] = ACTIONS(297),
    [anon_sym_COLONsection_COLON] = ACTIONS(297),
    [anon_sym_COLONsketch_COLON] = ACTIONS(297),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(297),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(297),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(297),
    [anon_sym_COLONstep_COLON] = ACTIONS(297),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(297),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(297),
  },
  [STATE(42)] = {
    [anon_sym_COLON_COLON] = ACTIONS(301),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(301),
    [aux_sym_mathblock_token1] = ACTIONS(301),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(301),
    [anon_sym_COLONappendix_COLON] = ACTIONS(301),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(301),
    [anon_sym_COLONtoc_COLON] = ACTIONS(301),
    [aux_sym_specialblock_token1] = ACTIONS(301),
    [aux_sym_specialblock_token2] = ACTIONS(301),
    [aux_sym_specialblock_token3] = ACTIONS(301),
    [aux_sym_specialblock_token4] = ACTIONS(301),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(301),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(301),
    [anon_sym_COLONcaption_COLON] = ACTIONS(301),
    [anon_sym_COLONitem_COLON] = ACTIONS(301),
    [anon_sym_COLONprev_COLON] = ACTIONS(301),
    [anon_sym_COLONprev2_COLON] = ACTIONS(301),
    [anon_sym_COLONprev3_COLON] = ACTIONS(301),
    [aux_sym_specialinline_token1] = ACTIONS(303),
    [aux_sym_specialinline_token2] = ACTIONS(303),
    [anon_sym_COLONmath_COLON] = ACTIONS(301),
    [anon_sym_COLONcode_COLON] = ACTIONS(301),
    [aux_sym_specialinline_token3] = ACTIONS(301),
    [aux_sym_specialinline_token4] = ACTIONS(301),
    [anon_sym_COLONref_COLON] = ACTIONS(301),
    [anon_sym_COLONprevious_COLON] = ACTIONS(301),
    [anon_sym_COLONurl_COLON] = ACTIONS(301),
    [anon_sym_COLONcite_COLON] = ACTIONS(301),
    [anon_sym_COLONqed_COLON] = ACTIONS(301),
    [anon_sym_COLONtable_COLON] = ACTIONS(301),
    [anon_sym_COLONassume_COLON] = ACTIONS(301),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(301),
    [anon_sym_COLONprove_COLON] = ACTIONS(301),
    [anon_sym_COLONthen_COLON] = ACTIONS(301),
    [anon_sym_COLONnew_COLON] = ACTIONS(301),
    [anon_sym_COLONlet_COLON] = ACTIONS(301),
    [anon_sym_COLONcase_COLON] = ACTIONS(301),
    [anon_sym_COLONdefine_COLON] = ACTIONS(301),
    [anon_sym_COLONwrite_COLON] = ACTIONS(301),
    [anon_sym_COLONwlog_COLON] = ACTIONS(301),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(301),
    [anon_sym_COLONclaim_COLON] = ACTIONS(301),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(301),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(301),
    [anon_sym_COLONpick_COLON] = ACTIONS(301),
    [anon_sym_COLONst_COLON] = ACTIONS(301),
    [anon_sym_COLONdraft_COLON] = ACTIONS(301),
    [anon_sym_COLONnote_COLON] = ACTIONS(301),
    [anon_sym_COLONspan_COLON] = ACTIONS(301),
    [anon_sym_COLONabstract_COLON] = ACTIONS(301),
    [anon_sym_COLONauthor_COLON] = ACTIONS(301),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(301),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(301),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(301),
    [anon_sym_COLONexample_COLON] = ACTIONS(301),
    [anon_sym_COLONitemize_COLON] = ACTIONS(301),
    [anon_sym_COLONlemma_COLON] = ACTIONS(301),
    [anon_sym_COLONfigure_COLON] = ACTIONS(301),
    [anon_sym_COLONp_COLON] = ACTIONS(301),
    [anon_sym_COLONproof_COLON] = ACTIONS(301),
    [anon_sym_COLONproposition_COLON] = ACTIONS(301),
    [anon_sym_COLONremark_COLON] = ACTIONS(301),
    [anon_sym_COLONsection_COLON] = ACTIONS(301),
    [anon_sym_COLONsketch_COLON] = ACTIONS(301),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(301),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(301),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(301),
    [anon_sym_COLONstep_COLON] = ACTIONS(301),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(301),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(301),
  },
  [STATE(43)] = {
    [anon_sym_COLON_COLON] = ACTIONS(305),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(305),
    [aux_sym_mathblock_token1] = ACTIONS(305),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(305),
    [anon_sym_COLONappendix_COLON] = ACTIONS(305),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(305),
    [anon_sym_COLONtoc_COLON] = ACTIONS(305),
    [aux_sym_specialblock_token1] = ACTIONS(305),
    [aux_sym_specialblock_token2] = ACTIONS(305),
    [aux_sym_specialblock_token3] = ACTIONS(305),
    [aux_sym_specialblock_token4] = ACTIONS(305),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(305),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(305),
    [anon_sym_COLONcaption_COLON] = ACTIONS(305),
    [anon_sym_COLONitem_COLON] = ACTIONS(305),
    [anon_sym_COLONprev_COLON] = ACTIONS(305),
    [anon_sym_COLONprev2_COLON] = ACTIONS(305),
    [anon_sym_COLONprev3_COLON] = ACTIONS(305),
    [aux_sym_specialinline_token1] = ACTIONS(307),
    [aux_sym_specialinline_token2] = ACTIONS(307),
    [anon_sym_COLONmath_COLON] = ACTIONS(305),
    [anon_sym_COLONcode_COLON] = ACTIONS(305),
    [aux_sym_specialinline_token3] = ACTIONS(305),
    [aux_sym_specialinline_token4] = ACTIONS(305),
    [anon_sym_COLONref_COLON] = ACTIONS(305),
    [anon_sym_COLONprevious_COLON] = ACTIONS(305),
    [anon_sym_COLONurl_COLON] = ACTIONS(305),
    [anon_sym_COLONcite_COLON] = ACTIONS(305),
    [anon_sym_COLONqed_COLON] = ACTIONS(305),
    [anon_sym_COLONtable_COLON] = ACTIONS(305),
    [anon_sym_COLONassume_COLON] = ACTIONS(305),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(305),
    [anon_sym_COLONprove_COLON] = ACTIONS(305),
    [anon_sym_COLONthen_COLON] = ACTIONS(305),
    [anon_sym_COLONnew_COLON] = ACTIONS(305),
    [anon_sym_COLONlet_COLON] = ACTIONS(305),
    [anon_sym_COLONcase_COLON] = ACTIONS(305),
    [anon_sym_COLONdefine_COLON] = ACTIONS(305),
    [anon_sym_COLONwrite_COLON] = ACTIONS(305),
    [anon_sym_COLONwlog_COLON] = ACTIONS(305),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(305),
    [anon_sym_COLONclaim_COLON] = ACTIONS(305),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(305),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(305),
    [anon_sym_COLONpick_COLON] = ACTIONS(305),
    [anon_sym_COLONst_COLON] = ACTIONS(305),
    [anon_sym_COLONdraft_COLON] = ACTIONS(305),
    [anon_sym_COLONnote_COLON] = ACTIONS(305),
    [anon_sym_COLONspan_COLON] = ACTIONS(305),
    [anon_sym_COLONabstract_COLON] = ACTIONS(305),
    [anon_sym_COLONauthor_COLON] = ACTIONS(305),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(305),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(305),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(305),
    [anon_sym_COLONexample_COLON] = ACTIONS(305),
    [anon_sym_COLONitemize_COLON] = ACTIONS(305),
    [anon_sym_COLONlemma_COLON] = ACTIONS(305),
    [anon_sym_COLONfigure_COLON] = ACTIONS(305),
    [anon_sym_COLONp_COLON] = ACTIONS(305),
    [anon_sym_COLONproof_COLON] = ACTIONS(305),
    [anon_sym_COLONproposition_COLON] = ACTIONS(305),
    [anon_sym_COLONremark_COLON] = ACTIONS(305),
    [anon_sym_COLONsection_COLON] = ACTIONS(305),
    [anon_sym_COLONsketch_COLON] = ACTIONS(305),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(305),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(305),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(305),
    [anon_sym_COLONstep_COLON] = ACTIONS(305),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(305),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(305),
  },
  [STATE(44)] = {
    [anon_sym_COLON_COLON] = ACTIONS(309),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(309),
    [aux_sym_mathblock_token1] = ACTIONS(309),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(309),
    [anon_sym_COLONappendix_COLON] = ACTIONS(309),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(309),
    [anon_sym_COLONtoc_COLON] = ACTIONS(309),
    [aux_sym_specialblock_token1] = ACTIONS(309),
    [aux_sym_specialblock_token2] = ACTIONS(309),
    [aux_sym_specialblock_token3] = ACTIONS(309),
    [aux_sym_specialblock_token4] = ACTIONS(309),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(309),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(309),
    [anon_sym_COLONcaption_COLON] = ACTIONS(309),
    [anon_sym_COLONitem_COLON] = ACTIONS(309),
    [anon_sym_COLONprev_COLON] = ACTIONS(309),
    [anon_sym_COLONprev2_COLON] = ACTIONS(309),
    [anon_sym_COLONprev3_COLON] = ACTIONS(309),
    [aux_sym_specialinline_token1] = ACTIONS(311),
    [aux_sym_specialinline_token2] = ACTIONS(311),
    [anon_sym_COLONmath_COLON] = ACTIONS(309),
    [anon_sym_COLONcode_COLON] = ACTIONS(309),
    [aux_sym_specialinline_token3] = ACTIONS(309),
    [aux_sym_specialinline_token4] = ACTIONS(309),
    [anon_sym_COLONref_COLON] = ACTIONS(309),
    [anon_sym_COLONprevious_COLON] = ACTIONS(309),
    [anon_sym_COLONurl_COLON] = ACTIONS(309),
    [anon_sym_COLONcite_COLON] = ACTIONS(309),
    [anon_sym_COLONqed_COLON] = ACTIONS(309),
    [anon_sym_COLONtable_COLON] = ACTIONS(309),
    [anon_sym_COLONassume_COLON] = ACTIONS(309),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(309),
    [anon_sym_COLONprove_COLON] = ACTIONS(309),
    [anon_sym_COLONthen_COLON] = ACTIONS(309),
    [anon_sym_COLONnew_COLON] = ACTIONS(309),
    [anon_sym_COLONlet_COLON] = ACTIONS(309),
    [anon_sym_COLONcase_COLON] = ACTIONS(309),
    [anon_sym_COLONdefine_COLON] = ACTIONS(309),
    [anon_sym_COLONwrite_COLON] = ACTIONS(309),
    [anon_sym_COLONwlog_COLON] = ACTIONS(309),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(309),
    [anon_sym_COLONclaim_COLON] = ACTIONS(309),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(309),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(309),
    [anon_sym_COLONpick_COLON] = ACTIONS(309),
    [anon_sym_COLONst_COLON] = ACTIONS(309),
    [anon_sym_COLONdraft_COLON] = ACTIONS(309),
    [anon_sym_COLONnote_COLON] = ACTIONS(309),
    [anon_sym_COLONspan_COLON] = ACTIONS(309),
    [anon_sym_COLONabstract_COLON] = ACTIONS(309),
    [anon_sym_COLONauthor_COLON] = ACTIONS(309),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(309),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(309),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(309),
    [anon_sym_COLONexample_COLON] = ACTIONS(309),
    [anon_sym_COLONitemize_COLON] = ACTIONS(309),
    [anon_sym_COLONlemma_COLON] = ACTIONS(309),
    [anon_sym_COLONfigure_COLON] = ACTIONS(309),
    [anon_sym_COLONp_COLON] = ACTIONS(309),
    [anon_sym_COLONproof_COLON] = ACTIONS(309),
    [anon_sym_COLONproposition_COLON] = ACTIONS(309),
    [anon_sym_COLONremark_COLON] = ACTIONS(309),
    [anon_sym_COLONsection_COLON] = ACTIONS(309),
    [anon_sym_COLONsketch_COLON] = ACTIONS(309),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(309),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(309),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(309),
    [anon_sym_COLONstep_COLON] = ACTIONS(309),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(309),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(309),
  },
  [STATE(45)] = {
    [anon_sym_COLON_COLON] = ACTIONS(313),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(313),
    [aux_sym_mathblock_token1] = ACTIONS(313),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(313),
    [anon_sym_COLONappendix_COLON] = ACTIONS(313),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(313),
    [anon_sym_COLONtoc_COLON] = ACTIONS(313),
    [aux_sym_specialblock_token1] = ACTIONS(313),
    [aux_sym_specialblock_token2] = ACTIONS(313),
    [aux_sym_specialblock_token3] = ACTIONS(313),
    [aux_sym_specialblock_token4] = ACTIONS(313),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(313),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(313),
    [anon_sym_COLONcaption_COLON] = ACTIONS(313),
    [anon_sym_COLONitem_COLON] = ACTIONS(313),
    [anon_sym_COLONprev_COLON] = ACTIONS(313),
    [anon_sym_COLONprev2_COLON] = ACTIONS(313),
    [anon_sym_COLONprev3_COLON] = ACTIONS(313),
    [aux_sym_specialinline_token1] = ACTIONS(315),
    [aux_sym_specialinline_token2] = ACTIONS(315),
    [anon_sym_COLONmath_COLON] = ACTIONS(313),
    [anon_sym_COLONcode_COLON] = ACTIONS(313),
    [aux_sym_specialinline_token3] = ACTIONS(313),
    [aux_sym_specialinline_token4] = ACTIONS(313),
    [anon_sym_COLONref_COLON] = ACTIONS(313),
    [anon_sym_COLONprevious_COLON] = ACTIONS(313),
    [anon_sym_COLONurl_COLON] = ACTIONS(313),
    [anon_sym_COLONcite_COLON] = ACTIONS(313),
    [anon_sym_COLONqed_COLON] = ACTIONS(313),
    [anon_sym_COLONtable_COLON] = ACTIONS(313),
    [anon_sym_COLONassume_COLON] = ACTIONS(313),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(313),
    [anon_sym_COLONprove_COLON] = ACTIONS(313),
    [anon_sym_COLONthen_COLON] = ACTIONS(313),
    [anon_sym_COLONnew_COLON] = ACTIONS(313),
    [anon_sym_COLONlet_COLON] = ACTIONS(313),
    [anon_sym_COLONcase_COLON] = ACTIONS(313),
    [anon_sym_COLONdefine_COLON] = ACTIONS(313),
    [anon_sym_COLONwrite_COLON] = ACTIONS(313),
    [anon_sym_COLONwlog_COLON] = ACTIONS(313),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(313),
    [anon_sym_COLONclaim_COLON] = ACTIONS(313),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(313),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(313),
    [anon_sym_COLONpick_COLON] = ACTIONS(313),
    [anon_sym_COLONst_COLON] = ACTIONS(313),
    [anon_sym_COLONdraft_COLON] = ACTIONS(313),
    [anon_sym_COLONnote_COLON] = ACTIONS(313),
    [anon_sym_COLONspan_COLON] = ACTIONS(313),
    [anon_sym_COLONabstract_COLON] = ACTIONS(313),
    [anon_sym_COLONauthor_COLON] = ACTIONS(313),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(313),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(313),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(313),
    [anon_sym_COLONexample_COLON] = ACTIONS(313),
    [anon_sym_COLONitemize_COLON] = ACTIONS(313),
    [anon_sym_COLONlemma_COLON] = ACTIONS(313),
    [anon_sym_COLONfigure_COLON] = ACTIONS(313),
    [anon_sym_COLONp_COLON] = ACTIONS(313),
    [anon_sym_COLONproof_COLON] = ACTIONS(313),
    [anon_sym_COLONproposition_COLON] = ACTIONS(313),
    [anon_sym_COLONremark_COLON] = ACTIONS(313),
    [anon_sym_COLONsection_COLON] = ACTIONS(313),
    [anon_sym_COLONsketch_COLON] = ACTIONS(313),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(313),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(313),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(313),
    [anon_sym_COLONstep_COLON] = ACTIONS(313),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(313),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(313),
  },
  [STATE(46)] = {
    [anon_sym_COLON_COLON] = ACTIONS(317),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(317),
    [aux_sym_mathblock_token1] = ACTIONS(317),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(317),
    [anon_sym_COLONappendix_COLON] = ACTIONS(317),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(317),
    [anon_sym_COLONtoc_COLON] = ACTIONS(317),
    [aux_sym_specialblock_token1] = ACTIONS(317),
    [aux_sym_specialblock_token2] = ACTIONS(317),
    [aux_sym_specialblock_token3] = ACTIONS(317),
    [aux_sym_specialblock_token4] = ACTIONS(317),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(317),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(317),
    [anon_sym_COLONcaption_COLON] = ACTIONS(317),
    [anon_sym_COLONitem_COLON] = ACTIONS(317),
    [anon_sym_COLONprev_COLON] = ACTIONS(317),
    [anon_sym_COLONprev2_COLON] = ACTIONS(317),
    [anon_sym_COLONprev3_COLON] = ACTIONS(317),
    [aux_sym_specialinline_token1] = ACTIONS(319),
    [aux_sym_specialinline_token2] = ACTIONS(319),
    [anon_sym_COLONmath_COLON] = ACTIONS(317),
    [anon_sym_COLONcode_COLON] = ACTIONS(317),
    [aux_sym_specialinline_token3] = ACTIONS(317),
    [aux_sym_specialinline_token4] = ACTIONS(317),
    [anon_sym_COLONref_COLON] = ACTIONS(317),
    [anon_sym_COLONprevious_COLON] = ACTIONS(317),
    [anon_sym_COLONurl_COLON] = ACTIONS(317),
    [anon_sym_COLONcite_COLON] = ACTIONS(317),
    [anon_sym_COLONqed_COLON] = ACTIONS(317),
    [anon_sym_COLONtable_COLON] = ACTIONS(317),
    [anon_sym_COLONassume_COLON] = ACTIONS(317),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(317),
    [anon_sym_COLONprove_COLON] = ACTIONS(317),
    [anon_sym_COLONthen_COLON] = ACTIONS(317),
    [anon_sym_COLONnew_COLON] = ACTIONS(317),
    [anon_sym_COLONlet_COLON] = ACTIONS(317),
    [anon_sym_COLONcase_COLON] = ACTIONS(317),
    [anon_sym_COLONdefine_COLON] = ACTIONS(317),
    [anon_sym_COLONwrite_COLON] = ACTIONS(317),
    [anon_sym_COLONwlog_COLON] = ACTIONS(317),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(317),
    [anon_sym_COLONclaim_COLON] = ACTIONS(317),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(317),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(317),
    [anon_sym_COLONpick_COLON] = ACTIONS(317),
    [anon_sym_COLONst_COLON] = ACTIONS(317),
    [anon_sym_COLONdraft_COLON] = ACTIONS(317),
    [anon_sym_COLONnote_COLON] = ACTIONS(317),
    [anon_sym_COLONspan_COLON] = ACTIONS(317),
    [anon_sym_COLONabstract_COLON] = ACTIONS(317),
    [anon_sym_COLONauthor_COLON] = ACTIONS(317),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(317),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(317),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(317),
    [anon_sym_COLONexample_COLON] = ACTIONS(317),
    [anon_sym_COLONitemize_COLON] = ACTIONS(317),
    [anon_sym_COLONlemma_COLON] = ACTIONS(317),
    [anon_sym_COLONfigure_COLON] = ACTIONS(317),
    [anon_sym_COLONp_COLON] = ACTIONS(317),
    [anon_sym_COLONproof_COLON] = ACTIONS(317),
    [anon_sym_COLONproposition_COLON] = ACTIONS(317),
    [anon_sym_COLONremark_COLON] = ACTIONS(317),
    [anon_sym_COLONsection_COLON] = ACTIONS(317),
    [anon_sym_COLONsketch_COLON] = ACTIONS(317),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(317),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(317),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(317),
    [anon_sym_COLONstep_COLON] = ACTIONS(317),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(317),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(317),
  },
  [STATE(47)] = {
    [anon_sym_COLON_COLON] = ACTIONS(321),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(321),
    [aux_sym_mathblock_token1] = ACTIONS(321),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(321),
    [anon_sym_COLONappendix_COLON] = ACTIONS(321),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(321),
    [anon_sym_COLONtoc_COLON] = ACTIONS(321),
    [aux_sym_specialblock_token1] = ACTIONS(321),
    [aux_sym_specialblock_token2] = ACTIONS(321),
    [aux_sym_specialblock_token3] = ACTIONS(321),
    [aux_sym_specialblock_token4] = ACTIONS(321),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(321),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(321),
    [anon_sym_COLONcaption_COLON] = ACTIONS(321),
    [anon_sym_COLONitem_COLON] = ACTIONS(321),
    [anon_sym_COLONprev_COLON] = ACTIONS(321),
    [anon_sym_COLONprev2_COLON] = ACTIONS(321),
    [anon_sym_COLONprev3_COLON] = ACTIONS(321),
    [aux_sym_specialinline_token1] = ACTIONS(323),
    [aux_sym_specialinline_token2] = ACTIONS(323),
    [anon_sym_COLONmath_COLON] = ACTIONS(321),
    [anon_sym_COLONcode_COLON] = ACTIONS(321),
    [aux_sym_specialinline_token3] = ACTIONS(321),
    [aux_sym_specialinline_token4] = ACTIONS(321),
    [anon_sym_COLONref_COLON] = ACTIONS(321),
    [anon_sym_COLONprevious_COLON] = ACTIONS(321),
    [anon_sym_COLONurl_COLON] = ACTIONS(321),
    [anon_sym_COLONcite_COLON] = ACTIONS(321),
    [anon_sym_COLONqed_COLON] = ACTIONS(321),
    [anon_sym_COLONtable_COLON] = ACTIONS(321),
    [anon_sym_COLONassume_COLON] = ACTIONS(321),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(321),
    [anon_sym_COLONprove_COLON] = ACTIONS(321),
    [anon_sym_COLONthen_COLON] = ACTIONS(321),
    [anon_sym_COLONnew_COLON] = ACTIONS(321),
    [anon_sym_COLONlet_COLON] = ACTIONS(321),
    [anon_sym_COLONcase_COLON] = ACTIONS(321),
    [anon_sym_COLONdefine_COLON] = ACTIONS(321),
    [anon_sym_COLONwrite_COLON] = ACTIONS(321),
    [anon_sym_COLONwlog_COLON] = ACTIONS(321),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(321),
    [anon_sym_COLONclaim_COLON] = ACTIONS(321),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(321),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(321),
    [anon_sym_COLONpick_COLON] = ACTIONS(321),
    [anon_sym_COLONst_COLON] = ACTIONS(321),
    [anon_sym_COLONdraft_COLON] = ACTIONS(321),
    [anon_sym_COLONnote_COLON] = ACTIONS(321),
    [anon_sym_COLONspan_COLON] = ACTIONS(321),
    [anon_sym_COLONabstract_COLON] = ACTIONS(321),
    [anon_sym_COLONauthor_COLON] = ACTIONS(321),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(321),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(321),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(321),
    [anon_sym_COLONexample_COLON] = ACTIONS(321),
    [anon_sym_COLONitemize_COLON] = ACTIONS(321),
    [anon_sym_COLONlemma_COLON] = ACTIONS(321),
    [anon_sym_COLONfigure_COLON] = ACTIONS(321),
    [anon_sym_COLONp_COLON] = ACTIONS(321),
    [anon_sym_COLONproof_COLON] = ACTIONS(321),
    [anon_sym_COLONproposition_COLON] = ACTIONS(321),
    [anon_sym_COLONremark_COLON] = ACTIONS(321),
    [anon_sym_COLONsection_COLON] = ACTIONS(321),
    [anon_sym_COLONsketch_COLON] = ACTIONS(321),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(321),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(321),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(321),
    [anon_sym_COLONstep_COLON] = ACTIONS(321),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(321),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(321),
  },
  [STATE(48)] = {
    [anon_sym_COLON_COLON] = ACTIONS(325),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(325),
    [aux_sym_mathblock_token1] = ACTIONS(325),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(325),
    [anon_sym_COLONappendix_COLON] = ACTIONS(325),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(325),
    [anon_sym_COLONtoc_COLON] = ACTIONS(325),
    [aux_sym_specialblock_token1] = ACTIONS(325),
    [aux_sym_specialblock_token2] = ACTIONS(325),
    [aux_sym_specialblock_token3] = ACTIONS(325),
    [aux_sym_specialblock_token4] = ACTIONS(325),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(325),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(325),
    [anon_sym_COLONcaption_COLON] = ACTIONS(325),
    [anon_sym_COLONitem_COLON] = ACTIONS(325),
    [anon_sym_COLONprev_COLON] = ACTIONS(325),
    [anon_sym_COLONprev2_COLON] = ACTIONS(325),
    [anon_sym_COLONprev3_COLON] = ACTIONS(325),
    [aux_sym_specialinline_token1] = ACTIONS(327),
    [aux_sym_specialinline_token2] = ACTIONS(327),
    [anon_sym_COLONmath_COLON] = ACTIONS(325),
    [anon_sym_COLONcode_COLON] = ACTIONS(325),
    [aux_sym_specialinline_token3] = ACTIONS(325),
    [aux_sym_specialinline_token4] = ACTIONS(325),
    [anon_sym_COLONref_COLON] = ACTIONS(325),
    [anon_sym_COLONprevious_COLON] = ACTIONS(325),
    [anon_sym_COLONurl_COLON] = ACTIONS(325),
    [anon_sym_COLONcite_COLON] = ACTIONS(325),
    [anon_sym_COLONqed_COLON] = ACTIONS(325),
    [anon_sym_COLONtable_COLON] = ACTIONS(325),
    [anon_sym_COLONassume_COLON] = ACTIONS(325),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(325),
    [anon_sym_COLONprove_COLON] = ACTIONS(325),
    [anon_sym_COLONthen_COLON] = ACTIONS(325),
    [anon_sym_COLONnew_COLON] = ACTIONS(325),
    [anon_sym_COLONlet_COLON] = ACTIONS(325),
    [anon_sym_COLONcase_COLON] = ACTIONS(325),
    [anon_sym_COLONdefine_COLON] = ACTIONS(325),
    [anon_sym_COLONwrite_COLON] = ACTIONS(325),
    [anon_sym_COLONwlog_COLON] = ACTIONS(325),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(325),
    [anon_sym_COLONclaim_COLON] = ACTIONS(325),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(325),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(325),
    [anon_sym_COLONpick_COLON] = ACTIONS(325),
    [anon_sym_COLONst_COLON] = ACTIONS(325),
    [anon_sym_COLONdraft_COLON] = ACTIONS(325),
    [anon_sym_COLONnote_COLON] = ACTIONS(325),
    [anon_sym_COLONspan_COLON] = ACTIONS(325),
    [anon_sym_COLONabstract_COLON] = ACTIONS(325),
    [anon_sym_COLONauthor_COLON] = ACTIONS(325),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(325),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(325),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(325),
    [anon_sym_COLONexample_COLON] = ACTIONS(325),
    [anon_sym_COLONitemize_COLON] = ACTIONS(325),
    [anon_sym_COLONlemma_COLON] = ACTIONS(325),
    [anon_sym_COLONfigure_COLON] = ACTIONS(325),
    [anon_sym_COLONp_COLON] = ACTIONS(325),
    [anon_sym_COLONproof_COLON] = ACTIONS(325),
    [anon_sym_COLONproposition_COLON] = ACTIONS(325),
    [anon_sym_COLONremark_COLON] = ACTIONS(325),
    [anon_sym_COLONsection_COLON] = ACTIONS(325),
    [anon_sym_COLONsketch_COLON] = ACTIONS(325),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(325),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(325),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(325),
    [anon_sym_COLONstep_COLON] = ACTIONS(325),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(325),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(325),
  },
  [STATE(49)] = {
    [anon_sym_COLON_COLON] = ACTIONS(329),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(329),
    [aux_sym_mathblock_token1] = ACTIONS(329),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(329),
    [anon_sym_COLONappendix_COLON] = ACTIONS(329),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(329),
    [anon_sym_COLONtoc_COLON] = ACTIONS(329),
    [aux_sym_specialblock_token1] = ACTIONS(329),
    [aux_sym_specialblock_token2] = ACTIONS(329),
    [aux_sym_specialblock_token3] = ACTIONS(329),
    [aux_sym_specialblock_token4] = ACTIONS(329),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(329),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(329),
    [anon_sym_COLONcaption_COLON] = ACTIONS(329),
    [anon_sym_COLONitem_COLON] = ACTIONS(329),
    [anon_sym_COLONprev_COLON] = ACTIONS(329),
    [anon_sym_COLONprev2_COLON] = ACTIONS(329),
    [anon_sym_COLONprev3_COLON] = ACTIONS(329),
    [aux_sym_specialinline_token1] = ACTIONS(331),
    [aux_sym_specialinline_token2] = ACTIONS(331),
    [anon_sym_COLONmath_COLON] = ACTIONS(329),
    [anon_sym_COLONcode_COLON] = ACTIONS(329),
    [aux_sym_specialinline_token3] = ACTIONS(329),
    [aux_sym_specialinline_token4] = ACTIONS(329),
    [anon_sym_COLONref_COLON] = ACTIONS(329),
    [anon_sym_COLONprevious_COLON] = ACTIONS(329),
    [anon_sym_COLONurl_COLON] = ACTIONS(329),
    [anon_sym_COLONcite_COLON] = ACTIONS(329),
    [anon_sym_COLONqed_COLON] = ACTIONS(329),
    [anon_sym_COLONtable_COLON] = ACTIONS(329),
    [anon_sym_COLONassume_COLON] = ACTIONS(329),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(329),
    [anon_sym_COLONprove_COLON] = ACTIONS(329),
    [anon_sym_COLONthen_COLON] = ACTIONS(329),
    [anon_sym_COLONnew_COLON] = ACTIONS(329),
    [anon_sym_COLONlet_COLON] = ACTIONS(329),
    [anon_sym_COLONcase_COLON] = ACTIONS(329),
    [anon_sym_COLONdefine_COLON] = ACTIONS(329),
    [anon_sym_COLONwrite_COLON] = ACTIONS(329),
    [anon_sym_COLONwlog_COLON] = ACTIONS(329),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(329),
    [anon_sym_COLONclaim_COLON] = ACTIONS(329),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(329),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(329),
    [anon_sym_COLONpick_COLON] = ACTIONS(329),
    [anon_sym_COLONst_COLON] = ACTIONS(329),
    [anon_sym_COLONdraft_COLON] = ACTIONS(329),
    [anon_sym_COLONnote_COLON] = ACTIONS(329),
    [anon_sym_COLONspan_COLON] = ACTIONS(329),
    [anon_sym_COLONabstract_COLON] = ACTIONS(329),
    [anon_sym_COLONauthor_COLON] = ACTIONS(329),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(329),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(329),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(329),
    [anon_sym_COLONexample_COLON] = ACTIONS(329),
    [anon_sym_COLONitemize_COLON] = ACTIONS(329),
    [anon_sym_COLONlemma_COLON] = ACTIONS(329),
    [anon_sym_COLONfigure_COLON] = ACTIONS(329),
    [anon_sym_COLONp_COLON] = ACTIONS(329),
    [anon_sym_COLONproof_COLON] = ACTIONS(329),
    [anon_sym_COLONproposition_COLON] = ACTIONS(329),
    [anon_sym_COLONremark_COLON] = ACTIONS(329),
    [anon_sym_COLONsection_COLON] = ACTIONS(329),
    [anon_sym_COLONsketch_COLON] = ACTIONS(329),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(329),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(329),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(329),
    [anon_sym_COLONstep_COLON] = ACTIONS(329),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(329),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(329),
  },
  [STATE(50)] = {
    [anon_sym_COLON_COLON] = ACTIONS(333),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(333),
    [aux_sym_mathblock_token1] = ACTIONS(333),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(333),
    [anon_sym_COLONappendix_COLON] = ACTIONS(333),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(333),
    [anon_sym_COLONtoc_COLON] = ACTIONS(333),
    [aux_sym_specialblock_token1] = ACTIONS(333),
    [aux_sym_specialblock_token2] = ACTIONS(333),
    [aux_sym_specialblock_token3] = ACTIONS(333),
    [aux_sym_specialblock_token4] = ACTIONS(333),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(333),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(333),
    [anon_sym_COLONcaption_COLON] = ACTIONS(333),
    [anon_sym_COLONitem_COLON] = ACTIONS(333),
    [anon_sym_COLONprev_COLON] = ACTIONS(333),
    [anon_sym_COLONprev2_COLON] = ACTIONS(333),
    [anon_sym_COLONprev3_COLON] = ACTIONS(333),
    [aux_sym_specialinline_token1] = ACTIONS(335),
    [aux_sym_specialinline_token2] = ACTIONS(335),
    [anon_sym_COLONmath_COLON] = ACTIONS(333),
    [anon_sym_COLONcode_COLON] = ACTIONS(333),
    [aux_sym_specialinline_token3] = ACTIONS(333),
    [aux_sym_specialinline_token4] = ACTIONS(333),
    [anon_sym_COLONref_COLON] = ACTIONS(333),
    [anon_sym_COLONprevious_COLON] = ACTIONS(333),
    [anon_sym_COLONurl_COLON] = ACTIONS(333),
    [anon_sym_COLONcite_COLON] = ACTIONS(333),
    [anon_sym_COLONqed_COLON] = ACTIONS(333),
    [anon_sym_COLONtable_COLON] = ACTIONS(333),
    [anon_sym_COLONassume_COLON] = ACTIONS(333),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(333),
    [anon_sym_COLONprove_COLON] = ACTIONS(333),
    [anon_sym_COLONthen_COLON] = ACTIONS(333),
    [anon_sym_COLONnew_COLON] = ACTIONS(333),
    [anon_sym_COLONlet_COLON] = ACTIONS(333),
    [anon_sym_COLONcase_COLON] = ACTIONS(333),
    [anon_sym_COLONdefine_COLON] = ACTIONS(333),
    [anon_sym_COLONwrite_COLON] = ACTIONS(333),
    [anon_sym_COLONwlog_COLON] = ACTIONS(333),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(333),
    [anon_sym_COLONclaim_COLON] = ACTIONS(333),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(333),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(333),
    [anon_sym_COLONpick_COLON] = ACTIONS(333),
    [anon_sym_COLONst_COLON] = ACTIONS(333),
    [anon_sym_COLONdraft_COLON] = ACTIONS(333),
    [anon_sym_COLONnote_COLON] = ACTIONS(333),
    [anon_sym_COLONspan_COLON] = ACTIONS(333),
    [anon_sym_COLONabstract_COLON] = ACTIONS(333),
    [anon_sym_COLONauthor_COLON] = ACTIONS(333),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(333),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(333),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(333),
    [anon_sym_COLONexample_COLON] = ACTIONS(333),
    [anon_sym_COLONitemize_COLON] = ACTIONS(333),
    [anon_sym_COLONlemma_COLON] = ACTIONS(333),
    [anon_sym_COLONfigure_COLON] = ACTIONS(333),
    [anon_sym_COLONp_COLON] = ACTIONS(333),
    [anon_sym_COLONproof_COLON] = ACTIONS(333),
    [anon_sym_COLONproposition_COLON] = ACTIONS(333),
    [anon_sym_COLONremark_COLON] = ACTIONS(333),
    [anon_sym_COLONsection_COLON] = ACTIONS(333),
    [anon_sym_COLONsketch_COLON] = ACTIONS(333),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(333),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(333),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(333),
    [anon_sym_COLONstep_COLON] = ACTIONS(333),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(333),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(333),
  },
  [STATE(51)] = {
    [anon_sym_COLON_COLON] = ACTIONS(337),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(337),
    [aux_sym_mathblock_token1] = ACTIONS(337),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(337),
    [anon_sym_COLONappendix_COLON] = ACTIONS(337),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(337),
    [anon_sym_COLONtoc_COLON] = ACTIONS(337),
    [aux_sym_specialblock_token1] = ACTIONS(337),
    [aux_sym_specialblock_token2] = ACTIONS(337),
    [aux_sym_specialblock_token3] = ACTIONS(337),
    [aux_sym_specialblock_token4] = ACTIONS(337),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(337),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(337),
    [anon_sym_COLONcaption_COLON] = ACTIONS(337),
    [anon_sym_COLONitem_COLON] = ACTIONS(337),
    [anon_sym_COLONprev_COLON] = ACTIONS(337),
    [anon_sym_COLONprev2_COLON] = ACTIONS(337),
    [anon_sym_COLONprev3_COLON] = ACTIONS(337),
    [aux_sym_specialinline_token1] = ACTIONS(339),
    [aux_sym_specialinline_token2] = ACTIONS(339),
    [anon_sym_COLONmath_COLON] = ACTIONS(337),
    [anon_sym_COLONcode_COLON] = ACTIONS(337),
    [aux_sym_specialinline_token3] = ACTIONS(337),
    [aux_sym_specialinline_token4] = ACTIONS(337),
    [anon_sym_COLONref_COLON] = ACTIONS(337),
    [anon_sym_COLONprevious_COLON] = ACTIONS(337),
    [anon_sym_COLONurl_COLON] = ACTIONS(337),
    [anon_sym_COLONcite_COLON] = ACTIONS(337),
    [anon_sym_COLONqed_COLON] = ACTIONS(337),
    [anon_sym_COLONtable_COLON] = ACTIONS(337),
    [anon_sym_COLONassume_COLON] = ACTIONS(337),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(337),
    [anon_sym_COLONprove_COLON] = ACTIONS(337),
    [anon_sym_COLONthen_COLON] = ACTIONS(337),
    [anon_sym_COLONnew_COLON] = ACTIONS(337),
    [anon_sym_COLONlet_COLON] = ACTIONS(337),
    [anon_sym_COLONcase_COLON] = ACTIONS(337),
    [anon_sym_COLONdefine_COLON] = ACTIONS(337),
    [anon_sym_COLONwrite_COLON] = ACTIONS(337),
    [anon_sym_COLONwlog_COLON] = ACTIONS(337),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(337),
    [anon_sym_COLONclaim_COLON] = ACTIONS(337),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(337),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(337),
    [anon_sym_COLONpick_COLON] = ACTIONS(337),
    [anon_sym_COLONst_COLON] = ACTIONS(337),
    [anon_sym_COLONdraft_COLON] = ACTIONS(337),
    [anon_sym_COLONnote_COLON] = ACTIONS(337),
    [anon_sym_COLONspan_COLON] = ACTIONS(337),
    [anon_sym_COLONabstract_COLON] = ACTIONS(337),
    [anon_sym_COLONauthor_COLON] = ACTIONS(337),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(337),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(337),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(337),
    [anon_sym_COLONexample_COLON] = ACTIONS(337),
    [anon_sym_COLONitemize_COLON] = ACTIONS(337),
    [anon_sym_COLONlemma_COLON] = ACTIONS(337),
    [anon_sym_COLONfigure_COLON] = ACTIONS(337),
    [anon_sym_COLONp_COLON] = ACTIONS(337),
    [anon_sym_COLONproof_COLON] = ACTIONS(337),
    [anon_sym_COLONproposition_COLON] = ACTIONS(337),
    [anon_sym_COLONremark_COLON] = ACTIONS(337),
    [anon_sym_COLONsection_COLON] = ACTIONS(337),
    [anon_sym_COLONsketch_COLON] = ACTIONS(337),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(337),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(337),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(337),
    [anon_sym_COLONstep_COLON] = ACTIONS(337),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(337),
  },
  [STATE(52)] = {
    [anon_sym_COLON_COLON] = ACTIONS(341),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(341),
    [aux_sym_mathblock_token1] = ACTIONS(341),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(341),
    [anon_sym_COLONappendix_COLON] = ACTIONS(341),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(341),
    [anon_sym_COLONtoc_COLON] = ACTIONS(341),
    [aux_sym_specialblock_token1] = ACTIONS(341),
    [aux_sym_specialblock_token2] = ACTIONS(341),
    [aux_sym_specialblock_token3] = ACTIONS(341),
    [aux_sym_specialblock_token4] = ACTIONS(341),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(341),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(341),
    [anon_sym_COLONcaption_COLON] = ACTIONS(341),
    [anon_sym_COLONitem_COLON] = ACTIONS(341),
    [anon_sym_COLONprev_COLON] = ACTIONS(341),
    [anon_sym_COLONprev2_COLON] = ACTIONS(341),
    [anon_sym_COLONprev3_COLON] = ACTIONS(341),
    [aux_sym_specialinline_token1] = ACTIONS(343),
    [aux_sym_specialinline_token2] = ACTIONS(343),
    [anon_sym_COLONmath_COLON] = ACTIONS(341),
    [anon_sym_COLONcode_COLON] = ACTIONS(341),
    [aux_sym_specialinline_token3] = ACTIONS(341),
    [aux_sym_specialinline_token4] = ACTIONS(341),
    [anon_sym_COLONref_COLON] = ACTIONS(341),
    [anon_sym_COLONprevious_COLON] = ACTIONS(341),
    [anon_sym_COLONurl_COLON] = ACTIONS(341),
    [anon_sym_COLONcite_COLON] = ACTIONS(341),
    [anon_sym_COLONqed_COLON] = ACTIONS(341),
    [anon_sym_COLONtable_COLON] = ACTIONS(341),
    [anon_sym_COLONassume_COLON] = ACTIONS(341),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(341),
    [anon_sym_COLONprove_COLON] = ACTIONS(341),
    [anon_sym_COLONthen_COLON] = ACTIONS(341),
    [anon_sym_COLONnew_COLON] = ACTIONS(341),
    [anon_sym_COLONlet_COLON] = ACTIONS(341),
    [anon_sym_COLONcase_COLON] = ACTIONS(341),
    [anon_sym_COLONdefine_COLON] = ACTIONS(341),
    [anon_sym_COLONwrite_COLON] = ACTIONS(341),
    [anon_sym_COLONwlog_COLON] = ACTIONS(341),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(341),
    [anon_sym_COLONclaim_COLON] = ACTIONS(341),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(341),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(341),
    [anon_sym_COLONpick_COLON] = ACTIONS(341),
    [anon_sym_COLONst_COLON] = ACTIONS(341),
    [anon_sym_COLONdraft_COLON] = ACTIONS(341),
    [anon_sym_COLONnote_COLON] = ACTIONS(341),
    [anon_sym_COLONspan_COLON] = ACTIONS(341),
    [anon_sym_COLONabstract_COLON] = ACTIONS(341),
    [anon_sym_COLONauthor_COLON] = ACTIONS(341),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(341),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(341),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(341),
    [anon_sym_COLONexample_COLON] = ACTIONS(341),
    [anon_sym_COLONitemize_COLON] = ACTIONS(341),
    [anon_sym_COLONlemma_COLON] = ACTIONS(341),
    [anon_sym_COLONfigure_COLON] = ACTIONS(341),
    [anon_sym_COLONp_COLON] = ACTIONS(341),
    [anon_sym_COLONproof_COLON] = ACTIONS(341),
    [anon_sym_COLONproposition_COLON] = ACTIONS(341),
    [anon_sym_COLONremark_COLON] = ACTIONS(341),
    [anon_sym_COLONsection_COLON] = ACTIONS(341),
    [anon_sym_COLONsketch_COLON] = ACTIONS(341),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(341),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(341),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(341),
    [anon_sym_COLONstep_COLON] = ACTIONS(341),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(341),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(341),
  },
  [STATE(53)] = {
    [anon_sym_COLON_COLON] = ACTIONS(345),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(345),
    [aux_sym_mathblock_token1] = ACTIONS(345),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(345),
    [anon_sym_COLONappendix_COLON] = ACTIONS(345),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(345),
    [anon_sym_COLONtoc_COLON] = ACTIONS(345),
    [aux_sym_specialblock_token1] = ACTIONS(345),
    [aux_sym_specialblock_token2] = ACTIONS(345),
    [aux_sym_specialblock_token3] = ACTIONS(345),
    [aux_sym_specialblock_token4] = ACTIONS(345),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(345),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(345),
    [anon_sym_COLONcaption_COLON] = ACTIONS(345),
    [anon_sym_COLONitem_COLON] = ACTIONS(345),
    [anon_sym_COLONprev_COLON] = ACTIONS(345),
    [anon_sym_COLONprev2_COLON] = ACTIONS(345),
    [anon_sym_COLONprev3_COLON] = ACTIONS(345),
    [aux_sym_specialinline_token1] = ACTIONS(347),
    [aux_sym_specialinline_token2] = ACTIONS(347),
    [anon_sym_COLONmath_COLON] = ACTIONS(345),
    [anon_sym_COLONcode_COLON] = ACTIONS(345),
    [aux_sym_specialinline_token3] = ACTIONS(345),
    [aux_sym_specialinline_token4] = ACTIONS(345),
    [anon_sym_COLONref_COLON] = ACTIONS(345),
    [anon_sym_COLONprevious_COLON] = ACTIONS(345),
    [anon_sym_COLONurl_COLON] = ACTIONS(345),
    [anon_sym_COLONcite_COLON] = ACTIONS(345),
    [anon_sym_COLONqed_COLON] = ACTIONS(345),
    [anon_sym_COLONtable_COLON] = ACTIONS(345),
    [anon_sym_COLONassume_COLON] = ACTIONS(345),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(345),
    [anon_sym_COLONprove_COLON] = ACTIONS(345),
    [anon_sym_COLONthen_COLON] = ACTIONS(345),
    [anon_sym_COLONnew_COLON] = ACTIONS(345),
    [anon_sym_COLONlet_COLON] = ACTIONS(345),
    [anon_sym_COLONcase_COLON] = ACTIONS(345),
    [anon_sym_COLONdefine_COLON] = ACTIONS(345),
    [anon_sym_COLONwrite_COLON] = ACTIONS(345),
    [anon_sym_COLONwlog_COLON] = ACTIONS(345),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(345),
    [anon_sym_COLONclaim_COLON] = ACTIONS(345),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(345),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(345),
    [anon_sym_COLONpick_COLON] = ACTIONS(345),
    [anon_sym_COLONst_COLON] = ACTIONS(345),
    [anon_sym_COLONdraft_COLON] = ACTIONS(345),
    [anon_sym_COLONnote_COLON] = ACTIONS(345),
    [anon_sym_COLONspan_COLON] = ACTIONS(345),
    [anon_sym_COLONabstract_COLON] = ACTIONS(345),
    [anon_sym_COLONauthor_COLON] = ACTIONS(345),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(345),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(345),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(345),
    [anon_sym_COLONexample_COLON] = ACTIONS(345),
    [anon_sym_COLONitemize_COLON] = ACTIONS(345),
    [anon_sym_COLONlemma_COLON] = ACTIONS(345),
    [anon_sym_COLONfigure_COLON] = ACTIONS(345),
    [anon_sym_COLONp_COLON] = ACTIONS(345),
    [anon_sym_COLONproof_COLON] = ACTIONS(345),
    [anon_sym_COLONproposition_COLON] = ACTIONS(345),
    [anon_sym_COLONremark_COLON] = ACTIONS(345),
    [anon_sym_COLONsection_COLON] = ACTIONS(345),
    [anon_sym_COLONsketch_COLON] = ACTIONS(345),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(345),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(345),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(345),
    [anon_sym_COLONstep_COLON] = ACTIONS(345),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(345),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(345),
  },
  [STATE(54)] = {
    [anon_sym_COLON_COLON] = ACTIONS(349),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(349),
    [aux_sym_mathblock_token1] = ACTIONS(349),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(349),
    [anon_sym_COLONappendix_COLON] = ACTIONS(349),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(349),
    [anon_sym_COLONtoc_COLON] = ACTIONS(349),
    [aux_sym_specialblock_token1] = ACTIONS(349),
    [aux_sym_specialblock_token2] = ACTIONS(349),
    [aux_sym_specialblock_token3] = ACTIONS(349),
    [aux_sym_specialblock_token4] = ACTIONS(349),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(349),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(349),
    [anon_sym_COLONcaption_COLON] = ACTIONS(349),
    [anon_sym_COLONitem_COLON] = ACTIONS(349),
    [anon_sym_COLONprev_COLON] = ACTIONS(349),
    [anon_sym_COLONprev2_COLON] = ACTIONS(349),
    [anon_sym_COLONprev3_COLON] = ACTIONS(349),
    [aux_sym_specialinline_token1] = ACTIONS(351),
    [aux_sym_specialinline_token2] = ACTIONS(351),
    [anon_sym_COLONmath_COLON] = ACTIONS(349),
    [anon_sym_COLONcode_COLON] = ACTIONS(349),
    [aux_sym_specialinline_token3] = ACTIONS(349),
    [aux_sym_specialinline_token4] = ACTIONS(349),
    [anon_sym_COLONref_COLON] = ACTIONS(349),
    [anon_sym_COLONprevious_COLON] = ACTIONS(349),
    [anon_sym_COLONurl_COLON] = ACTIONS(349),
    [anon_sym_COLONcite_COLON] = ACTIONS(349),
    [anon_sym_COLONqed_COLON] = ACTIONS(349),
    [anon_sym_COLONtable_COLON] = ACTIONS(349),
    [anon_sym_COLONassume_COLON] = ACTIONS(349),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(349),
    [anon_sym_COLONprove_COLON] = ACTIONS(349),
    [anon_sym_COLONthen_COLON] = ACTIONS(349),
    [anon_sym_COLONnew_COLON] = ACTIONS(349),
    [anon_sym_COLONlet_COLON] = ACTIONS(349),
    [anon_sym_COLONcase_COLON] = ACTIONS(349),
    [anon_sym_COLONdefine_COLON] = ACTIONS(349),
    [anon_sym_COLONwrite_COLON] = ACTIONS(349),
    [anon_sym_COLONwlog_COLON] = ACTIONS(349),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(349),
    [anon_sym_COLONclaim_COLON] = ACTIONS(349),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(349),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(349),
    [anon_sym_COLONpick_COLON] = ACTIONS(349),
    [anon_sym_COLONst_COLON] = ACTIONS(349),
    [anon_sym_COLONdraft_COLON] = ACTIONS(349),
    [anon_sym_COLONnote_COLON] = ACTIONS(349),
    [anon_sym_COLONspan_COLON] = ACTIONS(349),
    [anon_sym_COLONabstract_COLON] = ACTIONS(349),
    [anon_sym_COLONauthor_COLON] = ACTIONS(349),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(349),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(349),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(349),
    [anon_sym_COLONexample_COLON] = ACTIONS(349),
    [anon_sym_COLONitemize_COLON] = ACTIONS(349),
    [anon_sym_COLONlemma_COLON] = ACTIONS(349),
    [anon_sym_COLONfigure_COLON] = ACTIONS(349),
    [anon_sym_COLONp_COLON] = ACTIONS(349),
    [anon_sym_COLONproof_COLON] = ACTIONS(349),
    [anon_sym_COLONproposition_COLON] = ACTIONS(349),
    [anon_sym_COLONremark_COLON] = ACTIONS(349),
    [anon_sym_COLONsection_COLON] = ACTIONS(349),
    [anon_sym_COLONsketch_COLON] = ACTIONS(349),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(349),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(349),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(349),
    [anon_sym_COLONstep_COLON] = ACTIONS(349),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(349),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(349),
  },
  [STATE(55)] = {
    [anon_sym_COLON_COLON] = ACTIONS(353),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(353),
    [aux_sym_mathblock_token1] = ACTIONS(353),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(353),
    [anon_sym_COLONappendix_COLON] = ACTIONS(353),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(353),
    [anon_sym_COLONtoc_COLON] = ACTIONS(353),
    [aux_sym_specialblock_token1] = ACTIONS(353),
    [aux_sym_specialblock_token2] = ACTIONS(353),
    [aux_sym_specialblock_token3] = ACTIONS(353),
    [aux_sym_specialblock_token4] = ACTIONS(353),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(353),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(353),
    [anon_sym_COLONcaption_COLON] = ACTIONS(353),
    [anon_sym_COLONitem_COLON] = ACTIONS(353),
    [anon_sym_COLONprev_COLON] = ACTIONS(353),
    [anon_sym_COLONprev2_COLON] = ACTIONS(353),
    [anon_sym_COLONprev3_COLON] = ACTIONS(353),
    [aux_sym_specialinline_token1] = ACTIONS(355),
    [aux_sym_specialinline_token2] = ACTIONS(355),
    [anon_sym_COLONmath_COLON] = ACTIONS(353),
    [anon_sym_COLONcode_COLON] = ACTIONS(353),
    [aux_sym_specialinline_token3] = ACTIONS(353),
    [aux_sym_specialinline_token4] = ACTIONS(353),
    [anon_sym_COLONref_COLON] = ACTIONS(353),
    [anon_sym_COLONprevious_COLON] = ACTIONS(353),
    [anon_sym_COLONurl_COLON] = ACTIONS(353),
    [anon_sym_COLONcite_COLON] = ACTIONS(353),
    [anon_sym_COLONqed_COLON] = ACTIONS(353),
    [anon_sym_COLONtable_COLON] = ACTIONS(353),
    [anon_sym_COLONassume_COLON] = ACTIONS(353),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(353),
    [anon_sym_COLONprove_COLON] = ACTIONS(353),
    [anon_sym_COLONthen_COLON] = ACTIONS(353),
    [anon_sym_COLONnew_COLON] = ACTIONS(353),
    [anon_sym_COLONlet_COLON] = ACTIONS(353),
    [anon_sym_COLONcase_COLON] = ACTIONS(353),
    [anon_sym_COLONdefine_COLON] = ACTIONS(353),
    [anon_sym_COLONwrite_COLON] = ACTIONS(353),
    [anon_sym_COLONwlog_COLON] = ACTIONS(353),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(353),
    [anon_sym_COLONclaim_COLON] = ACTIONS(353),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(353),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(353),
    [anon_sym_COLONpick_COLON] = ACTIONS(353),
    [anon_sym_COLONst_COLON] = ACTIONS(353),
    [anon_sym_COLONdraft_COLON] = ACTIONS(353),
    [anon_sym_COLONnote_COLON] = ACTIONS(353),
    [anon_sym_COLONspan_COLON] = ACTIONS(353),
    [anon_sym_COLONabstract_COLON] = ACTIONS(353),
    [anon_sym_COLONauthor_COLON] = ACTIONS(353),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(353),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(353),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(353),
    [anon_sym_COLONexample_COLON] = ACTIONS(353),
    [anon_sym_COLONitemize_COLON] = ACTIONS(353),
    [anon_sym_COLONlemma_COLON] = ACTIONS(353),
    [anon_sym_COLONfigure_COLON] = ACTIONS(353),
    [anon_sym_COLONp_COLON] = ACTIONS(353),
    [anon_sym_COLONproof_COLON] = ACTIONS(353),
    [anon_sym_COLONproposition_COLON] = ACTIONS(353),
    [anon_sym_COLONremark_COLON] = ACTIONS(353),
    [anon_sym_COLONsection_COLON] = ACTIONS(353),
    [anon_sym_COLONsketch_COLON] = ACTIONS(353),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(353),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(353),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(353),
    [anon_sym_COLONstep_COLON] = ACTIONS(353),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(353),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(353),
  },
  [STATE(56)] = {
    [anon_sym_COLON_COLON] = ACTIONS(357),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(357),
    [aux_sym_mathblock_token1] = ACTIONS(357),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(357),
    [anon_sym_COLONappendix_COLON] = ACTIONS(357),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(357),
    [anon_sym_COLONtoc_COLON] = ACTIONS(357),
    [aux_sym_specialblock_token1] = ACTIONS(357),
    [aux_sym_specialblock_token2] = ACTIONS(357),
    [aux_sym_specialblock_token3] = ACTIONS(357),
    [aux_sym_specialblock_token4] = ACTIONS(357),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(357),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(357),
    [anon_sym_COLONcaption_COLON] = ACTIONS(357),
    [anon_sym_COLONitem_COLON] = ACTIONS(357),
    [anon_sym_COLONprev_COLON] = ACTIONS(357),
    [anon_sym_COLONprev2_COLON] = ACTIONS(357),
    [anon_sym_COLONprev3_COLON] = ACTIONS(357),
    [aux_sym_specialinline_token1] = ACTIONS(359),
    [aux_sym_specialinline_token2] = ACTIONS(359),
    [anon_sym_COLONmath_COLON] = ACTIONS(357),
    [anon_sym_COLONcode_COLON] = ACTIONS(357),
    [aux_sym_specialinline_token3] = ACTIONS(357),
    [aux_sym_specialinline_token4] = ACTIONS(357),
    [anon_sym_COLONref_COLON] = ACTIONS(357),
    [anon_sym_COLONprevious_COLON] = ACTIONS(357),
    [anon_sym_COLONurl_COLON] = ACTIONS(357),
    [anon_sym_COLONcite_COLON] = ACTIONS(357),
    [anon_sym_COLONqed_COLON] = ACTIONS(357),
    [anon_sym_COLONtable_COLON] = ACTIONS(357),
    [anon_sym_COLONassume_COLON] = ACTIONS(357),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(357),
    [anon_sym_COLONprove_COLON] = ACTIONS(357),
    [anon_sym_COLONthen_COLON] = ACTIONS(357),
    [anon_sym_COLONnew_COLON] = ACTIONS(357),
    [anon_sym_COLONlet_COLON] = ACTIONS(357),
    [anon_sym_COLONcase_COLON] = ACTIONS(357),
    [anon_sym_COLONdefine_COLON] = ACTIONS(357),
    [anon_sym_COLONwrite_COLON] = ACTIONS(357),
    [anon_sym_COLONwlog_COLON] = ACTIONS(357),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(357),
    [anon_sym_COLONclaim_COLON] = ACTIONS(357),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(357),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(357),
    [anon_sym_COLONpick_COLON] = ACTIONS(357),
    [anon_sym_COLONst_COLON] = ACTIONS(357),
    [anon_sym_COLONdraft_COLON] = ACTIONS(357),
    [anon_sym_COLONnote_COLON] = ACTIONS(357),
    [anon_sym_COLONspan_COLON] = ACTIONS(357),
    [anon_sym_COLONabstract_COLON] = ACTIONS(357),
    [anon_sym_COLONauthor_COLON] = ACTIONS(357),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(357),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(357),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(357),
    [anon_sym_COLONexample_COLON] = ACTIONS(357),
    [anon_sym_COLONitemize_COLON] = ACTIONS(357),
    [anon_sym_COLONlemma_COLON] = ACTIONS(357),
    [anon_sym_COLONfigure_COLON] = ACTIONS(357),
    [anon_sym_COLONp_COLON] = ACTIONS(357),
    [anon_sym_COLONproof_COLON] = ACTIONS(357),
    [anon_sym_COLONproposition_COLON] = ACTIONS(357),
    [anon_sym_COLONremark_COLON] = ACTIONS(357),
    [anon_sym_COLONsection_COLON] = ACTIONS(357),
    [anon_sym_COLONsketch_COLON] = ACTIONS(357),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(357),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(357),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(357),
    [anon_sym_COLONstep_COLON] = ACTIONS(357),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(357),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(357),
  },
  [STATE(57)] = {
    [anon_sym_COLON_COLON] = ACTIONS(361),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(361),
    [aux_sym_mathblock_token1] = ACTIONS(361),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(361),
    [anon_sym_COLONappendix_COLON] = ACTIONS(361),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(361),
    [anon_sym_COLONtoc_COLON] = ACTIONS(361),
    [aux_sym_specialblock_token1] = ACTIONS(361),
    [aux_sym_specialblock_token2] = ACTIONS(361),
    [aux_sym_specialblock_token3] = ACTIONS(361),
    [aux_sym_specialblock_token4] = ACTIONS(361),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(361),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(361),
    [anon_sym_COLONcaption_COLON] = ACTIONS(361),
    [anon_sym_COLONitem_COLON] = ACTIONS(361),
    [anon_sym_COLONprev_COLON] = ACTIONS(361),
    [anon_sym_COLONprev2_COLON] = ACTIONS(361),
    [anon_sym_COLONprev3_COLON] = ACTIONS(361),
    [aux_sym_specialinline_token1] = ACTIONS(363),
    [aux_sym_specialinline_token2] = ACTIONS(363),
    [anon_sym_COLONmath_COLON] = ACTIONS(361),
    [anon_sym_COLONcode_COLON] = ACTIONS(361),
    [aux_sym_specialinline_token3] = ACTIONS(361),
    [aux_sym_specialinline_token4] = ACTIONS(361),
    [anon_sym_COLONref_COLON] = ACTIONS(361),
    [anon_sym_COLONprevious_COLON] = ACTIONS(361),
    [anon_sym_COLONurl_COLON] = ACTIONS(361),
    [anon_sym_COLONcite_COLON] = ACTIONS(361),
    [anon_sym_COLONqed_COLON] = ACTIONS(361),
    [anon_sym_COLONtable_COLON] = ACTIONS(361),
    [anon_sym_COLONassume_COLON] = ACTIONS(361),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(361),
    [anon_sym_COLONprove_COLON] = ACTIONS(361),
    [anon_sym_COLONthen_COLON] = ACTIONS(361),
    [anon_sym_COLONnew_COLON] = ACTIONS(361),
    [anon_sym_COLONlet_COLON] = ACTIONS(361),
    [anon_sym_COLONcase_COLON] = ACTIONS(361),
    [anon_sym_COLONdefine_COLON] = ACTIONS(361),
    [anon_sym_COLONwrite_COLON] = ACTIONS(361),
    [anon_sym_COLONwlog_COLON] = ACTIONS(361),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(361),
    [anon_sym_COLONclaim_COLON] = ACTIONS(361),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(361),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(361),
    [anon_sym_COLONpick_COLON] = ACTIONS(361),
    [anon_sym_COLONst_COLON] = ACTIONS(361),
    [anon_sym_COLONdraft_COLON] = ACTIONS(361),
    [anon_sym_COLONnote_COLON] = ACTIONS(361),
    [anon_sym_COLONspan_COLON] = ACTIONS(361),
    [anon_sym_COLONabstract_COLON] = ACTIONS(361),
    [anon_sym_COLONauthor_COLON] = ACTIONS(361),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(361),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(361),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(361),
    [anon_sym_COLONexample_COLON] = ACTIONS(361),
    [anon_sym_COLONitemize_COLON] = ACTIONS(361),
    [anon_sym_COLONlemma_COLON] = ACTIONS(361),
    [anon_sym_COLONfigure_COLON] = ACTIONS(361),
    [anon_sym_COLONp_COLON] = ACTIONS(361),
    [anon_sym_COLONproof_COLON] = ACTIONS(361),
    [anon_sym_COLONproposition_COLON] = ACTIONS(361),
    [anon_sym_COLONremark_COLON] = ACTIONS(361),
    [anon_sym_COLONsection_COLON] = ACTIONS(361),
    [anon_sym_COLONsketch_COLON] = ACTIONS(361),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(361),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(361),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(361),
    [anon_sym_COLONstep_COLON] = ACTIONS(361),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(361),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(361),
  },
  [STATE(58)] = {
    [anon_sym_COLON_COLON] = ACTIONS(365),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(365),
    [aux_sym_mathblock_token1] = ACTIONS(365),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(365),
    [anon_sym_COLONappendix_COLON] = ACTIONS(365),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(365),
    [anon_sym_COLONtoc_COLON] = ACTIONS(365),
    [aux_sym_specialblock_token1] = ACTIONS(365),
    [aux_sym_specialblock_token2] = ACTIONS(365),
    [aux_sym_specialblock_token3] = ACTIONS(365),
    [aux_sym_specialblock_token4] = ACTIONS(365),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(365),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(365),
    [anon_sym_COLONcaption_COLON] = ACTIONS(365),
    [anon_sym_COLONitem_COLON] = ACTIONS(365),
    [anon_sym_COLONprev_COLON] = ACTIONS(365),
    [anon_sym_COLONprev2_COLON] = ACTIONS(365),
    [anon_sym_COLONprev3_COLON] = ACTIONS(365),
    [aux_sym_specialinline_token1] = ACTIONS(367),
    [aux_sym_specialinline_token2] = ACTIONS(367),
    [anon_sym_COLONmath_COLON] = ACTIONS(365),
    [anon_sym_COLONcode_COLON] = ACTIONS(365),
    [aux_sym_specialinline_token3] = ACTIONS(365),
    [aux_sym_specialinline_token4] = ACTIONS(365),
    [anon_sym_COLONref_COLON] = ACTIONS(365),
    [anon_sym_COLONprevious_COLON] = ACTIONS(365),
    [anon_sym_COLONurl_COLON] = ACTIONS(365),
    [anon_sym_COLONcite_COLON] = ACTIONS(365),
    [anon_sym_COLONqed_COLON] = ACTIONS(365),
    [anon_sym_COLONtable_COLON] = ACTIONS(365),
    [anon_sym_COLONassume_COLON] = ACTIONS(365),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(365),
    [anon_sym_COLONprove_COLON] = ACTIONS(365),
    [anon_sym_COLONthen_COLON] = ACTIONS(365),
    [anon_sym_COLONnew_COLON] = ACTIONS(365),
    [anon_sym_COLONlet_COLON] = ACTIONS(365),
    [anon_sym_COLONcase_COLON] = ACTIONS(365),
    [anon_sym_COLONdefine_COLON] = ACTIONS(365),
    [anon_sym_COLONwrite_COLON] = ACTIONS(365),
    [anon_sym_COLONwlog_COLON] = ACTIONS(365),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(365),
    [anon_sym_COLONclaim_COLON] = ACTIONS(365),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(365),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(365),
    [anon_sym_COLONpick_COLON] = ACTIONS(365),
    [anon_sym_COLONst_COLON] = ACTIONS(365),
    [anon_sym_COLONdraft_COLON] = ACTIONS(365),
    [anon_sym_COLONnote_COLON] = ACTIONS(365),
    [anon_sym_COLONspan_COLON] = ACTIONS(365),
    [anon_sym_COLONabstract_COLON] = ACTIONS(365),
    [anon_sym_COLONauthor_COLON] = ACTIONS(365),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(365),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(365),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(365),
    [anon_sym_COLONexample_COLON] = ACTIONS(365),
    [anon_sym_COLONitemize_COLON] = ACTIONS(365),
    [anon_sym_COLONlemma_COLON] = ACTIONS(365),
    [anon_sym_COLONfigure_COLON] = ACTIONS(365),
    [anon_sym_COLONp_COLON] = ACTIONS(365),
    [anon_sym_COLONproof_COLON] = ACTIONS(365),
    [anon_sym_COLONproposition_COLON] = ACTIONS(365),
    [anon_sym_COLONremark_COLON] = ACTIONS(365),
    [anon_sym_COLONsection_COLON] = ACTIONS(365),
    [anon_sym_COLONsketch_COLON] = ACTIONS(365),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(365),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(365),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(365),
    [anon_sym_COLONstep_COLON] = ACTIONS(365),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(365),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(365),
  },
  [STATE(59)] = {
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(369),
    [aux_sym_mathblock_token1] = ACTIONS(369),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(369),
    [anon_sym_COLONappendix_COLON] = ACTIONS(369),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(369),
    [anon_sym_COLONtoc_COLON] = ACTIONS(369),
    [aux_sym_specialblock_token1] = ACTIONS(369),
    [aux_sym_specialblock_token2] = ACTIONS(369),
    [aux_sym_specialblock_token3] = ACTIONS(369),
    [aux_sym_specialblock_token4] = ACTIONS(369),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(369),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(369),
    [anon_sym_COLONcaption_COLON] = ACTIONS(369),
    [anon_sym_COLONitem_COLON] = ACTIONS(369),
    [anon_sym_COLONprev_COLON] = ACTIONS(369),
    [anon_sym_COLONprev2_COLON] = ACTIONS(369),
    [anon_sym_COLONprev3_COLON] = ACTIONS(369),
    [aux_sym_specialinline_token1] = ACTIONS(371),
    [aux_sym_specialinline_token2] = ACTIONS(371),
    [anon_sym_COLONmath_COLON] = ACTIONS(369),
    [anon_sym_COLONcode_COLON] = ACTIONS(369),
    [aux_sym_specialinline_token3] = ACTIONS(369),
    [aux_sym_specialinline_token4] = ACTIONS(369),
    [anon_sym_COLONref_COLON] = ACTIONS(369),
    [anon_sym_COLONprevious_COLON] = ACTIONS(369),
    [anon_sym_COLONurl_COLON] = ACTIONS(369),
    [anon_sym_COLONcite_COLON] = ACTIONS(369),
    [anon_sym_COLONqed_COLON] = ACTIONS(369),
    [anon_sym_COLONtable_COLON] = ACTIONS(369),
    [anon_sym_COLONassume_COLON] = ACTIONS(369),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(369),
    [anon_sym_COLONprove_COLON] = ACTIONS(369),
    [anon_sym_COLONthen_COLON] = ACTIONS(369),
    [anon_sym_COLONnew_COLON] = ACTIONS(369),
    [anon_sym_COLONlet_COLON] = ACTIONS(369),
    [anon_sym_COLONcase_COLON] = ACTIONS(369),
    [anon_sym_COLONdefine_COLON] = ACTIONS(369),
    [anon_sym_COLONwrite_COLON] = ACTIONS(369),
    [anon_sym_COLONwlog_COLON] = ACTIONS(369),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(369),
    [anon_sym_COLONclaim_COLON] = ACTIONS(369),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(369),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(369),
    [anon_sym_COLONpick_COLON] = ACTIONS(369),
    [anon_sym_COLONst_COLON] = ACTIONS(369),
    [anon_sym_COLONdraft_COLON] = ACTIONS(369),
    [anon_sym_COLONnote_COLON] = ACTIONS(369),
    [anon_sym_COLONspan_COLON] = ACTIONS(369),
    [anon_sym_COLONabstract_COLON] = ACTIONS(369),
    [anon_sym_COLONauthor_COLON] = ACTIONS(369),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(369),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(369),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(369),
    [anon_sym_COLONexample_COLON] = ACTIONS(369),
    [anon_sym_COLONitemize_COLON] = ACTIONS(369),
    [anon_sym_COLONlemma_COLON] = ACTIONS(369),
    [anon_sym_COLONfigure_COLON] = ACTIONS(369),
    [anon_sym_COLONp_COLON] = ACTIONS(369),
    [anon_sym_COLONproof_COLON] = ACTIONS(369),
    [anon_sym_COLONproposition_COLON] = ACTIONS(369),
    [anon_sym_COLONremark_COLON] = ACTIONS(369),
    [anon_sym_COLONsection_COLON] = ACTIONS(369),
    [anon_sym_COLONsketch_COLON] = ACTIONS(369),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(369),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(369),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(369),
    [anon_sym_COLONstep_COLON] = ACTIONS(369),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(369),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(369),
  },
  [STATE(60)] = {
    [anon_sym_COLON_COLON] = ACTIONS(373),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(373),
    [aux_sym_mathblock_token1] = ACTIONS(373),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(373),
    [anon_sym_COLONappendix_COLON] = ACTIONS(373),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(373),
    [anon_sym_COLONtoc_COLON] = ACTIONS(373),
    [aux_sym_specialblock_token1] = ACTIONS(373),
    [aux_sym_specialblock_token2] = ACTIONS(373),
    [aux_sym_specialblock_token3] = ACTIONS(373),
    [aux_sym_specialblock_token4] = ACTIONS(373),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(373),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(373),
    [anon_sym_COLONcaption_COLON] = ACTIONS(373),
    [anon_sym_COLONitem_COLON] = ACTIONS(373),
    [anon_sym_COLONprev_COLON] = ACTIONS(373),
    [anon_sym_COLONprev2_COLON] = ACTIONS(373),
    [anon_sym_COLONprev3_COLON] = ACTIONS(373),
    [aux_sym_specialinline_token1] = ACTIONS(375),
    [aux_sym_specialinline_token2] = ACTIONS(375),
    [anon_sym_COLONmath_COLON] = ACTIONS(373),
    [anon_sym_COLONcode_COLON] = ACTIONS(373),
    [aux_sym_specialinline_token3] = ACTIONS(373),
    [aux_sym_specialinline_token4] = ACTIONS(373),
    [anon_sym_COLONref_COLON] = ACTIONS(373),
    [anon_sym_COLONprevious_COLON] = ACTIONS(373),
    [anon_sym_COLONurl_COLON] = ACTIONS(373),
    [anon_sym_COLONcite_COLON] = ACTIONS(373),
    [anon_sym_COLONqed_COLON] = ACTIONS(373),
    [anon_sym_COLONtable_COLON] = ACTIONS(373),
    [anon_sym_COLONassume_COLON] = ACTIONS(373),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(373),
    [anon_sym_COLONprove_COLON] = ACTIONS(373),
    [anon_sym_COLONthen_COLON] = ACTIONS(373),
    [anon_sym_COLONnew_COLON] = ACTIONS(373),
    [anon_sym_COLONlet_COLON] = ACTIONS(373),
    [anon_sym_COLONcase_COLON] = ACTIONS(373),
    [anon_sym_COLONdefine_COLON] = ACTIONS(373),
    [anon_sym_COLONwrite_COLON] = ACTIONS(373),
    [anon_sym_COLONwlog_COLON] = ACTIONS(373),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(373),
    [anon_sym_COLONclaim_COLON] = ACTIONS(373),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(373),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(373),
    [anon_sym_COLONpick_COLON] = ACTIONS(373),
    [anon_sym_COLONst_COLON] = ACTIONS(373),
    [anon_sym_COLONdraft_COLON] = ACTIONS(373),
    [anon_sym_COLONnote_COLON] = ACTIONS(373),
    [anon_sym_COLONspan_COLON] = ACTIONS(373),
    [anon_sym_COLONabstract_COLON] = ACTIONS(373),
    [anon_sym_COLONauthor_COLON] = ACTIONS(373),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(373),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(373),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(373),
    [anon_sym_COLONexample_COLON] = ACTIONS(373),
    [anon_sym_COLONitemize_COLON] = ACTIONS(373),
    [anon_sym_COLONlemma_COLON] = ACTIONS(373),
    [anon_sym_COLONfigure_COLON] = ACTIONS(373),
    [anon_sym_COLONp_COLON] = ACTIONS(373),
    [anon_sym_COLONproof_COLON] = ACTIONS(373),
    [anon_sym_COLONproposition_COLON] = ACTIONS(373),
    [anon_sym_COLONremark_COLON] = ACTIONS(373),
    [anon_sym_COLONsection_COLON] = ACTIONS(373),
    [anon_sym_COLONsketch_COLON] = ACTIONS(373),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(373),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(373),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(373),
    [anon_sym_COLONstep_COLON] = ACTIONS(373),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(373),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(373),
  },
  [STATE(61)] = {
    [anon_sym_COLON_COLON] = ACTIONS(377),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(377),
    [aux_sym_mathblock_token1] = ACTIONS(377),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(377),
    [anon_sym_COLONappendix_COLON] = ACTIONS(377),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(377),
    [anon_sym_COLONtoc_COLON] = ACTIONS(377),
    [aux_sym_specialblock_token1] = ACTIONS(377),
    [aux_sym_specialblock_token2] = ACTIONS(377),
    [aux_sym_specialblock_token3] = ACTIONS(377),
    [aux_sym_specialblock_token4] = ACTIONS(377),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(377),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(377),
    [anon_sym_COLONcaption_COLON] = ACTIONS(377),
    [anon_sym_COLONitem_COLON] = ACTIONS(377),
    [anon_sym_COLONprev_COLON] = ACTIONS(377),
    [anon_sym_COLONprev2_COLON] = ACTIONS(377),
    [anon_sym_COLONprev3_COLON] = ACTIONS(377),
    [aux_sym_specialinline_token1] = ACTIONS(379),
    [aux_sym_specialinline_token2] = ACTIONS(379),
    [anon_sym_COLONmath_COLON] = ACTIONS(377),
    [anon_sym_COLONcode_COLON] = ACTIONS(377),
    [aux_sym_specialinline_token3] = ACTIONS(377),
    [aux_sym_specialinline_token4] = ACTIONS(377),
    [anon_sym_COLONref_COLON] = ACTIONS(377),
    [anon_sym_COLONprevious_COLON] = ACTIONS(377),
    [anon_sym_COLONurl_COLON] = ACTIONS(377),
    [anon_sym_COLONcite_COLON] = ACTIONS(377),
    [anon_sym_COLONqed_COLON] = ACTIONS(377),
    [anon_sym_COLONtable_COLON] = ACTIONS(377),
    [anon_sym_COLONassume_COLON] = ACTIONS(377),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(377),
    [anon_sym_COLONprove_COLON] = ACTIONS(377),
    [anon_sym_COLONthen_COLON] = ACTIONS(377),
    [anon_sym_COLONnew_COLON] = ACTIONS(377),
    [anon_sym_COLONlet_COLON] = ACTIONS(377),
    [anon_sym_COLONcase_COLON] = ACTIONS(377),
    [anon_sym_COLONdefine_COLON] = ACTIONS(377),
    [anon_sym_COLONwrite_COLON] = ACTIONS(377),
    [anon_sym_COLONwlog_COLON] = ACTIONS(377),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(377),
    [anon_sym_COLONclaim_COLON] = ACTIONS(377),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(377),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(377),
    [anon_sym_COLONpick_COLON] = ACTIONS(377),
    [anon_sym_COLONst_COLON] = ACTIONS(377),
    [anon_sym_COLONdraft_COLON] = ACTIONS(377),
    [anon_sym_COLONnote_COLON] = ACTIONS(377),
    [anon_sym_COLONspan_COLON] = ACTIONS(377),
    [anon_sym_COLONabstract_COLON] = ACTIONS(377),
    [anon_sym_COLONauthor_COLON] = ACTIONS(377),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(377),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(377),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(377),
    [anon_sym_COLONexample_COLON] = ACTIONS(377),
    [anon_sym_COLONitemize_COLON] = ACTIONS(377),
    [anon_sym_COLONlemma_COLON] = ACTIONS(377),
    [anon_sym_COLONfigure_COLON] = ACTIONS(377),
    [anon_sym_COLONp_COLON] = ACTIONS(377),
    [anon_sym_COLONproof_COLON] = ACTIONS(377),
    [anon_sym_COLONproposition_COLON] = ACTIONS(377),
    [anon_sym_COLONremark_COLON] = ACTIONS(377),
    [anon_sym_COLONsection_COLON] = ACTIONS(377),
    [anon_sym_COLONsketch_COLON] = ACTIONS(377),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(377),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(377),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(377),
    [anon_sym_COLONstep_COLON] = ACTIONS(377),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(377),
  },
  [STATE(62)] = {
    [anon_sym_COLON_COLON] = ACTIONS(381),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(381),
    [aux_sym_mathblock_token1] = ACTIONS(381),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(381),
    [anon_sym_COLONappendix_COLON] = ACTIONS(381),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(381),
    [anon_sym_COLONtoc_COLON] = ACTIONS(381),
    [aux_sym_specialblock_token1] = ACTIONS(381),
    [aux_sym_specialblock_token2] = ACTIONS(381),
    [aux_sym_specialblock_token3] = ACTIONS(381),
    [aux_sym_specialblock_token4] = ACTIONS(381),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(381),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(381),
    [anon_sym_COLONcaption_COLON] = ACTIONS(381),
    [anon_sym_COLONitem_COLON] = ACTIONS(381),
    [anon_sym_COLONprev_COLON] = ACTIONS(381),
    [anon_sym_COLONprev2_COLON] = ACTIONS(381),
    [anon_sym_COLONprev3_COLON] = ACTIONS(381),
    [aux_sym_specialinline_token1] = ACTIONS(383),
    [aux_sym_specialinline_token2] = ACTIONS(383),
    [anon_sym_COLONmath_COLON] = ACTIONS(381),
    [anon_sym_COLONcode_COLON] = ACTIONS(381),
    [aux_sym_specialinline_token3] = ACTIONS(381),
    [aux_sym_specialinline_token4] = ACTIONS(381),
    [anon_sym_COLONref_COLON] = ACTIONS(381),
    [anon_sym_COLONprevious_COLON] = ACTIONS(381),
    [anon_sym_COLONurl_COLON] = ACTIONS(381),
    [anon_sym_COLONcite_COLON] = ACTIONS(381),
    [anon_sym_COLONqed_COLON] = ACTIONS(381),
    [anon_sym_COLONtable_COLON] = ACTIONS(381),
    [anon_sym_COLONassume_COLON] = ACTIONS(381),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(381),
    [anon_sym_COLONprove_COLON] = ACTIONS(381),
    [anon_sym_COLONthen_COLON] = ACTIONS(381),
    [anon_sym_COLONnew_COLON] = ACTIONS(381),
    [anon_sym_COLONlet_COLON] = ACTIONS(381),
    [anon_sym_COLONcase_COLON] = ACTIONS(381),
    [anon_sym_COLONdefine_COLON] = ACTIONS(381),
    [anon_sym_COLONwrite_COLON] = ACTIONS(381),
    [anon_sym_COLONwlog_COLON] = ACTIONS(381),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(381),
    [anon_sym_COLONclaim_COLON] = ACTIONS(381),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(381),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(381),
    [anon_sym_COLONpick_COLON] = ACTIONS(381),
    [anon_sym_COLONst_COLON] = ACTIONS(381),
    [anon_sym_COLONdraft_COLON] = ACTIONS(381),
    [anon_sym_COLONnote_COLON] = ACTIONS(381),
    [anon_sym_COLONspan_COLON] = ACTIONS(381),
    [anon_sym_COLONabstract_COLON] = ACTIONS(381),
    [anon_sym_COLONauthor_COLON] = ACTIONS(381),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(381),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(381),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(381),
    [anon_sym_COLONexample_COLON] = ACTIONS(381),
    [anon_sym_COLONitemize_COLON] = ACTIONS(381),
    [anon_sym_COLONlemma_COLON] = ACTIONS(381),
    [anon_sym_COLONfigure_COLON] = ACTIONS(381),
    [anon_sym_COLONp_COLON] = ACTIONS(381),
    [anon_sym_COLONproof_COLON] = ACTIONS(381),
    [anon_sym_COLONproposition_COLON] = ACTIONS(381),
    [anon_sym_COLONremark_COLON] = ACTIONS(381),
    [anon_sym_COLONsection_COLON] = ACTIONS(381),
    [anon_sym_COLONsketch_COLON] = ACTIONS(381),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(381),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(381),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(381),
    [anon_sym_COLONstep_COLON] = ACTIONS(381),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(381),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(381),
  },
  [STATE(63)] = {
    [anon_sym_COLON_COLON] = ACTIONS(385),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(385),
    [aux_sym_mathblock_token1] = ACTIONS(385),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(385),
    [anon_sym_COLONappendix_COLON] = ACTIONS(385),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(385),
    [anon_sym_COLONtoc_COLON] = ACTIONS(385),
    [aux_sym_specialblock_token1] = ACTIONS(385),
    [aux_sym_specialblock_token2] = ACTIONS(385),
    [aux_sym_specialblock_token3] = ACTIONS(385),
    [aux_sym_specialblock_token4] = ACTIONS(385),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(385),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(385),
    [anon_sym_COLONcaption_COLON] = ACTIONS(385),
    [anon_sym_COLONitem_COLON] = ACTIONS(385),
    [anon_sym_COLONprev_COLON] = ACTIONS(385),
    [anon_sym_COLONprev2_COLON] = ACTIONS(385),
    [anon_sym_COLONprev3_COLON] = ACTIONS(385),
    [aux_sym_specialinline_token1] = ACTIONS(387),
    [aux_sym_specialinline_token2] = ACTIONS(387),
    [anon_sym_COLONmath_COLON] = ACTIONS(385),
    [anon_sym_COLONcode_COLON] = ACTIONS(385),
    [aux_sym_specialinline_token3] = ACTIONS(385),
    [aux_sym_specialinline_token4] = ACTIONS(385),
    [anon_sym_COLONref_COLON] = ACTIONS(385),
    [anon_sym_COLONprevious_COLON] = ACTIONS(385),
    [anon_sym_COLONurl_COLON] = ACTIONS(385),
    [anon_sym_COLONcite_COLON] = ACTIONS(385),
    [anon_sym_COLONqed_COLON] = ACTIONS(385),
    [anon_sym_COLONtable_COLON] = ACTIONS(385),
    [anon_sym_COLONassume_COLON] = ACTIONS(385),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(385),
    [anon_sym_COLONprove_COLON] = ACTIONS(385),
    [anon_sym_COLONthen_COLON] = ACTIONS(385),
    [anon_sym_COLONnew_COLON] = ACTIONS(385),
    [anon_sym_COLONlet_COLON] = ACTIONS(385),
    [anon_sym_COLONcase_COLON] = ACTIONS(385),
    [anon_sym_COLONdefine_COLON] = ACTIONS(385),
    [anon_sym_COLONwrite_COLON] = ACTIONS(385),
    [anon_sym_COLONwlog_COLON] = ACTIONS(385),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(385),
    [anon_sym_COLONclaim_COLON] = ACTIONS(385),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(385),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(385),
    [anon_sym_COLONpick_COLON] = ACTIONS(385),
    [anon_sym_COLONst_COLON] = ACTIONS(385),
    [anon_sym_COLONdraft_COLON] = ACTIONS(385),
    [anon_sym_COLONnote_COLON] = ACTIONS(385),
    [anon_sym_COLONspan_COLON] = ACTIONS(385),
    [anon_sym_COLONabstract_COLON] = ACTIONS(385),
    [anon_sym_COLONauthor_COLON] = ACTIONS(385),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(385),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(385),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(385),
    [anon_sym_COLONexample_COLON] = ACTIONS(385),
    [anon_sym_COLONitemize_COLON] = ACTIONS(385),
    [anon_sym_COLONlemma_COLON] = ACTIONS(385),
    [anon_sym_COLONfigure_COLON] = ACTIONS(385),
    [anon_sym_COLONp_COLON] = ACTIONS(385),
    [anon_sym_COLONproof_COLON] = ACTIONS(385),
    [anon_sym_COLONproposition_COLON] = ACTIONS(385),
    [anon_sym_COLONremark_COLON] = ACTIONS(385),
    [anon_sym_COLONsection_COLON] = ACTIONS(385),
    [anon_sym_COLONsketch_COLON] = ACTIONS(385),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(385),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(385),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(385),
    [anon_sym_COLONstep_COLON] = ACTIONS(385),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(385),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(385),
  },
  [STATE(64)] = {
    [anon_sym_COLON_COLON] = ACTIONS(389),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(389),
    [aux_sym_mathblock_token1] = ACTIONS(389),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(389),
    [anon_sym_COLONappendix_COLON] = ACTIONS(389),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(389),
    [anon_sym_COLONtoc_COLON] = ACTIONS(389),
    [aux_sym_specialblock_token1] = ACTIONS(389),
    [aux_sym_specialblock_token2] = ACTIONS(389),
    [aux_sym_specialblock_token3] = ACTIONS(389),
    [aux_sym_specialblock_token4] = ACTIONS(389),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(389),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(389),
    [anon_sym_COLONcaption_COLON] = ACTIONS(389),
    [anon_sym_COLONitem_COLON] = ACTIONS(389),
    [anon_sym_COLONprev_COLON] = ACTIONS(389),
    [anon_sym_COLONprev2_COLON] = ACTIONS(389),
    [anon_sym_COLONprev3_COLON] = ACTIONS(389),
    [aux_sym_specialinline_token1] = ACTIONS(391),
    [aux_sym_specialinline_token2] = ACTIONS(391),
    [anon_sym_COLONmath_COLON] = ACTIONS(389),
    [anon_sym_COLONcode_COLON] = ACTIONS(389),
    [aux_sym_specialinline_token3] = ACTIONS(389),
    [aux_sym_specialinline_token4] = ACTIONS(389),
    [anon_sym_COLONref_COLON] = ACTIONS(389),
    [anon_sym_COLONprevious_COLON] = ACTIONS(389),
    [anon_sym_COLONurl_COLON] = ACTIONS(389),
    [anon_sym_COLONcite_COLON] = ACTIONS(389),
    [anon_sym_COLONqed_COLON] = ACTIONS(389),
    [anon_sym_COLONtable_COLON] = ACTIONS(389),
    [anon_sym_COLONassume_COLON] = ACTIONS(389),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(389),
    [anon_sym_COLONprove_COLON] = ACTIONS(389),
    [anon_sym_COLONthen_COLON] = ACTIONS(389),
    [anon_sym_COLONnew_COLON] = ACTIONS(389),
    [anon_sym_COLONlet_COLON] = ACTIONS(389),
    [anon_sym_COLONcase_COLON] = ACTIONS(389),
    [anon_sym_COLONdefine_COLON] = ACTIONS(389),
    [anon_sym_COLONwrite_COLON] = ACTIONS(389),
    [anon_sym_COLONwlog_COLON] = ACTIONS(389),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(389),
    [anon_sym_COLONclaim_COLON] = ACTIONS(389),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(389),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(389),
    [anon_sym_COLONpick_COLON] = ACTIONS(389),
    [anon_sym_COLONst_COLON] = ACTIONS(389),
    [anon_sym_COLONdraft_COLON] = ACTIONS(389),
    [anon_sym_COLONnote_COLON] = ACTIONS(389),
    [anon_sym_COLONspan_COLON] = ACTIONS(389),
    [anon_sym_COLONabstract_COLON] = ACTIONS(389),
    [anon_sym_COLONauthor_COLON] = ACTIONS(389),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(389),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(389),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(389),
    [anon_sym_COLONexample_COLON] = ACTIONS(389),
    [anon_sym_COLONitemize_COLON] = ACTIONS(389),
    [anon_sym_COLONlemma_COLON] = ACTIONS(389),
    [anon_sym_COLONfigure_COLON] = ACTIONS(389),
    [anon_sym_COLONp_COLON] = ACTIONS(389),
    [anon_sym_COLONproof_COLON] = ACTIONS(389),
    [anon_sym_COLONproposition_COLON] = ACTIONS(389),
    [anon_sym_COLONremark_COLON] = ACTIONS(389),
    [anon_sym_COLONsection_COLON] = ACTIONS(389),
    [anon_sym_COLONsketch_COLON] = ACTIONS(389),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(389),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(389),
    [anon_sym_COLONsubsubsubsection_COLON] = ACTIONS(389),
    [anon_sym_COLONstep_COLON] = ACTIONS(389),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(389),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(389),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(417), 1,
      anon_sym_COLONtd_COLON,
    ACTIONS(423), 1,
      sym_text,
    STATE(96), 1,
      aux_sym_trshort_repeat1,
    STATE(390), 1,
      sym_tdcontent,
    STATE(338), 2,
      sym_td,
      aux_sym_tr_repeat1,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(95), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [88] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(431), 1,
      anon_sym_LBRACE,
    ACTIONS(433), 1,
      sym_text,
    STATE(83), 1,
      sym_inlinemeta,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(74), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [176] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(431), 1,
      anon_sym_LBRACE,
    ACTIONS(435), 1,
      sym_text,
    STATE(81), 1,
      sym_inlinemeta,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(73), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [264] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(431), 1,
      anon_sym_LBRACE,
    ACTIONS(437), 1,
      sym_text,
    STATE(93), 1,
      sym_inlinemeta,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(77), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [352] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(441), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [437] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(443), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [522] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(445), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [607] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(447), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [692] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(449), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [777] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(451), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [862] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(453), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [947] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(455), 1,
      aux_sym_mathblock_token1,
    ACTIONS(458), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(464), 1,
      aux_sym_specialinline_token1,
    ACTIONS(467), 1,
      aux_sym_specialinline_token2,
    ACTIONS(470), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(473), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(476), 1,
      aux_sym_specialinline_token3,
    ACTIONS(479), 1,
      aux_sym_specialinline_token4,
    ACTIONS(482), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(485), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(488), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(491), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(494), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(503), 1,
      sym_text,
    ACTIONS(506), 1,
      sym_paragraph_end,
    ACTIONS(461), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(500), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(497), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1032] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(439), 1,
      sym_text,
    ACTIONS(508), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(76), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1117] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(510), 1,
      sym_text,
    ACTIONS(512), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(71), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1202] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(514), 1,
      sym_text,
    ACTIONS(516), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(72), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1287] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(518), 1,
      anon_sym_COLON_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(522), 1,
      sym_text,
    STATE(101), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(105), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1371] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(524), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(70), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1453] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(526), 1,
      anon_sym_COLON_COLON,
    ACTIONS(528), 1,
      sym_text,
    STATE(99), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(100), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1537] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(530), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(75), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1619] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(423), 1,
      sym_text,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    STATE(103), 1,
      sym_inlinemeta,
    STATE(593), 1,
      sym_tdcontent,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(95), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1703] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(532), 1,
      anon_sym_COLON_COLON,
    ACTIONS(534), 1,
      sym_text,
    STATE(118), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1787] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(536), 1,
      anon_sym_COLON_COLON,
    ACTIONS(538), 1,
      sym_text,
    STATE(116), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(117), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1871] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(542), 1,
      sym_text,
    STATE(129), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(130), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1955] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(544), 1,
      anon_sym_COLON_COLON,
    ACTIONS(546), 1,
      sym_text,
    STATE(137), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(138), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2039] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(548), 1,
      anon_sym_COLON_COLON,
    ACTIONS(550), 1,
      sym_text,
    STATE(139), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(140), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2123] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(554), 1,
      sym_text,
    STATE(98), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(147), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2207] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(556), 1,
      anon_sym_COLON_COLON,
    ACTIONS(558), 1,
      sym_text,
    STATE(148), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(149), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2291] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(560), 1,
      anon_sym_COLON_COLON,
    ACTIONS(562), 1,
      sym_text,
    STATE(127), 1,
      sym_inlinemeta,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(128), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2375] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(425), 1,
      aux_sym_mathblock_token1,
    ACTIONS(427), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(564), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(69), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2457] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(569), 1,
      aux_sym_specialinline_token1,
    ACTIONS(572), 1,
      aux_sym_specialinline_token2,
    ACTIONS(575), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(578), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(581), 1,
      aux_sym_specialinline_token3,
    ACTIONS(584), 1,
      aux_sym_specialinline_token4,
    ACTIONS(587), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(590), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(593), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(596), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(599), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(608), 1,
      sym_text,
    STATE(94), 1,
      aux_sym_trshort_repeat1,
    STATE(483), 1,
      sym_tdcontent,
    ACTIONS(566), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(605), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(109), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(602), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2538] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(611), 1,
      anon_sym_COLON_COLON,
    ACTIONS(613), 1,
      anon_sym_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2619] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(423), 1,
      sym_text,
    STATE(94), 1,
      aux_sym_trshort_repeat1,
    STATE(446), 1,
      sym_tdcontent,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(95), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2700] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(622), 1,
      aux_sym_specialinline_token1,
    ACTIONS(625), 1,
      aux_sym_specialinline_token2,
    ACTIONS(628), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(631), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(634), 1,
      aux_sym_specialinline_token3,
    ACTIONS(637), 1,
      aux_sym_specialinline_token4,
    ACTIONS(640), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(643), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(646), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(649), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(652), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(655), 1,
      anon_sym_COLON,
    ACTIONS(663), 1,
      sym_text,
    ACTIONS(619), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(660), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(657), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2781] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(666), 1,
      anon_sym_COLON_COLON,
    ACTIONS(668), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(150), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2859] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(670), 1,
      anon_sym_COLON_COLON,
    ACTIONS(672), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(102), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2937] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(674), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3015] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(676), 1,
      anon_sym_COLON_COLON,
    ACTIONS(678), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(104), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3093] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(680), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3171] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(423), 1,
      sym_text,
    STATE(480), 1,
      sym_tdcontent,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(95), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3249] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(682), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3327] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(684), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3405] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(698), 1,
      anon_sym_STAR,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(716), 1,
      sym_text,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(113), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3483] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(698), 1,
      anon_sym_SLASH,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(746), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(120), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3561] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(617), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      aux_sym_specialinline_token1,
    ACTIONS(754), 1,
      aux_sym_specialinline_token2,
    ACTIONS(757), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(760), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(763), 1,
      aux_sym_specialinline_token3,
    ACTIONS(766), 1,
      aux_sym_specialinline_token4,
    ACTIONS(769), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(772), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(775), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(778), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(781), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(790), 1,
      sym_text,
    ACTIONS(748), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(787), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(108), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(784), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3639] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 1,
      anon_sym_COLON,
    ACTIONS(795), 1,
      aux_sym_specialinline_token1,
    ACTIONS(797), 1,
      aux_sym_specialinline_token2,
    ACTIONS(799), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(801), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(803), 1,
      aux_sym_specialinline_token3,
    ACTIONS(805), 1,
      aux_sym_specialinline_token4,
    ACTIONS(807), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(809), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(811), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(813), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(815), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(821), 1,
      sym_text,
    ACTIONS(793), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(819), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(110), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(817), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3717] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(655), 1,
      anon_sym_COLON,
    ACTIONS(826), 1,
      aux_sym_specialinline_token1,
    ACTIONS(829), 1,
      aux_sym_specialinline_token2,
    ACTIONS(832), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(835), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(838), 1,
      aux_sym_specialinline_token3,
    ACTIONS(841), 1,
      aux_sym_specialinline_token4,
    ACTIONS(844), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(847), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(850), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(853), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(856), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(865), 1,
      sym_text,
    ACTIONS(823), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(862), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(110), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(859), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3795] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(868), 1,
      anon_sym_STAR,
    ACTIONS(870), 1,
      sym_text,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(114), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(868), 1,
      anon_sym_SLASH,
    ACTIONS(872), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(115), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3951] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(876), 1,
      sym_text,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4029] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(876), 1,
      sym_text,
    ACTIONS(878), 1,
      anon_sym_STAR,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4107] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(878), 1,
      anon_sym_SLASH,
    ACTIONS(880), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(108), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4185] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(882), 1,
      anon_sym_COLON_COLON,
    ACTIONS(884), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(152), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4263] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(886), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4341] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(888), 1,
      anon_sym_COLON_COLON,
    ACTIONS(890), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(122), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4419] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(892), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4497] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(880), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(108), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4575] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(617), 1,
      anon_sym_STAR,
    ACTIONS(897), 1,
      aux_sym_specialinline_token1,
    ACTIONS(900), 1,
      aux_sym_specialinline_token2,
    ACTIONS(903), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(906), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(909), 1,
      aux_sym_specialinline_token3,
    ACTIONS(912), 1,
      aux_sym_specialinline_token4,
    ACTIONS(915), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(918), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(921), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(924), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(927), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(936), 1,
      sym_text,
    ACTIONS(894), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(933), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(930), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4653] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4731] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(941), 1,
      anon_sym_STAR,
    ACTIONS(943), 1,
      sym_text,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(125), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4809] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(941), 1,
      anon_sym_SLASH,
    ACTIONS(945), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(126), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4887] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(876), 1,
      sym_text,
    ACTIONS(947), 1,
      anon_sym_STAR,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4965] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(880), 1,
      sym_text,
    ACTIONS(947), 1,
      anon_sym_SLASH,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(108), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5043] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(949), 1,
      anon_sym_COLON_COLON,
    ACTIONS(951), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(131), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5121] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(953), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5199] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(955), 1,
      anon_sym_COLON_COLON,
    ACTIONS(957), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(132), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5277] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(959), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5355] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5433] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(963), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5511] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(965), 1,
      anon_sym_STAR,
    ACTIONS(967), 1,
      sym_text,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(135), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5589] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(965), 1,
      anon_sym_SLASH,
    ACTIONS(969), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(136), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5667] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(876), 1,
      sym_text,
    ACTIONS(971), 1,
      anon_sym_STAR,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5745] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(880), 1,
      sym_text,
    ACTIONS(971), 1,
      anon_sym_SLASH,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(108), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5823] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(973), 1,
      anon_sym_COLON_COLON,
    ACTIONS(975), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(141), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5901] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(977), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5979] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(979), 1,
      anon_sym_COLON_COLON,
    ACTIONS(981), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(142), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6057] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(983), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6135] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(985), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6213] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(987), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6291] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(989), 1,
      anon_sym_STAR,
    ACTIONS(991), 1,
      sym_text,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(145), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6369] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(989), 1,
      anon_sym_SLASH,
    ACTIONS(993), 1,
      sym_text,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(146), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6447] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(688), 1,
      aux_sym_specialinline_token1,
    ACTIONS(690), 1,
      aux_sym_specialinline_token2,
    ACTIONS(692), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(694), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(696), 1,
      aux_sym_specialinline_token3,
    ACTIONS(700), 1,
      aux_sym_specialinline_token4,
    ACTIONS(702), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(704), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(706), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(708), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(710), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(876), 1,
      sym_text,
    ACTIONS(995), 1,
      anon_sym_STAR,
    ACTIONS(686), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(714), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(712), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6525] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      aux_sym_specialinline_token1,
    ACTIONS(722), 1,
      aux_sym_specialinline_token2,
    ACTIONS(724), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(726), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(728), 1,
      aux_sym_specialinline_token3,
    ACTIONS(730), 1,
      aux_sym_specialinline_token4,
    ACTIONS(732), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(734), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(736), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(738), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(740), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(880), 1,
      sym_text,
    ACTIONS(995), 1,
      anon_sym_SLASH,
    ACTIONS(718), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(744), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(108), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(742), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6603] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(997), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6681] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(999), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1001), 1,
      sym_text,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(151), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6759] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(1003), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6837] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(1005), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6915] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(1007), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 1,
      aux_sym_specialinline_token1,
    ACTIONS(397), 1,
      aux_sym_specialinline_token2,
    ACTIONS(399), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(401), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(403), 1,
      aux_sym_specialinline_token3,
    ACTIONS(405), 1,
      aux_sym_specialinline_token4,
    ACTIONS(407), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(409), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(411), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(413), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(415), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(615), 1,
      sym_text,
    ACTIONS(1009), 1,
      anon_sym_COLON_COLON,
    ACTIONS(393), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(421), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(419), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [7071] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(429), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1011), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1013), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(78), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      sym__paragraphcontent_no_special,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [7146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1015), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1021), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1019), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1025), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1023), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1027), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1033), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1031), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1037), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1035), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1039), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1045), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1043), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1049), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1047), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1051), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1055), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1059), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1063), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1067), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1073), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1071), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1077), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1075), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(243), 1,
      aux_sym_specialinline_token1,
    ACTIONS(241), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1081), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1079), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1083), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8001] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(299), 1,
      aux_sym_specialinline_token1,
    ACTIONS(297), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1087), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1083), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1093), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1091), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1097), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1095), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1073), 1,
      anon_sym_COLON,
    ACTIONS(1071), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1045), 1,
      anon_sym_COLON,
    ACTIONS(1043), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      anon_sym_COLON,
    ACTIONS(1039), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      anon_sym_COLON,
    ACTIONS(1063), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1077), 1,
      anon_sym_COLON,
    ACTIONS(1075), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1081), 1,
      anon_sym_COLON,
    ACTIONS(1079), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COLON,
    ACTIONS(1083), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COLON,
    ACTIONS(1083), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 1,
      anon_sym_COLON,
    ACTIONS(1067), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      anon_sym_COLON,
    ACTIONS(1055), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 1,
      anon_sym_COLON,
    ACTIONS(1027), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1049), 1,
      anon_sym_COLON,
    ACTIONS(1047), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_COLON,
    ACTIONS(1087), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1025), 1,
      anon_sym_COLON,
    ACTIONS(1023), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_COLON,
    ACTIONS(1051), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1093), 1,
      anon_sym_COLON,
    ACTIONS(1091), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8930] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1021), 1,
      anon_sym_COLON,
    ACTIONS(1019), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1101), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1099), 35,
      sym_text,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1097), 1,
      anon_sym_COLON,
    ACTIONS(1095), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      anon_sym_COLON,
    ACTIONS(1015), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      anon_sym_COLON,
    ACTIONS(1059), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1033), 1,
      anon_sym_COLON,
    ACTIONS(1031), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1105), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1103), 35,
      sym_text,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1037), 1,
      anon_sym_COLON,
    ACTIONS(1035), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1093), 1,
      anon_sym_COLON,
    ACTIONS(1091), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1039), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1077), 1,
      anon_sym_COLON,
    ACTIONS(1075), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1081), 1,
      anon_sym_COLON,
    ACTIONS(1079), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COLON,
    ACTIONS(1083), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COLON,
    ACTIONS(1083), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      anon_sym_COLON,
    ACTIONS(1055), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 1,
      anon_sym_COLON,
    ACTIONS(1027), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1049), 1,
      anon_sym_COLON,
    ACTIONS(1047), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_COLON,
    ACTIONS(1087), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1025), 1,
      anon_sym_COLON,
    ACTIONS(1023), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9755] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_COLON,
    ACTIONS(1051), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1055), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1021), 1,
      anon_sym_COLON,
    ACTIONS(1019), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9884] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1097), 1,
      anon_sym_COLON,
    ACTIONS(1095), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      anon_sym_COLON,
    ACTIONS(1015), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      anon_sym_COLON,
    ACTIONS(1059), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1033), 1,
      anon_sym_COLON,
    ACTIONS(1031), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1037), 1,
      anon_sym_COLON,
    ACTIONS(1035), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1027), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1049), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1047), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1087), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1025), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1023), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1051), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1093), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1091), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1021), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1019), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1097), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1095), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1015), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1059), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10529] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1099), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1073), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1071), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10613] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1067), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1045), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1043), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1039), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1033), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1031), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1063), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1063), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1077), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1075), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1077), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1075), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10957] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1081), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1079), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1083), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1083), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1103), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1055), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1027), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1049), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1047), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1081), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1079), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1083), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1087), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1025), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1023), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1051), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1083), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11514] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1093), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1091), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1021), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1019), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1097), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1095), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1073), 1,
      anon_sym_COLON,
    ACTIONS(1071), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1015), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 1,
      anon_sym_COLON,
    ACTIONS(1067), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1059), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1045), 1,
      anon_sym_COLON,
    ACTIONS(1043), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      anon_sym_COLON,
    ACTIONS(1039), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1033), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1031), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1037), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1035), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1073), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1071), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12030] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1067), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1045), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1043), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12116] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      anon_sym_COLON,
    ACTIONS(1063), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1037), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1035), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1107), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12242] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1109), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1113), 1,
      anon_sym_COLONthead_COLON,
    ACTIONS(1115), 1,
      anon_sym_COLONtbody_COLON,
    STATE(299), 1,
      sym_metakey_bool,
    STATE(327), 1,
      sym_blockmeta,
    STATE(331), 1,
      sym_thead,
    STATE(350), 1,
      sym_tbody,
    STATE(357), 1,
      sym_metakey_list,
    STATE(405), 1,
      sym_metakey_text,
    STATE(407), 1,
      sym_metakey_any,
    STATE(571), 1,
      sym_caption,
    STATE(273), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12313] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(299), 1,
      sym_metakey_bool,
    STATE(357), 1,
      sym_metakey_list,
    STATE(405), 1,
      sym_metakey_text,
    STATE(407), 1,
      sym_metakey_any,
    STATE(272), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(91), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(94), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(81), 4,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1119), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(85), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12366] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(299), 1,
      sym_metakey_bool,
    STATE(357), 1,
      sym_metakey_list,
    STATE(405), 1,
      sym_metakey_text,
    STATE(407), 1,
      sym_metakey_any,
    STATE(272), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(77), 4,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12419] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1124), 1,
      sym_asis_halmos_text,
    STATE(314), 1,
      sym_metakey_bool,
    STATE(351), 1,
      sym_metakey_list,
    STATE(380), 1,
      sym_metakey_any,
    STATE(418), 1,
      sym_metakey_text,
    STATE(581), 1,
      sym_blockmeta,
    STATE(284), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1122), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12472] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1126), 1,
      sym_asis_halmos_text,
    STATE(314), 1,
      sym_metakey_bool,
    STATE(351), 1,
      sym_metakey_list,
    STATE(380), 1,
      sym_metakey_any,
    STATE(418), 1,
      sym_metakey_text,
    STATE(582), 1,
      sym_blockmeta,
    STATE(284), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1122), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12525] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1130), 1,
      sym_asis_three_backticks_text,
    STATE(305), 1,
      sym_metakey_bool,
    STATE(352), 1,
      sym_metakey_list,
    STATE(389), 1,
      sym_metakey_text,
    STATE(391), 1,
      sym_metakey_any,
    STATE(467), 1,
      sym_blockmeta,
    STATE(285), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1128), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12578] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1134), 1,
      sym_asis_two_dollars_text,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(348), 1,
      sym_metakey_list,
    STATE(422), 1,
      sym_metakey_text,
    STATE(427), 1,
      sym_metakey_any,
    STATE(509), 1,
      sym_blockmeta,
    STATE(282), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1132), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12631] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1136), 1,
      sym_asis_halmos_text,
    STATE(314), 1,
      sym_metakey_bool,
    STATE(351), 1,
      sym_metakey_list,
    STATE(380), 1,
      sym_metakey_any,
    STATE(418), 1,
      sym_metakey_text,
    STATE(493), 1,
      sym_blockmeta,
    STATE(284), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1122), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12684] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1138), 1,
      sym_asis_two_dollars_text,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(348), 1,
      sym_metakey_list,
    STATE(422), 1,
      sym_metakey_text,
    STATE(427), 1,
      sym_metakey_any,
    STATE(552), 1,
      sym_blockmeta,
    STATE(282), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1132), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12737] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1140), 1,
      sym_asis_halmos_text,
    STATE(314), 1,
      sym_metakey_bool,
    STATE(351), 1,
      sym_metakey_list,
    STATE(380), 1,
      sym_metakey_any,
    STATE(418), 1,
      sym_metakey_text,
    STATE(553), 1,
      sym_blockmeta,
    STATE(284), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1122), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12790] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 1,
      sym_asis_two_dollars_text,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(348), 1,
      sym_metakey_list,
    STATE(422), 1,
      sym_metakey_text,
    STATE(427), 1,
      sym_metakey_any,
    STATE(281), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(91), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(94), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1142), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(85), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12840] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 1,
      sym_asis_two_dollars_text,
    STATE(324), 1,
      sym_metakey_bool,
    STATE(348), 1,
      sym_metakey_list,
    STATE(422), 1,
      sym_metakey_text,
    STATE(427), 1,
      sym_metakey_any,
    STATE(281), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1132), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12890] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 1,
      sym_asis_halmos_text,
    STATE(314), 1,
      sym_metakey_bool,
    STATE(351), 1,
      sym_metakey_list,
    STATE(380), 1,
      sym_metakey_any,
    STATE(418), 1,
      sym_metakey_text,
    STATE(283), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(91), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(94), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1145), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(85), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12940] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 1,
      sym_asis_halmos_text,
    STATE(314), 1,
      sym_metakey_bool,
    STATE(351), 1,
      sym_metakey_list,
    STATE(380), 1,
      sym_metakey_any,
    STATE(418), 1,
      sym_metakey_text,
    STATE(283), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1122), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12990] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 1,
      sym_asis_three_backticks_text,
    STATE(305), 1,
      sym_metakey_bool,
    STATE(352), 1,
      sym_metakey_list,
    STATE(389), 1,
      sym_metakey_text,
    STATE(391), 1,
      sym_metakey_any,
    STATE(286), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1128), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13040] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 1,
      sym_asis_three_backticks_text,
    STATE(305), 1,
      sym_metakey_bool,
    STATE(352), 1,
      sym_metakey_list,
    STATE(389), 1,
      sym_metakey_text,
    STATE(391), 1,
      sym_metakey_any,
    STATE(286), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(91), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(94), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1148), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(85), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13090] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(287), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    STATE(564), 1,
      sym_inlinemetapair,
    ACTIONS(1157), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1160), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1154), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1151), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13139] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 25,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13170] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(292), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(400), 1,
      sym_inlinemetapair,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13219] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(294), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(383), 1,
      sym_inlinemetapair,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13268] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(295), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    STATE(438), 1,
      sym_inlinemetapair,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13317] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(287), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(430), 1,
      sym_inlinemetapair,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13366] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(287), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(378), 1,
      sym_inlinemetapair,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13415] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(287), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(385), 1,
      sym_inlinemetapair,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13464] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(287), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    STATE(441), 1,
      sym_inlinemetapair,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13513] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(293), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(398), 1,
      sym_inlinemetapair,
    STATE(404), 1,
      sym_metakey_text,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13562] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(298), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(413), 1,
      sym_inlinemetapair,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13611] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(287), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(349), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(415), 1,
      sym_inlinemetapair,
    STATE(428), 1,
      sym_metakey_bool,
    STATE(435), 1,
      sym_metakey_any,
    ACTIONS(1165), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1167), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1117), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1163), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13660] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(105), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(109), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13834] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(109), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13886] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13912] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14068] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(105), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(109), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(105), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(109), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(105), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1169), 19,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14405] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1113), 1,
      anon_sym_COLONthead_COLON,
    ACTIONS(1115), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1171), 1,
      anon_sym_COLON_COLON,
    STATE(328), 1,
      sym_thead,
    STATE(342), 1,
      sym_tbody,
    STATE(455), 1,
      sym_caption,
  [14430] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1115), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1173), 1,
      anon_sym_COLON_COLON,
    STATE(346), 1,
      sym_tbody,
    STATE(498), 1,
      sym_caption,
  [14449] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1175), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1177), 1,
      anon_sym_COLONtr_COLON,
    STATE(329), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14464] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1182), 1,
      anon_sym_COLONtr_COLON,
    STATE(329), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14479] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1115), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1184), 1,
      anon_sym_COLON_COLON,
    STATE(344), 1,
      sym_tbody,
    STATE(485), 1,
      sym_caption,
  [14498] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 1,
      anon_sym_COLONtr_COLON,
    ACTIONS(1186), 1,
      anon_sym_COLON_COLON,
    STATE(329), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14513] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1188), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1190), 1,
      anon_sym_COLONtd_COLON,
    STATE(333), 2,
      sym_td,
      aux_sym_tr_repeat1,
  [14527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1193), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1195), 1,
      anon_sym_AT,
    STATE(334), 2,
      sym_bibitem,
      aux_sym_bibtex_repeat1,
  [14541] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1200), 1,
      anon_sym_AT,
    STATE(339), 2,
      sym_bibitem,
      aux_sym_bibtex_repeat1,
  [14555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 1,
      anon_sym_COLONtr_COLON,
    STATE(330), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14567] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 1,
      anon_sym_COLONtr_COLON,
    STATE(332), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 1,
      anon_sym_COLONtd_COLON,
    ACTIONS(1202), 1,
      anon_sym_COLON_COLON,
    STATE(333), 2,
      sym_td,
      aux_sym_tr_repeat1,
  [14593] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1200), 1,
      anon_sym_AT,
    ACTIONS(1204), 1,
      anon_sym_COLON_COLON,
    STATE(334), 2,
      sym_bibitem,
      aux_sym_bibtex_repeat1,
  [14607] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 1,
      anon_sym_LBRACE,
    ACTIONS(1208), 1,
      sym_text,
    STATE(10), 1,
      sym_metaval_list,
  [14620] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 1,
      ts_builtin_sym_end,
    ACTIONS(1212), 1,
      anon_sym_COLONbibtex_COLON,
    STATE(463), 1,
      sym_bibtex,
  [14633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1214), 1,
      anon_sym_COLON_COLON,
    STATE(506), 1,
      sym_caption,
  [14646] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1216), 3,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONtbody_COLON,
  [14655] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1218), 1,
      anon_sym_COLON_COLON,
    STATE(513), 1,
      sym_caption,
  [14668] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1212), 1,
      anon_sym_COLONbibtex_COLON,
    ACTIONS(1220), 1,
      ts_builtin_sym_end,
    STATE(464), 1,
      sym_bibtex,
  [14681] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1222), 1,
      anon_sym_COLON_COLON,
    STATE(465), 1,
      sym_caption,
  [14694] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1212), 1,
      anon_sym_COLONbibtex_COLON,
    ACTIONS(1224), 1,
      ts_builtin_sym_end,
    STATE(524), 1,
      sym_bibtex,
  [14707] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      sym_text,
    STATE(321), 1,
      sym_metaval_list,
  [14720] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1230), 1,
      anon_sym_LBRACE,
    ACTIONS(1232), 1,
      sym_upto_brace_or_comma_text,
    STATE(406), 1,
      sym_metaval_list_inline,
  [14733] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1234), 1,
      anon_sym_COLON_COLON,
    STATE(499), 1,
      sym_caption,
  [14746] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1236), 1,
      anon_sym_LBRACE,
    ACTIONS(1238), 1,
      sym_text,
    STATE(316), 1,
      sym_metaval_list,
  [14759] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 1,
      anon_sym_LBRACE,
    ACTIONS(1242), 1,
      sym_text,
    STATE(306), 1,
      sym_metaval_list,
  [14772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1244), 1,
      aux_sym_bibitempair_token1,
    STATE(354), 1,
      aux_sym_bibitem_repeat1,
    STATE(397), 1,
      sym_bibitempair,
  [14785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1244), 1,
      aux_sym_bibitempair_token1,
    STATE(377), 1,
      aux_sym_bibitem_repeat1,
    STATE(403), 1,
      sym_bibitempair,
  [14798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1212), 1,
      anon_sym_COLONbibtex_COLON,
    ACTIONS(1246), 1,
      ts_builtin_sym_end,
    STATE(599), 1,
      sym_bibtex,
  [14811] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1250), 1,
      sym_asis_halmos_text,
    STATE(615), 1,
      sym_inlinemeta,
  [14824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1252), 1,
      anon_sym_LBRACE,
    ACTIONS(1254), 1,
      sym_text,
    STATE(304), 1,
      sym_metaval_list,
  [14837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      sym_asis_dollar_text,
    STATE(555), 1,
      sym_inlinemeta,
  [14850] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_LBRACE,
    ACTIONS(1262), 1,
      sym_asis_backtick_text,
    STATE(556), 1,
      sym_inlinemeta,
  [14863] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1264), 1,
      sym_asis_halmos_text,
    STATE(557), 1,
      sym_inlinemeta,
  [14876] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1266), 1,
      sym_asis_halmos_text,
    STATE(558), 1,
      sym_inlinemeta,
  [14889] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1268), 1,
      sym_asis_dollar_text,
    STATE(572), 1,
      sym_inlinemeta,
  [14902] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_LBRACE,
    ACTIONS(1270), 1,
      sym_asis_backtick_text,
    STATE(573), 1,
      sym_inlinemeta,
  [14915] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1272), 1,
      sym_asis_halmos_text,
    STATE(574), 1,
      sym_inlinemeta,
  [14928] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1274), 1,
      sym_asis_halmos_text,
    STATE(575), 1,
      sym_inlinemeta,
  [14941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1276), 1,
      sym_asis_dollar_text,
    STATE(589), 1,
      sym_inlinemeta,
  [14954] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_LBRACE,
    ACTIONS(1278), 1,
      sym_asis_backtick_text,
    STATE(590), 1,
      sym_inlinemeta,
  [14967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1280), 1,
      sym_asis_halmos_text,
    STATE(591), 1,
      sym_inlinemeta,
  [14980] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1282), 1,
      sym_asis_halmos_text,
    STATE(592), 1,
      sym_inlinemeta,
  [14993] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1284), 1,
      sym_asis_dollar_text,
    STATE(522), 1,
      sym_inlinemeta,
  [15006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_LBRACE,
    ACTIONS(1286), 1,
      sym_asis_backtick_text,
    STATE(529), 1,
      sym_inlinemeta,
  [15019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1288), 1,
      sym_asis_dollar_text,
    STATE(606), 1,
      sym_inlinemeta,
  [15032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_LBRACE,
    ACTIONS(1290), 1,
      sym_asis_backtick_text,
    STATE(607), 1,
      sym_inlinemeta,
  [15045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1292), 1,
      sym_asis_halmos_text,
    STATE(608), 1,
      sym_inlinemeta,
  [15058] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1294), 1,
      sym_asis_halmos_text,
    STATE(609), 1,
      sym_inlinemeta,
  [15071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_LBRACE,
    ACTIONS(1296), 1,
      sym_asis_halmos_text,
    STATE(566), 1,
      sym_inlinemeta,
  [15084] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 1,
      aux_sym_bibitempair_token1,
    STATE(377), 1,
      aux_sym_bibitem_repeat1,
    STATE(526), 1,
      sym_bibitempair,
  [15097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1303), 1,
      anon_sym_RBRACE,
  [15107] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1305), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
  [15115] = 3,
    ACTIONS(1307), 1,
      aux_sym_metaval_any_token1,
    ACTIONS(1309), 1,
      sym_comment,
    STATE(316), 1,
      sym_metaval_any,
  [15125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1311), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1313), 1,
      anon_sym_COMMA,
  [15135] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1315), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 1,
      anon_sym_COMMA,
  [15145] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1319), 1,
      anon_sym_RBRACE,
  [15155] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
    ACTIONS(1323), 1,
      anon_sym_RBRACE,
  [15165] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1325), 1,
      anon_sym_RBRACE,
  [15175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
    ACTIONS(1327), 1,
      anon_sym_RBRACE,
  [15185] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1329), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtd_COLON,
  [15193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1331), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1333), 1,
      sym_text,
    STATE(306), 1,
      sym_metaval_text,
  [15211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1335), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1337), 1,
      anon_sym_COLON,
  [15221] = 3,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1339), 1,
      aux_sym_metaval_any_token1,
    STATE(306), 1,
      sym_metaval_any,
  [15231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1343), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1345), 1,
      anon_sym_COMMA,
  [15249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1347), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1349), 1,
      anon_sym_COMMA,
  [15259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1351), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15267] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtd_COLON,
  [15275] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1355), 1,
      anon_sym_COMMA,
    ACTIONS(1357), 1,
      anon_sym_RBRACE,
  [15285] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1359), 1,
      anon_sym_RBRACE,
  [15295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1363), 1,
      anon_sym_COMMA,
  [15305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1365), 1,
      anon_sym_RBRACE,
  [15315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
    ACTIONS(1367), 1,
      anon_sym_RBRACE,
  [15325] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15333] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1371), 1,
      anon_sym_COMMA,
    ACTIONS(1373), 1,
      anon_sym_RBRACE,
  [15343] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1375), 1,
      sym_upto_brace_or_comma_text,
    STATE(406), 1,
      sym_metaval_text_inline,
  [15353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 1,
      sym_text,
    STATE(304), 1,
      sym_metaval_text,
  [15363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1379), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15371] = 3,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1381), 1,
      aux_sym_metaval_any_token1,
    STATE(304), 1,
      sym_metaval_any,
  [15381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1383), 1,
      anon_sym_RBRACE,
    ACTIONS(1385), 1,
      aux_sym_bibitempair_token1,
  [15391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1387), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1389), 1,
      anon_sym_COMMA,
  [15401] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1391), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1393), 1,
      anon_sym_COMMA,
  [15411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1395), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1399), 1,
      anon_sym_RBRACE,
  [15437] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1403), 1,
      anon_sym_RBRACE,
  [15455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
    ACTIONS(1405), 1,
      anon_sym_RBRACE,
  [15465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1407), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 1,
      sym_text,
    STATE(316), 1,
      sym_metaval_text,
  [15485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
    ACTIONS(1411), 1,
      anon_sym_RBRACE,
  [15495] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15505] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1416), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      sym_text,
    STATE(321), 1,
      sym_metaval_text,
  [15525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      sym_upto_brace_or_comma_text,
    STATE(421), 1,
      aux_sym_metaval_list_repeat1,
  [15535] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15543] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1424), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15561] = 3,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1428), 1,
      aux_sym_metaval_any_token1,
    STATE(321), 1,
      sym_metaval_any,
  [15571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15579] = 3,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1432), 1,
      aux_sym_metaval_any_token1,
    STATE(10), 1,
      sym_metaval_any,
  [15589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1434), 1,
      anon_sym_RBRACE,
  [15599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    STATE(153), 1,
      sym_inlinemeta,
  [15609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1436), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1440), 1,
      anon_sym_COMMA,
  [15629] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1444), 1,
      anon_sym_COMMA,
  [15639] = 3,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1446), 1,
      aux_sym_metaval_any_inline_token1,
    STATE(406), 1,
      sym_metaval_any_inline,
  [15649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      sym_upto_brace_or_comma_text,
    STATE(417), 1,
      aux_sym_metaval_list_repeat1,
  [15659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1448), 2,
      sym_text,
      anon_sym_LBRACE,
  [15667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1450), 1,
      anon_sym_RBRACE,
  [15677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1452), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
    ACTIONS(1456), 1,
      anon_sym_RBRACE,
  [15705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
    ACTIONS(1458), 1,
      anon_sym_RBRACE,
  [15715] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1460), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15723] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1448), 2,
      sym_upto_brace_or_comma_text,
      anon_sym_LBRACE,
  [15731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 1,
      sym_text,
    STATE(10), 1,
      sym_metaval_text,
  [15741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      anon_sym_COLON,
    ACTIONS(1464), 1,
      anon_sym_COLON_COLON,
  [15751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      sym_upto_brace_or_comma_text,
    STATE(420), 1,
      aux_sym_metaval_list_repeat1,
  [15761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      sym_upto_brace_or_comma_text,
    STATE(425), 1,
      aux_sym_metaval_list_repeat1,
  [15771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      sym_upto_brace_or_comma_text,
    STATE(432), 1,
      aux_sym_metaval_list_repeat1,
  [15781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      sym_upto_brace_or_comma_text,
    STATE(440), 1,
      aux_sym_metaval_list_repeat1,
  [15791] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 1,
      sym_upto_brace_or_comma_text,
    STATE(447), 1,
      aux_sym_metaval_list_repeat1,
  [15801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1470), 1,
      anon_sym_COMMA,
  [15811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      sym_text,
  [15818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1474), 1,
      anon_sym_COLON_COLON,
  [15825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      anon_sym_COLON_COLON,
  [15832] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1478), 1,
      anon_sym_COLON_COLON,
  [15839] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      aux_sym_specialinline_token1,
  [15846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      aux_sym_specialinline_token2,
  [15853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLON_COLON,
  [15860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_COLON_COLON,
  [15867] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1486), 1,
      aux_sym_specialinline_token5,
  [15874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      aux_sym_specialinline_token6,
  [15881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1220), 1,
      ts_builtin_sym_end,
  [15888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1490), 1,
      ts_builtin_sym_end,
  [15895] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1492), 1,
      anon_sym_COLON_COLON,
  [15902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1494), 1,
      aux_sym_specialblock_token4,
  [15909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1496), 1,
      sym_asis_three_backticks_text,
  [15916] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1498), 1,
      aux_sym_specialblock_token4,
  [15923] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1500), 1,
      anon_sym_LBRACE,
  [15930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 1,
      aux_sym_specialinline_token1,
  [15937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1504), 1,
      aux_sym_specialinline_token2,
  [15944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1506), 1,
      anon_sym_COLON_COLON,
  [15951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1504), 1,
      anon_sym_COLON_COLON,
  [15958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1508), 1,
      anon_sym_COMMA,
  [15965] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1103), 1,
      sym_asis_dollar_text,
  [15972] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1510), 1,
      ts_builtin_sym_end,
  [15979] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
  [15986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1514), 1,
      anon_sym_COLON_COLON,
  [15993] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1516), 1,
      aux_sym_metaval_any_inline_token1,
  [16000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1518), 1,
      anon_sym_COLON_COLON,
  [16007] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1486), 1,
      aux_sym_specialinline_token7,
  [16014] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(257), 1,
      anon_sym_COLON_COLON,
  [16021] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1520), 1,
      anon_sym_COLON,
  [16028] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1522), 1,
      aux_sym_specialinline_token8,
  [16035] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1524), 1,
      anon_sym_COLON_COLON,
  [16042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1526), 1,
      sym_text,
  [16049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1528), 1,
      aux_sym_specialinline_token1,
  [16056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1530), 1,
      aux_sym_specialinline_token2,
  [16063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_COLON_COLON,
  [16070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1530), 1,
      anon_sym_COLON_COLON,
  [16077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1498), 1,
      anon_sym_COLON_COLON,
  [16084] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1534), 1,
      aux_sym_specialinline_token1,
  [16091] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1536), 1,
      sym_asis_halmos_text,
  [16098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1538), 1,
      aux_sym_specialinline_token2,
  [16105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1540), 1,
      anon_sym_COLON_COLON,
  [16112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1542), 1,
      aux_sym_specialinline_token1,
  [16119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1544), 1,
      anon_sym_EQ,
  [16126] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1546), 1,
      anon_sym_COLON_COLON,
  [16133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1548), 1,
      anon_sym_COLON_COLON,
  [16140] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1550), 1,
      aux_sym_specialinline_token1,
  [16147] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1552), 1,
      aux_sym_specialinline_token2,
  [16154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1554), 1,
      anon_sym_COLON_COLON,
  [16161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1552), 1,
      anon_sym_COLON_COLON,
  [16168] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1556), 1,
      aux_sym_mathblock_token1,
  [16175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1558), 1,
      anon_sym_LBRACE,
  [16182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1560), 1,
      anon_sym_COLON_COLON,
  [16189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1562), 1,
      anon_sym_COLON_COLON,
  [16196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1564), 1,
      anon_sym_COLON_COLON,
  [16203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1566), 1,
      sym_asis_two_dollars_text,
  [16210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 1,
      aux_sym_bibitempair_token1,
  [16217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1568), 1,
      ts_builtin_sym_end,
  [16224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1099), 1,
      sym_asis_halmos_text,
  [16231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1570), 1,
      anon_sym_COLON_COLON,
  [16238] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1572), 1,
      aux_sym_bibitem_token1,
  [16245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1574), 1,
      anon_sym_COLON_COLON,
  [16252] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1538), 1,
      anon_sym_COLON_COLON,
  [16259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1576), 1,
      aux_sym_specialinline_token1,
  [16266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1578), 1,
      aux_sym_specialinline_token2,
  [16273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      anon_sym_COLON_COLON,
  [16280] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1578), 1,
      anon_sym_COLON_COLON,
  [16287] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1582), 1,
      aux_sym_bibitempair_token2,
  [16294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1584), 1,
      sym_asis_dollar_text,
  [16301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1103), 1,
      sym_asis_halmos_text,
  [16308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      ts_builtin_sym_end,
  [16315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1588), 1,
      sym_upto_brace_or_comma_text,
  [16322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1355), 1,
      anon_sym_COMMA,
  [16329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1590), 1,
      anon_sym_RBRACE,
  [16336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      aux_sym_specialinline_token2,
  [16343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_asis_backtick_text,
  [16350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1596), 1,
      aux_sym_specialinline_token1,
  [16357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      aux_sym_specialinline_token2,
  [16364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1600), 1,
      anon_sym_COLON_COLON,
  [16371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_COLON_COLON,
  [16378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1602), 1,
      sym_text,
  [16385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1494), 1,
      anon_sym_COLON_COLON,
  [16392] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1604), 1,
      aux_sym_bibitem_token2,
  [16399] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1606), 1,
      anon_sym_COLON_COLON,
  [16406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1608), 1,
      anon_sym_COLON_COLON,
  [16413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1610), 1,
      anon_sym_COLON_COLON,
  [16420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(321), 1,
      anon_sym_COLON_COLON,
  [16427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_COLON_COLON,
  [16434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1614), 1,
      anon_sym_COLON_COLON,
  [16441] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1516), 1,
      aux_sym_metaval_any_token1,
  [16448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1616), 1,
      aux_sym_mathblock_token1,
  [16455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1616), 1,
      anon_sym_COLON_COLON,
  [16462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1618), 1,
      ts_builtin_sym_end,
  [16469] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1620), 1,
      aux_sym_specialinline_token5,
  [16476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1622), 1,
      aux_sym_specialinline_token6,
  [16483] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1620), 1,
      aux_sym_specialinline_token7,
  [16490] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1624), 1,
      aux_sym_specialinline_token8,
  [16497] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1626), 1,
      aux_sym_specialinline_token1,
  [16504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1628), 1,
      sym_asis_two_dollars_text,
  [16511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1630), 1,
      sym_asis_halmos_text,
  [16518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1632), 1,
      sym_upto_brace_or_comma_text,
  [16525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1634), 1,
      sym_asis_dollar_text,
  [16532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1636), 1,
      sym_asis_backtick_text,
  [16539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1638), 1,
      sym_asis_halmos_text,
  [16546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1640), 1,
      sym_asis_halmos_text,
  [16553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1642), 1,
      aux_sym_specialinline_token2,
  [16560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1644), 1,
      sym_text,
  [16567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1646), 1,
      sym_text,
  [16574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1648), 1,
      anon_sym_COLON_COLON,
  [16581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1642), 1,
      anon_sym_COLON_COLON,
  [16588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_COMMA,
  [16595] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1650), 1,
      sym_text,
  [16602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      sym_asis_halmos_text,
  [16609] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1654), 1,
      aux_sym_specialinline_token5,
  [16616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1656), 1,
      aux_sym_specialinline_token6,
  [16623] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1654), 1,
      aux_sym_specialinline_token7,
  [16630] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1658), 1,
      aux_sym_specialinline_token8,
  [16637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1660), 1,
      anon_sym_COLON_COLON,
  [16644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1662), 1,
      sym_asis_dollar_text,
  [16651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 1,
      sym_asis_backtick_text,
  [16658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 1,
      sym_asis_halmos_text,
  [16665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      sym_asis_halmos_text,
  [16672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1670), 1,
      anon_sym_COLON_COLON,
  [16679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      sym_text,
  [16686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      sym_text,
  [16693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1099), 1,
      sym_asis_backtick_text,
  [16700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1556), 1,
      anon_sym_COLON_COLON,
  [16707] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      sym_asis_halmos_text,
  [16714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 1,
      sym_asis_halmos_text,
  [16721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      aux_sym_mathblock_token1,
  [16728] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1682), 1,
      aux_sym_specialinline_token5,
  [16735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      aux_sym_specialinline_token6,
  [16742] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1682), 1,
      aux_sym_specialinline_token7,
  [16749] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1686), 1,
      aux_sym_specialinline_token8,
  [16756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COLON_COLON,
  [16763] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1688), 1,
      sym_asis_dollar_text,
  [16770] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1690), 1,
      sym_asis_backtick_text,
  [16777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1692), 1,
      sym_asis_halmos_text,
  [16784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1694), 1,
      sym_asis_halmos_text,
  [16791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1696), 1,
      anon_sym_COLON_COLON,
  [16798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      sym_text,
  [16805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1700), 1,
      aux_sym_specialinline_token1,
  [16812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1702), 1,
      aux_sym_specialinline_token2,
  [16819] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1704), 1,
      anon_sym_COLON_COLON,
  [16826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1702), 1,
      anon_sym_COLON_COLON,
  [16833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1224), 1,
      ts_builtin_sym_end,
  [16840] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      aux_sym_mathblock_token1,
  [16847] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1706), 1,
      aux_sym_specialinline_token5,
  [16854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1708), 1,
      aux_sym_specialinline_token6,
  [16861] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1706), 1,
      aux_sym_specialinline_token7,
  [16868] = 2,
    ACTIONS(1309), 1,
      sym_comment,
    ACTIONS(1710), 1,
      aux_sym_specialinline_token8,
  [16875] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_COLON_COLON,
  [16882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      sym_asis_dollar_text,
  [16889] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1714), 1,
      sym_asis_backtick_text,
  [16896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1716), 1,
      sym_asis_halmos_text,
  [16903] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_asis_halmos_text,
  [16910] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1720), 1,
      anon_sym_COLON_COLON,
  [16917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_text,
  [16924] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1724), 1,
      sym_text,
  [16931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1726), 1,
      anon_sym_COLON_COLON,
  [16938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1099), 1,
      sym_asis_dollar_text,
  [16945] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1728), 1,
      sym_asis_halmos_text,
  [16952] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1103), 1,
      sym_asis_backtick_text,
  [16959] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_COMMA,
  [16966] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1632), 1,
      sym_text,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(65)] = 0,
  [SMALL_STATE(66)] = 88,
  [SMALL_STATE(67)] = 176,
  [SMALL_STATE(68)] = 264,
  [SMALL_STATE(69)] = 352,
  [SMALL_STATE(70)] = 437,
  [SMALL_STATE(71)] = 522,
  [SMALL_STATE(72)] = 607,
  [SMALL_STATE(73)] = 692,
  [SMALL_STATE(74)] = 777,
  [SMALL_STATE(75)] = 862,
  [SMALL_STATE(76)] = 947,
  [SMALL_STATE(77)] = 1032,
  [SMALL_STATE(78)] = 1117,
  [SMALL_STATE(79)] = 1202,
  [SMALL_STATE(80)] = 1287,
  [SMALL_STATE(81)] = 1371,
  [SMALL_STATE(82)] = 1453,
  [SMALL_STATE(83)] = 1537,
  [SMALL_STATE(84)] = 1619,
  [SMALL_STATE(85)] = 1703,
  [SMALL_STATE(86)] = 1787,
  [SMALL_STATE(87)] = 1871,
  [SMALL_STATE(88)] = 1955,
  [SMALL_STATE(89)] = 2039,
  [SMALL_STATE(90)] = 2123,
  [SMALL_STATE(91)] = 2207,
  [SMALL_STATE(92)] = 2291,
  [SMALL_STATE(93)] = 2375,
  [SMALL_STATE(94)] = 2457,
  [SMALL_STATE(95)] = 2538,
  [SMALL_STATE(96)] = 2619,
  [SMALL_STATE(97)] = 2700,
  [SMALL_STATE(98)] = 2781,
  [SMALL_STATE(99)] = 2859,
  [SMALL_STATE(100)] = 2937,
  [SMALL_STATE(101)] = 3015,
  [SMALL_STATE(102)] = 3093,
  [SMALL_STATE(103)] = 3171,
  [SMALL_STATE(104)] = 3249,
  [SMALL_STATE(105)] = 3327,
  [SMALL_STATE(106)] = 3405,
  [SMALL_STATE(107)] = 3483,
  [SMALL_STATE(108)] = 3561,
  [SMALL_STATE(109)] = 3639,
  [SMALL_STATE(110)] = 3717,
  [SMALL_STATE(111)] = 3795,
  [SMALL_STATE(112)] = 3873,
  [SMALL_STATE(113)] = 3951,
  [SMALL_STATE(114)] = 4029,
  [SMALL_STATE(115)] = 4107,
  [SMALL_STATE(116)] = 4185,
  [SMALL_STATE(117)] = 4263,
  [SMALL_STATE(118)] = 4341,
  [SMALL_STATE(119)] = 4419,
  [SMALL_STATE(120)] = 4497,
  [SMALL_STATE(121)] = 4575,
  [SMALL_STATE(122)] = 4653,
  [SMALL_STATE(123)] = 4731,
  [SMALL_STATE(124)] = 4809,
  [SMALL_STATE(125)] = 4887,
  [SMALL_STATE(126)] = 4965,
  [SMALL_STATE(127)] = 5043,
  [SMALL_STATE(128)] = 5121,
  [SMALL_STATE(129)] = 5199,
  [SMALL_STATE(130)] = 5277,
  [SMALL_STATE(131)] = 5355,
  [SMALL_STATE(132)] = 5433,
  [SMALL_STATE(133)] = 5511,
  [SMALL_STATE(134)] = 5589,
  [SMALL_STATE(135)] = 5667,
  [SMALL_STATE(136)] = 5745,
  [SMALL_STATE(137)] = 5823,
  [SMALL_STATE(138)] = 5901,
  [SMALL_STATE(139)] = 5979,
  [SMALL_STATE(140)] = 6057,
  [SMALL_STATE(141)] = 6135,
  [SMALL_STATE(142)] = 6213,
  [SMALL_STATE(143)] = 6291,
  [SMALL_STATE(144)] = 6369,
  [SMALL_STATE(145)] = 6447,
  [SMALL_STATE(146)] = 6525,
  [SMALL_STATE(147)] = 6603,
  [SMALL_STATE(148)] = 6681,
  [SMALL_STATE(149)] = 6759,
  [SMALL_STATE(150)] = 6837,
  [SMALL_STATE(151)] = 6915,
  [SMALL_STATE(152)] = 6993,
  [SMALL_STATE(153)] = 7071,
  [SMALL_STATE(154)] = 7146,
  [SMALL_STATE(155)] = 7191,
  [SMALL_STATE(156)] = 7236,
  [SMALL_STATE(157)] = 7281,
  [SMALL_STATE(158)] = 7326,
  [SMALL_STATE(159)] = 7371,
  [SMALL_STATE(160)] = 7416,
  [SMALL_STATE(161)] = 7461,
  [SMALL_STATE(162)] = 7506,
  [SMALL_STATE(163)] = 7551,
  [SMALL_STATE(164)] = 7596,
  [SMALL_STATE(165)] = 7641,
  [SMALL_STATE(166)] = 7686,
  [SMALL_STATE(167)] = 7731,
  [SMALL_STATE(168)] = 7776,
  [SMALL_STATE(169)] = 7821,
  [SMALL_STATE(170)] = 7866,
  [SMALL_STATE(171)] = 7911,
  [SMALL_STATE(172)] = 7956,
  [SMALL_STATE(173)] = 8001,
  [SMALL_STATE(174)] = 8046,
  [SMALL_STATE(175)] = 8091,
  [SMALL_STATE(176)] = 8136,
  [SMALL_STATE(177)] = 8181,
  [SMALL_STATE(178)] = 8226,
  [SMALL_STATE(179)] = 8270,
  [SMALL_STATE(180)] = 8314,
  [SMALL_STATE(181)] = 8358,
  [SMALL_STATE(182)] = 8402,
  [SMALL_STATE(183)] = 8446,
  [SMALL_STATE(184)] = 8490,
  [SMALL_STATE(185)] = 8534,
  [SMALL_STATE(186)] = 8578,
  [SMALL_STATE(187)] = 8622,
  [SMALL_STATE(188)] = 8666,
  [SMALL_STATE(189)] = 8710,
  [SMALL_STATE(190)] = 8754,
  [SMALL_STATE(191)] = 8798,
  [SMALL_STATE(192)] = 8842,
  [SMALL_STATE(193)] = 8886,
  [SMALL_STATE(194)] = 8930,
  [SMALL_STATE(195)] = 8974,
  [SMALL_STATE(196)] = 9018,
  [SMALL_STATE(197)] = 9062,
  [SMALL_STATE(198)] = 9106,
  [SMALL_STATE(199)] = 9150,
  [SMALL_STATE(200)] = 9194,
  [SMALL_STATE(201)] = 9238,
  [SMALL_STATE(202)] = 9282,
  [SMALL_STATE(203)] = 9325,
  [SMALL_STATE(204)] = 9368,
  [SMALL_STATE(205)] = 9411,
  [SMALL_STATE(206)] = 9454,
  [SMALL_STATE(207)] = 9497,
  [SMALL_STATE(208)] = 9540,
  [SMALL_STATE(209)] = 9583,
  [SMALL_STATE(210)] = 9626,
  [SMALL_STATE(211)] = 9669,
  [SMALL_STATE(212)] = 9712,
  [SMALL_STATE(213)] = 9755,
  [SMALL_STATE(214)] = 9798,
  [SMALL_STATE(215)] = 9841,
  [SMALL_STATE(216)] = 9884,
  [SMALL_STATE(217)] = 9927,
  [SMALL_STATE(218)] = 9970,
  [SMALL_STATE(219)] = 10013,
  [SMALL_STATE(220)] = 10056,
  [SMALL_STATE(221)] = 10099,
  [SMALL_STATE(222)] = 10142,
  [SMALL_STATE(223)] = 10185,
  [SMALL_STATE(224)] = 10228,
  [SMALL_STATE(225)] = 10271,
  [SMALL_STATE(226)] = 10314,
  [SMALL_STATE(227)] = 10357,
  [SMALL_STATE(228)] = 10400,
  [SMALL_STATE(229)] = 10443,
  [SMALL_STATE(230)] = 10486,
  [SMALL_STATE(231)] = 10529,
  [SMALL_STATE(232)] = 10570,
  [SMALL_STATE(233)] = 10613,
  [SMALL_STATE(234)] = 10656,
  [SMALL_STATE(235)] = 10699,
  [SMALL_STATE(236)] = 10742,
  [SMALL_STATE(237)] = 10785,
  [SMALL_STATE(238)] = 10828,
  [SMALL_STATE(239)] = 10871,
  [SMALL_STATE(240)] = 10914,
  [SMALL_STATE(241)] = 10957,
  [SMALL_STATE(242)] = 11000,
  [SMALL_STATE(243)] = 11043,
  [SMALL_STATE(244)] = 11086,
  [SMALL_STATE(245)] = 11127,
  [SMALL_STATE(246)] = 11170,
  [SMALL_STATE(247)] = 11213,
  [SMALL_STATE(248)] = 11256,
  [SMALL_STATE(249)] = 11299,
  [SMALL_STATE(250)] = 11342,
  [SMALL_STATE(251)] = 11385,
  [SMALL_STATE(252)] = 11428,
  [SMALL_STATE(253)] = 11471,
  [SMALL_STATE(254)] = 11514,
  [SMALL_STATE(255)] = 11557,
  [SMALL_STATE(256)] = 11600,
  [SMALL_STATE(257)] = 11643,
  [SMALL_STATE(258)] = 11686,
  [SMALL_STATE(259)] = 11729,
  [SMALL_STATE(260)] = 11772,
  [SMALL_STATE(261)] = 11815,
  [SMALL_STATE(262)] = 11858,
  [SMALL_STATE(263)] = 11901,
  [SMALL_STATE(264)] = 11944,
  [SMALL_STATE(265)] = 11987,
  [SMALL_STATE(266)] = 12030,
  [SMALL_STATE(267)] = 12073,
  [SMALL_STATE(268)] = 12116,
  [SMALL_STATE(269)] = 12159,
  [SMALL_STATE(270)] = 12202,
  [SMALL_STATE(271)] = 12242,
  [SMALL_STATE(272)] = 12313,
  [SMALL_STATE(273)] = 12366,
  [SMALL_STATE(274)] = 12419,
  [SMALL_STATE(275)] = 12472,
  [SMALL_STATE(276)] = 12525,
  [SMALL_STATE(277)] = 12578,
  [SMALL_STATE(278)] = 12631,
  [SMALL_STATE(279)] = 12684,
  [SMALL_STATE(280)] = 12737,
  [SMALL_STATE(281)] = 12790,
  [SMALL_STATE(282)] = 12840,
  [SMALL_STATE(283)] = 12890,
  [SMALL_STATE(284)] = 12940,
  [SMALL_STATE(285)] = 12990,
  [SMALL_STATE(286)] = 13040,
  [SMALL_STATE(287)] = 13090,
  [SMALL_STATE(288)] = 13139,
  [SMALL_STATE(289)] = 13170,
  [SMALL_STATE(290)] = 13219,
  [SMALL_STATE(291)] = 13268,
  [SMALL_STATE(292)] = 13317,
  [SMALL_STATE(293)] = 13366,
  [SMALL_STATE(294)] = 13415,
  [SMALL_STATE(295)] = 13464,
  [SMALL_STATE(296)] = 13513,
  [SMALL_STATE(297)] = 13562,
  [SMALL_STATE(298)] = 13611,
  [SMALL_STATE(299)] = 13660,
  [SMALL_STATE(300)] = 13689,
  [SMALL_STATE(301)] = 13718,
  [SMALL_STATE(302)] = 13747,
  [SMALL_STATE(303)] = 13776,
  [SMALL_STATE(304)] = 13805,
  [SMALL_STATE(305)] = 13834,
  [SMALL_STATE(306)] = 13860,
  [SMALL_STATE(307)] = 13886,
  [SMALL_STATE(308)] = 13912,
  [SMALL_STATE(309)] = 13938,
  [SMALL_STATE(310)] = 13964,
  [SMALL_STATE(311)] = 13990,
  [SMALL_STATE(312)] = 14016,
  [SMALL_STATE(313)] = 14042,
  [SMALL_STATE(314)] = 14068,
  [SMALL_STATE(315)] = 14094,
  [SMALL_STATE(316)] = 14120,
  [SMALL_STATE(317)] = 14146,
  [SMALL_STATE(318)] = 14172,
  [SMALL_STATE(319)] = 14198,
  [SMALL_STATE(320)] = 14224,
  [SMALL_STATE(321)] = 14250,
  [SMALL_STATE(322)] = 14276,
  [SMALL_STATE(323)] = 14302,
  [SMALL_STATE(324)] = 14328,
  [SMALL_STATE(325)] = 14354,
  [SMALL_STATE(326)] = 14380,
  [SMALL_STATE(327)] = 14405,
  [SMALL_STATE(328)] = 14430,
  [SMALL_STATE(329)] = 14449,
  [SMALL_STATE(330)] = 14464,
  [SMALL_STATE(331)] = 14479,
  [SMALL_STATE(332)] = 14498,
  [SMALL_STATE(333)] = 14513,
  [SMALL_STATE(334)] = 14527,
  [SMALL_STATE(335)] = 14541,
  [SMALL_STATE(336)] = 14555,
  [SMALL_STATE(337)] = 14567,
  [SMALL_STATE(338)] = 14579,
  [SMALL_STATE(339)] = 14593,
  [SMALL_STATE(340)] = 14607,
  [SMALL_STATE(341)] = 14620,
  [SMALL_STATE(342)] = 14633,
  [SMALL_STATE(343)] = 14646,
  [SMALL_STATE(344)] = 14655,
  [SMALL_STATE(345)] = 14668,
  [SMALL_STATE(346)] = 14681,
  [SMALL_STATE(347)] = 14694,
  [SMALL_STATE(348)] = 14707,
  [SMALL_STATE(349)] = 14720,
  [SMALL_STATE(350)] = 14733,
  [SMALL_STATE(351)] = 14746,
  [SMALL_STATE(352)] = 14759,
  [SMALL_STATE(353)] = 14772,
  [SMALL_STATE(354)] = 14785,
  [SMALL_STATE(355)] = 14798,
  [SMALL_STATE(356)] = 14811,
  [SMALL_STATE(357)] = 14824,
  [SMALL_STATE(358)] = 14837,
  [SMALL_STATE(359)] = 14850,
  [SMALL_STATE(360)] = 14863,
  [SMALL_STATE(361)] = 14876,
  [SMALL_STATE(362)] = 14889,
  [SMALL_STATE(363)] = 14902,
  [SMALL_STATE(364)] = 14915,
  [SMALL_STATE(365)] = 14928,
  [SMALL_STATE(366)] = 14941,
  [SMALL_STATE(367)] = 14954,
  [SMALL_STATE(368)] = 14967,
  [SMALL_STATE(369)] = 14980,
  [SMALL_STATE(370)] = 14993,
  [SMALL_STATE(371)] = 15006,
  [SMALL_STATE(372)] = 15019,
  [SMALL_STATE(373)] = 15032,
  [SMALL_STATE(374)] = 15045,
  [SMALL_STATE(375)] = 15058,
  [SMALL_STATE(376)] = 15071,
  [SMALL_STATE(377)] = 15084,
  [SMALL_STATE(378)] = 15097,
  [SMALL_STATE(379)] = 15107,
  [SMALL_STATE(380)] = 15115,
  [SMALL_STATE(381)] = 15125,
  [SMALL_STATE(382)] = 15135,
  [SMALL_STATE(383)] = 15145,
  [SMALL_STATE(384)] = 15155,
  [SMALL_STATE(385)] = 15165,
  [SMALL_STATE(386)] = 15175,
  [SMALL_STATE(387)] = 15185,
  [SMALL_STATE(388)] = 15193,
  [SMALL_STATE(389)] = 15201,
  [SMALL_STATE(390)] = 15211,
  [SMALL_STATE(391)] = 15221,
  [SMALL_STATE(392)] = 15231,
  [SMALL_STATE(393)] = 15239,
  [SMALL_STATE(394)] = 15249,
  [SMALL_STATE(395)] = 15259,
  [SMALL_STATE(396)] = 15267,
  [SMALL_STATE(397)] = 15275,
  [SMALL_STATE(398)] = 15285,
  [SMALL_STATE(399)] = 15295,
  [SMALL_STATE(400)] = 15305,
  [SMALL_STATE(401)] = 15315,
  [SMALL_STATE(402)] = 15325,
  [SMALL_STATE(403)] = 15333,
  [SMALL_STATE(404)] = 15343,
  [SMALL_STATE(405)] = 15353,
  [SMALL_STATE(406)] = 15363,
  [SMALL_STATE(407)] = 15371,
  [SMALL_STATE(408)] = 15381,
  [SMALL_STATE(409)] = 15391,
  [SMALL_STATE(410)] = 15401,
  [SMALL_STATE(411)] = 15411,
  [SMALL_STATE(412)] = 15419,
  [SMALL_STATE(413)] = 15427,
  [SMALL_STATE(414)] = 15437,
  [SMALL_STATE(415)] = 15445,
  [SMALL_STATE(416)] = 15455,
  [SMALL_STATE(417)] = 15465,
  [SMALL_STATE(418)] = 15475,
  [SMALL_STATE(419)] = 15485,
  [SMALL_STATE(420)] = 15495,
  [SMALL_STATE(421)] = 15505,
  [SMALL_STATE(422)] = 15515,
  [SMALL_STATE(423)] = 15525,
  [SMALL_STATE(424)] = 15535,
  [SMALL_STATE(425)] = 15543,
  [SMALL_STATE(426)] = 15553,
  [SMALL_STATE(427)] = 15561,
  [SMALL_STATE(428)] = 15571,
  [SMALL_STATE(429)] = 15579,
  [SMALL_STATE(430)] = 15589,
  [SMALL_STATE(431)] = 15599,
  [SMALL_STATE(432)] = 15609,
  [SMALL_STATE(433)] = 15619,
  [SMALL_STATE(434)] = 15629,
  [SMALL_STATE(435)] = 15639,
  [SMALL_STATE(436)] = 15649,
  [SMALL_STATE(437)] = 15659,
  [SMALL_STATE(438)] = 15667,
  [SMALL_STATE(439)] = 15677,
  [SMALL_STATE(440)] = 15685,
  [SMALL_STATE(441)] = 15695,
  [SMALL_STATE(442)] = 15705,
  [SMALL_STATE(443)] = 15715,
  [SMALL_STATE(444)] = 15723,
  [SMALL_STATE(445)] = 15731,
  [SMALL_STATE(446)] = 15741,
  [SMALL_STATE(447)] = 15751,
  [SMALL_STATE(448)] = 15761,
  [SMALL_STATE(449)] = 15771,
  [SMALL_STATE(450)] = 15781,
  [SMALL_STATE(451)] = 15791,
  [SMALL_STATE(452)] = 15801,
  [SMALL_STATE(453)] = 15811,
  [SMALL_STATE(454)] = 15818,
  [SMALL_STATE(455)] = 15825,
  [SMALL_STATE(456)] = 15832,
  [SMALL_STATE(457)] = 15839,
  [SMALL_STATE(458)] = 15846,
  [SMALL_STATE(459)] = 15853,
  [SMALL_STATE(460)] = 15860,
  [SMALL_STATE(461)] = 15867,
  [SMALL_STATE(462)] = 15874,
  [SMALL_STATE(463)] = 15881,
  [SMALL_STATE(464)] = 15888,
  [SMALL_STATE(465)] = 15895,
  [SMALL_STATE(466)] = 15902,
  [SMALL_STATE(467)] = 15909,
  [SMALL_STATE(468)] = 15916,
  [SMALL_STATE(469)] = 15923,
  [SMALL_STATE(470)] = 15930,
  [SMALL_STATE(471)] = 15937,
  [SMALL_STATE(472)] = 15944,
  [SMALL_STATE(473)] = 15951,
  [SMALL_STATE(474)] = 15958,
  [SMALL_STATE(475)] = 15965,
  [SMALL_STATE(476)] = 15972,
  [SMALL_STATE(477)] = 15979,
  [SMALL_STATE(478)] = 15986,
  [SMALL_STATE(479)] = 15993,
  [SMALL_STATE(480)] = 16000,
  [SMALL_STATE(481)] = 16007,
  [SMALL_STATE(482)] = 16014,
  [SMALL_STATE(483)] = 16021,
  [SMALL_STATE(484)] = 16028,
  [SMALL_STATE(485)] = 16035,
  [SMALL_STATE(486)] = 16042,
  [SMALL_STATE(487)] = 16049,
  [SMALL_STATE(488)] = 16056,
  [SMALL_STATE(489)] = 16063,
  [SMALL_STATE(490)] = 16070,
  [SMALL_STATE(491)] = 16077,
  [SMALL_STATE(492)] = 16084,
  [SMALL_STATE(493)] = 16091,
  [SMALL_STATE(494)] = 16098,
  [SMALL_STATE(495)] = 16105,
  [SMALL_STATE(496)] = 16112,
  [SMALL_STATE(497)] = 16119,
  [SMALL_STATE(498)] = 16126,
  [SMALL_STATE(499)] = 16133,
  [SMALL_STATE(500)] = 16140,
  [SMALL_STATE(501)] = 16147,
  [SMALL_STATE(502)] = 16154,
  [SMALL_STATE(503)] = 16161,
  [SMALL_STATE(504)] = 16168,
  [SMALL_STATE(505)] = 16175,
  [SMALL_STATE(506)] = 16182,
  [SMALL_STATE(507)] = 16189,
  [SMALL_STATE(508)] = 16196,
  [SMALL_STATE(509)] = 16203,
  [SMALL_STATE(510)] = 16210,
  [SMALL_STATE(511)] = 16217,
  [SMALL_STATE(512)] = 16224,
  [SMALL_STATE(513)] = 16231,
  [SMALL_STATE(514)] = 16238,
  [SMALL_STATE(515)] = 16245,
  [SMALL_STATE(516)] = 16252,
  [SMALL_STATE(517)] = 16259,
  [SMALL_STATE(518)] = 16266,
  [SMALL_STATE(519)] = 16273,
  [SMALL_STATE(520)] = 16280,
  [SMALL_STATE(521)] = 16287,
  [SMALL_STATE(522)] = 16294,
  [SMALL_STATE(523)] = 16301,
  [SMALL_STATE(524)] = 16308,
  [SMALL_STATE(525)] = 16315,
  [SMALL_STATE(526)] = 16322,
  [SMALL_STATE(527)] = 16329,
  [SMALL_STATE(528)] = 16336,
  [SMALL_STATE(529)] = 16343,
  [SMALL_STATE(530)] = 16350,
  [SMALL_STATE(531)] = 16357,
  [SMALL_STATE(532)] = 16364,
  [SMALL_STATE(533)] = 16371,
  [SMALL_STATE(534)] = 16378,
  [SMALL_STATE(535)] = 16385,
  [SMALL_STATE(536)] = 16392,
  [SMALL_STATE(537)] = 16399,
  [SMALL_STATE(538)] = 16406,
  [SMALL_STATE(539)] = 16413,
  [SMALL_STATE(540)] = 16420,
  [SMALL_STATE(541)] = 16427,
  [SMALL_STATE(542)] = 16434,
  [SMALL_STATE(543)] = 16441,
  [SMALL_STATE(544)] = 16448,
  [SMALL_STATE(545)] = 16455,
  [SMALL_STATE(546)] = 16462,
  [SMALL_STATE(547)] = 16469,
  [SMALL_STATE(548)] = 16476,
  [SMALL_STATE(549)] = 16483,
  [SMALL_STATE(550)] = 16490,
  [SMALL_STATE(551)] = 16497,
  [SMALL_STATE(552)] = 16504,
  [SMALL_STATE(553)] = 16511,
  [SMALL_STATE(554)] = 16518,
  [SMALL_STATE(555)] = 16525,
  [SMALL_STATE(556)] = 16532,
  [SMALL_STATE(557)] = 16539,
  [SMALL_STATE(558)] = 16546,
  [SMALL_STATE(559)] = 16553,
  [SMALL_STATE(560)] = 16560,
  [SMALL_STATE(561)] = 16567,
  [SMALL_STATE(562)] = 16574,
  [SMALL_STATE(563)] = 16581,
  [SMALL_STATE(564)] = 16588,
  [SMALL_STATE(565)] = 16595,
  [SMALL_STATE(566)] = 16602,
  [SMALL_STATE(567)] = 16609,
  [SMALL_STATE(568)] = 16616,
  [SMALL_STATE(569)] = 16623,
  [SMALL_STATE(570)] = 16630,
  [SMALL_STATE(571)] = 16637,
  [SMALL_STATE(572)] = 16644,
  [SMALL_STATE(573)] = 16651,
  [SMALL_STATE(574)] = 16658,
  [SMALL_STATE(575)] = 16665,
  [SMALL_STATE(576)] = 16672,
  [SMALL_STATE(577)] = 16679,
  [SMALL_STATE(578)] = 16686,
  [SMALL_STATE(579)] = 16693,
  [SMALL_STATE(580)] = 16700,
  [SMALL_STATE(581)] = 16707,
  [SMALL_STATE(582)] = 16714,
  [SMALL_STATE(583)] = 16721,
  [SMALL_STATE(584)] = 16728,
  [SMALL_STATE(585)] = 16735,
  [SMALL_STATE(586)] = 16742,
  [SMALL_STATE(587)] = 16749,
  [SMALL_STATE(588)] = 16756,
  [SMALL_STATE(589)] = 16763,
  [SMALL_STATE(590)] = 16770,
  [SMALL_STATE(591)] = 16777,
  [SMALL_STATE(592)] = 16784,
  [SMALL_STATE(593)] = 16791,
  [SMALL_STATE(594)] = 16798,
  [SMALL_STATE(595)] = 16805,
  [SMALL_STATE(596)] = 16812,
  [SMALL_STATE(597)] = 16819,
  [SMALL_STATE(598)] = 16826,
  [SMALL_STATE(599)] = 16833,
  [SMALL_STATE(600)] = 16840,
  [SMALL_STATE(601)] = 16847,
  [SMALL_STATE(602)] = 16854,
  [SMALL_STATE(603)] = 16861,
  [SMALL_STATE(604)] = 16868,
  [SMALL_STATE(605)] = 16875,
  [SMALL_STATE(606)] = 16882,
  [SMALL_STATE(607)] = 16889,
  [SMALL_STATE(608)] = 16896,
  [SMALL_STATE(609)] = 16903,
  [SMALL_STATE(610)] = 16910,
  [SMALL_STATE(611)] = 16917,
  [SMALL_STATE(612)] = 16924,
  [SMALL_STATE(613)] = 16931,
  [SMALL_STATE(614)] = 16938,
  [SMALL_STATE(615)] = 16945,
  [SMALL_STATE(616)] = 16952,
  [SMALL_STATE(617)] = 16959,
  [SMALL_STATE(618)] = 16966,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blockmeta, 1, 0, 0),
  [79] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blockmeta, 1, 0, 0),
  [81] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0),
  [83] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0),
  [85] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(618),
  [88] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(7),
  [91] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(437),
  [94] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(543),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_bool, 1, 0, 0),
  [99] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metakey_bool, 1, 0, 0),
  [101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 1, 0, 0),
  [103] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pair, 1, 0, 0),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_text, 1, 0, 3),
  [107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_text, 1, 0, 3),
  [109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 2, 0, 0),
  [111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pair, 2, 0, 0),
  [113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list, 1, 0, 4),
  [115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_list, 1, 0, 4),
  [117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_any, 1, 0, 0),
  [119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_any, 1, 0, 0),
  [121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list, 4, 0, 0),
  [123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_list, 4, 0, 0),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(431),
  [146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(277),
  [149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(274),
  [152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(25),
  [155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(495),
  [158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(276),
  [164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(278),
  [167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(275),
  [170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(66),
  [173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(67),
  [176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(168),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(371),
  [185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(356),
  [191] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(107),
  [197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(461),
  [200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(462),
  [203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(481),
  [206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(484),
  [209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(271),
  [215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(79),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 4, 0, 2),
  [231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 4, 0, 2),
  [233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 1, 0, 0),
  [235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 1, 0, 0),
  [237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 2, 0, 1),
  [239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 2, 0, 1),
  [241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mathblock, 3, 0, 0),
  [243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mathblock, 3, 0, 0),
  [245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 5),
  [247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 5),
  [249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 6),
  [251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 6),
  [253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 1),
  [255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 1),
  [257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption, 3, 0, 0),
  [259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caption, 3, 0, 0),
  [261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item, 3, 0, 0),
  [263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item, 3, 0, 0),
  [265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 11),
  [267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 11),
  [269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 2),
  [271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 2),
  [273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 12),
  [275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 12),
  [277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 13),
  [279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 13),
  [281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 2),
  [283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 2),
  [285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 1),
  [287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 1),
  [289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 3, 0, 0),
  [291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 3, 0, 0),
  [293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 2, 0, 1),
  [295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 2, 0, 1),
  [297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mathblock, 4, 0, 14),
  [299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mathblock, 4, 0, 14),
  [301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 2, 0, 0),
  [303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 2, 0, 0),
  [305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 1),
  [307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 1),
  [309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 5),
  [311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 5),
  [313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 16),
  [315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 16),
  [317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 2),
  [319] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 2),
  [321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption, 4, 0, 14),
  [323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caption, 4, 0, 14),
  [325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item, 4, 0, 14),
  [327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item, 4, 0, 14),
  [329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 19),
  [331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 19),
  [333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 20),
  [335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 20),
  [337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 21),
  [339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 21),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 22),
  [343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 22),
  [345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 23),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 23),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 24),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 24),
  [353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 2),
  [355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 2),
  [357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 5, 0, 2),
  [359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 5, 0, 2),
  [361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 5, 0, 15),
  [363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 5, 0, 15),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 27),
  [367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 27),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 28),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 28),
  [373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 29),
  [375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 29),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 30),
  [379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 30),
  [381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 1, 0, 0),
  [383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 1, 0, 0),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 6, 0, 31),
  [387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 6, 0, 31),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 15),
  [391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 15),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(279),
  [458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(280),
  [461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(168),
  [464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [467] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(371),
  [470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [473] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(356),
  [476] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [479] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(107),
  [482] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(461),
  [485] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(462),
  [488] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(481),
  [491] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(484),
  [494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(76),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0),
  [508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(257),
  [569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(372),
  [572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [578] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [581] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(143),
  [584] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(144),
  [587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(601),
  [590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(602),
  [593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(603),
  [596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(604),
  [599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(90),
  [605] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(91),
  [608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(109),
  [611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tdcontent, 1, 0, 0),
  [613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tdcontent, 1, 0, 0),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0),
  [619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(178),
  [622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(366),
  [625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(367),
  [628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(368),
  [631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(133),
  [637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(134),
  [640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(584),
  [643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(585),
  [646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(586),
  [649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(587),
  [652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(186),
  [655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0),
  [657] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [660] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(89),
  [663] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(97),
  [666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(265),
  [751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(362),
  [754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(363),
  [757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(364),
  [760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(124),
  [769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(567),
  [772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(568),
  [775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(570),
  [781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(266),
  [784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(92),
  [787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(108),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(257),
  [826] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(372),
  [829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(375),
  [838] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(143),
  [841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(144),
  [844] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(601),
  [847] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(602),
  [850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(603),
  [853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(604),
  [856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(90),
  [862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(91),
  [865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(110),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [894] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(358),
  [900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(359),
  [903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(360),
  [906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(361),
  [909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(111),
  [912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(112),
  [915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(547),
  [918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(548),
  [921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(549),
  [924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(550),
  [927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(233),
  [930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(86),
  [933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(85),
  [936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(121),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 4, 0, 2),
  [1017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 4, 0, 2),
  [1019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 18),
  [1021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 18),
  [1023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 3, 0, 2),
  [1025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 3, 0, 2),
  [1027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 10),
  [1029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 10),
  [1031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 5, 0, 25),
  [1033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 5, 0, 25),
  [1035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 5, 0, 26),
  [1037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 5, 0, 26),
  [1039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 2, 0, 1),
  [1041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 2, 0, 1),
  [1043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 2, 0, 1),
  [1045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 2, 0, 1),
  [1047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 3, 0, 2),
  [1049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 3, 0, 2),
  [1051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 3, 0, 1),
  [1053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 3, 0, 1),
  [1055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 9),
  [1057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 9),
  [1059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 4, 0, 2),
  [1061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 4, 0, 2),
  [1063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 2, 0, 1),
  [1065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 2, 0, 1),
  [1067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialconstruct, 1, 0, 1),
  [1069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialconstruct, 1, 0, 1),
  [1071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 1, 0, 0),
  [1073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 1, 0, 0),
  [1075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 7),
  [1077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 7),
  [1079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 8),
  [1081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 8),
  [1083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 1),
  [1085] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 1),
  [1087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 3, 0, 1),
  [1089] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 3, 0, 1),
  [1091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 17),
  [1093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 17),
  [1095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 2),
  [1097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 2),
  [1099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemeta, 3, 0, 0),
  [1101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inlinemeta, 3, 0, 0),
  [1103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemeta, 4, 0, 0),
  [1105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inlinemeta, 4, 0, 0),
  [1107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(288),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(318),
  [1145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(309),
  [1148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(323),
  [1151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(554),
  [1154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(288),
  [1157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(444),
  [1160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(479),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [1175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_thead_repeat1, 2, 0, 0),
  [1177] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_thead_repeat1, 2, 0, 0), SHIFT_REPEAT(65),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0),
  [1190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0), SHIFT_REPEAT(84),
  [1193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bibtex_repeat1, 2, 0, 0),
  [1195] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bibtex_repeat1, 2, 0, 0), SHIFT_REPEAT(514),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [1208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [1210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 1),
  [1212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_thead, 3, 0, 1),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 3, 0, 1),
  [1222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [1224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 4, 0, 2),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [1228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [1246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 3, 0, 2),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bibitem_repeat1, 2, 0, 0), SHIFT_REPEAT(497),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [1305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tbody, 3, 0, 1),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_td, 3, 0, 1),
  [1331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trshort, 4, 0, 1),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_text_inline, 1, 0, 3),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list_inline, 4, 0, 0),
  [1353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_td, 4, 0, 2),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 7, 0, 32),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemetapair, 2, 0, 0),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [1385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bibitem_repeat1, 2, 0, 0),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [1395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 8, 0, 32),
  [1397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 9, 0, 32),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitempair, 5, 0, 0),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaval_list_repeat1, 2, 0, 0), SHIFT_REPEAT(617),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [1422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_any_inline, 1, 0, 0),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [1426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list_inline, 1, 0, 0),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemetapair, 1, 0, 0),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_list, 1, 0, 0),
  [1450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trshort, 3, 0, 1),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 3, 0, 1),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [1464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 4, 0, 1),
  [1492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [1494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [1496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibtex, 3, 0, 0),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_any, 1, 0, 0),
  [1518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(452),
  [1524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [1528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [1544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [1568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibtex, 2, 0, 0),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 5, 0, 2),
  [1588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaval_list_repeat1, 2, 0, 0),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [1604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1618] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [1622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_text, 1, 0, 0),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [1684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [1688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [1718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_upto_brace_or_comma_text = 0,
  ts_external_token_asis_dollar_text = 1,
  ts_external_token_asis_two_dollars_text = 2,
  ts_external_token_asis_backtick_text = 3,
  ts_external_token_asis_three_backticks_text = 4,
  ts_external_token_asis_halmos_text = 5,
  ts_external_token_text = 6,
  ts_external_token_paragraph_end = 7,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_upto_brace_or_comma_text] = sym_upto_brace_or_comma_text,
  [ts_external_token_asis_dollar_text] = sym_asis_dollar_text,
  [ts_external_token_asis_two_dollars_text] = sym_asis_two_dollars_text,
  [ts_external_token_asis_backtick_text] = sym_asis_backtick_text,
  [ts_external_token_asis_three_backticks_text] = sym_asis_three_backticks_text,
  [ts_external_token_asis_halmos_text] = sym_asis_halmos_text,
  [ts_external_token_text] = sym_text,
  [ts_external_token_paragraph_end] = sym_paragraph_end,
};

static const bool ts_external_scanner_states[10][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_upto_brace_or_comma_text] = true,
    [ts_external_token_asis_dollar_text] = true,
    [ts_external_token_asis_two_dollars_text] = true,
    [ts_external_token_asis_backtick_text] = true,
    [ts_external_token_asis_three_backticks_text] = true,
    [ts_external_token_asis_halmos_text] = true,
    [ts_external_token_text] = true,
    [ts_external_token_paragraph_end] = true,
  },
  [2] = {
    [ts_external_token_text] = true,
  },
  [3] = {
    [ts_external_token_text] = true,
    [ts_external_token_paragraph_end] = true,
  },
  [4] = {
    [ts_external_token_asis_halmos_text] = true,
  },
  [5] = {
    [ts_external_token_asis_three_backticks_text] = true,
  },
  [6] = {
    [ts_external_token_asis_two_dollars_text] = true,
  },
  [7] = {
    [ts_external_token_upto_brace_or_comma_text] = true,
  },
  [8] = {
    [ts_external_token_asis_dollar_text] = true,
  },
  [9] = {
    [ts_external_token_asis_backtick_text] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_rsm_external_scanner_create(void);
void tree_sitter_rsm_external_scanner_destroy(void *);
bool tree_sitter_rsm_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_rsm_external_scanner_serialize(void *, char *);
void tree_sitter_rsm_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_rsm(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_rsm_external_scanner_create,
      tree_sitter_rsm_external_scanner_destroy,
      tree_sitter_rsm_external_scanner_scan,
      tree_sitter_rsm_external_scanner_serialize,
      tree_sitter_rsm_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "rsm",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 3,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
